@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_absstime
-#: Date       : 2018-03-16
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -12,6 +12,11 @@ EXT=;
 fi
 
 PROGRAM=../../absstime$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -20,11 +25,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f ../data/us1328.bld ] || [ ! -f ../data/ep0152_blo.lis ]; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -713,9 +713,8 @@ printf " Test case: Invalid option. \n"
 printf " Expected result: Error. \n\n"
 
 cp -f ../data/us1328.bld test.bld
-rm -f stdout.txt
 
-$PROGRAM -stupidoption test.bld &> stdout.txt
+$PROGRAM -stupidoption test.bld 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -728,9 +727,8 @@ printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
 cp -f ../data/us1328.bld test.bld
-rm -f stdout.txt
 
-$PROGRAM test.bld 13:45:00 extra &> stdout.txt
+$PROGRAM test.bld 13:45:00 extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "invalid argument 'extra'."
@@ -742,8 +740,7 @@ printf "\n 3.1.0 \n"
 printf " Test case: Input file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.dat 13:45:00 &> stdout.txt
+$PROGRAM nonexistingfile.dat 13:45:00 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "cannot open file"
