@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_ana2ecat
-#: Date       : 2016-07-18
+#: Date       : 2023-06-30
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,11 @@ else
 EXT=;
 fi
 PROGRAM=../../ana2ecat$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 # Make sure that environment variable for flipping is not set
 ANALYZE_FLIP=;
@@ -25,11 +30,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f image1.dat ] || [ ! -f image1.inf ] || [ ! -f image1.fra ] ; then
   printf "Failed: required file does not exist.\n"
   exit 1
@@ -165,9 +165,9 @@ printf "\n Analyze input \n"
 printf "\n 2.0.0 \n"
 printf "Database not given \n\n"
 
-rm -f stdout.txt temp/*
+rm -f temp/*
 rmdir temp
-$PROGRAM -d2 -o=temp &> stdout.txt
+$PROGRAM -d2 -o=temp 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "Analyze database was not given."
@@ -178,8 +178,7 @@ printf "\n Passed. \n\n"
 printf "\n 2.0.1 \n"
 printf "non-existing input path \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -o=temp nonexisting &> stdout.txt
+$PROGRAM -d2 -o=temp nonexisting 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot open Analyze image or directory nonexisting"
@@ -190,12 +189,12 @@ printf "\n Passed. \n\n"
 printf "\n 2.0.2 \n"
 printf "input path exists but contains no Analyze images \n\n"
 
-rm -f stdout.txt temp/*
+rm -f temp/*
 rmdir temp
 mkdir temp
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -7 -o=temp2 temp &> stdout.txt
+$PROGRAM -7 -o=temp2 temp 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "No Analyze files were found in temp"
@@ -206,10 +205,10 @@ printf "\n Passed. \n\n"
 printf "\n 2.0.3 \n"
 printf "input path exists but specified database does not \n\n"
 
-rm -f stdout.txt temp/*
+rm -f temp/*
 rmdir temp
 
-$PROGRAM -7 -o=temp ana_unix_files/nonexisting &> stdout.txt
+$PROGRAM -7 -o=temp ana_unix_files/nonexisting 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot open Analyze image or directory ana_unix_files/nonexisting"
@@ -242,8 +241,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 cp -f image1.img ana_unix_files/stupid.img
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt
-$PROGRAM -7 -o=temp ana_unix_files &> stdout.txt
+$PROGRAM -7 -o=temp ana_unix_files 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then
 rm -f ana_unix_files/stupid.hdr ana_unix_files/stupid.img
 printf "Failed!\n"; exit 1;
@@ -270,9 +268,9 @@ printf "\n Output options \n"
 printf "\n 3.0.0 \n"
 printf " Output path not specified \n\n"
 
-rm -f image1.v image2.v stdout.txt
+rm -f image1.v image2.v
 
-$PROGRAM -7 -d2 ana_unix_files &> stdout.txt
+$PROGRAM -7 -d2 ana_unix_files 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -298,9 +296,8 @@ printf " Output path given with option -o= \n\n"
 
 rm temp/*
 rmdir temp
-rm -f stdout.txt
 
-$PROGRAM -7 -d2 -o=temp ana_unix_files &> stdout.txt
+$PROGRAM -7 -d2 -o=temp ana_unix_files 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -324,9 +321,9 @@ printf "\n Passed. \n\n"
 printf "\n 3.1.1 \n"
 printf " Output path set to current dir with option -o= \n\n"
 
-rm -f image1.v image2.v stdout.txt
+rm -f image1.v image2.v
 
-$PROGRAM -7 -d2 -o= ana_unix_files &> stdout.txt
+$PROGRAM -7 -d2 -o= ana_unix_files 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -357,7 +354,7 @@ cp -f ana_unix_files/* temp
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
 rm -f stdout.txt
-$PROGRAM -6 -o=temp temp &> stdout.txt
+$PROGRAM -6 -o=temp temp 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -374,8 +371,7 @@ if [ $? -ne 0 ] ; then
 fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -6 -o=temp temp/image2 &> stdout.txt
+$PROGRAM -6 -o=temp temp/image2 1>stdout.txt 2>&1
 
 iftisval stdout.txt Error "temp/image2.img would be overwritten."
 if [ $? -ne 0 ] ; then 
@@ -422,14 +418,13 @@ printf " no option or environment variable \n\n"
 
 rm -f temp/*
 rmdir temp
-rm -f stdout.txt
 
 ANALYZE_FLIP=;
 export ANALYZE_FLIP
 printf "\n ANALYZE_FLIP = %s\n\n", $ANALYZE_FLIP
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 -o=temp ana_unix_files/image1 &> stdout.txt
+$PROGRAM -d2 -o=temp ana_unix_files/image1 1>stdout.txt 2>&1
 iftisval stdout.txt flipping "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
@@ -440,14 +435,13 @@ printf " environment variable is y \n\n"
 
 rm -f temp/*
 rmdir temp
-rm -f stdout.txt
 
 ANALYZE_FLIP=y;
 export ANALYZE_FLIP
 printf "\n ANALYZE_FLIP = %s\n\n", $ANALYZE_FLIP
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 -o=temp ana_unix_files/image2 &> stdout.txt
+$PROGRAM -d2 -o=temp ana_unix_files/image2 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt flipping "1"
@@ -460,14 +454,13 @@ printf " environment variable is n \n\n"
 
 rm -f temp/*
 rmdir temp
-rm -f stdout.txt
 
 ANALYZE_FLIP=n;
 export ANALYZE_FLIP
 printf "\n ANALYZE_FLIP = %s\n\n", $ANALYZE_FLIP
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 -o=temp ana_unix_files/image2 &> stdout.txt
+$PROGRAM -d2 -o=temp ana_unix_files/image2 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt flipping "0"
@@ -480,14 +473,13 @@ printf " option -flip=y overrides environment variable \n\n"
 
 rm -f temp/*
 rmdir temp
-rm -f stdout.txt
 
 ANALYZE_FLIP=n;
 export ANALYZE_FLIP
 printf "\n ANALYZE_FLIP = %s\n\n", $ANALYZE_FLIP
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 -flip=y -o=temp ana_unix_files/image2 &> stdout.txt
+$PROGRAM -d2 -flip=y -o=temp ana_unix_files/image2 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt flipping "1"
@@ -500,14 +492,13 @@ printf " option -flip=n overrides environment variable \n\n"
 
 rm -f temp/*
 rmdir temp
-rm -f stdout.txt
 
 ANALYZE_FLIP=y;
 export ANALYZE_FLIP
 printf "\n ANALYZE_FLIP = %s\n\n", $ANALYZE_FLIP
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 -flip=n -o=temp ana_unix_files/image2 &> stdout.txt
+$PROGRAM -d2 -flip=n -o=temp ana_unix_files/image2 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt flipping "0"
@@ -569,9 +560,8 @@ printf " no option \n\n"
 
 rm -f temp/*
 rmdir temp
-rm -f stdout.txt
 
-$PROGRAM -d2 -o=temp ana_unix_files/image1 &> stdout.txt
+$PROGRAM -d2 -o=temp ana_unix_files/image1 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt outFormat "7"
@@ -586,9 +576,8 @@ printf " option -7 \n\n"
 
 rm -f temp/*
 rmdir temp
-rm -f stdout.txt
 
-$PROGRAM -d2 -7 -o=temp ana_unix_files/image1 &> stdout.txt
+$PROGRAM -d2 -7 -o=temp ana_unix_files/image1 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt outFormat "7"
@@ -603,9 +592,8 @@ printf " option -6 \n\n"
 
 rm -f temp/*
 rmdir temp
-rm -f stdout.txt
 
-$PROGRAM -d2 -6 -o=temp ana_unix_files/image1 &> stdout.txt
+$PROGRAM -d2 -6 -o=temp ana_unix_files/image1 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt outFormat "6"
@@ -657,8 +645,7 @@ printf "\n Misc tests \n"
 printf "\n 7.0.0 \n"
 printf " Fails if no arguments or options \n\n"
 
-rm -f stdout.txt
-$PROGRAM &> stdout.txt
+$PROGRAM 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
@@ -666,10 +653,10 @@ printf "\n Passed. \n\n"
 printf "\n 7.0.1 \n"
 printf " Fails if extra arguments \n\n"
 
-rm -f stdout.txt temp/*
+rm -f temp/*
 rmdir temp
 
-$PROGRAM -o=temp ana_unix_files extra &> stdout.txt
+$PROGRAM -o=temp ana_unix_files extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'"
@@ -680,10 +667,10 @@ printf "\n Passed. \n\n"
 printf "\n 7.1.0 \n"
 printf " Fails if unknown option \n\n"
 
-rm -f stdout.txt temp/*
+rm -f temp/*
 rmdir temp
 
-$PROGRAM -o=temp -stupidoption ana_unix_files &> stdout.txt
+$PROGRAM -o=temp -stupidoption ana_unix_files 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'"
