@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_ecat2ana
-#: Date       : 2014-09-21
+#: Date       : 2023-06-30
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,11 @@ else
 EXT=;
 fi
 PROGRAM=../../ecat2ana$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 # Make sure that environment variable for flipping is not set
 ANALYZE_FLIP=;
@@ -24,11 +29,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f image1.dat ] || [ ! -f image1.inf ] || [ ! -f image1.fra ] ; then
   printf "Failed: required file does not exist.\n"
   exit 1
@@ -114,8 +114,7 @@ printf "\n 1.0.0 \n"
 printf "Options -little and -big \n\n"
 
 printf "\n without options \n\n"
-rm -f stdout.txt
-$PROGRAM -d1 image1.v &> stdout.txt
+$PROGRAM -d1 image1.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt ana_order "1"
@@ -123,8 +122,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
 printf "\n with option -little \n\n"
-rm -f stdout.txt
-$PROGRAM -d1 -little image1.v &> stdout.txt
+$PROGRAM -d1 -little image1.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt ana_order "0"
@@ -132,8 +130,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
 printf "\n with option -big \n\n"
-rm -f stdout.txt
-$PROGRAM -d1 -big image1.v &> stdout.txt
+$PROGRAM -d1 -big image1.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt ana_order "1"
@@ -146,8 +143,7 @@ printf "\n 1.1.0 \n"
 printf "Option -o \n\n"
 
 printf "\n without option \n\n"
-rm -f stdout.txt
-$PROGRAM -d1 image1.v &> stdout.txt
+$PROGRAM -d1 image1.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt outputdir ""
@@ -155,8 +151,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
 printf "\n with option \n\n"
-rm -f stdout.txt
-$PROGRAM -d1 -o=newdir image1.v &> stdout.txt
+$PROGRAM -d1 -o=newdir image1.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt outputdir "newdir"
@@ -164,9 +159,9 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
 printf "\n option -o= \n\n"
-rm -f temp.hdr temp.img stdout.txt
+rm -f temp.hdr temp.img
 cp -f image1.v temp.v
-$PROGRAM -d1 -o= temp.v &> stdout.txt
+$PROGRAM -d1 -o= temp.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt outputdir "."
@@ -180,11 +175,11 @@ printf "\n Passed. \n\n"
 printf "\n 1.1.1 \n"
 printf "Check that original ECAT file is not overwritten by Analyze data \n\n"
 
-rm -f stdout.txt temp.img temp.hdr temp2.v temp2.img temp2.hdr
+rm -f temp.img temp.hdr temp2.v temp2.img temp2.hdr
 cp -f image1.img temp.img
 cp -f image1.v temp2.v
 
-$PROGRAM -d1 -o= temp.img temp2.v &> stdout.txt
+$PROGRAM -d1 -o= temp.img temp2.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "./temp.img would be overwritten."
@@ -204,7 +199,7 @@ printf "\n Passed. \n\n"
 printf "\n 1.1.2 \n"
 printf "Existing Analyze data is overwritten \n\n"
 
-rm -f temp.img temp.v stdout.txt
+rm -f temp.img temp.v
 cp -f image1.img temp.img
 cp -f image2.v temp.v
 rm -f temp/* temp2/* 
@@ -239,14 +234,12 @@ printf "\n=================================================================\n\n"
 printf "\n 1.2.0 \n"
 printf "Z flipping; no option or environment variable \n\n"
 
-rm -f stdout.txt
-
 ANALYZE_FLIP=;
 export ANALYZE_FLIP
 printf "\n ANALYZE_FLIP = %s\n\n", $ANALYZE_FLIP
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 image1.v &> stdout.txt
+$PROGRAM -d2 image1.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt flipping "1"
@@ -256,14 +249,12 @@ printf "\n Passed. \n\n"
 printf "\n 1.2.1 \n"
 printf "Z flipping; environment variable is y \n\n"
 
-rm -f stdout.txt
-
 ANALYZE_FLIP=y;
 export ANALYZE_FLIP
 printf "\n ANALYZE_FLIP = %s\n\n", $ANALYZE_FLIP
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 image1.v &> stdout.txt
+$PROGRAM -d2 image1.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt flipping "1"
@@ -273,14 +264,12 @@ printf "\n Passed. \n\n"
 printf "\n 1.2.2 \n"
 printf "Z flipping; environment variable is n \n\n"
 
-rm -f stdout.txt
-
 ANALYZE_FLIP=n;
 export ANALYZE_FLIP
 printf "\n ANALYZE_FLIP = %s\n\n", $ANALYZE_FLIP
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 image1.v &> stdout.txt
+$PROGRAM -d2 image1.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt flipping "0"
@@ -290,14 +279,12 @@ printf "\n Passed. \n\n"
 printf "\n 1.2.3 \n"
 printf "Z flipping; option -flip=y overrides environment variable \n\n"
 
-rm -f stdout.txt
-
 ANALYZE_FLIP=n;
 export ANALYZE_FLIP
 printf "\n ANALYZE_FLIP = %s\n\n", $ANALYZE_FLIP
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 -flip=y image1.v &> stdout.txt
+$PROGRAM -d2 -flip=y image1.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt flipping "1"
@@ -307,14 +294,12 @@ printf "\n Passed. \n\n"
 printf "\n 1.2.4 \n"
 printf "Z flipping; option -flip=n overrides environment variable \n\n"
 
-rm -f stdout.txt
-
 ANALYZE_FLIP=y;
 export ANALYZE_FLIP
 printf "\n ANALYZE_FLIP = %s\n\n", $ANALYZE_FLIP
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 -flip=n image1.v &> stdout.txt
+$PROGRAM -d2 -flip=n image1.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt flipping "0"
@@ -334,8 +319,7 @@ printf "\n=================================================================\n\n"
 printf "\n 1.3.0 \n"
 printf "Writing frames separately; no option \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 image1.v &> stdout.txt
+$PROGRAM -d2 image1.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt separate_frames "0"
@@ -344,11 +328,10 @@ printf "\n Passed. \n\n"
 
 printf "\n 1.3.1 \n"
 printf "Writing frames separately; option -frames \n\n"
-rm -f stdout.txt
 rm -f frames/*
 rmdir frames 2> nul
 
-$PROGRAM -d2 -frames -o=frames image2.v &> stdout.txt
+$PROGRAM -d2 -frames -o=frames image2.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt separate_frames "1"
@@ -368,8 +351,7 @@ printf "\n=================================================================\n\n"
 printf "\n 1.4.0 \n"
 printf "Input file: not given \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -frames -o=frames &> stdout.txt
+$PROGRAM -d2 -frames -o=frames 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "no ECAT files were specified."
@@ -380,8 +362,7 @@ printf "\n Passed. \n\n"
 printf "\n 1.4.1 \n"
 printf "Input file: not exists \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -frames -o=frames nonexisting.v &> stdout.txt
+$PROGRAM -d2 -frames -o=frames nonexisting.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "file nonexisting.v does not exist"
@@ -392,16 +373,14 @@ printf "\n Passed. \n\n"
 printf "\n 1.4.2 \n"
 printf "Input file: not ECAT image \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 image1.bin &> stdout.txt
+$PROGRAM -d2 image1.bin 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "unsupported file type"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 image1.dat &> stdout.txt
+$PROGRAM -d2 image1.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "unsupported file type"
@@ -412,10 +391,9 @@ printf "\n Passed. \n\n"
 printf "\n 1.4.3 \n"
 printf "Input file: ECAT 7 image volume ok \n\n"
 
-rm -f stdout.txt
 rm -f temp/* temp2/* 
 rmdir temp temp2 2> nul
-$PROGRAM -d2 -o=temp -sif image2.v &> stdout.txt
+$PROGRAM -d2 -o=temp -sif image2.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 ana2ecat -7 -o=temp2 temp/image2
@@ -429,10 +407,9 @@ printf "\n Passed. \n\n"
 printf "\n 1.4.4 \n"
 printf "Input file: ECAT 7 2D image ok \n\n"
 
-rm -f stdout.txt
 rm -f temp/* temp2/* 
 rmdir temp temp2 2> nul
-$PROGRAM -d2 -o=temp -sif image2.i &> stdout.txt
+$PROGRAM -d2 -o=temp -sif image2.i 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 ana2ecat -7 -o=temp2 temp/image2
@@ -446,10 +423,9 @@ printf "\n Passed. \n\n"
 printf "\n 1.4.5 \n"
 printf "Input file: ECAT 6.3 image ok \n\n"
 
-rm -f stdout.txt
 rm -f temp/* temp2/* 
 rmdir temp temp2 2> nul
-$PROGRAM -d2 -o=temp -sif image2.img &> stdout.txt
+$PROGRAM -d2 -o=temp -sif image2.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 ana2ecat -6 -o=temp2 temp/image2
@@ -463,13 +439,12 @@ printf "\n Passed. \n\n"
 printf "\n 1.4.6 \n"
 printf "Input file: ECAT file contains discontinuous frame or plane numbers \n\n"
 
-rm -f stdout.txt
 rm -f temp/* temp2/* 
 rmdir temp temp2 2> nul
 esplit image2.img 2 3-4 temp.img
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 -o=temp -sif temp.img &> stdout.txt
+$PROGRAM -d2 -o=temp -sif temp.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -484,11 +459,10 @@ printf "\n Passed. \n\n"
 printf "\n 1.4.7 \n"
 printf "Input file: More than one ECAT files as command-line arguments \n\n"
 
-rm -f stdout.txt
 rm -f temp/* temp2/* 
 rmdir temp temp2 2> nul
 
-$PROGRAM -d2 -o=temp image1.v image2.v &> stdout.txt
+$PROGRAM -d2 -o=temp image1.v image2.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ -f temp/image1.hdr ] ; then rm temp/image1.hdr; else printf "Failed!\n"; exit 1 ; fi
@@ -501,11 +475,10 @@ printf "\n Passed. \n\n"
 printf "\n 1.4.8 \n"
 printf "Input file: More than one ECAT files given with wildcards \n\n"
 
-rm -f stdout.txt
 rm -f temp/* temp2/* 
 rmdir temp temp2  2> nul
 
-$PROGRAM -d2 -o=temp image?.v &> stdout.txt
+$PROGRAM -d2 -o=temp image?.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ -f temp/image1.hdr ] ; then rm temp/image1.hdr; else printf "Failed!\n"; exit 1 ; fi
@@ -518,12 +491,11 @@ printf "\n Passed. \n\n"
 printf "\n 1.4.9 \n"
 printf "Input file: Even when one file fails, others are processed ok \n\n"
 
-rm -f stdout.txt
 rm -f temp/* temp2/* 
 rmdir temp temp2  2> nul
 cp -f image2.bin temp.v
 
-$PROGRAM -d2 -o=temp image1.v temp.v image2.v &> stdout.txt
+$PROGRAM -d2 -o=temp image1.v temp.v image2.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "unsupported file type"
