@@ -283,6 +283,10 @@ int main(int argc, char **argv)
     printf("xunit := %s\n", unitName(ttac.tunit));
     printf("yunit := %s\n", unitName(ttac.cunit));
     printf("fitdur := %g s\n", fitdur);
+    int i=iftFindKey(&ttac.h, "studynr", 0);
+    if(i<0) i=iftFindKey(&ttac.h, "study_number", 0);
+    if(i>=0) printf("%s := %s\n", ttac.h.item[i].key, ttac.h.item[i].value);
+
   }
   if(fitSampleNr<4 || btac.sampleNr<4) {
     fprintf(stderr, "Error: too few samples in specified fit duration.\n");
@@ -598,7 +602,7 @@ int main(int argc, char **argv)
     sprintf(buf, "Radiowater BFM fit");
     i=iftFindKey(&ttac.h, "studynr", 0);
     if(i<0) i=iftFindKey(&ttac.h, "study_number", 0);
-    if(i>0) {strcat(buf, ": "); strcat(buf, ttac.h.item[i].value);}
+    if(i>=0) {strcat(buf, ": "); strcat(buf, ttac.h.item[i].value);}
     ret=tacPlotFitSVG(&ttac, &ftac, buf, 0.0, nan(""), 0.0, nan(""), svgfile, &status);
     if(ret!=TPCERROR_OK) {
       fprintf(stderr, "Error: %s\n", errorMsg(status.error));
