@@ -629,7 +629,7 @@ int main(int argc, char **argv)
     sprintf(buf, "SRTM-BFM fit");
     i=iftFindKey(&ttac.h, "studynr", 0);
     if(i<0) i=iftFindKey(&ttac.h, "study_number", 0);
-    if(i>0) {strcat(buf, ": "); strcat(buf, ttac.h.item[i].value);}
+    if(i>=0) {strcat(buf, ": "); strcat(buf, ttac.h.item[i].value);}
     ret=tacPlotFitSVG(&ttac, &ftac, buf, 0.0, nan(""), 0.0, nan(""),
                       svgfile, &status);
     if(ret!=TPCERROR_OK) {
