@@ -67,7 +67,7 @@ static char *info[] = {
   "     Optional reference region is used to calculate BPnd, BPp, or DVR;",
   "     BPnd=DVroi/DVref-1, BPp=DVroi-DVref, and DVR=DVroi/DVref",
   " -refVfm=refVfp",
-  "     In reference region Vfm is set to equal Vfp=1.",
+  "     In reference region Vfm is set to equal Vfp.",
   " -mc=<Filename>",
   "     Fit-based metabolite corrected regional TACs are written in the file.",
   " -fit=<Filename>",
@@ -83,7 +83,7 @@ static char *info[] = {
   "by the DV of region 'cer'",
   "     @P -Vb=0 -R=cer p25apc.bld p25apm.bld none p25.tac 60 p25k2di.res",
   " ",
-  "See also: fitk2, logan, fitk4, p2t_di, tacweigh, taccbv",
+  "See also: fitk2, fitk4di, logan, fitk4, p2t_di, tacweigh, taccbv",
   " ",
   "Keywords: TAC, modelling, distribution volume, reversible uptake, dual-input",
   0};
@@ -445,8 +445,7 @@ int main(int argc, char **argv)
     }
     if(verbose>30) dftPrint(&dft); 
     if(n>1)
-      fprintf(stderr, "Warning: %s selected of %d reference regions.\n",
-        dft.voi[ref].name, n);
+      fprintf(stderr, "Warning: %s selected of %d reference regions.\n", dft.voi[ref].name, n);
     if(verbose>1)
       fprintf(stdout, "selected reference region := %s\n", dft.voi[ref].name);
     if(inputtype==5) { // Reference region name was given
@@ -611,8 +610,7 @@ int main(int argc, char **argv)
     res.voi[ri].parameter[res.parNr-1]=wss;
 
     /* done with this region */
-    if(dft.voiNr>2 && verbose==1) {
-      fprintf(stdout, "."); fflush(stdout);}
+    if(dft.voiNr>2 && verbose==1) {fprintf(stdout, "."); fflush(stdout);}
 
   } /* next region */
   if(verbose>0) {fprintf(stdout, "\n"); fflush(stdout);}
