@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fit_h2o
-#: Date       : 2022-03-29
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -12,7 +12,6 @@ EXT=;
 fi
 
 PROGRAM=../../fit_h2o$EXT;
-
 if [ ! -f $PROGRAM ]; then
   printf "Failed: executable does not exist.\n"
   exit 1
@@ -317,8 +316,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -nonexistingoption blood.dat quick.dft 999 output.res &> stdout.txt
+$PROGRAM -nonexistingoption blood.dat quick.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-nonexistingoption'."
@@ -330,24 +328,22 @@ printf "\n 2.0.1 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  blood.dat  999 output.res &> stdout.txt
+$PROGRAM  blood.dat  999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  blood.dat quick.dft 999  &> stdout.txt
+$PROGRAM  blood.dat quick.dft 999  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.res
-$PROGRAM blood.dat quick.dft output.res &> stdout.txt
+rm -f output.res
+$PROGRAM blood.dat quick.dft output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
@@ -359,16 +355,14 @@ printf "\n 2.1.0 \n"
 printf " Test case: Nonexisting data file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.dat quick.dft 999 output.res &> stdout.txt
+$PROGRAM nonexistingfile.dat quick.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat nonexistingfile.dat 999 output.res &> stdout.txt
+$PROGRAM blood.dat nonexistingfile.dat 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
@@ -379,8 +373,7 @@ printf "\n 2.1.1 \n"
 printf " Test case: Forgotten fit duration. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat quick.dft  output.res &> stdout.txt
+$PROGRAM blood.dat quick.dft  output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid fit time 'output.res'."
@@ -393,21 +386,18 @@ printf "\n 2.2.0 \n"
 printf " Test case: Invalid data file contents. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f badfile.dat
 printf "# badfile\n" > badfile.dat
 printf "ugh banzai\n" >> badfile.dat
 printf "2 meh\n" >> badfile.dat
 
-rm -f stdout.txt
-$PROGRAM badfile.dat quick.dft 999 output.res &> stdout.txt
+$PROGRAM badfile.dat quick.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat badfile.dat 999 output.res &> stdout.txt
+$PROGRAM blood.dat badfile.dat 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
@@ -429,8 +419,8 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacadd blood_2_3_0.bld temp.bld
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt output.res
-$PROGRAM -delay=0 -Va=2 blood_2_3_0.bld quick.tac 999 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -delay=0 -Va=2 blood_2_3_0.bld quick.tac 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "using only first TAC in blood_2_3_0.bld"
@@ -445,16 +435,14 @@ printf "\n 2.4.0 \n"
 printf " Test case: Data file contains NaN. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood_na.bld quick.dft 999 output.res &> stdout.txt
+$PROGRAM blood_na.bld quick.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.bld quick_na.dft 999 output.res &> stdout.txt
+$PROGRAM blood.bld quick_na.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s) in quick_na.dft"
@@ -468,8 +456,7 @@ printf "\n 2.5.0 \n"
 printf " Test case: Data file contains only 3 samples. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood_3.bld quick.dft 999 output.res &> stdout.txt
+$PROGRAM blood_3.bld quick.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "blood_3.bld contains too few samples"
@@ -477,8 +464,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
-rm -f stdout.txt
-$PROGRAM blood.bld quick_3.dft 999 output.res &> stdout.txt
+$PROGRAM blood.bld quick_3.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too few samples in specified fit duration."
@@ -492,10 +478,10 @@ printf "\n-----------------------------------------------------------------\n"
 printf "\n 2.6.0 \n"
 printf " Test case: 3 sec gap in beginning of TTAC. \n"
 printf " Expected result: not even an error. \n\n"
-rm -f stdout.txt output.res
+rm -f output.res
 tactime quick.dft +3 temp.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-$PROGRAM -Va=2 -pH2O=1 blood.bld temp.dft 999 output.res &> stdout.txt
+$PROGRAM -Va=2 -pH2O=1 blood.bld temp.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning
@@ -506,12 +492,12 @@ printf "\n passed. \n\n"
 printf "\n 2.6.1 \n"
 printf " Test case: 6 sec gap in beginning of TTAC. \n"
 printf " Expected result: warning. \n\n"
-rm -f stdout.txt output.res
+rm -f output.res
 tactime quick.dft +6 temp.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacsety temp.dft 1 1 1.0
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-$PROGRAM -Va=2 -pH2O=1 blood.bld temp.dft 999 output.res &> stdout.txt
+$PROGRAM -Va=2 -pH2O=1 blood.bld temp.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "TACs should start at time zero."
@@ -522,12 +508,12 @@ printf "\n passed. \n\n"
 printf "\n 2.6.2 \n"
 printf " Test case: 1 min gap in beginning of TTAC. \n"
 printf " Expected result: error, if first concentration is not zero. \n\n"
-rm -f stdout.txt output.res
+rm -f output.res
 tactime quick.dft +60 temp.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacsety temp.dft 1 1 1.0
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-$PROGRAM -Va=2 -pH2O=1 blood.bld temp.dft 999 output.res &> stdout.txt
+$PROGRAM -Va=2 -pH2O=1 blood.bld temp.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "TACs must start at time zero."
@@ -545,8 +531,8 @@ $PROGRAM -Va=2 blood.bld normal.dft 999 flow1.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt output.res
-$PROGRAM -Va=2 blood.bld smallgap.dft 999 flow2.res &> stdout.txt
+rm -f output.res
+$PROGRAM -Va=2 blood.bld smallgap.dft 999 flow2.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.01 -rel=1 -par=1-4 flow1.res flow2.res
@@ -557,8 +543,8 @@ printf "\n 2.7.1 \n"
 printf " Test case: Longer gap between frames. \n"
 printf " Expected result: about the same results as wo the gap. \n\n"
 
-rm -f stdout.txt output.res
-$PROGRAM -Va=2 blood.bld biggap.dft 999 flow3.res &> stdout.txt
+rm -f output.res
+$PROGRAM -Va=2 blood.bld biggap.dft 999 flow3.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.01 -rel=3 -par=1-4 flow1.res flow3.res
@@ -569,8 +555,8 @@ printf "\n 2.8.0 \n"
 printf " Test case: Short overlap between frames. \n"
 printf " Expected result: almost the same results as wo the overlap. \n\n"
 
-rm -f stdout.txt output.res
-$PROGRAM -Va=2 blood.bld smalloverlap.dft 999 flow4.res &> stdout.txt
+rm -f output.res
+$PROGRAM -Va=2 blood.bld smalloverlap.dft 999 flow4.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.01 -rel=1 -par=1-4 flow1.res flow4.res
@@ -581,8 +567,8 @@ printf "\n 2.8.1 \n"
 printf " Test case: Longer overlap between frames. \n"
 printf " Expected result: almost the same results as wo the overlap. \n\n"
 
-rm -f stdout.txt output.res
-$PROGRAM -Va=2 blood.bld bigoverlap.dft 999 flow5.res &> stdout.txt
+rm -f output.res
+$PROGRAM -Va=2 blood.bld bigoverlap.dft 999 flow5.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.01 -rel=3 -par=1-4 flow1.res flow5.res
@@ -596,8 +582,8 @@ printf "\n 2.9.0 \n"
 printf " Test case: User-specified fit time is zero. \n"
 printf " Expected result: using all data, correct results. \n\n"
 
-rm -f stdout.txt output.res
-$PROGRAM -Va=2 -delay=0 blood.bld quick.dft 0 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -Va=2 -delay=0 blood.bld quick.dft 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.01 -rel=3 -par=1-4 correct_quick.res output.res
@@ -612,8 +598,8 @@ printf "\n 2.9.1 \n"
 printf " Test case: User-specified fit time is letter o. \n"
 printf " Expected result: error. \n\n"
 
-rm -f stdout.txt output.res
-$PROGRAM -Va=2 blood.bld quick.dft O output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -Va=2 blood.bld quick.dft O output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
@@ -625,8 +611,8 @@ printf "\n 2.9.2 \n"
 printf " Test case: User-specified fit time is in minutes. \n"
 printf " Expected result: error, if too short time. \n\n"
 
-rm -f stdout.txt output.res
-$PROGRAM -Va=2 blood.bld quick.dft 4 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -Va=2 blood.bld quick.dft 4 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
@@ -638,8 +624,8 @@ printf "\n 2.9.3 \n"
 printf " Test case: User-specified fit time limits fit time. \n"
 printf " Expected result: correct results. \n\n"
 
-rm -f stdout.txt output.res
-$PROGRAM -Va=2 -delay=0 blood.bld quick.dft 270 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -Va=2 -delay=0 blood.bld quick.dft 270 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.01 -rel=5 -par=1-4 correct_quick.res output.res
@@ -666,7 +652,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
 rm -f output.res
-$PROGRAM -svg=fit300a.svg blood_bq.bld quick.dft 999 output.res &> stdout.txt
+$PROGRAM -svg=fit300a.svg blood_bq.bld quick.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.001 -rel=3 -parunits=y -par=1-4 correct_quick.res output.res
@@ -674,7 +660,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 rm -f output.res
-$PROGRAM -svg=fit300b.svg blood.bld quick_bq.dft 999 output.res &> stdout.txt
+$PROGRAM -svg=fit300b.svg blood.bld quick_bq.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.001 -rel=3 -parunits=y -par=1-4 correct_quick.res output.res
@@ -693,16 +679,16 @@ tacunit -xconv=min quick_min.dft blood_min.bld
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f output.res stdout.txt
-$PROGRAM -svg=fit310a.svg blood_min.bld quick.dft 999 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -svg=fit310a.svg blood_min.bld quick.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.001 -rel=3 -parunits=y -par=1-4 correct_quick.res output.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.res stdout.txt
-$PROGRAM -svg=fit310b.svg blood.bld quick_min.dft 999 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -svg=fit310b.svg blood.bld quick_min.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.001 -rel=3 -parunits=y -par=1-4 correct_quick.res output.res
@@ -723,8 +709,8 @@ tacunit -yset=unknown quick_uc.dft blood_uc.bld
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f output.res stdout.txt
-$PROGRAM -svg=fit320a.svg blood_uc.bld quick.dft 999 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -svg=fit320a.svg blood_uc.bld quick.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.001 -rel=3 -parunits=y -par=1-4 correct_quick.res output.res
@@ -734,8 +720,8 @@ iftisval stdout.txt "Note" "check the units of input and tissue data."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.res stdout.txt
-$PROGRAM -svg=fit320b.svg blood.bld quick_uc.dft 999 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -svg=fit320b.svg blood.bld quick_uc.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.001 -rel=3 -parunits=y -par=1-4 correct_quick.res output.res
@@ -745,8 +731,8 @@ iftisval stdout.txt "Note" "check the units of input and tissue data."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.res stdout.txt
-$PROGRAM -svg=fit320c.svg blood_uc.bld quick_uc.dft 999 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -svg=fit320c.svg blood_uc.bld quick_uc.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.001 -rel=3 -parunits=y -par=1-4 correct_quick.res output.res
@@ -771,16 +757,16 @@ iftisval stdout.txt "Note" "check the units of input and tissue data."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f output.res stdout.txt
-$PROGRAM -svg=fit330a.svg blood_ut.bld quick.dft 999 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -svg=fit330a.svg blood_ut.bld quick.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.001 -rel=3 -parunits=y -par=1-4 correct_quick.res output.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.res stdout.txt
-$PROGRAM -svg=fit330b.svg blood.bld quick_ut.dft 999 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -svg=fit330b.svg blood.bld quick_ut.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.001 -rel=3 -parunits=y -par=1-4 correct_quick.res output.res
@@ -791,8 +777,8 @@ printf "\n 3.3.1 \n"
 printf " Test case: Neither data file contains time units, but data is in sec.\n"
 printf " Expected result: error, if reasonable fit time is set. \n\n"
 
-rm -f output.res stdout.txt
-$PROGRAM blood_ut.bld quick_ut.dft 330 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM blood_ut.bld quick_ut.dft 330 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning"
@@ -807,8 +793,8 @@ cp quick_min.dft quick_ut.dft
 cp blood_min.bld blood_ut.bld
 tacunit -xset=unknown quick_ut.dft blood_ut.bld
 
-rm -f output.res stdout.txt
-$PROGRAM -svg=fit332.svg -Va=2 blood_ut.bld quick_ut.dft 999 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -svg=fit332.svg -Va=2 blood_ut.bld quick_ut.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 parmatch -abs=0.001 -rel=3 -parunits=y -par=1-4 correct_quick.res output.res
@@ -826,6 +812,7 @@ printf " Test case: constraint file is created with option -lim=fname.\n"
 printf " Expected result: File is created with correct contents. \n\n"
 
 rm -f output.par
+
 $PROGRAM -lim=output.par
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
@@ -852,8 +839,7 @@ printf "\n 4.0.1 \n"
 printf " Test case: existing constraint file and option -lim=fname.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=output.par &> stdout.txt
+$PROGRAM -lim=output.par 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "parameter constraint file output.par exists."
@@ -864,8 +850,7 @@ printf "\n 4.0.2 \n"
 printf " Test case: trying to use nonexisting constraint file.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=nonexisting.par blood.bld quick.dft 999 output.res &> stdout.txt
+$PROGRAM -lim=nonexisting.par blood.bld quick.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.par'" "cannot open file"
@@ -876,8 +861,7 @@ printf "\n 4.0.3 \n"
 printf " Test case: trying to use constraint file with bad contents.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=badfile.dat blood.bld quick.tac 999 output.res &> stdout.txt
+$PROGRAM -lim=badfile.dat blood.bld quick.tac 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'badfile.dat'" "file contains no data"
@@ -891,8 +875,7 @@ printf " Expected result: Limits are set correctly. \n\n"
 printf "K1_lower := 6\n"  > limit.par
 printf "K1_upper := 60\n" >> limit.par
 
-rm -f stdout.txt
-$PROGRAM -d -lim=limit.par blood.bld quick.tac 0 output.res &> stdout.txt
+$PROGRAM -d -lim=limit.par blood.bld quick.tac 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "def_pmin[1]" "0.001"
@@ -913,8 +896,7 @@ printf "Va_upper := 2\n"  >> limit.par
 printf "Delay_lower := -5\n"  >> limit.par
 printf "Delay_upper := +5\n"  >> limit.par
 
-rm -f stdout.txt
-$PROGRAM -d -lim=limit.par blood.bld quick.dft 0 output.res &> stdout.txt
+$PROGRAM -d -lim=limit.par blood.bld quick.dft 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "def_pmin[2]" "0.5"
@@ -941,8 +923,7 @@ printf "\n 4.2.0 \n"
 printf " Test case: option -Va=0\n"
 printf " Expected result: Limits are set correctly. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d -Va=0 blood.bld quick.tac 0 output.res &> stdout.txt
+$PROGRAM -d -Va=0 blood.bld quick.tac 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "def_pmin[3]" "0"
@@ -956,8 +937,7 @@ printf "\n 4.2.1 \n"
 printf " Test case: option -Va=4.5\n"
 printf " Expected result: Limits are set correctly. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d -Va=4.5 blood.bld quick.dft 0 output.res &> stdout.txt
+$PROGRAM -d -Va=4.5 blood.bld quick.dft 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "def_pmin[3]" "0.045"
@@ -971,8 +951,7 @@ printf "\n 4.2.2 \n"
 printf " Test case: option -Va=0.045 by mistake\n"
 printf " Expected result: Warning. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Va=0.045 blood.bld quick.dft 0 output.res &> stdout.txt
+$PROGRAM -Va=0.045 blood.bld quick.dft 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "Va was set to 0.045%"
@@ -993,8 +972,7 @@ printf "Va_upper := 10\n"  >> limit2.par
 printf "Delay_lower := -30\n"  >> limit2.par
 printf "Delay_upper := +50\n"  >> limit2.par
 
-rm -f stdout.txt
-$PROGRAM -d -Va=2 -delay=0 -pH2O=1 -lim=limit2.par blood.bld quick.tac 0 output.res &> stdout.txt
+$PROGRAM -d -Va=2 -delay=0 -pH2O=1 -lim=limit2.par blood.bld quick.tac 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "def_pmin[1]" "0.001"
@@ -1032,8 +1010,7 @@ printf "\n 5.0.0 \n"
 printf " Test case: by default weights are 1\n"
 printf " Expected result: correct weights are printed in test mode. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d -Va=2 blood.bld quick.tac 0 output.res &> stdout.txt
+$PROGRAM -d -Va=2 blood.bld quick.tac 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt common_data_weights "1.000, 1.000, 1.000, 1.000, 1.000, 1.000, 1.000, 1.000, 1.000, 1.000, 1.000, 1.000, 1.000, 1.000, 1.000"
@@ -1049,8 +1026,7 @@ cp -f quick.tac temp.tac
 tacweigh -wf temp.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt
-$PROGRAM -d -Va=2 blood.bld temp.tac 0 output.res &> stdout.txt
+$PROGRAM -d -Va=2 blood.bld temp.tac 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt common_data_weights "0.455, 0.227, 0.227, 0.455, 0.455, 0.455, 0.455, 0.682, 0.682, 1.364, 1.364, 1.364, 1.364, 2.727, 2.727"
