@@ -12,7 +12,6 @@ EXT=;
 fi
 
 PROGRAM=../../fit_srtm$EXT;
-
 if [ ! -f $PROGRAM ]; then
   printf "Failed: executable does not exist.\n"
   exit 1
@@ -335,8 +334,7 @@ printf "\n 1.4.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -nonexistingoption basicsim refer 900 output.res &> stdout.txt
+$PROGRAM -nonexistingoption basicsim refer 900 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-nonexistingoption'."
@@ -347,24 +345,21 @@ printf "\n 1.4.1 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM basicsim.tac refer 900 &> stdout.txt
+$PROGRAM basicsim.tac refer 900 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM basicsim.tac refer output.res &> stdout.txt
+$PROGRAM basicsim.tac refer output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM basicsim.tac 999 output.res &> stdout.txt
+$PROGRAM basicsim.tac 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
@@ -382,7 +377,7 @@ printf " Expected result 2: Warning about several reference regions. \n"
 printf " Expected result 3: Reference TACs not saved with fitted TTACs. \n"
 printf " Expected result 4: Reference regions omitted from result file. \n\n"
 
-rm -f fit_2_0_0.res fit_2_0_0.tac fit_2_0_0.svg stdout.txt
+rm -f fit_2_0_0.res fit_2_0_0.tac fit_2_0_0.svg
 
 cp -f basicsim.tac test.tac
 tacadd -ovr -move refer.tac test.tac refer
@@ -395,7 +390,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
 
-$PROGRAM -fit=fit_2_0_0.tac -svg=fit_2_0_0.svg test.tac refer.tac 120 fit_2_0_0.res &> stdout.txt
+$PROGRAM -fit=fit_2_0_0.tac -svg=fit_2_0_0.svg test.tac refer.tac 120 fit_2_0_0.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -429,9 +424,7 @@ printf "\n 2.0.1 \n"
 printf " Test case: Given reference region file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM basicsim.tac nonexisting.tac 999 output.res &> stdout.txt
+$PROGRAM basicsim.tac nonexisting.tac 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading reference input" "cannot find region"
@@ -448,9 +441,9 @@ printf " Expected result 1: Warning about several reference regions. \n"
 printf " Expected result 2: All TACs saved with fitted TTACs. \n"
 printf " Expected result 3: Only selected reference omitted from result file. \n\n"
 
-rm -f fit_2_1_0.res fit_2_1_0.tac fit_2_1_0.svg stdout.txt
+rm -f fit_2_1_0.res fit_2_1_0.tac fit_2_1_0.svg
 
-$PROGRAM -fit=fit_2_1_0.tac -svg=fit_2_1_0.svg basicsim.tac refer 120 fit_2_1_0.res &> stdout.txt
+$PROGRAM -fit=fit_2_1_0.tac -svg=fit_2_1_0.svg basicsim.tac refer 120 fit_2_1_0.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -481,9 +474,9 @@ printf " Expected result 1: No warning about several reference regions. \n"
 printf " Expected result 2: All TACs saved with fitted TTACs. \n"
 printf " Expected result 3: Only selected reference omitted from result file. \n\n"
 
-rm -f fit_2_1_1.res fit_2_1_1.tac fit_2_1_1.svg stdout.txt
+rm -f fit_2_1_1.res fit_2_1_1.tac fit_2_1_1.svg
 
-$PROGRAM -fit=fit_2_1_1.tac basicsim.tac "refer highk" 120 fit_2_1_1.res &> stdout.txt
+$PROGRAM -fit=fit_2_1_1.tac basicsim.tac "refer highk" 120 fit_2_1_1.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -511,7 +504,7 @@ printf " Expected result 2: Existing result file can be overwritten. \n\n"
 
 rm -f fit_2_2_0.res stdout.txt
 
-$PROGRAM basicsim.tac 1 120 fit_2_2_0.res &> stdout.txt
+$PROGRAM basicsim.tac 1 120 fit_2_2_0.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -530,7 +523,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
-$PROGRAM basicsim.tac 2 120 fit_2_2_0.res &> stdout.txt
+$PROGRAM basicsim.tac 2 120 fit_2_2_0.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -550,9 +543,7 @@ printf "\n 2.3.0 \n"
 printf " Test case: Given reference region name does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM basicsim.tac stupid 999 output.res &> stdout.txt
+$PROGRAM basicsim.tac stupid 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading reference input" "cannot find region"
@@ -564,9 +555,7 @@ printf "\n 2.3.1 \n"
 printf " Test case: Given reference region nr does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM basicsim.tac 30 999 output.res &> stdout.txt
+$PROGRAM basicsim.tac 30 999 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading reference input" "cannot find region"
@@ -662,9 +651,7 @@ printf "\n 3.4.0 \n"
 printf " Test case: Nonexisting data file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM nonexistingfile.dat cereb 60 output.res &> stdout.txt
+$PROGRAM nonexistingfile.dat cereb 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexistingfile.dat'" "cannot open file"
@@ -678,7 +665,7 @@ printf " Test case: 3 s time gap in the beginning. \n"
 printf " Expected result 1: Result file is created, and results are about the same. \n"
 printf " Expected result 2: No warning. \n\n"
 
-rm -f fit_4_0_0.res stdout.txt
+rm -f fit_4_0_0.res
 tactime rpsim.tac 0.05 test.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
@@ -688,7 +675,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
 
-$PROGRAM -w1 test.tac cereb 60 fit_4_0_0.res &> stdout.txt
+$PROGRAM -w1 test.tac cereb 60 fit_4_0_0.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -706,12 +693,12 @@ printf " Test case: 6 s time gap in the beginning. \n"
 printf " Expected result 1: Result file is created, and results are about the same. \n"
 printf " Expected result 2: Warning. \n\n"
 
-rm -f fit_4_0_1.res stdout.txt
+rm -f fit_4_0_1.res
 tactime rpsim.tac 0.10 test.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM -w1 test.tac cereb 60 fit_4_0_1.res &> stdout.txt
+$PROGRAM -w1 test.tac cereb 60 fit_4_0_1.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -733,7 +720,7 @@ tactime rpsim.tac 1.0 test.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM -w1 test.tac cereb 60 fit_4_0_2.res &> stdout.txt
+$PROGRAM -w1 test.tac cereb 60 fit_4_0_2.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ -f fit_4_0_2.res ]; then printf "Failed!\n" ; exit 1 ; fi
@@ -749,13 +736,13 @@ printf "\n 4.1.0 \n"
 printf " Test case:       Small gap between frames. \n"
 printf " Expected result: Result file is created, and results are about the same. \n\n"
 
-rm -f fit_4_1_0.res stdout.txt
+rm -f fit_4_1_0.res
 
 $PROGRAM rpsim.tac "cereb" 60 test.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM rpsim_smallgap.tac cereb 60 fit_4_1_0.res &> stdout.txt
+$PROGRAM rpsim_smallgap.tac cereb 60 fit_4_1_0.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -767,9 +754,9 @@ printf "\n 4.1.1 \n"
 printf " Test case:       Larger gap between frames. \n"
 printf " Expected result: Result file is created, and results are still about the same. \n\n"
 
-rm -f fit_4_1_1.res stdout.txt
+rm -f fit_4_1_1.res
 
-$PROGRAM rpsim_biggap.tac cereb 60 fit_4_1_1.res &> stdout.txt
+$PROGRAM rpsim_biggap.tac cereb 60 fit_4_1_1.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -782,9 +769,9 @@ printf "\n 4.2.0 \n"
 printf " Test case:       Small frame overlap. \n"
 printf " Expected result: Result file is created, and results are about the same. \n\n"
 
-rm -f fit_4_2_0.res stdout.txt
+rm -f fit_4_2_0.res
 
-$PROGRAM rpsim_smalloverlap.tac cereb 60 fit_4_2_0.res &> stdout.txt
+$PROGRAM rpsim_smalloverlap.tac cereb 60 fit_4_2_0.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -796,9 +783,9 @@ printf "\n 4.2.1 \n"
 printf " Test case:       Larger frame overlap. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f fit_4_2_1.res stdout.txt
+rm -f fit_4_2_1.res
 
-$PROGRAM -d rpsim_bigoverlap.tac cereb 60 fit_4_2_1.res &> stdout.txt
+$PROGRAM -d rpsim_bigoverlap.tac cereb 60 fit_4_2_1.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ -f fit_4_2_1.res ]; then printf "Failed!\n" ; exit 1 ; fi
@@ -977,9 +964,9 @@ printf "\n 5.0.2 \n"
 printf " Test case: Fit time is accidentally set to letter 'O'. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f fit_5_0_2.res stdout.txt
+rm -f fit_5_0_2.res
 
-$PROGRAM rpsim.tac cereb O fit_5_0_2.res &> stdout.txt
+$PROGRAM rpsim.tac cereb O fit_5_0_2.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "invalid fit time: 'O'."
@@ -1018,9 +1005,7 @@ printf "\n 5.1.1 \n"
 printf " Test case: Fit time would cover less than four frames. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM rpsim_fewframes.tac cereb 20 output.res &> stdout.txt
+$PROGRAM rpsim_fewframes.tac cereb 20 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "too few data points for a decent fit."
@@ -1069,9 +1054,7 @@ printf "\n 6.0.1 \n"
 printf " Test case: Default constraints are tried to be written in file but file exists. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM -lim=temp.lim &> stdout.txt
+$PROGRAM -lim=temp.lim 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "parameter constraint file temp.lim exists."
@@ -1090,9 +1073,9 @@ printf "R1_upper := 1.5 \n"  >>  test.lim
 printf "k2_upper := 0.5 \n"  >>  test.lim
 printf "BP_upper := 2.9 \n"  >>  test.lim
 
-rm -f fit_6_1_0.res stdout.txt
+rm -f fit_6_1_0.res
 
-$PROGRAM -d6 -lim=test.lim rpsim.tac cereb 60 fit_6_1_0.res  &> stdout.txt
+$PROGRAM -d6 -lim=test.lim rpsim.tac cereb 60 fit_6_1_0.res  1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -1119,9 +1102,9 @@ printf " Expected result: Limits are used. \n\n"
 printf "k2_lower := 0.5 \n"  >   test2.lim
 printf "k2_upper := 0.5 \n"  >>  test2.lim
 
-rm -f fit_6_1_1.res stdout.txt
+rm -f fit_6_1_1.res
 
-$PROGRAM -d6 -lim=test2.lim rpsim.tac cereb 60 fit_6_1_1.res  &> stdout.txt
+$PROGRAM -d6 -lim=test2.lim rpsim.tac cereb 60 fit_6_1_1.res  1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -1145,9 +1128,9 @@ printf " Expected result: Error. \n\n"
 
 printf "k2 := 0.5 \n"  >  test.lim
 
-rm -f output.res stdout.txt
+rm -f output.res
 
-$PROGRAM -lim=test.lim rpsim.tac cereb 60 output.res  &> stdout.txt
+$PROGRAM -lim=test.lim rpsim.tac cereb 60 output.res  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -1162,9 +1145,9 @@ printf " Test case: Given constraint file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
 
-rm -f output.res stdout.txt
+rm -f output.res
 
-$PROGRAM -lim=nonexisting.lim rpsim.tac cereb 60 output.res  &> stdout.txt
+$PROGRAM -lim=nonexisting.lim rpsim.tac cereb 60 output.res  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -1185,13 +1168,12 @@ printf "\n 7.0.0 \n"
 printf " Test case: If file does not contain weights then by default weights are 1\n"
 printf " Expected result: correct weights are printed in test mode. \n\n"
 
-rm -f stdout.txt
 cp -f rpsim_fewframes.tac test.tac
 tacweigh -rm test.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM -d4 test.tac cereb 999 output.res &> stdout.txt
+$PROGRAM -d4 test.tac cereb 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval output.res "Weighting" "no"
@@ -1210,7 +1192,7 @@ tacweigh -wf test.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM -d4 test.tac cereb 999 output.res &> stdout.txt
+$PROGRAM -d4 test.tac cereb 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval output.res "Weighting" "yes"
@@ -1225,7 +1207,7 @@ printf "\n 7.0.2 \n"
 printf " Test case: Datafile contains weights but set to 1 optionally.\n"
 printf " Expected result: correct weights are printed in test mode. \n\n"
 
-$PROGRAM -d4 -w1 test.tac cereb 999 output.res &> stdout.txt
+$PROGRAM -d4 -w1 test.tac cereb 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval output.res "Weighting" "no"
@@ -1244,7 +1226,7 @@ tacweigh -i=C-11 test.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM -d4 -wf test.tac cereb 999 output.res &> stdout.txt
+$PROGRAM -d4 -wf test.tac cereb 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval output.res "Weighting" "yes"
@@ -1263,7 +1245,7 @@ tacweigh -rm test.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM -d4 -wf test.tac cereb 999 output.res &> stdout.txt
+$PROGRAM -d4 -wf test.tac cereb 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval output.res "Weighting" "yes"
