@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fitk2
-#: Date       : 2022-03-29
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -338,8 +338,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: Unknwon option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -nonexistingoption plasma.bld blood.bld k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM -nonexistingoption plasma.bld blood.bld k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-nonexistingoption'."
@@ -351,16 +350,14 @@ printf "\n 2.0.1 \n"
 printf " Test case: Missing filename. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  blood.bld k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM  blood.bld k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld k2tis1.dft 30  &> stdout.txt
+$PROGRAM plasma.bld blood.bld k2tis1.dft 30  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
@@ -372,24 +369,21 @@ printf "\n 2.1.0 \n"
 printf " Test case: Nonexisting data file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.dat blood.bld k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM nonexistingfile.dat blood.bld k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld nonexistingfile.dat k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM plasma.bld nonexistingfile.dat k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld nonexistingfile.dat 30 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld nonexistingfile.dat 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
@@ -401,8 +395,7 @@ printf "\n 2.1.1 \n"
 printf " Test case: Nonexisting blood file. \n"
 printf " Expected result: No error if Vb=0. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Vb=0 plasma.bld nonexistingfile.dat k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM -Vb=0 plasma.bld nonexistingfile.dat k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -411,8 +404,7 @@ printf "\n 2.1.2 \n"
 printf " Test case: Nonexisting ref file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -DVR=nonexistingfile.dat plasma.bld blood.bld k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM -DVR=nonexistingfile.dat plasma.bld blood.bld k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexistingfile.dat'" "cannot find region"
@@ -424,8 +416,7 @@ printf "\n 2.1.3 \n"
 printf " Test case: Given reference region name does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -DVR=stupid plasma.bld blood.bld k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM -DVR=stupid plasma.bld blood.bld k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'stupid'" "cannot find region"
@@ -437,16 +428,14 @@ printf "\n 2.1.4 \n"
 printf " Test case: Given reference region nr does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -DVR=16 plasma.bld blood.bld k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM -DVR=16 plasma.bld blood.bld k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading '16'" "cannot find region"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -DVR=0 plasma.bld blood.bld k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM -DVR=0 plasma.bld blood.bld k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading '0'" "cannot find region"
@@ -459,29 +448,25 @@ printf "\n 2.2.0 \n"
 printf " Test case: Invalid data file contents. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f badfile.dat
 printf "# badfile\n" > badfile.dat
 printf "ugh banzai\n" >> badfile.dat
 printf "2 meh\n" >> badfile.dat
 
-rm -f stdout.txt
-$PROGRAM badfile.dat blood.bld k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM badfile.dat blood.bld k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld badfile.dat k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM plasma.bld badfile.dat k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld badfile.dat 30 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld badfile.dat 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
@@ -493,8 +478,7 @@ printf "\n 2.2.1 \n"
 printf " Test case: Invalid blood file contents. \n"
 printf " Expected result: No error if Vb=0. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Vb=0 plasma.bld badfile.dat k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM -Vb=0 plasma.bld badfile.dat k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -503,8 +487,7 @@ printf "\n 2.2.2 \n"
 printf " Test case: Invalid ref file contents. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -DVR=badfile.dat plasma.bld blood.bld k2tis1.dft 30 output.res &> stdout.txt
+$PROGRAM -DVR=badfile.dat plasma.bld blood.bld k2tis1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'badfile.dat'"
@@ -532,8 +515,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacadd blood_2_3_0.bld temp.bld
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt
-$PROGRAM plasma_2_3_0.bld blood_2_3_0.bld k2tis1.dft 60 output.res &> stdout.txt
+$PROGRAM plasma_2_3_0.bld blood_2_3_0.bld k2tis1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "using only first TAC in plasma_2_3_0.bld"
@@ -557,8 +539,8 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacadd reftemp.tac k2tis.dft tis8
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt output.res
-$PROGRAM -dvr=reftemp.tac plasma.bld blood.bld k2tis.dft 60 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -dvr=reftemp.tac plasma.bld blood.bld k2tis.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "ref1 mean Pl01 selected of 2 reference regions."
@@ -576,8 +558,7 @@ printf "\n 2.3.2 \n"
 printf " Test case: Ref file contains different sample nr. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -dvr=k2tis_long.dft plasma.bld blood.bld k2tis.dft 30 output.res &> stdout.txt
+$PROGRAM -dvr=k2tis_long.dft plasma.bld blood.bld k2tis.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'k2tis_long.dft'"
@@ -589,24 +570,21 @@ printf "\n 2.4.0 \n"
 printf " Test case: Data file contains NaN. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma_na.bld blood.bld k2tis1.dft 60 output.res &> stdout.txt
+$PROGRAM plasma_na.bld blood.bld k2tis1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s) in data"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood_na.bld k2tis1.dft 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood_na.bld k2tis1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld k2tis1_na.dft 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld k2tis1_na.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s) in k2tis1_na.dft"
@@ -618,24 +596,21 @@ printf "\n 2.5.0 \n"
 printf " Test case: Data file contains only 3 samples. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma_3.bld blood.bld k2tis1.dft 60 output.res &> stdout.txt
+$PROGRAM plasma_3.bld blood.bld k2tis1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "plasma_3.bld contains too few samples"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood_3.bld k2tis1.dft 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood_3.bld k2tis1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "blood_3.bld contains too few samples"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld k2tis_few.dft 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld k2tis_few.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too few samples in specified fit duration."
@@ -647,8 +622,7 @@ printf "\n 2.5.1 \n"
 printf " Test case: Blood file contains only 3 samples. \n"
 printf " Expected result: No error if Vb=0. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Vb=0 plasma.bld blood_3.bld k2tis1.dft 60 output.res &> stdout.txt
+$PROGRAM -Vb=0 plasma.bld blood_3.bld k2tis1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -684,8 +658,7 @@ printf "\n 3.0.1 \n"
 printf " Test case: existing constraint file and option -lim=fname.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=output.par &> stdout.txt
+$PROGRAM -lim=output.par 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "parameter constraint file output.par exists."
@@ -696,8 +669,7 @@ printf "\n 3.0.2 \n"
 printf " Test case: trying to use nonexisting constraint file.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=nonexisting.par plasma.bld blood.bld k2tis1.dft 60 output.res &> stdout.txt
+$PROGRAM -lim=nonexisting.par plasma.bld blood.bld k2tis1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.par'" "cannot open file"
@@ -708,8 +680,7 @@ printf "\n 3.0.3 \n"
 printf " Test case: trying to use constraint file with bad contents.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=badfile.dat plasma.bld blood.bld k2tis1.dft 60 output.res &> stdout.txt
+$PROGRAM -lim=badfile.dat plasma.bld blood.bld k2tis1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'badfile.dat'" "file contains no data"
@@ -725,8 +696,7 @@ printf " Expected result: Limits are set correctly. \n\n"
 printf "K1_lower := 0.1\n"  > limit.par
 printf "K1_upper := 1.2\n" >> limit.par
 
-rm -f stdout.txt
-$PROGRAM -d4 -lim=limit.par plasma.bld blood.bld k2tis1.dft 20 output.res &> stdout.txt
+$PROGRAM -d4 -lim=limit.par plasma.bld blood.bld k2tis1.dft 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[0.1,1.2] [0,500] [0,0.08]"
@@ -743,8 +713,7 @@ printf "K1k2_upper := 1.0\n" >> limit.par
 printf "Vb_lower := 0.02\n"  >> limit.par
 printf "Vb_upper := 0.05\n"  >> limit.par
 
-rm -f stdout.txt
-$PROGRAM -d4 -lim=limit.par plasma.bld blood.bld k2tis1.dft 20 output.res &> stdout.txt
+$PROGRAM -d4 -lim=limit.par plasma.bld blood.bld k2tis1.dft 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[0.1,1.2] [0.6,1] [0.02,0.05]"
@@ -756,8 +725,7 @@ printf "\n 3.2.0 \n"
 printf " Test case: option -Vb=0\n"
 printf " Expected result: Limits are set correctly. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=0 plasma.bld blood.bld k2tis1.dft 20 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=0 plasma.bld blood.bld k2tis1.dft 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[0,10] [0,500] [0,0]"
@@ -769,8 +737,7 @@ printf "\n 3.2.1 \n"
 printf " Test case: option -Vb=4.5\n"
 printf " Expected result: Limits are set correctly. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=4.5 plasma.bld blood.bld k2tis1.dft 20 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=4.5 plasma.bld blood.bld k2tis1.dft 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[0,10] [0,500] [0.045,0.045]"
@@ -782,8 +749,7 @@ printf "\n 3.2.2 \n"
 printf " Test case: option -Vb=0.045 by mistake\n"
 printf " Expected result: Warning. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=0.045 plasma.bld blood.bld k2tis1.dft 20 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=0.045 plasma.bld blood.bld k2tis1.dft 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "Vb was set to 0.045%"
@@ -800,8 +766,7 @@ printf "\n 4.0.0 \n"
 printf " Test case: by default weights are 1\n"
 printf " Expected result: correct weights are printed in test mode. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=4 plasma.bld blood.bld k2tis_long.dft 999 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=4 plasma.bld blood.bld k2tis_long.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt common_data_weights "1, 1, 1, 1, 1, 1, 1, 1"
@@ -816,8 +781,7 @@ cp -f k2tis_long.dft temp.tac
 tacweigh -wf temp.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=4 plasma.bld blood.bld temp.tac 999 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=4 plasma.bld blood.bld temp.tac 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt common_data_weights "0.0666667, 0.0666667, 0.266667, 0.266667, 0.666667, 1.33333, 1.33333, 4"
