@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fitk2di
-#: Date       : 2020-03-11
+#: Date       : 2023-06-30
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -325,8 +325,8 @@ printf " Expected result 1: Test output contains correct variable values. \n"
 printf " Expected result 2: Result file is created. \n\n"
 printf " Notice: Fitting may take a long time. \n\n"
 
-rm -f stdout.txt test1l.res
-$PROGRAM -d3 -lim=test1.lim parent_i.dat metabolite1_i.dat blood_i.dat test1l.dat 90 test1l.res &> stdout.txt
+rm -f test1l.res
+$PROGRAM -d3 -lim=test1.lim parent_i.dat metabolite1_i.dat blood_i.dat test1l.dat 90 test1l.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt pfile "parent_i.dat"
