@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fitk3
-#: Date       : 2022-03-29
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -284,8 +284,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -nonexistingoption plasma.bld blood.bld k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM -nonexistingoption plasma.bld blood.bld k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-nonexistingoption'."
@@ -297,16 +296,14 @@ printf "\n 2.0.1 \n"
 printf " Test case: Missing filename. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  blood.bld k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM  blood.bld k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld k3reg1.dft 30  &> stdout.txt
+$PROGRAM plasma.bld blood.bld k3reg1.dft 30  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
@@ -318,24 +315,21 @@ printf "\n 2.1.0 \n"
 printf " Test case: Nonexisting data file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.dat blood.bld k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM nonexistingfile.dat blood.bld k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld nonexistingfile.dat k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM plasma.bld nonexistingfile.dat k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld nonexistingfile.dat 30 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld nonexistingfile.dat 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
@@ -347,8 +341,7 @@ printf "\n 2.1.1 \n"
 printf " Test case: Nonexisting blood file. \n"
 printf " Expected result: No error if Vb=0. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Vb=0 plasma.bld nonexistingfile.dat k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM -Vb=0 plasma.bld nonexistingfile.dat k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -357,8 +350,7 @@ printf "\n 2.1.2 \n"
 printf " Test case: Nonexisting ref file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -R=nonexistingfile.dat plasma.bld blood.bld k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM -R=nonexistingfile.dat plasma.bld blood.bld k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexistingfile.dat'" "cannot find region"
@@ -370,8 +362,7 @@ printf "\n 2.1.3 \n"
 printf " Test case: Given reference region name does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -r=stupid plasma.bld blood.bld k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM -r=stupid plasma.bld blood.bld k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'stupid'" "cannot find region"
@@ -383,16 +374,14 @@ printf "\n 2.1.4 \n"
 printf " Test case: Given reference region nr does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -R=16 plasma.bld blood.bld k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM -R=16 plasma.bld blood.bld k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading '16'" "cannot find region"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -R=0 plasma.bld blood.bld k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM -R=0 plasma.bld blood.bld k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading '0'" "cannot find region"
@@ -412,24 +401,21 @@ printf "# badfile\n" > badfile.dat
 printf "ugh banzai\n" >> badfile.dat
 printf "2 meh\n" >> badfile.dat
 
-rm -f stdout.txt
-$PROGRAM badfile.dat blood.bld k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM badfile.dat blood.bld k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld badfile.dat k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM plasma.bld badfile.dat k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld badfile.dat 30 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld badfile.dat 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
@@ -442,8 +428,7 @@ printf "\n 2.2.1 \n"
 printf " Test case: Invalid blood file contents. \n"
 printf " Expected result: No error if Vb=0. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Vb=0 plasma.bld badfile.dat k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM -Vb=0 plasma.bld badfile.dat k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -452,8 +437,7 @@ printf "\n 2.2.2 \n"
 printf " Test case: Invalid ref file contents. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -r=badfile.dat plasma.bld blood.bld k3reg1.dft 30 output.res &> stdout.txt
+$PROGRAM -r=badfile.dat plasma.bld blood.bld k3reg1.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'badfile.dat'"
@@ -481,8 +465,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacadd blood_2_3_0.bld temp.bld
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt
-$PROGRAM plasma_2_3_0.bld blood_2_3_0.bld k3reg1.dft 60 output.res &> stdout.txt
+$PROGRAM plasma_2_3_0.bld blood_2_3_0.bld k3reg1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "using only first TAC in plasma_2_3_0.bld"
@@ -506,8 +489,8 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacadd reftemp.tac k3tis.dft regio2
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt output.res
-$PROGRAM -r=reftemp.tac plasma.bld blood.bld k3tis.dft 30 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -r=reftemp.tac plasma.bld blood.bld k3tis.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "regio3 1 L1 selected of 2 reference regions."
@@ -525,8 +508,7 @@ printf "\n 2.3.2 \n"
 printf " Test case: Ref file contains different sample nr. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -r=k3reg3_long.dft plasma.bld blood.bld k3tis.dft 30 output.res &> stdout.txt
+$PROGRAM -r=k3reg3_long.dft plasma.bld blood.bld k3tis.dft 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'k3reg3_long.dft'"
@@ -540,24 +522,21 @@ printf "\n 2.4.0 \n"
 printf " Test case: Data file contains NaN. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma_na.bld blood.bld k3reg1.dft 60 output.res &> stdout.txt
+$PROGRAM plasma_na.bld blood.bld k3reg1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s) in data"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood_na.bld k3reg1.dft 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood_na.bld k3reg1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld k3reg1_na.dft 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld k3reg1_na.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s) in k3reg1_na.dft"
@@ -569,24 +548,21 @@ printf "\n 2.5.0 \n"
 printf " Test case: Data file contains only 3 samples. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma_3.bld blood.bld k3reg1.dft 60 output.res &> stdout.txt
+$PROGRAM plasma_3.bld blood.bld k3reg1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "plasma_3.bld contains too few samples"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood_3.bld k3reg1.dft 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood_3.bld k3reg1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "blood_3.bld contains too few samples"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld k3tis_few.dft 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld k3tis_few.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too few samples in specified fit duration."
@@ -599,8 +575,7 @@ printf "\n 2.5.1 \n"
 printf " Test case: Blood file contains only 3 samples. \n"
 printf " Expected result: No error if Vb=0. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Vb=0 plasma.bld blood_3.bld k3reg1.dft 60 output.res &> stdout.txt
+$PROGRAM -Vb=0 plasma.bld blood_3.bld k3reg1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -640,8 +615,7 @@ printf "\n 3.0.1 \n"
 printf " Test case: existing constraint file and option -lim=fname.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=output.par &> stdout.txt
+$PROGRAM -lim=output.par 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "parameter constraint file output.par exists."
@@ -653,8 +627,7 @@ printf "\n 3.0.2 \n"
 printf " Test case: trying to use nonexisting constraint file.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=nonexisting.par plasma.bld blood.bld k3reg1.dft 60 output.res &> stdout.txt
+$PROGRAM -lim=nonexisting.par plasma.bld blood.bld k3reg1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.par'" "cannot open file"
@@ -666,8 +639,7 @@ printf "\n 3.0.3 \n"
 printf " Test case: trying to use constraint file with bad contents.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=badfile.dat plasma.bld blood.bld k3ref1.dft 60 output.res &> stdout.txt
+$PROGRAM -lim=badfile.dat plasma.bld blood.bld k3ref1.dft 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'badfile.dat'" "file contains no data"
@@ -683,8 +655,7 @@ printf " Expected result: Limits are set correctly. \n\n"
 printf "K1_lower := 0.05\n"  > limit.par
 printf "K1_upper := 0.8\n" >> limit.par
 
-rm -f stdout.txt
-$PROGRAM -d4 -lim=limit.par plasma.bld blood.bld k3reg1.dft 20 output.res &> stdout.txt
+$PROGRAM -d4 -lim=limit.par plasma.bld blood.bld k3reg1.dft 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[0.05,0.8] [1e-05,10] [0,2] [0,0.08]"
@@ -703,8 +674,7 @@ printf "k3_upper := 3.0\n" >> limit.par
 printf "Vb_lower := 0.02\n"  >> limit.par
 printf "Vb_upper := 0.06\n"  >> limit.par
 
-rm -f stdout.txt
-$PROGRAM -d4 -lim=limit.par plasma.bld blood.bld k3reg1.dft 20 output.res &> stdout.txt
+$PROGRAM -d4 -lim=limit.par plasma.bld blood.bld k3reg1.dft 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[0.05,0.8] [0.1,2] [0,3] [0.02,0.06]"
@@ -716,8 +686,7 @@ printf "\n 3.2.0 \n"
 printf " Test case: option -Vb=0\n"
 printf " Expected result: Limits are set correctly. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=0 plasma.bld blood.bld k3reg1.dft 20 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=0 plasma.bld blood.bld k3reg1.dft 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[0,5] [1e-05,10] [0,2] [0,0]"
@@ -729,8 +698,7 @@ printf "\n 3.2.1 \n"
 printf " Test case: option -Vb=4.5\n"
 printf " Expected result: Limits are set correctly. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=4.5 plasma.bld blood.bld k3reg1.dft 20 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=4.5 plasma.bld blood.bld k3reg1.dft 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[0,5] [1e-05,10] [0,2] [0.045,0.045]"
@@ -742,8 +710,7 @@ printf "\n 3.2.2 \n"
 printf " Test case: option -Vb=0.045 by mistake\n"
 printf " Expected result: Warning. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=0.045 plasma.bld blood.bld k3reg1.dft 20 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=0.045 plasma.bld blood.bld k3reg1.dft 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "Vb was set to 0.045%"
@@ -761,8 +728,7 @@ printf "\n 4.0.0 \n"
 printf " Test case: by default weights are 1\n"
 printf " Expected result: correct weights are printed in test mode. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=4 plasma.bld blood.bld k3reg3_long.dft 999 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=4 plasma.bld blood.bld k3reg3_long.dft 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt common_data_weights "1, 1, 1, 1, 1, 1, 1, 1"
@@ -777,8 +743,7 @@ cp -f k3reg3_long.dft temp.tac
 tacweigh -wf temp.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=4 plasma.bld blood.bld temp.tac 999 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=4 plasma.bld blood.bld temp.tac 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt common_data_weights "0.0666667, 0.0666667, 0.266667, 0.266667, 0.666667, 1.33333, 1.33333, 4"
