@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fitk4
-#: Date       : 2022-03-29
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -371,8 +371,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -nonexistingoption plasma.bld blood.bld pet_t2_long.tac 30 output.res &> stdout.txt
+$PROGRAM -nonexistingoption plasma.bld blood.bld pet_t2_long.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-nonexistingoption'."
@@ -385,32 +384,28 @@ printf "\n 2.0.1 \n"
 printf " Test case: Missing filename. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  blood.bld pet_t2_long.tac 30 output.res &> stdout.txt
+$PROGRAM  blood.bld pet_t2_long.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  plasma.bld pet_t2_long.tac 30 output.res &> stdout.txt
+$PROGRAM  plasma.bld pet_t2_long.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld  30 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld  30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld pet_t2_long.tac 30  &> stdout.txt
+$PROGRAM plasma.bld blood.bld pet_t2_long.tac 30  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
@@ -424,24 +419,21 @@ printf "\n 2.1.0 \n"
 printf " Test case: Nonexisting data file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.dat blood.bld pet.tac 30 output.res &> stdout.txt
+$PROGRAM nonexistingfile.dat blood.bld pet.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld nonexistingfile.dat pet.tac 30 output.res &> stdout.txt
+$PROGRAM plasma.bld nonexistingfile.dat pet.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld nonexistingfile.dat 30 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld nonexistingfile.dat 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
@@ -452,8 +444,7 @@ printf "\n 2.1.1 \n"
 printf " Test case: Nonexisting blood file. \n"
 printf " Expected result: No error if Vb=0. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Vb=0 plasma.bld nonexistingfile.dat pet_t2_long.tac 30 output.res &> stdout.txt
+$PROGRAM -Vb=0 plasma.bld nonexistingfile.dat pet_t2_long.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -462,8 +453,7 @@ printf "\n 2.1.2 \n"
 printf " Test case: Nonexisting ref file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -R=nonexistingfile.dat plasma.bld blood.bld pet.tac 30 output.res &> stdout.txt
+$PROGRAM -R=nonexistingfile.dat plasma.bld blood.bld pet.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexistingfile.dat'" "cannot find region"
@@ -475,16 +465,14 @@ printf "\n 2.1.3 \n"
 printf " Test case: Given reference region name does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -r=stupid plasma.bld blood.bld pet.tac 30 output.res &> stdout.txt
+$PROGRAM -r=stupid plasma.bld blood.bld pet.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'stupid'" "cannot find region"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -BPnd=stupid plasma.bld blood.bld pet.tac 30 output.res &> stdout.txt
+$PROGRAM -BPnd=stupid plasma.bld blood.bld pet.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "reference region stupid not found"
@@ -496,16 +484,14 @@ printf "\n 2.1.4 \n"
 printf " Test case: Given reference region nr does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -R=16 plasma.bld blood.bld pet.tac 30 output.res &> stdout.txt
+$PROGRAM -R=16 plasma.bld blood.bld pet.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading '16'" "cannot find region"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -R=0 plasma.bld blood.bld pet.tac 30 output.res &> stdout.txt
+$PROGRAM -R=0 plasma.bld blood.bld pet.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading '0'" "cannot find region"
@@ -523,24 +509,21 @@ printf "# badfile\n" > badfile.dat
 printf "ugh banzai\n" >> badfile.dat
 printf "2 meh\n" >> badfile.dat
 
-rm -f stdout.txt
-$PROGRAM badfile.dat blood.bld pet.tac 30 output.res &> stdout.txt
+$PROGRAM badfile.dat blood.bld pet.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld badfile.dat pet.tac 30 output.res &> stdout.txt
+$PROGRAM plasma.bld badfile.dat pet.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld badfile.dat 30 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld badfile.dat 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
@@ -551,8 +534,7 @@ printf "\n 2.2.1 \n"
 printf " Test case: Invalid blood file contents. \n"
 printf " Expected result: No error if Vb=0. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Vb=0 plasma.bld badfile.dat pet_t2_long.tac 30 output.res &> stdout.txt
+$PROGRAM -Vb=0 plasma.bld badfile.dat pet_t2_long.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -561,8 +543,7 @@ printf "\n 2.2.2 \n"
 printf " Test case: Invalid ref file contents. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -r=badfile.dat plasma.bld blood.bld pet.tac 30 output.res &> stdout.txt
+$PROGRAM -r=badfile.dat plasma.bld blood.bld pet.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'badfile.dat'"
@@ -591,8 +572,8 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacadd blood_2_3_0.bld temp.bld
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt output.res
-$PROGRAM -Vb=4 plasma_2_3_0.bld blood_2_3_0.bld pet_t2_long.tac 60 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -Vb=4 plasma_2_3_0.bld blood_2_3_0.bld pet_t2_long.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "using only first TAC in plasma_2_3_0.bld"
@@ -617,8 +598,8 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacadd reftemp.tac pet_long.tac "tis 4"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt output.res
-$PROGRAM -r=reftemp.tac -rmod=2 plasma.bld blood.bld pet_t2_long.tac 30 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -r=reftemp.tac -rmod=2 plasma.bld blood.bld pet_t2_long.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "ref 1 selected of 2 reference regions."
@@ -646,24 +627,21 @@ printf "\n 2.4.0 \n"
 printf " Test case: Data file contains NaN. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma_na.bld blood.bld pet.tac 60 output.res &> stdout.txt
+$PROGRAM plasma_na.bld blood.bld pet.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s) in data"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood_na.bld pet.tac 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood_na.bld pet.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld pet_na.tac 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld pet_na.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s) in pet_na.tac"
@@ -678,24 +656,21 @@ printf "\n 2.5.0 \n"
 printf " Test case: Data file contains only 3 samples. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma_3.bld blood.bld pet.tac 60 output.res &> stdout.txt
+$PROGRAM plasma_3.bld blood.bld pet.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "plasma_3.bld contains too few samples"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood_3.bld pet.tac 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood_3.bld pet.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "blood_3.bld contains too few samples"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld pet_few.tac 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld pet_few.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too few samples in specified fit duration."
@@ -708,8 +683,7 @@ printf "\n 2.5.1 \n"
 printf " Test case: Blood file contains only 3 samples. \n"
 printf " Expected result: No error if Vb=0. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Vb=0 plasma.bld blood_3.bld pet_t2_long.tac 60 output.res &> stdout.txt
+$PROGRAM -Vb=0 plasma.bld blood_3.bld pet_t2_long.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -755,8 +729,7 @@ printf "\n 3.0.1 \n"
 printf " Test case: existing constraint file and option -lim=fname.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=output.par &> stdout.txt
+$PROGRAM -lim=output.par 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "parameter constraint file output.par exists."
@@ -768,8 +741,7 @@ printf "\n 3.0.2 \n"
 printf " Test case: trying to use nonexisting constraint file.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=nonexisting.par plasma.bld blood.bld pet_long.tac 60 output.res &> stdout.txt
+$PROGRAM -lim=nonexisting.par plasma.bld blood.bld pet_long.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.par'" "cannot open file"
@@ -781,8 +753,7 @@ printf "\n 3.0.3 \n"
 printf " Test case: trying to use constraint file with bad contents.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=badfile.dat plasma.bld blood.bld pet_long.tac 60 output.res &> stdout.txt
+$PROGRAM -lim=badfile.dat plasma.bld blood.bld pet_long.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'badfile.dat'" "file contains no data"
@@ -799,8 +770,7 @@ printf " Expected result: Limits are set correctly. \n\n"
 printf "K1_lower := 0.05\n"  > limit.par
 printf "K1_upper := 0.8\n" >> limit.par
 
-rm -f stdout.txt
-$PROGRAM -d4 -lim=limit.par plasma.bld blood.bld pet_t2_long.tac 20 output.res &> stdout.txt
+$PROGRAM -d4 -lim=limit.par plasma.bld blood.bld pet_t2_long.tac 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[0.05,0.8] [1e-05,10] [0,2] [0,10] [0,0.08]"
@@ -821,8 +791,7 @@ printf "k3k4_upper := 30.0\n" >> limit.par
 printf "Vb_lower := 0.02\n"  >> limit.par
 printf "Vb_upper := 0.06\n"  >> limit.par
 
-rm -f stdout.txt
-$PROGRAM -d4 -lim=limit.par plasma.bld blood.bld pet_t2_long.tac 20 output.res &> stdout.txt
+$PROGRAM -d4 -lim=limit.par plasma.bld blood.bld pet_t2_long.tac 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[0.05,0.8] [0.1,2] [0,3] [0,30] [0.02,0.06]"
@@ -834,8 +803,7 @@ printf "\n 3.2.0 \n"
 printf " Test case: option -Vb=0\n"
 printf " Expected result: Limits are set correctly. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=0 plasma.bld blood.bld pet_t2_long.tac 20 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=0 plasma.bld blood.bld pet_t2_long.tac 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[0,5] [1e-05,10] [0,2] [0,10] [0,0]"
@@ -847,8 +815,7 @@ printf "\n 3.2.1 \n"
 printf " Test case: option -Vb=4.5\n"
 printf " Expected result: Limits are set correctly. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=4.5 plasma.bld blood.bld pet_t2_long.tac 20 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=4.5 plasma.bld blood.bld pet_t2_long.tac 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[0,5] [1e-05,10] [0,2] [0,10] [0.045,0.045]"
@@ -860,8 +827,7 @@ printf "\n 3.2.2 \n"
 printf " Test case: option -Vb=0.045 by mistake\n"
 printf " Expected result: Warning. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=0.045 plasma.bld blood.bld pet_t2_long.tac 20 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=0.045 plasma.bld blood.bld pet_t2_long.tac 20 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "Vb was set to 0.045%"
@@ -881,8 +847,7 @@ printf "\n 4.0.0 \n"
 printf " Test case: by default weights are 1\n"
 printf " Expected result: correct weights are printed in test mode. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=4 plasma.bld blood.bld pet_t2_long.tac 999 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=4 plasma.bld blood.bld pet_t2_long.tac 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt common_data_weights "1, 1, 1, 1, 1, 1, 1, 1, 1"
@@ -897,8 +862,7 @@ cp -f pet_t2_long.tac temp.tac
 tacweigh -wf temp.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt
-$PROGRAM -d4 -Vb=4 plasma.bld blood.bld temp.tac 999 output.res &> stdout.txt
+$PROGRAM -d4 -Vb=4 plasma.bld blood.bld temp.tac 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt common_data_weights "0.05, 0.05, 0.2, 0.2, 0.5, 1, 1, 3, 3"
