@@ -371,8 +371,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -nonexistingoption plasma.bld blood.bld pet_pk5_t2_long.tac 30 output.res &> stdout.txt
+$PROGRAM -nonexistingoption plasma.bld blood.bld pet_pk5_t2_long.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-nonexistingoption'."
@@ -386,32 +385,28 @@ printf "\n 2.0.1 \n"
 printf " Test case: Missing filename. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  blood.bld pet_pk5_t2_long.tac 30 output.res &> stdout.txt
+$PROGRAM  blood.bld pet_pk5_t2_long.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  plasma.bld pet_pk5_t2_long.tac 30 output.res &> stdout.txt
+$PROGRAM  plasma.bld pet_pk5_t2_long.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld  30 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld  30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld pet_pk5_t2_long.tac 30  &> stdout.txt
+$PROGRAM plasma.bld blood.bld pet_pk5_t2_long.tac 30  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
@@ -425,24 +420,21 @@ printf "\n 2.1.0 \n"
 printf " Test case: Nonexisting data file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.dat blood.bld pet_pk5.tac 30 output.res &> stdout.txt
+$PROGRAM nonexistingfile.dat blood.bld pet_pk5.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld nonexistingfile.dat pet_pk5.tac 30 output.res &> stdout.txt
+$PROGRAM plasma.bld nonexistingfile.dat pet_pk5.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld nonexistingfile.dat 30 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld nonexistingfile.dat 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'nonexistingfile.dat': cannot open file"
@@ -454,8 +446,7 @@ printf "\n 2.1.1 \n"
 printf " Test case: Nonexisting blood file. \n"
 printf " Expected result: No error if Vb=0. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Vb=0 plasma.bld nonexistingfile.dat pet_pk5_t2_long.tac 30 output.res &> stdout.txt
+$PROGRAM -Vb=0 plasma.bld nonexistingfile.dat pet_pk5_t2_long.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -469,8 +460,7 @@ printf "\n 2.1.2 \n"
 printf " Test case: Nonexisting ref file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -R=nonexistingfile.dat plasma.bld blood.bld pet_pk5.tac 30 output.res &> stdout.txt
+$PROGRAM -R=nonexistingfile.dat plasma.bld blood.bld pet_pk5.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexistingfile.dat'" "cannot find region"
@@ -482,8 +472,7 @@ printf "\n 2.1.3 \n"
 printf " Test case: Given reference region name does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -r=stupid plasma.bld blood.bld pet_pk5.tac 30 output.res &> stdout.txt
+$PROGRAM -r=stupid plasma.bld blood.bld pet_pk5.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'stupid'" "cannot find region"
@@ -495,16 +484,14 @@ printf "\n 2.1.4 \n"
 printf " Test case: Given reference region nr does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -R=16 plasma.bld blood.bld pet_pk5.tac 30 output.res &> stdout.txt
+$PROGRAM -R=16 plasma.bld blood.bld pet_pk5.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading '16'" "cannot find region"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -R=0 plasma.bld blood.bld pet_pk5.tac 30 output.res &> stdout.txt
+$PROGRAM -R=0 plasma.bld blood.bld pet_pk5.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading '0'" "cannot find region"
@@ -523,24 +510,21 @@ printf "# badfile\n" > badfile.dat
 printf "ugh banzai\n" >> badfile.dat
 printf "2 meh\n" >> badfile.dat
 
-rm -f stdout.txt
-$PROGRAM badfile.dat blood.bld pet_pk5.tac 30 output.res &> stdout.txt
+$PROGRAM badfile.dat blood.bld pet_pk5.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld badfile.dat pet_pk5.tac 30 output.res &> stdout.txt
+$PROGRAM plasma.bld badfile.dat pet_pk5.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld badfile.dat 30 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld badfile.dat 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot read 'badfile.dat': wrong format"
@@ -551,8 +535,7 @@ printf "\n 2.2.1 \n"
 printf " Test case: Invalid blood file contents. \n"
 printf " Expected result: No error if Vb=0. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Vb=0 plasma.bld badfile.dat pet_pk5_t2_long.tac 30 output.res &> stdout.txt
+$PROGRAM -Vb=0 plasma.bld badfile.dat pet_pk5_t2_long.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -561,8 +544,7 @@ printf "\n 2.2.2 \n"
 printf " Test case: Invalid ref file contents. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -r=badfile.dat plasma.bld blood.bld pet_pk5.tac 30 output.res &> stdout.txt
+$PROGRAM -r=badfile.dat plasma.bld blood.bld pet_pk5.tac 30 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'badfile.dat'"
@@ -591,8 +573,8 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacadd blood_2_3_0.bld temp.bld
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt output.res
-$PROGRAM -lim=paral.lim plasma_2_3_0.bld blood_2_3_0.bld pet_pk5_t2_long.tac 90 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -lim=paral.lim plasma_2_3_0.bld blood_2_3_0.bld pet_pk5_t2_long.tac 90 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "using only first TAC in plasma_2_3_0.bld"
@@ -617,8 +599,8 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacadd reftemp.tac pet_pk5_long.tac "tis 4"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt output.res
-$PROGRAM -lim=paral.lim -r=reftemp.tac plasma.bld blood.bld pet_pk5_t2_long.tac 90 output.res &> stdout.txt
+rm -f output.res
+$PROGRAM -lim=paral.lim -r=reftemp.tac plasma.bld blood.bld pet_pk5_t2_long.tac 90 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "ref 1 selected of 2 reference regions."
@@ -649,24 +631,21 @@ printf "\n 2.4.0 \n"
 printf " Test case: Data file contains NaN. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma_na.bld blood.bld pet_pk5.tac 60 output.res &> stdout.txt
+$PROGRAM plasma_na.bld blood.bld pet_pk5.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s) in data"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood_na.bld pet_pk5.tac 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood_na.bld pet_pk5.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld pet_pk5_na.tac 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld pet_pk5_na.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing sample(s) in pet_pk5_na.tac"
@@ -682,24 +661,21 @@ printf "\n 2.5.0 \n"
 printf " Test case: Data file contains only 3 samples. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma_3.bld blood.bld pet_pk5.tac 60 output.res &> stdout.txt
+$PROGRAM plasma_3.bld blood.bld pet_pk5.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "plasma_3.bld contains too few samples"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood_3.bld pet_pk5.tac 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood_3.bld pet_pk5.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "blood_3.bld contains too few samples"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.bld blood.bld pet_pk5_few.tac 60 output.res &> stdout.txt
+$PROGRAM plasma.bld blood.bld pet_pk5_few.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too few samples in specified fit duration."
@@ -712,8 +688,7 @@ printf "\n 2.5.1 \n"
 printf " Test case: Blood file contains only 3 samples. \n"
 printf " Expected result: No error if Vb=0. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -Vb=0 plasma.bld blood_3.bld pet_pk5_t2_long.tac 60 output.res &> stdout.txt
+$PROGRAM -Vb=0 plasma.bld blood_3.bld pet_pk5_t2_long.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -764,8 +739,7 @@ printf "\n 3.0.1 \n"
 printf " Test case: existing constraint file and option -lim=fname.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=output.par &> stdout.txt
+$PROGRAM -lim=output.par 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "parameter constraint file output.par exists."
@@ -777,8 +751,7 @@ printf "\n 3.0.2 \n"
 printf " Test case: trying to use nonexisting constraint file.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=nonexisting.par plasma.bld blood.bld pet_pk5_long.tac 60 output.res &> stdout.txt
+$PROGRAM -lim=nonexisting.par plasma.bld blood.bld pet_pk5_long.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.par'" "cannot open file"
@@ -790,8 +763,7 @@ printf "\n 3.0.3 \n"
 printf " Test case: trying to use constraint file with bad contents.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=badfile.dat plasma.bld blood.bld pet_pk5_long.tac 60 output.res &> stdout.txt
+$PROGRAM -lim=badfile.dat plasma.bld blood.bld pet_pk5_long.tac 60 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'badfile.dat'" "file contains no data"
