@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_dft2img
-#: Date       : 2023-03-24
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,16 +11,17 @@ else
 EXT=;
 fi
 PROGRAM=../../dft2img$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "\nError: application file missing.\n\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
 printf "=====================================================================\n"
 
 # Check that required files exist
-if [ ! -f $PROGRAM ]; then
-  printf "\nError: application file missing.\n\n"
-  exit 1
-fi
 if [ ! -f plasma.dat ]; then
   printf "\nError: required file missing.\n\n"
   exit 1
@@ -102,8 +103,7 @@ printf "=====================================================================\n"
 
 printf "\n0.1.0 Unknown option\n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption origf.dft dynamic.img &> stdout.txt
+$PROGRAM -stupidoption origf.dft dynamic.img 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -114,8 +114,7 @@ printf "\n===================================================================\n"
 
 printf "\n0.2.0 Extra argument\n\n"
 
-rm -f stdout.txt
-$PROGRAM origf.dft dynamic.img dynamic.roi extra &> stdout.txt
+$PROGRAM origf.dft dynamic.img dynamic.roi extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
