@@ -240,17 +240,15 @@ printf "\n Detailed tests \n\n"
 printf "\n 2.0.0 \n"
 printf "  Fail if no arguments and options \n\n"
 
-rm -f stdout.txt
-$PROGRAM  &> stdout.txt
+$PROGRAM  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
 printf "\n 2.0.1 \n"
 printf "  Fail if invalid option \n\n"
 
-rm -f stdout.txt
 cp -f original.v test.v
-$PROGRAM -stupidoption test.v &> stdout.txt
+$PROGRAM -stupidoption test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -260,9 +258,8 @@ printf "\n Passed. \n\n"
 printf "\n 2.0.2 \n"
 printf "  Fail if extra argument \n\n"
 
-rm -f stdout.txt
 cp -f original.v test.v
-$PROGRAM test.v frames.lst extra &> stdout.txt
+$PROGRAM test.v frames.lst extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -276,24 +273,21 @@ printf "  option -sec and -min \n\n"
 
 cp -f original.v test.v
 
-rm -f stdout.txt
-$PROGRAM -d2 -sec test.v &> stdout.txt
+$PROGRAM -d2 -sec test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt SEC "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -min test.v &> stdout.txt
+$PROGRAM -d2 -min test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt SEC "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 test.v &> stdout.txt
+$PROGRAM -d2 test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt SEC "0"
@@ -305,8 +299,8 @@ printf "\n=================================================================\n\n"
 printf "\n 2.2.0 \n"
 printf "  ECAT filename not given \n\n"
 
-rm -f stdout.txt temp.sif
-$PROGRAM -d2 temp.sif &> stdout.txt
+rm -f temp.sif
+$PROGRAM -d2 temp.sif 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
@@ -314,16 +308,16 @@ printf "\n Passed. \n\n"
 printf "\n 2.2.1 \n"
 printf "  ECAT file does not exist \n\n"
 
-rm -f stdout.txt temp.sif
-$PROGRAM -d2 nonexisting.v temp.sif &> stdout.txt
+rm -f temp.sif
+$PROGRAM -d2 nonexisting.v temp.sif 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftisval stdout.txt "Error in reading nonexisting.v" "cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
 
-rm -f stdout.txt temp.sif
-$PROGRAM -d2 nonexisting.v  &> stdout.txt
+rm -f temp.sif
+$PROGRAM -d2 nonexisting.v  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftisval stdout.txt "Error in reading nonexisting.v" "cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -333,11 +327,10 @@ printf "\n Passed. \n\n"
 printf "\n 2.2.2 \n"
 printf "  ECAT file in wrong format \n\n"
 
-rm -f stdout.txt
 img2flat --silent original.v test.bin
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 test.bin  &> stdout.txt
+$PROGRAM -d2 test.bin  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
@@ -345,7 +338,7 @@ printf "\n Passed. \n\n"
 printf "\n 2.2.3 \n"
 printf "  Backup is made of original ECAT file \n\n"
 
-rm -f stdout.txt test.v.bak temp.sif
+rm -f test.v.bak temp.sif
 cp -f original.v test.v
 $PROGRAM test.v temp.sif
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -361,11 +354,11 @@ printf "\n Passed. \n\n"
 printf "\n 2.2.4 \n"
 printf "  ECAT image is not edited if operation fails \n\n"
 
-rm -f stdout.txt test.v.bak failing.fra
+rm -f test.v.bak
 echo 0 120 > failing.fra
 cp -f original.v test.v
 
-$PROGRAM test.v failing.fra &> stdout.txt
+$PROGRAM test.v failing.fra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ ! -f test.v ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -381,11 +374,11 @@ printf "\n---------------------------------------------------------------\n\n"
 printf "\n 2.3.0 \n"
 printf "  Frame file in wrong format \n\n"
 
-rm -f stdout.txt test.v.bak failing.fra
+rm -f test.v.bak failing.fra
 echo This is not a frame time file > failing.fra
 cp -f original.v test.v
 
-$PROGRAM test.v failing.fra &> stdout.txt
+$PROGRAM test.v failing.fra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ ! -f test.v ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -401,10 +394,10 @@ printf "\n Passed. \n\n"
 printf "\n 2.3.1 \n"
 printf "  Frame time file has start times and lengths in min \n\n"
 
-rm -f fine.fra temp.fra stdout.txt
+rm -f temp.fra
 echo 0 1 > fine.fra
 echo 1 4 >> fine.fra
-$PROGRAM test.v fine.fra &> stdout.txt
+$PROGRAM test.v fine.fra 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
@@ -418,10 +411,10 @@ printf "\n Passed. \n\n"
 printf "\n 2.3.2 \n"
 printf "  Frame time file has start times and lengths in sec \n\n"
 
-rm -f fine.fra temp.fra stdout.txt
+rm -f temp.fra
 echo 0 60 > fine.fra
 echo 60 240 >> fine.fra
-$PROGRAM -sec test.v fine.fra &> stdout.txt
+$PROGRAM -sec test.v fine.fra 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
@@ -437,12 +430,12 @@ printf "\n Passed. \n\n"
 printf "\n 2.3.3 \n"
 printf "  Frame time file has frame lengths in min \n\n"
 
-rm -f fine.fra fine1.fra temp.fra stdout.txt
+rm -f fine.fra fine1.fra temp.fra
 echo 1 > fine1.fra
 echo 4 >> fine1.fra
 echo 0 1 > fine.fra
 echo 1 4 >> fine.fra
-$PROGRAM test.v fine1.fra &> stdout.txt
+$PROGRAM test.v fine1.fra 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
@@ -456,12 +449,12 @@ printf "\n Passed. \n\n"
 printf "\n 2.3.4 \n"
 printf "  Frame time file has frame lengths in sec \n\n"
 
-rm -f fine2.fra temp.fra stdout.txt
+rm -f fine2.fra temp.fra
 echo 60 > fine2.fra
 echo 240 >> fine2.fra
 echo 0 60 > fine.fra
 echo 60 240 >> fine.fra
-$PROGRAM -sec test.v fine2.fra &> stdout.txt
+$PROGRAM -sec test.v fine2.fra 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n Passed. \n\n"
 
