@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_tacdecay
-#: Date       : 2019-09-02
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -53,9 +53,9 @@ printf "\n 0.1.0 \n"
 printf " Test case: Decay correction option not given. \n"
 printf " Expected result: Decay correction on by default. \n\n"
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 
-$PROGRAM -d -i=O-15 o15blood.kbq output.dft &> stdout.txt
+$PROGRAM -d -i=O-15 o15blood.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt correct 1
@@ -67,9 +67,9 @@ printf "\n 0.1.1 \n"
 printf " Test case: Decay correction option has invalid value. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 
-$PROGRAM -d -i=O-15 -decay=1 o15blood.kbq output.dft &> stdout.txt
+$PROGRAM -d -i=O-15 -decay=1 o15blood.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-decay=1'."
@@ -81,18 +81,18 @@ printf "\n 0.1.2 \n"
 printf " Test case: Decay correction option given. \n"
 printf " Expected result: Option interpreted correctly. \n\n"
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 
-$PROGRAM -d -i=O-15 -decay=off o15blood.kbq output.dft &> stdout.txt
+$PROGRAM -d -i=O-15 -decay=off o15blood.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt correct 0
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 
-$PROGRAM -d -i=O-15 -decay=on o15blood.kbq output.dft &> stdout.txt
+$PROGRAM -d -i=O-15 -decay=on o15blood.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt correct 1
@@ -105,10 +105,10 @@ printf "\n 0.2.0 \n"
 printf " Test case: Isotope code not given by user or in file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 cp -f o15blood.kbq temp.kbq
 
-$PROGRAM -decay=on temp.kbq output.dft &> stdout.txt
+$PROGRAM -decay=on temp.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "valid isotope not specified."
@@ -120,22 +120,22 @@ printf "\n 0.2.1 \n"
 printf " Test case: Isotope code not given by user but is in file. \n"
 printf " Expected result: Isotope code is correctly read from file. \n\n"
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 cp -f o15blood.kbq temp.kbq
 echo "# isotope := O-15" >> temp.kbq
 
-$PROGRAM -d -decay=on temp.kbq output.dft &> stdout.txt
+$PROGRAM -d -decay=on temp.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt isotope "O-15"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 cp -f o15blood.kbq temp.kbq
 echo "# isotope := C-11" >> temp.kbq
 
-$PROGRAM -d -decay=on temp.kbq output.dft &> stdout.txt
+$PROGRAM -d -decay=on temp.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt isotope "C-11"
@@ -143,11 +143,11 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 cp -f o15blood.kbq temp.kbq
 printf "# isotope := F-18" >> temp.kbq
 
-$PROGRAM -d -decay=on temp.kbq output.dft &> stdout.txt
+$PROGRAM -d -decay=on temp.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt isotope "F-18"
@@ -159,11 +159,11 @@ printf "\n 0.2.2 \n"
 printf " Test case: Isotope code not given by user and is invalid in file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 cp -f o15blood.kbq temp.kbq
 printf "# isotope := oxygen-25" >> temp.kbq
 
-$PROGRAM -d -decay=on temp.kbq output.dft &> stdout.txt
+$PROGRAM -d -decay=on temp.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -173,9 +173,9 @@ printf " Test case: Isotope code given by user, not in file. \n"
 printf " Expected result: Isotope code is correctly identified. \n\n"
 
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 
-$PROGRAM -d -decay=on -i=O-15 o15blood.kbq output.dft &> stdout.txt
+$PROGRAM -d -decay=on -i=O-15 o15blood.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt isotope "O-15"
@@ -183,9 +183,9 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 
-$PROGRAM -d -decay=on -i=C-11 o15blood.kbq output.dft &> stdout.txt
+$PROGRAM -d -decay=on -i=C-11 o15blood.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt isotope "C-11"
@@ -193,9 +193,9 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 
-$PROGRAM -d -decay=on -i=F-18 o15blood.kbq output.dft &> stdout.txt
+$PROGRAM -d -decay=on -i=F-18 o15blood.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt isotope "F-18"
@@ -208,11 +208,11 @@ printf " Test case: Isotope code given by user and is the same in file. \n"
 printf " Expected result: Isotope code is correctly identified. \n\n"
 
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 cp -f o15blood.kbq temp.kbq
 printf "# isotope := O-15" >> temp.kbq
 
-$PROGRAM -d -decay=on -i=O-15 temp.kbq output.dft &> stdout.txt
+$PROGRAM -d -decay=on -i=O-15 temp.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt isotope "O-15"
@@ -225,11 +225,11 @@ printf " Test case: Isotope code given by user and is different in file. \n"
 printf " Expected result: Error. \n\n"
 
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 cp -f o15blood.kbq temp.kbq
 printf "# isotope := F-18" >> temp.kbq
 
-$PROGRAM -d -decay=on -i=C-11 temp.kbq output.dft &> stdout.txt
+$PROGRAM -d -decay=on -i=C-11 temp.kbq output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "different isotope in temp.kbq"
@@ -289,9 +289,9 @@ printf "\n 1.1.0 \n"
 printf " Test case: Sample time unit unknown with isotope O-15. \n"
 printf " Expected result: assumed to be in sec. \n\n"
 
-rm -f output.kbq stdout.txt
+rm -f output.kbq
 
-$PROGRAM -d2 -decay=on -i=O-15 o15blood.kbq output.kbq &> stdout.txt
+$PROGRAM -d2 -decay=on -i=O-15 o15blood.kbq output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt xunit "sec"
@@ -303,9 +303,9 @@ printf "\n 1.1.1 \n"
 printf " Test case: Sample time unit unknown with isotope C-11. \n"
 printf " Expected result: assumed to be in min. \n\n"
 
-rm -f output.kbq stdout.txt
+rm -f output.kbq
 
-$PROGRAM -d2 -decay=on -i=C-11 o15blood.kbq output.kbq &> stdout.txt
+$PROGRAM -d2 -decay=on -i=C-11 o15blood.kbq output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt xunit "min"
@@ -317,7 +317,7 @@ printf "\n 1.1.2 \n"
 printf " Test case: Sample time unit given in the file. \n"
 printf " Expected result: min and sec are processed correctly. \n\n"
 
-rm -f output1.dft stdout.txt
+rm -f output1.dft
 
 $PROGRAM -decay=on -i=C-11 c11_min.dft output1.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -332,7 +332,7 @@ iftisval stdout.txt timeunit "min"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output2.dft stdout.txt
+rm -f output2.dft
 cp -f c11_min.dft c11_sec.dft
 tacunit -xconv=sec c11_sec.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -356,36 +356,36 @@ printf "\n 1.1.3 \n"
 printf " Test case: Sample time unit given by user. \n"
 printf " Expected result: min and sec are processed correctly. \n\n"
 
-rm -f output.kbq stdout.txt
+rm -f output.kbq
 
-$PROGRAM -d2 -decay=on -i=O-15 -sec o15blood.kbq output.kbq &> stdout.txt
+$PROGRAM -d2 -decay=on -i=O-15 -sec o15blood.kbq output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt xunit "sec"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.kbq stdout.txt
+rm -f output.kbq
 
-$PROGRAM -d2 -decay=on -i=O-15 -min o15blood.kbq output.kbq &> stdout.txt
+$PROGRAM -d2 -decay=on -i=O-15 -min o15blood.kbq output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt xunit "min"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.kbq stdout.txt
+rm -f output.kbq
 
-$PROGRAM -d2 -decay=on -i=C-11 -min o15blood.kbq output.kbq &> stdout.txt
+$PROGRAM -d2 -decay=on -i=C-11 -min o15blood.kbq output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt xunit "min"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.kbq stdout.txt
+rm -f output.kbq
 
-$PROGRAM -d2 -decay=on -i=C-11 -sec o15blood.kbq output.kbq &> stdout.txt
+$PROGRAM -d2 -decay=on -i=C-11 -sec o15blood.kbq output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt xunit "sec"
@@ -403,7 +403,7 @@ printf " Test case 1: Output filename not given. \n"
 printf " Test case 2: Output file contains decay correction information. \n"
 printf " Expected result: Input file is modified. \n\n"
 
-rm -f stdout.txt datafile.dft
+rm -f datafile.dft
 
 $PROGRAM -decay=on -i=F-18 f18_sec.dft datafile.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -518,12 +518,12 @@ printf "\n 4.0.0 \n"
 printf " Test case: Trying to do decay correction twice \n"
 printf " Expected result: Error, if file contains decay correction info. \n\n"
 
-rm -f datafile.dft stdout.txt
+rm -f datafile.dft
 
 $PROGRAM -decay=on -i=C-11 c11_min.dft datafile.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM -decay=on -i=C-11 datafile.dft &> stdout.txt
+$PROGRAM -decay=on -i=C-11 datafile.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "physical decay is already corrected in datafile.dft."
@@ -535,12 +535,10 @@ printf "\n 4.0.1 \n"
 printf " Test case: Trying to remove decay correction twice \n"
 printf " Expected result: Error, if file contains decay correction info. \n\n"
 
-rm -f stdout.txt
-
 $PROGRAM -decay=off datafile.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM -decay=off datafile.dft &> stdout.txt
+$PROGRAM -decay=off datafile.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "physical decay is not corrected in datafile.dft."
