@@ -416,6 +416,8 @@ int main(int argc, char **argv)
       if(verbose>1) printf("  ret := %d\n", ret);
       return(2);
     }
+    if(imgNaNs(&img, 1)>0)
+      if(verbose>0) fprintf(stderr, "Warning: missing pixel values.\n");
   }
   //printf("last x2 = %g\n", tac.x2[tac.frameNr-1]);
   /* Set time unit to min */
