@@ -28,9 +28,9 @@
 
 /*****************************************************************************/
 static char *info[] = {
-  "Estimation of rate constants K1 (perfusion), k2 and Va from dynamic",
+  "Estimation of rate constants K1 (perfusion), k2, and Va from dynamic",
   "radiowater PET image in ECAT 6.3, ECAT 7.x, NIfTI-1, or Analyze 7.5 file",
-  "format using. The two-compartment model equations",
+  "format using the two-compartment model equations",
   "  dCt(t)/dt = K1*Ca(t) - k2*Ct(t)",
   "  Croi(t) = Va*Ca(t) + Ct(t)",
   "are linearized (1) into equation",
