@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgbfbp
-#: Date       : 2017-06-06
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -12,6 +12,11 @@ EXT=;
 fi
 
 PROGRAM=../../imgbfbp$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -20,11 +25,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f plasma.dat ] || [ ! -f frames.dat ] || [ ! -f shortframes.dat ]; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -246,7 +246,7 @@ mv ana/dynamic.sif ana/dynamic.siiif
 rm -f stdout.txt
 rm -f ana/output.sif ana/output.hdr ana/output.img output_bp.dft
 
-$PROGRAM -min=0.009 -max=0.4 -thr=0 ana/dynamic refdynamic.tac ana/output &> stdout.txt
+$PROGRAM -min=0.009 -max=0.4 -thr=0 ana/dynamic refdynamic.tac ana/output 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 mv ana/dynamic.siiif ana/dynamic.sif
@@ -320,7 +320,7 @@ mv nii/dynamic.sif nii/dynamic.siiif
 rm -f stdout.txt
 rm -f nii/output.sif nii/output.nii output_bp.dft
 
-$PROGRAM -min=0.009 -max=0.4 -thr=0 nii/dynamic refdynamic.tac nii/output &> stdout.txt
+$PROGRAM -min=0.009 -max=0.4 -thr=0 nii/dynamic refdynamic.tac nii/output 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 mv nii/dynamic.siiif nii/dynamic.sif
@@ -337,7 +337,7 @@ printf " Test case 1: Option -end with large time. \n"
 printf " Test case 2: Weighting from separate SIF. \n"
 printf " Expected result: Correct results calculated. \n\n"
 
-rm -f output_bp.v output_bp.dft stdout.txt
+rm -f output_bp.v output_bp.dft
 
 $PROGRAM -end=999 -d3 -min=0.009 -max=0.4 -thr=0 dynamic.v refdynamic.tac output_bp.v dynamic.sif > stdout.txt
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -357,7 +357,7 @@ printf " Test case 1: Option -end with a bit shorter time than in the data. \n"
 printf " Test case 2: Weighting from separate SIF. \n"
 printf " Expected result: Correct results calculated. \n\n"
 
-rm -f output_bp.v output_bp.dft stdout.txt
+rm -f output_bp.v output_bp.dft
 
 $PROGRAM -end=100 -d3 -min=0.009 -max=0.4 -thr=0 dynamic.v refdynamic.tac output_bp.v dynamic.sif > stdout.txt
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -377,7 +377,7 @@ printf " Test case 1: Option -end with a lot shorter time than in the data. \n"
 printf " Test case 2: Weighting from separate SIF. \n"
 printf " Expected result: Correct results calculated. \n\n"
 
-rm -f output_bp.v output_bp.dft stdout.txt
+rm -f output_bp.v output_bp.dft
 
 $PROGRAM -end=60 -d3 -min=0.009 -max=0.4 -thr=0 dynamic.v refdynamic.tac output_bp.v dynamic.sif > stdout.txt
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -474,8 +474,7 @@ printf "\n 3.0.0 \n"
 printf " Test case: Invalid option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption dynamic.v refdynamic.tac output.v &> stdout.txt
+$PROGRAM -stupidoption dynamic.v refdynamic.tac output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -487,8 +486,7 @@ printf "\n 3.0.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v refdynamic.tac output.v dynamic.sif extra &> stdout.txt
+$PROGRAM dynamic.v refdynamic.tac output.v dynamic.sif extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -500,24 +498,21 @@ printf "\n 3.0.2 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM refdynamic.tac output.v  &> stdout.txt
+$PROGRAM refdynamic.tac output.v  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing command-line argument; use option --help"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM refdynamic.tac output.v dynamic.sif &> stdout.txt
+$PROGRAM refdynamic.tac output.v dynamic.sif 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing command-line argument; use option --help"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v output.v dynamic.sif &> stdout.txt
+$PROGRAM dynamic.v output.v dynamic.sif 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing command-line argument; use option --help"
@@ -531,24 +526,21 @@ printf "\n 3.1.0 \n"
 printf " Test case: Input file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.v refdynamic.tac output.v &> stdout.txt
+$PROGRAM nonexistingfile.v refdynamic.tac output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v nonexistingfile.tac output.v &> stdout.txt
+$PROGRAM dynamic.v nonexistingfile.tac output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v refdynamic.tac output.v nonexistingfile.sif &> stdout.txt
+$PROGRAM dynamic.v refdynamic.tac output.v nonexistingfile.sif 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
