@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgbfh2o
-#: Date       : 2018-03-22
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -12,6 +12,11 @@ EXT=;
 fi
 
 PROGRAM=../../imgbfh2o$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -20,11 +25,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f blood.dat ] || [ ! -f frames.dat ]; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -457,9 +457,9 @@ printf " Expected result: Error. \n\n"
 
 taccut blood.dat 0 240 test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-rm -f flow.v stdout.txt
+rm -f flow.v
 
-$PROGRAM -fmax=0.5 test.dat lowmid.v 360 flow.v &> stdout.txt
+$PROGRAM -fmax=0.5 test.dat lowmid.v 360 flow.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftlist stdout.txt error
 printf "\n passed. \n\n"
@@ -472,9 +472,9 @@ printf " Expected result: Results are close to correct. \n\n"
 
 taccut blood.dat 0 240 test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-rm -f flow.v stdout.txt output.ift
+rm -f flow.v output.ift
 
-$PROGRAM -d2 -fmin=0.2 -fmax=5 test.dat midhigh.v 240 flow.v &> stdout.txt
+$PROGRAM -d2 -fmin=0.2 -fmax=5 test.dat midhigh.v 240 flow.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmax -both --verbose flow.v
@@ -524,7 +524,7 @@ tacunit -xconv=min test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 rm -f flow.v stdout.txt
 
-$PROGRAM -d -fmax=0.5 test.dat lowmid.v 9999 flow.v &> stdout.txt
+$PROGRAM -d -fmax=0.5 test.dat lowmid.v 9999 flow.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmatch -abs=0.0001 -rel=1 -header=n correct_lowmid_flow.v flow.v
@@ -540,8 +540,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: Invalid option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption blood.dat lowmid.v 9999 flow.v &> stdout.txt
+$PROGRAM -stupidoption blood.dat lowmid.v 9999 flow.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -552,8 +551,7 @@ printf "\n 2.0.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat lowmid.v 9999 flow.v extra &> stdout.txt
+$PROGRAM blood.dat lowmid.v 9999 flow.v extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -564,24 +562,21 @@ printf "\n 2.0.2 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  lowmid.v 9999 flow.v &> stdout.txt
+$PROGRAM  lowmid.v 9999 flow.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat  9999 flow.v &> stdout.txt
+$PROGRAM blood.dat  9999 flow.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat lowmid.v 9999  &> stdout.txt
+$PROGRAM blood.dat lowmid.v 9999  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing command-line argument; use option --help"
@@ -595,16 +590,14 @@ printf "\n 2.1.0 \n"
 printf " Test case: Input file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.bld lowmid.v 9999 flow.v &> stdout.txt
+$PROGRAM nonexistingfile.bld lowmid.v 9999 flow.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat nonexistingfile.v 9999 flow.v &> stdout.txt
+$PROGRAM blood.dat nonexistingfile.v 9999 flow.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
