@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgbfh2om
-#: Date       : 2023-03-22
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -450,7 +450,7 @@ taccut blood.dat 0 240 test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 rm -f flow.nii stdout.txt
 
-$PROGRAM -fmax=0.5 test.dat lowmid.nii 360 flow.nii &> stdout.txt
+$PROGRAM -fmax=0.5 test.dat lowmid.nii 360 flow.nii 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftlist stdout.txt error
 printf "\n passed. \n\n"
@@ -463,9 +463,9 @@ printf " Expected result: Results are close to correct. \n\n"
 
 taccut blood.dat 0 240 test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-rm -f flow.nii stdout.txt output.ift
+rm -f flow.nii output.ift
 
-$PROGRAM -d2 -fmin=0.2 -fmax=5 test.dat midhigh.nii 240 flow.nii &> stdout.txt
+$PROGRAM -d2 -fmin=0.2 -fmax=5 test.dat midhigh.nii 240 flow.nii 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmax -both --verbose flow.nii
@@ -515,7 +515,7 @@ tacunit -xconv=min test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 rm -f flow.nii stdout.txt
 
-$PROGRAM -d -fmax=0.5 test.dat lowmid.nii 9999 flow.nii &> stdout.txt
+$PROGRAM -d -fmax=0.5 test.dat lowmid.nii 9999 flow.nii 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmatch -abs=0.0001 -rel=1 -header=n -frames=n correct_lowmid_flow.nii flow.nii
@@ -531,8 +531,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: Invalid option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption blood.dat lowmid.nii 9999 flow.nii &> stdout.txt
+$PROGRAM -stupidoption blood.dat lowmid.nii 9999 flow.nii 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -543,8 +542,7 @@ printf "\n 2.0.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat lowmid.nii 9999 flow.nii extra &> stdout.txt
+$PROGRAM blood.dat lowmid.nii 9999 flow.nii extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -555,24 +553,21 @@ printf "\n 2.0.2 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  lowmid.nii 9999 flow.nii &> stdout.txt
+$PROGRAM  lowmid.nii 9999 flow.nii 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat  9999 flow.nii &> stdout.txt
+$PROGRAM blood.dat  9999 flow.nii 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat lowmid.nii 9999  &> stdout.txt
+$PROGRAM blood.dat lowmid.nii 9999  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing command-line argument; use option --help"
@@ -586,16 +581,14 @@ printf "\n 2.1.0 \n"
 printf " Test case: Input file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.bld lowmid.nii 9999 flow.nii &> stdout.txt
+$PROGRAM nonexistingfile.bld lowmid.nii 9999 flow.nii 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat nonexistingfile.nii 9999 flow.nii &> stdout.txt
+$PROGRAM blood.dat nonexistingfile.nii 9999 flow.nii 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
