@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgflow
-#: Date       : 2023-03-26
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -12,6 +12,11 @@ EXT=;
 fi
 
 PROGRAM=../../imgflow$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -20,11 +25,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f blood.dat ] || [ ! -f frames.sif ]; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -491,7 +491,7 @@ printf "\n 1.4.0 \n"
 printf " Test case: Option -max. \n"
 printf " Expected result: Resulting flow values do not exceed specified max. \n\n"
 
-rm -f flow.v stdout.txt
+rm -f flow.v
 
 $PROGRAM -thr=0 -max=0.041 blood.dat lowmid.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -509,7 +509,7 @@ printf "\n 1.4.1 \n"
 printf " Test case: Option -max with option -dL. \n"
 printf " Expected result: Resulting flow values do not exceed specified max. \n\n"
 
-rm -f flow.v stdout.txt
+rm -f flow.v
 
 $PROGRAM -thr=0 -dL -max=4.1 blood.dat lowmid.v flow.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -550,7 +550,7 @@ taccut blood.dat 0 240 test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 rm -f flow.v stdout.txt
 
-$PROGRAM -thr=0 -end=360 test.dat lowmid.v flow.v &> stdout.txt
+$PROGRAM -thr=0 -end=360 test.dat lowmid.v flow.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftlist stdout.txt error
 printf "\n passed. \n\n"
@@ -565,7 +565,7 @@ taccut blood.dat 0 240 test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 rm -f flow.v stdout.txt output.ift
 
-$PROGRAM -d2 -thr=0 -end=240 test.dat midhigh.v flow.v &> stdout.txt
+$PROGRAM -d2 -thr=0 -end=240 test.dat midhigh.v flow.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmax -both --verbose flow.v
@@ -614,7 +614,7 @@ tacunit -xconv=min test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 rm -f flow.v stdout.txt
 
-$PROGRAM -d -thr=0 test.dat lowmid.v flow.v &> stdout.txt
+$PROGRAM -d -thr=0 test.dat lowmid.v flow.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmatch -abs=0.0001 -rel=1 -header=n correct_lowmid_flow.v flow.v
@@ -628,7 +628,7 @@ printf " Expected result: Correct results are saved. \n\n"
 
 rm -f flow.nii stdout.txt
 
-$PROGRAM -d -thr=0 test.dat lowmid.nii flow.nii &> stdout.txt
+$PROGRAM -d -thr=0 test.dat lowmid.nii flow.nii 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 imgmatch -abs=0.0001 -rel=1 -header=n -frames=n correct_lowmid_flow.nii flow.nii
@@ -679,8 +679,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: Invalid option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption blood.dat lowmid.v flow.v &> stdout.txt
+$PROGRAM -stupidoption blood.dat lowmid.v flow.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -691,8 +690,7 @@ printf "\n 2.0.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat lowmid.v flow.v extra &> stdout.txt
+$PROGRAM blood.dat lowmid.v flow.v extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -703,24 +701,21 @@ printf "\n 2.0.2 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  lowmid.v flow.v &> stdout.txt
+$PROGRAM  lowmid.v flow.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat  flow.v &> stdout.txt
+$PROGRAM blood.dat  flow.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat lowmid.v  &> stdout.txt
+$PROGRAM blood.dat lowmid.v  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing command-line argument; use option --help"
@@ -734,16 +729,14 @@ printf "\n 2.1.0 \n"
 printf " Test case: Input file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.bld lowmid.v flow.v &> stdout.txt
+$PROGRAM nonexistingfile.bld lowmid.v flow.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM blood.dat nonexistingfile.v flow.v &> stdout.txt
+$PROGRAM blood.dat nonexistingfile.v flow.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
