@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgsrtm
-#: Date       : 2016-08-18
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -12,6 +12,11 @@ EXT=;
 fi
 
 PROGRAM=../../imgsrtm$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -20,11 +25,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 
 
 if [ ! -f plasma.dat ] || [ ! -f frames.dat ] || [ ! -f shortframes.dat ]; then
@@ -227,7 +227,7 @@ mv ana/dynamic.sif ana/dynamic.siiif
 rm -f stdout.txt
 rm -f ana/output.sif ana/output.hdr ana/output.img output_bp.dft
 
-$PROGRAM -thr=0 ana/dynamic refdynamic.tac ana/output &> stdout.txt
+$PROGRAM -thr=0 ana/dynamic refdynamic.tac ana/output 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 mv ana/dynamic.siiif ana/dynamic.sif
@@ -266,7 +266,7 @@ mv nii/dynamic.sif nii/dynamic.siiif
 rm -f stdout.txt
 rm -f nii/output.sif nii/output.nii output_bp.dft
 
-$PROGRAM -thr=0 nii/dynamic refdynamic.tac nii/output &> stdout.txt
+$PROGRAM -thr=0 nii/dynamic refdynamic.tac nii/output 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 mv nii/dynamic.siiif nii/dynamic.sif
@@ -283,7 +283,7 @@ printf "\n 2.0.0 \n"
 printf " Test case 1: Option -end with large time. \n"
 printf " Expected result: Correct results calculated. \n\n"
 
-rm -f output_bp.v output_bp.dft stdout.txt
+rm -f output_bp.v output_bp.dft
 
 $PROGRAM -end=999 -d3 -thr=0 dynamic.v refdynamic.tac output_bp.v > stdout.txt
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -302,7 +302,7 @@ printf "\n 2.0.1 \n"
 printf " Test case 1: Option -end with a bit shorter time than in the data. \n"
 printf " Expected result: Correct results calculated. \n\n"
 
-rm -f output_bp.v output_bp.dft stdout.txt
+rm -f output_bp.v output_bp.dft
 
 $PROGRAM -end=100 -d3 -thr=0 dynamic.v refdynamic.tac output_bp.v > stdout.txt
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -321,7 +321,7 @@ printf "\n 2.0.2 \n"
 printf " Test case 1: Option -end with a lot shorter time than in the data. \n"
 printf " Expected result: Correct results calculated. \n\n"
 
-rm -f output_bp.v output_bp.dft stdout.txt
+rm -f output_bp.v output_bp.dft
 
 $PROGRAM -end=60 -d3 -thr=0 dynamic.v refdynamic.tac output_bp.v > stdout.txt
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -348,7 +348,7 @@ printf "\n 2.1.0 \n"
 printf " Test case: Option -dvr. \n"
 printf " Expected result: Correct results calculated. \n\n"
 
-rm -f output_dvr.v output_dvr.dft stdout.txt
+rm -f output_dvr.v output_dvr.dft
 taccalc correct_bp.dft + 1 temp.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
@@ -512,8 +512,7 @@ printf "\n 3.0.0 \n"
 printf " Test case: Invalid option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption dynamic.v refdynamic.tac output.v &> stdout.txt
+$PROGRAM -stupidoption dynamic.v refdynamic.tac output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -525,8 +524,7 @@ printf "\n 3.0.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v refdynamic.tac output.v extra &> stdout.txt
+$PROGRAM dynamic.v refdynamic.tac output.v extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -538,24 +536,21 @@ printf "\n 3.0.2 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM refdynamic.tac output.v  &> stdout.txt
+$PROGRAM refdynamic.tac output.v  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing command-line argument; use option --help"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v output.v &> stdout.txt
+$PROGRAM dynamic.v output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing command-line argument; use option --help"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v refdynamic.tac  &> stdout.txt
+$PROGRAM dynamic.v refdynamic.tac  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing command-line argument; use option --help"
@@ -569,16 +564,14 @@ printf "\n 3.1.0 \n"
 printf " Test case: Input file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.v refdynamic.tac output.v &> stdout.txt
+$PROGRAM nonexistingfile.v refdynamic.tac output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v nonexistingfile.tac output.v &> stdout.txt
+$PROGRAM dynamic.v nonexistingfile.tac output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
