@@ -155,8 +155,7 @@ int main(int argc, char **argv)
     return(1);
   }
   if(maxpix>0) {
-    if(calcsum>0) 
-      fprintf(stderr, "Warning: options -sum and -cps ignored.\n");
+    if(calcsum>0) fprintf(stderr, "Warning: options -sum and -cps ignored.\n");
     calcsum=0;
   }
 
@@ -185,6 +184,8 @@ int main(int argc, char **argv)
     if(verbose>1) printf("ret=%d\n", ret);
     imgEmpty(&img); return(2);
   }
+  if(imgNaNs(&img, 1)>0)
+    if(verbose>0) fprintf(stderr, "Warning: missing pixel values.\n");
 
   /* For raw data, divide counts by frame duration */
   ret=imgRawCountsPerTime(&img, 1);
