@@ -397,6 +397,8 @@ int main(int argc, char **argv)
     fprintf(stderr, "Error: method works only for dynamic data.\n");
     imgEmpty(&img); return(2);
   }
+  if(imgNaNs(&img, 1)>0)
+    if(verbose>0) fprintf(stderr, "Warning: missing pixel values.\n");
   /* Check that frame times are available */
   if(!imgExistentTimes(&img)) {
     if(img.dimt>1) fprintf(stderr, "Warning: unknown frame times.\n");
