@@ -199,6 +199,8 @@ int main(int argc, char **argv)
     fprintf(stderr, "Error: image is not dynamic.\n");
     imgEmpty(&img); return(2);
   }
+  if(imgNaNs(&img, 1)>0)
+    if(verbose>0) fprintf(stderr, "Warning: missing pixel values.\n");
   /* Check that frame times are available */
   if(!imgExistentTimes(&img)) {
     fprintf(stderr, "Error: image does not contain frame times.\n");
