@@ -488,6 +488,8 @@ int main(int argc, char **argv)
     fprintf(stderr, "Error: %s is not an image.\n", petfile);
     imgEmpty(&img); return(2);
   }
+  if(imgNaNs(&img, 1)>0)
+    if(verbose>0) fprintf(stderr, "Warning: missing pixel values.\n");
 
   /*
    *  Convert FWHM into pixel units, if necessary
