@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_flat2img
-#: Date       : 2018-10-23
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,17 +11,17 @@ else
 EXT=;
 fi
 PROGRAM=../../flat2img$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "\nError: application file missing.\n\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
 printf "=====================================================================\n"
 
 # Check that required files exist
-if [ ! -f $PROGRAM ]; then
-  printf "\nError: application file missing.\n\n"
-  exit 1
-fi
-
 if [ ! -f original.dat ]; then
   printf "\nError: required file missing.\n\n"
   exit 1
@@ -115,8 +115,7 @@ printf "\n 1.0.0 option -bins \n\n"
 
 printf "\n without option \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 image1.bin image1.v 1 1 40 40 &> stdout.txt
+$PROGRAM -d2 image1.bin image1.v 1 1 40 40 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt binNr "40"
@@ -125,8 +124,7 @@ printf "\n passed. \n\n"
 
 printf "\n error with image \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -bins=192 image1.bin image1.v 1 1 40 40 &> stdout.txt
+$PROGRAM -d2 -bins=192 image1.bin image1.v 1 1 40 40 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "bin nr can be used only with sinograms."
@@ -135,8 +133,7 @@ printf "\n passed. \n\n"
 
 printf "\n binNr too small \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -bins=19 scan1.bin scan1.scn 2 3 29 40 &> stdout.txt
+$PROGRAM -d2 -bins=19 scan1.bin scan1.scn 2 3 29 40 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "binNr should be larger than dimx."
@@ -146,13 +143,12 @@ printf "\n passed. \n\n"
 
 printf "\n binNr is ok with ECAT6 2D sinogram \n\n"
 
-rm -f stdout.txt scan1.scn scan2.scn
-$PROGRAM -d2 scan2.bin scan2.scn 2 3 35 40 &> stdout.txt
+rm -f scan1.scn scan2.scn
+$PROGRAM -d2 scan2.bin scan2.scn 2 3 35 40 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -bins=35 scan1.bin scan1.scn 2 3 29 40 &> stdout.txt
+$PROGRAM -d2 -bins=35 scan1.bin scan1.scn 2 3 29 40 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt dimx 35
@@ -167,12 +163,11 @@ printf "\n passed. \n\n"
 
 printf "\n binNr is ok with Ecat7 3D sinogram \n\n"
 
-rm -f stdout.txt scan1.s scan2.s
-$PROGRAM -d2 scan2.bin scan2.s 2 3 35 40 &> stdout.txt
+rm -f scan1.s scan2.s
+$PROGRAM -d2 scan2.bin scan2.s 2 3 35 40 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
 $PROGRAM -d2 -bins=35 scan1.bin scan1.s 2 3 29 40 > stdout.txt
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
@@ -189,8 +184,8 @@ printf "\n passed. \n\n"
 
 printf "\n bin_nr is now even (previously odd): ok \n\n"
 
-rm -f stdout.txt scan1.s
-$PROGRAM -d2 -bins=34 scan1.bin scan1.s 3 2 29 40 &> stdout.txt
+rm -f scan1.s
+$PROGRAM -d2 -bins=34 scan1.bin scan1.s 3 2 29 40 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt dimx 34
@@ -207,8 +202,7 @@ printf "\n 1.1.0 option -scanner \n\n"
 
 printf "\n without option \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 image2.bin image2.v 5 2 5 5 &> stdout.txt
+$PROGRAM -d2 image2.bin image2.v 5 2 5 5 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt scanner_type "0"
@@ -216,8 +210,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 printf "\n invalid scanner \n\n"
-rm -f stdout.txt
-$PROGRAM -d2 -scanner=stupid image2.bin image2.v 5 2 5 5 &> stdout.txt
+$PROGRAM -d2 -scanner=stupid image2.bin image2.v 5 2 5 5 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt  Error "invalid option '-scanner=stupid'"
@@ -226,8 +219,8 @@ printf "\n passed. \n\n"
 
 printf "\n set scanner to GE Advance \n\n"
 
-rm -f stdout.txt image2.v mhdr.txt
-$PROGRAM -d2 -scanner=Advance image2.bin image2.v 2 5 5 5 &> stdout.txt
+rm -f image2.v mhdr.txt
+$PROGRAM -d2 -scanner=Advance image2.bin image2.v 2 5 5 5 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt scanner_type "12096"
@@ -244,8 +237,8 @@ printf "\n passed. \n\n"
 
 printf "\n the same but with sinogram \n\n"
 
-rm -f stdout.txt scan1.scn mhdr.txt
-$PROGRAM -d2 -scanner=Advance scan1.bin scan1.scn 3 2 29 40 &> stdout.txt
+rm -f scan1.scn mhdr.txt
+$PROGRAM -d2 -scanner=Advance scan1.bin scan1.scn 3 2 29 40 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt scanner_type "12096"
@@ -263,8 +256,8 @@ printf "\n passed. \n\n"
 
 printf "\n set scanner to CTI ECAT 931 \n\n"
 
-rm -f stdout.txt image2.v mhdr.txt
-$PROGRAM -d2 -scanner=931 image2.bin image2.v 2 5 5 5 &> stdout.txt
+rm -f image2.v mhdr.txt
+$PROGRAM -d2 -scanner=931 image2.bin image2.v 2 5 5 5 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt scanner_type "12"
@@ -281,8 +274,8 @@ printf "\n passed. \n\n"
 
 printf "\n the same but with sinogram \n\n"
 
-rm -f stdout.txt scan1.scn mhdr.txt
-$PROGRAM -d2 -scanner=931 scan1.bin scan1.scn 3 2 29 40 &> stdout.txt
+rm -f scan1.scn mhdr.txt
+$PROGRAM -d2 -scanner=931 scan1.bin scan1.scn 3 2 29 40 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt scanner_type "12"
@@ -300,8 +293,8 @@ printf "\n passed. \n\n"
 
 printf "\n set scanner to HR+ \n\n"
 
-rm -f stdout.txt image2.i mhdr.txt
-$PROGRAM -d2 -scanner=HR+ image2.bin image2.v 2 5 5 5 &> stdout.txt
+rm -f image2.i mhdr.txt
+$PROGRAM -d2 -scanner=HR+ image2.bin image2.v 2 5 5 5 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt scanner_type "3"
@@ -317,8 +310,8 @@ printf "\n passed. \n\n"
 
 printf "\n the same but with sinogram \n\n"
 
-rm -f stdout.txt scan1.s mhdr.txt
-$PROGRAM -d2 -scanner=HR+ scan1.bin scan1.s 3 2 29 40 &> stdout.txt
+rm -f scan1.s mhdr.txt
+$PROGRAM -d2 -scanner=HR+ scan1.bin scan1.s 3 2 29 40 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt scanner_type "3"
@@ -336,8 +329,8 @@ printf "\n passed. \n\n"
 
 printf "\n set scanner to HRRT \n\n"
 
-rm -f stdout.txt image2.v mhdr.txt
-$PROGRAM -d2 -scanner=HRRT image2.bin image2.v 2 5 5 5 &> stdout.txt
+rm -f image2.v mhdr.txt
+$PROGRAM -d2 -scanner=HRRT image2.bin image2.v 2 5 5 5 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt scanner_type "4"
@@ -353,8 +346,8 @@ printf "\n passed. \n\n"
 
 printf "\n the same but with sinogram \n\n"
 
-rm -f stdout.txt scan1.s mhdr.txt
-$PROGRAM -d2 -scanner=HRRT scan1.bin scan1.s 3 2 29 40 &> stdout.txt
+rm -f scan1.s mhdr.txt
+$PROGRAM -d2 -scanner=HRRT scan1.bin scan1.s 3 2 29 40 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt scanner_type "4"
@@ -376,8 +369,7 @@ printf "\n 1.2.0 option -zoom \n\n"
 
 printf "\n without option \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 image2.bin image2.v 5 2 5 5 &> stdout.txt
+$PROGRAM -d2 image2.bin image2.v 5 2 5 5 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt zoom "1"
@@ -386,24 +378,21 @@ printf "\n passed. \n\n"
 
 printf "\n invalid zoom \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -zoom=Zoom image2.bin image2.v 5 2 5 5 &> stdout.txt
+$PROGRAM -d2 -zoom=Zoom image2.bin image2.v 5 2 5 5 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt  Error "invalid option '-zoom=Zoom'"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -zoom=-2 image2.bin image2.v 5 2 5 5 &> stdout.txt
+$PROGRAM -d2 -zoom=-2 image2.bin image2.v 5 2 5 5 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt  Error "invalid option '-zoom=-2'"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -zoom=0 image2.bin image2.v 5 2 5 5 &> stdout.txt
+$PROGRAM -d2 -zoom=0 image2.bin image2.v 5 2 5 5 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt  Error "invalid option '-zoom=0'"
@@ -412,8 +401,8 @@ printf "\n passed. \n\n"
 
 
 printf "\n zoom ok with image \n\n"
-rm -f stdout.txt image2.v lshdr.txt
-$PROGRAM -d2 -zoom=1.5 image2.bin image2.v 5 2 5 5 &> stdout.txt
+rm -f image2.v lshdr.txt
+$PROGRAM -d2 -zoom=1.5 image2.bin image2.v 5 2 5 5 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt zoom "1.5"
@@ -433,8 +422,8 @@ printf "\n 1.3.0 option -zero \n\n"
 
 printf "\n without option \n\n"
 
-rm -f stdout.txt image3.v
-$PROGRAM -d2 image3.bin image3.v 1 1 80 80 &> stdout.txt
+rm -f image3.v
+$PROGRAM -d2 image3.bin image3.v 1 1 80 80 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt fov_corr "0"
@@ -443,8 +432,8 @@ printf "\n passed. \n\n"
 
 printf "\n option fails with sinogram \n\n"
 
-rm -f stdout.txt scan1.s
-$PROGRAM -d2 -zero scan1.bin scan1.s 3 2 29 40 &> stdout.txt
+rm -f scan1.s
+$PROGRAM -d2 -zero scan1.bin scan1.s 3 2 29 40 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "option -zero is available only for images."
@@ -454,8 +443,8 @@ printf "\n passed. \n\n"
 
 printf "\n option works with image \n\n"
 
-rm -f stdout.txt image3z.v
-$PROGRAM -d2 -zero -scanner=HR+ image3.bin image3z.v 1 1 80 80 &> stdout.txt
+rm -f image3z.v
+$PROGRAM -d2 -zero -scanner=HR+ image3.bin image3z.v 1 1 80 80 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 img2tif -rb image3z.v image3z.tif
@@ -477,8 +466,8 @@ printf "\n 1.4.0 option -mif \n\n"
 
 printf "\n without option ok if given as arguments \n\n"
 
-rm -f stdout.txt image2.v
-$PROGRAM -d2 image2.bin image2.v 2 5 5 5 &> stdout.txt
+rm -f image2.v
+$PROGRAM -d2 image2.bin image2.v 2 5 5 5 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt planeNr "2"
@@ -497,8 +486,8 @@ printf "\n passed. \n\n"
 
 printf "\n fails without option and arguments \n\n"
 
-rm -f stdout.txt image2.v
-$PROGRAM -d2 image2.bin image2.v  &> stdout.txt
+rm -f image2.v
+$PROGRAM -d2 image2.bin image2.v  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing/invalid data size argument."
@@ -508,8 +497,8 @@ printf "\n passed. \n\n"
 
 printf "\n fails if both option and arguments \n\n"
 
-rm -f stdout.txt image2.v
-$PROGRAM -d2 -mif=image2.inf image2.bin image2.v 5 2 5 5 &> stdout.txt
+rm -f image2.v
+$PROGRAM -d2 -mif=image2.inf image2.bin image2.v 5 2 5 5 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too many arguments."
@@ -519,8 +508,8 @@ printf "\n passed. \n\n"
 
 printf "\n fails if file does not exist \n\n"
 
-rm -f stdout.txt image2.v
-$PROGRAM -d2 -mif=nonexisting.fil image2.bin image2.v  &> stdout.txt
+rm -f image2.v
+$PROGRAM -d2 -mif=nonexisting.fil image2.bin image2.v  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid matrix information file."
@@ -529,8 +518,8 @@ printf "\n passed. \n\n"
 
 printf "\n fails if file has stupid contents \n\n"
 
-rm -f stdout.txt image2.v
-$PROGRAM -d2 -mif=image2.bin image2.bin image2.v  &> stdout.txt
+rm -f image2.v
+$PROGRAM -d2 -mif=image2.bin image2.bin image2.v  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid matrix information file."
@@ -545,8 +534,8 @@ printf "\n 1.5.0 transpose option \n\n"
 
 printf "\n without option \n\n"
 
-rm -f stdout.txt image2.v
-$PROGRAM -d2 -mif=image2.inf image2.bin image2.v  &> stdout.txt
+rm -f image2.v
+$PROGRAM -d2 -mif=image2.inf image2.bin image2.v  1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt transpose "0"
@@ -558,8 +547,8 @@ printf "\n passed. \n\n"
 
 printf "\n with option \n\n"
 
-rm -f stdout.txt image2_transposed.v
-$PROGRAM -d2 -transpose -mif=image2.inf image2.bin image2_transposed.v  &> stdout.txt
+rm -f image2_transposed.v
+$PROGRAM -d2 -transpose -mif=image2.inf image2.bin image2_transposed.v  1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt transpose "1"
@@ -580,8 +569,8 @@ printf "\n 1.6.0 option to switch byte order \n\n"
 
 printf "\n without option \n\n"
 
-rm -f stdout.txt image2.v
-$PROGRAM -d2 -mif=image2.inf image2.bin image2.v  &> stdout.txt
+rm -f image2.v
+$PROGRAM -d2 -mif=image2.inf image2.bin image2.v  1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt change_endian "0"
@@ -590,11 +579,11 @@ printf "\n passed. \n\n"
 
 printf "\n with option \n\n"
 
-rm -f stdout.txt image2e.v temp.bin
+rm -f image2e.v temp.bin
 convend float image2.bin temp.bin
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM -d2 -e -mif=image2.inf temp.bin image2e.v  &> stdout.txt
+$PROGRAM -d2 -e -mif=image2.inf temp.bin image2e.v  1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt change_endian "1"
@@ -628,16 +617,16 @@ printf "\n passed. \n\n"
 
 printf "\n 2.1.0 input file not given \n\n"
 
-rm -f stdout.txt image2.v
-$PROGRAM -mif=image2.inf image2.v &> stdout.txt
+rm -f image2.v
+$PROGRAM -mif=image2.inf image2.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing command-line argument; use option --help"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt image2.v
-$PROGRAM image2.v 5 2 5 5 &> stdout.txt
+rm -f image2.v
+$PROGRAM image2.v 5 2 5 5 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing/invalid data size argument."
@@ -646,8 +635,8 @@ printf "\n passed. \n\n"
 
 printf "\n 2.1.1 input file does not exist \n\n"
 
-rm -f stdout.txt image2.v
-$PROGRAM -mif=image2.inf nonexisting.bin image2.v &> stdout.txt
+rm -f image2.v
+$PROGRAM -mif=image2.inf nonexisting.bin image2.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot open file nonexisting.bin"
@@ -658,16 +647,16 @@ printf "\n===================================================================\n"
 
 printf "\n 3.0.0 fail if output filename not given \n\n"
 
-rm -f image2.v stdout.txt
-$PROGRAM -mif=image2.inf image2.bin &> stdout.txt
+rm -f image2.v
+$PROGRAM -mif=image2.inf image2.bin 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing command-line argument; use option --help"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f image2.v stdout.txt
-$PROGRAM image2.bin 5 2 5 5 &> stdout.txt
+rm -f image2.v
+$PROGRAM image2.bin 5 2 5 5 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing/invalid data size argument."
@@ -676,9 +665,9 @@ printf "\n passed. \n\n"
 
 printf "\n 3.0.1 fail if output filename is the same as input filename \n\n"
 
-rm -f temp.v stdout.txt
+rm -f temp.v
 cp -f image1.bin temp.v
-$PROGRAM temp.v temp.v 1 1 40 40 &> stdout.txt
+$PROGRAM temp.v temp.v 1 1 40 40 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "same name for input and output file."
@@ -707,8 +696,7 @@ printf "\n 3.2.0 Output extension is identified correctly \n\n"
 
 prinf "\n ECAT 7 image volume \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -mif=image1.inf image1.bin image1.v &> stdout.txt
+$PROGRAM -d2 -mif=image1.inf image1.bin image1.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "type" 1
@@ -720,8 +708,7 @@ printf "\n passed. \n\n"
 
 prinf "\n ECAT 6 image \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -mif=image1.inf image1.bin image1.img &> stdout.txt
+$PROGRAM -d2 -mif=image1.inf image1.bin image1.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "type" 1
@@ -733,8 +720,7 @@ printf "\n passed. \n\n"
 
 prinf "\n ECAT 7 sinogram \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -mif=scan1.inf scan1.bin scan1.s &> stdout.txt
+$PROGRAM -d2 -mif=scan1.inf scan1.bin scan1.s 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "type" 2
@@ -746,8 +732,7 @@ printf "\n passed. \n\n"
 
 prinf "\n ECAT 6 sinogram \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -mif=scan1.inf scan1.bin scan1.scn &> stdout.txt
+$PROGRAM -d2 -mif=scan1.inf scan1.bin scan1.scn 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "type" 2
@@ -760,8 +745,8 @@ printf "\n passed. \n\n"
 
 prinf "\n NIfTI 1S image \n\n"
 
-rm -f stdout.txt output.nii
-$PROGRAM -d2 -mif=image1.inf image1.bin output.nii &> stdout.txt
+rm -f output.nii
+$PROGRAM -d2 -mif=image1.inf image1.bin output.nii 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "type" 1
@@ -776,8 +761,7 @@ printf "\n===================================================================\n"
 
 printf "\n 4.0.0 Matrix data dimensions: both MIF file and on command-line \n\n"
 
-rm -f stdout.txt image2.v
-$PROGRAM -d2 -mif=image2.inf image2.bin image2.v 1 10 5 5 &> stdout.txt
+$PROGRAM -d2 -mif=image2.inf image2.bin image2.v 1 10 5 5 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too many arguments."
@@ -786,8 +770,8 @@ printf "\n passed. \n\n"
 
 printf "\n 4.1.0 Matrix data dimensions: binary file too small \n\n"
 
-rm -f stdout.txt image2.v
-$PROGRAM -d2 image2.bin image2.v 2 5 128 128 &> stdout.txt
+rm -f image2.v
+$PROGRAM -d2 image2.bin image2.v 2 5 128 128 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "file does not contain all pixel values."
@@ -796,8 +780,8 @@ printf "\n passed. \n\n"
 
 printf "\n 4.1.1 Matrix data dimensions: binary file too big \n\n"
 
-rm -f stdout.txt image2.v mhdr.txt
-$PROGRAM -d2 image2.bin image2.v 2 4 5 5 &> stdout.txt
+rm -f image2.v mhdr.txt
+$PROGRAM -d2 image2.bin image2.v 2 4 5 5 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "some data in image2.bin were not read!"
