@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgdecay
-#: Date       : 2014-10-05
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,16 +11,17 @@ else
 EXT=;
 fi
 PROGRAM=../../imgdecay$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "\nError: application file missing.\n\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
 printf "=====================================================================\n"
 
 # Check that required files exist
-if [ ! -f $PROGRAM ]; then
-  printf "\nError: application file missing.\n\n"
-  exit 1
-fi
 if [ ! -f origdata.dft ]; then
   printf "\nError: required file missing.\n\n"
   exit 1
@@ -56,9 +57,8 @@ printf "=====================================================================\n"
 
 printf "\n0.1.0 Unknown option \n\n"
 
-rm -f stdout.txt
 cp -f original.v test.v
-$PROGRAM -stupidoption test.v &> stdout.txt
+$PROGRAM -stupidoption test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -69,9 +69,8 @@ printf "\n===================================================================\n"
 
 printf "\n0.2.0 Extra argument \n\n"
 
-rm -f stdout.txt
 cp -f original.v test.v
-$PROGRAM test.v extra &> stdout.txt
+$PROGRAM test.v extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -82,9 +81,8 @@ printf "\n===================================================================\n"
 
 printf "\n0.3.0 Isotope option \n\n"
 
-rm -f stdout.txt
 cp -f original.v test.v
-$PROGRAM test.v &> stdout.txt
+$PROGRAM test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "unknown"
@@ -96,9 +94,8 @@ printf "\n passed. \n\n"
 
 printf "\n0.3.1 With isotope option \n\n"
 
-rm -f stdout.txt
 cp -f original.v test.v
-$PROGRAM -d1 -i=C11 test.v &> stdout.txt
+$PROGRAM -d1 -i=C11 test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "halflife" "1224"
@@ -106,8 +103,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
 # Now image should have the isotope
-rm -f stdout.txt
-$PROGRAM -d1 test.v &> stdout.txt
+$PROGRAM -d1 test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
@@ -127,8 +123,7 @@ printf "\n passed. \n\n"
 
 printf "\n0.3.2 Previously set isotope can be changed \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d1 -i=F18 test.v &> stdout.txt
+$PROGRAM -d1 -i=F18 test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "halflife" "6588"
@@ -144,8 +139,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 printf "\n0.3.3 Invalid isotope code by option \n\n"
-rm -f stdout.txt
-$PROGRAM -d1 -i=Au-129 test.v &> stdout.txt
+$PROGRAM -d1 -i=Au-129 test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid isotope with option -i"
@@ -158,9 +152,8 @@ printf "\n===================================================================\n"
 printf "\n0.4.0 option -dc, -rc, -dd, and -rd \n\n"
 
 printf "\n without option \n\n"
-rm -f stdout.txt
 cp -f original.v test.v
-$PROGRAM -d1 test.v &> stdout.txt
+$PROGRAM -d1 test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt decaycor "0"
@@ -169,8 +162,7 @@ printf "\n passed. \n\n"
 
 printf "\n any of the options gives an error while isotope is missing \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d1 -dd test.v &> stdout.txt
+$PROGRAM -d1 -dd test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt decaycor "2"
@@ -180,8 +172,7 @@ iftisval stdout.txt "Error" "set isotope with option -i"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d1 -rd test.v &> stdout.txt
+$PROGRAM -d1 -rd test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt decaycor "-2"
@@ -191,8 +182,7 @@ iftisval stdout.txt "Error" "set isotope with option -i"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d1 -dc test.v &> stdout.txt
+$PROGRAM -d1 -dc test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt decaycor "1"
@@ -202,8 +192,7 @@ iftisval stdout.txt "Error" "set isotope with option -i"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d1 -rc test.v &> stdout.txt
+$PROGRAM -d1 -rc test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt decaycor "-1"
@@ -217,13 +206,12 @@ printf "\n passed. \n\n"
 printf "\n0.4.1 invalid combinations of -dc, -rc, -dd, and -rd \n\n"
 
 printf "\n -dd -dc \n\n"
-rm -f stdout.txt
 cp -f original.v test.v
 # set isotope to test image
 $PROGRAM -i=C-11 test.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM -dd -dc test.v &> stdout.txt
+$PROGRAM -dd -dc test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "invalid combination of options."
@@ -231,8 +219,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 printf "\n -rc -rd \n\n"
-rm -f stdout.txt
-$PROGRAM -rc -rd test.v &> stdout.txt
+$PROGRAM -rc -rd test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "invalid combination of options."
@@ -240,8 +227,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 printf "\n -dd -rd \n\n"
-rm -f stdout.txt
-$PROGRAM -dd -rd test.v &> stdout.txt
+$PROGRAM -dd -rd test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "invalid combination of options."
@@ -249,8 +235,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 printf "\n -dc -rd \n\n"
-rm -f stdout.txt
-$PROGRAM -dc -rd test.v &> stdout.txt
+$PROGRAM -dc -rd test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "invalid combination of options."
@@ -261,16 +246,14 @@ printf "\n===================================================================\n"
 
 printf "\n0.5.0 No input file name \n\n"
 
-rm -f stdout.txt
-$PROGRAM -i=F-18 -d2 &> stdout.txt
+$PROGRAM -i=F-18 -d2 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
 printf "\n0.5.1 Input file does not exist \n\n"
 
-rm -f stdout.txt
-$PROGRAM -i=F-18 nonexisting.v &> stdout.txt
+$PROGRAM -i=F-18 nonexisting.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftisval stdout.txt "Error in reading nonexisting.v" "cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -278,8 +261,7 @@ printf "\n passed. \n\n"
 
 printf "\n0.5.2 Input file in wrong format \n\n"
 
-rm -f stdout.txt
-$PROGRAM -i=F-18 $PROGRAM &> stdout.txt
+$PROGRAM -i=F-18 $PROGRAM 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftisval stdout.txt "Error in reading $PROGRAM" "unknown file format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -303,15 +285,13 @@ printf "\n ok \n"
 if [ ! -f test.v ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM test.v &> stdout.txt
+$PROGRAM test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftisval stdout.txt "isotope" "C-11"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM test.v.bak &> stdout.txt
+$PROGRAM test.v.bak 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftisval stdout.txt "isotope" "F-18"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -336,8 +316,7 @@ printf "\n1.0.0 status printing when information is NOT available \n\n"
 printf "\n ECAT7 \n\n"
 
 cp -f original.v test.v
-rm -f stdout.txt
-$PROGRAM test.v &> stdout.txt
+$PROGRAM test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "unknown"
@@ -350,8 +329,7 @@ printf "\n passed. \n\n"
 printf "\n ECAT6 \n\n"
 
 cp -f original.img test.img
-rm -f stdout.txt
-$PROGRAM test.img &> stdout.txt
+$PROGRAM test.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "unknown"
@@ -371,8 +349,7 @@ $PROGRAM -i=C-11 -dc test.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM test.v &> stdout.txt
+$PROGRAM test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
@@ -392,8 +369,7 @@ $PROGRAM -i=C-11 -dc test.img
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM test.img &> stdout.txt
+$PROGRAM test.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
@@ -417,8 +393,7 @@ $PROGRAM --silent -i=C-11 test.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM --silent test.v &> stdout.txt
+$PROGRAM --silent test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
@@ -432,8 +407,7 @@ $PROGRAM --silent -i=C-11 test.img
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM --silent test.img &> stdout.txt
+$PROGRAM --silent test.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
@@ -445,8 +419,7 @@ printf "\n1.1.1 set isotope when set before to the same isotope \n\n"
 
 printf "\n ECAT7 \n\n"
 
-rm -f stdout.txt
-$PROGRAM -i=C-11 test.v &> stdout.txt
+$PROGRAM -i=C-11 test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Note" "same isotope was previously set."
@@ -458,8 +431,7 @@ printf "\n passed. \n\n"
 
 printf "\n ECAT6 \n\n"
 
-rm -f stdout.txt
-$PROGRAM -i=C-11 test.img &> stdout.txt
+$PROGRAM -i=C-11 test.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Note" "same isotope was previously set."
@@ -475,16 +447,14 @@ printf "\n      image is not corrected for decay"
 
 printf "\n ECAT7 \n\n"
 
-rm -f stdout.txt
-$PROGRAM -i=F-18 test.v &> stdout.txt
+$PROGRAM -i=F-18 test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning" "possible decay correction should have been removed before isotope was changed to F-18"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM test.v &> stdout.txt
+$PROGRAM test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftisval stdout.txt "isotope" "F-18"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -492,16 +462,14 @@ printf "\n passed. \n\n"
 
 printf "\n ECAT6 \n\n"
 
-rm -f stdout.txt
-$PROGRAM -i=F-18 test.img &> stdout.txt
+$PROGRAM -i=F-18 test.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning" "possible decay correction should have been removed before isotope was changed to F-18"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM test.img &> stdout.txt
+$PROGRAM test.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftisval stdout.txt "isotope" "F-18"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -518,8 +486,8 @@ $PROGRAM -i=C-11 -dc test.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt test.v.bak
-$PROGRAM -i=F-18 test.v &> stdout.txt
+rm -f test.v.bak
+$PROGRAM -i=F-18 test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "remove previous decay correction before changing isotope."
@@ -536,8 +504,8 @@ $PROGRAM -i=C-11 -dc test.img
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt test.img.bak
-$PROGRAM -i=F-18 test.img &> stdout.txt
+rm -f test.img.bak
+$PROGRAM -i=F-18 test.img 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "remove previous decay correction before changing isotope."
@@ -561,8 +529,7 @@ $PROGRAM --silent -i=C-11 -dd test.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 test.v &> stdout.txt
+$PROGRAM -d2 test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
@@ -598,8 +565,7 @@ $PROGRAM --silent -i=C-11 -dd test.img
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 test.img &> stdout.txt
+$PROGRAM -d2 test.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
@@ -635,8 +601,7 @@ printf "\n      Image contains decay factors (added in previous step) \n\n"
 
 printf "\n ECAT7 \n\n"
 
-rm -f stdout.txt
-$PROGRAM -dd test.v &> stdout.txt
+$PROGRAM -dd test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "test.v is already corrected for decay."
@@ -645,8 +610,7 @@ printf "\n passed. \n\n"
 
 printf "\n ECAT6 \n\n"
 
-rm -f stdout.txt
-$PROGRAM -dd test.img &> stdout.txt
+$PROGRAM -dd test.img 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "test.img is already corrected for decay."
@@ -701,8 +665,7 @@ printf "\n      Image does not contain decay factors \n\n"
 printf "\n ECAT7 \n\n"
 
 cp -f original.v test.v
-rm -f stdout.txt
-$PROGRAM -rd -i=C-11 test.v &> stdout.txt
+$PROGRAM -rd -i=C-11 test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning" "removing decay correction."
@@ -730,8 +693,7 @@ printf "\n passed. \n\n"
 printf "\n ECAT6 \n\n"
 
 cp -f original.img test.img
-rm -f stdout.txt
-$PROGRAM -rd -i=C-11 test.img &> stdout.txt
+$PROGRAM -rd -i=C-11 test.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning" "removing decay correction."
@@ -769,8 +731,7 @@ $PROGRAM -dc -i=C-11 test.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 test.v &> stdout.txt
+$PROGRAM -d2 test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
@@ -798,8 +759,7 @@ $PROGRAM -dc -i=C-11 test.img
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 test.img &> stdout.txt
+$PROGRAM -d2 test.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
@@ -827,8 +787,7 @@ printf "\n      Image already contains factors \n\n"
 
 printf "\n ECAT7 \n\n"
 
-rm -f stdout.txt
-$PROGRAM -dc test.v &> stdout.txt
+$PROGRAM -dc test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "test.v is already corrected for decay."
@@ -837,8 +796,7 @@ printf "\n passed. \n\n"
 
 printf "\n ECAT6 \n\n"
 
-rm -f stdout.txt
-$PROGRAM -dc test.img &> stdout.txt
+$PROGRAM -dc test.img 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "test.img is already corrected for decay."
@@ -863,8 +821,7 @@ $PROGRAM -rc test.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 test.v &> stdout.txt
+$PROGRAM -d2 test.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
@@ -889,8 +846,7 @@ $PROGRAM -rc test.img
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 test.img &> stdout.txt
+$PROGRAM -d2 test.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
@@ -913,8 +869,7 @@ printf "\n      Image does not contain factors \n\n"
 printf "\n ECAT7 \n\n"
 
 cp -f original.v test.v
-rm -f stdout.txt
-$PROGRAM -rc -i=C-11 test.v &> stdout.txt
+$PROGRAM -rc -i=C-11 test.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "no need to delete decay correction factors."
@@ -924,8 +879,7 @@ printf "\n passed. \n\n"
 printf "\n ECAT6 \n\n"
 
 cp -f original.img test.img
-rm -f stdout.txt
-$PROGRAM -rc -i=C-11 test.img &> stdout.txt
+$PROGRAM -rc -i=C-11 test.img 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "no need to delete decay correction factors."
