@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgfiltg
-#: Date       : 2019-11-28
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -375,7 +375,7 @@ imgprofi -pxl=1,1,1 cross_tiny.v xo.pro yo.pro
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM cross_tiny.v filtered.v 0 &> stdout.txt
+$PROGRAM cross_tiny.v filtered.v 0 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ ! -f filtered.v ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -596,9 +596,9 @@ printf " Test case 2: Set SD to zero. \n"
 printf " Expected result 1: Warning. \n"
 printf " Expected result 2: Output image contents are the same as in input image. \n\n"
 
-rm -f cube_filtered.v stdout.txt
+rm -f cube_filtered.v
 
-$PROGRAM cube.v cube_filtered.v 0 0 &> stdout.txt
+$PROGRAM cube.v cube_filtered.v 0 0 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ ! -f cube_filtered.v ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -975,8 +975,8 @@ printf "\n 6.0.0 \n"
 printf " Test case: Invalid option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.v
-$PROGRAM -stupidoption static.v output.v 5 &> stdout.txt
+rm -f output.v
+$PROGRAM -stupidoption static.v output.v 5 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -987,8 +987,7 @@ printf "\n 6.0.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM static.v output.v 5 0 extra &> stdout.txt
+$PROGRAM static.v output.v 5 0 extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too many arguments."
@@ -999,32 +998,28 @@ printf "\n 6.0.2 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  output.v 5 &> stdout.txt
+$PROGRAM  output.v 5 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM static.v  0  &> stdout.txt
+$PROGRAM static.v  0  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM static.v 2 2  &> stdout.txt
+$PROGRAM static.v 2 2  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM static.v output.v &> stdout.txt
+$PROGRAM static.v output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
@@ -1036,8 +1031,7 @@ printf "\n 6.1.0 \n"
 printf " Test case: Input file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.v output.v 5 &> stdout.txt
+$PROGRAM nonexistingfile.v output.v 5 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
@@ -1049,8 +1043,7 @@ printf "\n 6.2.0 \n"
 printf " Test case: Trying to do 3D smoothing for 2D image. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM cross.v output.v 5 5 &> stdout.txt
+$PROGRAM cross.v output.v 5 5 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "invalid Z dimension for 3D filtering."
