@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imginteg
-#: Date       : 2014-10-13
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,11 @@ else
 EXT=;
 fi
 PROGRAM=../../imginteg$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -19,11 +24,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f test_dyn.dft ] || [ ! -f test_dyn2.dft ]; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -115,8 +115,7 @@ printf "\n 0.1.0 \n"
 printf " Test case: No command line options or arguments. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM &> stdout.txt
+$PROGRAM 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Usage"
@@ -130,8 +129,7 @@ printf "\n 0.1.1 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption test_dyn.v 0 0 output.v &> stdout.txt
+$PROGRAM -stupidoption test_dyn.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -142,8 +140,7 @@ printf "\n 0.1.2 \n"
 printf " Test case: Too many arguments. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM test_dyn.v 0 0 output.v extra &> stdout.txt
+$PROGRAM test_dyn.v 0 0 output.v extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -154,18 +151,15 @@ printf "\n 0.1.3 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  0 0 output.v &> stdout.txt
+$PROGRAM  0 0 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM test_dyn.v  0 output.v &> stdout.txt
+$PROGRAM test_dyn.v  0 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM test_dyn.v 0 0   &> stdout.txt
+$PROGRAM test_dyn.v 0 0   1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -254,16 +248,14 @@ printf "\n 1.3.0 \n"
 printf " Test case: AUC outside ECAT7 frames. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v 60 30 failed.v &> stdout.txt
+$PROGRAM dynamic.v 60 30 failed.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "integration time range oversteps data range."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v 0 180 failed.v &> stdout.txt
+$PROGRAM dynamic.v 0 180 failed.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "integration time range oversteps data range."
@@ -293,8 +285,7 @@ printf "\n 1.4.1 \n"
 printf " Test case: AUC from static image with inappropriate time range. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM integral2.v 0 30 failed.v &> stdout.txt
+$PROGRAM integral2.v 0 30 failed.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "for static image the integration time range must be exactly as long as the scan."
@@ -387,7 +378,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: Image format ECAT7. \n"
 printf " Expected result: Correct result with zeroes as time range. \n\n"
 
-rm -f output.v stdout.txt
+rm -f output.v
 cp -f test_dyn.dft temp.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacunit -xconv=sec temp.dft
@@ -398,7 +389,7 @@ tacunit -xconv=min test.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM --silent test_dyn.v 0 0 output.v &> stdout.txt
+$PROGRAM --silent test_dyn.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 img2dft output.v test_dyn.roi output.dft
@@ -448,8 +439,8 @@ printf "\n 2.1.1 \n"
 printf " Test case: Image format Analyze without SIF. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f ana/*.sif stdout.txt
-$PROGRAM --silent ana/test_dyn 0 0 ana/output &> stdout.txt
+rm -f ana/*.sif
+$PROGRAM --silent ana/test_dyn 0 0 ana/output 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "image does not contain frame times."
@@ -487,8 +478,8 @@ printf "\n 2.2.1 \n"
 printf " Test case: Image format NIfTI without SIF. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f nii/*.sif stdout.txt
-$PROGRAM --silent nii/test_dyn 0 0 nii/output &> stdout.txt
+rm -f nii/*.sif
+$PROGRAM --silent nii/test_dyn 0 0 nii/output 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "image does not contain frame times."
@@ -646,8 +637,7 @@ printf "\n 3.3.1 \n"
 printf " Test case: Large overlap between time frames. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM test_largeoverlap.v 60 840 failed.v &> stdout.txt
+$PROGRAM test_largeoverlap.v 60 840 failed.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "image test_largeoverlap.v has overlapping frame times."
@@ -715,8 +705,7 @@ printf "\n 3.4.2 \n"
 printf " Test case: AUC from zero to end time much over the end of image data. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM test_dyn.v 0 3600 failed.v &> stdout.txt
+$PROGRAM test_dyn.v 0 3600 failed.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "integration time range oversteps data range."
@@ -756,8 +745,7 @@ printf "\n 3.5.1 \n"
 printf " Test case: AUC from zero with late scan image. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -min test_latescan.v 0 60 failed.v &> stdout.txt
+$PROGRAM -min test_latescan.v 0 60 failed.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "integration time range oversteps data range."
@@ -769,8 +757,7 @@ printf "\n 3.5.2 \n"
 printf " Test case: time range much after the image data ends. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -avg test_dyn.v 7200 3600 failed.v &> stdout.txt
+$PROGRAM -avg test_dyn.v 7200 3600 failed.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "integration time range oversteps data range."
