@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgthrs
-#: Date       : 2018-02-25
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,11 @@ else
 EXT=;
 fi
 PROGRAM=../../imgthrs$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -19,11 +24,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f test_dyn.tac ]; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -391,8 +391,7 @@ printf "\n 3.0.0 \n"
 printf " Test case: Option -abs with dynamic image. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f output.v stdout.txt
-$PROGRAM -abs dynamic.v 0 1000 output.v &> stdout.txt
+$PROGRAM -abs dynamic.v 0 1000 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "do not use absolute thresholds for dynamic image."
@@ -405,8 +404,8 @@ printf " Test case 1: Option -abs with static image. \n"
 printf " Test case 2: Threshold limits so wide that nothing is removed. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f output.v stdout.txt
-$PROGRAM -abs static.v -10000 10000000 output.v &> stdout.txt
+rm -f output.v
+$PROGRAM -abs static.v -10000 10000000 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "no pixels thresholded."
@@ -520,8 +519,7 @@ printf "\n 4.0.0 \n"
 printf " Test case: Invalid option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.v
-$PROGRAM -stupidoption dynamic.v 0 90 output.v &> stdout.txt
+$PROGRAM -stupidoption dynamic.v 0 90 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -532,8 +530,7 @@ printf "\n 4.0.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v 0 90 output.v extra &> stdout.txt
+$PROGRAM dynamic.v 0 90 output.v extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too many arguments."
@@ -544,24 +541,21 @@ printf "\n 4.0.2 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM   0 90 output.v &> stdout.txt
+$PROGRAM   0 90 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v 0  &> stdout.txt
+$PROGRAM dynamic.v 0  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v 90 output.v &> stdout.txt
+$PROGRAM dynamic.v 90 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
@@ -573,8 +567,7 @@ printf "\n 4.1.0 \n"
 printf " Test case: Input file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.v 0 90 output.v &> stdout.txt
+$PROGRAM nonexistingfile.v 0 90 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
@@ -586,8 +579,7 @@ printf "\n 4.2.0 \n"
 printf " Test case: Invalid limits. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v 90 60 output.v &> stdout.txt
+$PROGRAM dynamic.v 90 60 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
