@@ -480,12 +480,12 @@ int main(int argc, char *argv[])
       dc=1.0;
       if(format==SCANDITRONICS) {
         if(ptr->scanditronics.time_since_start>=0.0) {
-          dc = lambda2factor(lambda,
+          dc = hlLambda2factor(lambda,
                  ptr->scanditronics.time_since_start, ptr->scanditronics.meas_interval);
         }
       } else {
         if(ptr->allogg.time_since_start>=0.0) {
-          dc = lambda2factor(lambda, ptr->allogg.time_since_start, ptr->allogg.meas_interval);
+          dc = hlLambda2factor(lambda, ptr->allogg.time_since_start, ptr->allogg.meas_interval);
           if(verbose>5) printf("dc:%f %f\n",dc,ptr->allogg.time_since_start);
         }
       }
