@@ -277,6 +277,8 @@ int main(int argc, char *argv[])
     fprintf(stderr, "Error in reading image: %s\n", img.statmsg);
     imgEmpty(&img); return(3);
   }
+  if(imgNaNs(&img, 1)>0)
+    if(verbose>0) fprintf(stderr, "Warning: missing pixel values.\n");
   /* Check if PET data is raw or image */
   if(img.type!=IMG_TYPE_IMAGE) {
     fprintf(stderr, "Error: %s is not an image.\n", imgfile);
