@@ -27,9 +27,11 @@
 /*****************************************************************************/
 
 /*****************************************************************************/
-const int maxParNr=4;
 /* Local functions */
-double func_pbr(int parNr, double *p, void*);
+double func_pbr_src(int parNr, double *p, void*);
+double func_pbr_fm2(int parNr, double *p, void*);
+double func_pbr_rf(int parNr, double *p, void*);
+double func_pbr_hill(int parNr, double *p, void*);
 /*****************************************************************************/
 typedef struct FITDATA {
   /** Nr of TAC samples */
@@ -51,13 +53,27 @@ typedef struct FITDATA {
 
 /*****************************************************************************/
 static char *info[] = {
-  "Non-linear fitting of a function to sampled plasma-to-blood ratio data.",
+  "Non-linear fitting of a function to sampled plasma-to-blood ratio (PBR) data.",
+  " ",
+  "Plasma-to-blood ratio is calculated from RBC-to-plasma ratio (RPC) as",
+  "  PBR(t)=1/((1-HCT)+HCT*RPC(t))",
+  "and RBC-to-plasma ratio is modelled with function 1 (SRC)",
+  "  RPC(t)=p1*t*exp(-p2*t) + p3*p1*(1-exp(-p2*t)*(1+p2*t))/(p2*p2)",
+  "function 2 (FM2)",
+  "  RPC(t)=(p1*t-p3-p5)*exp(-p2*t) + p3*exp(-p4*t) + p5*exp(-p6*t)",
+  "function 3 (RF)",
+  "  RPC(t)=(p1*t + p3*t^2 + p5*t^3) / (1 + p2*t + p4*t^2 + p6*t^3)",
+  "or function 4 (HILL)",
+  "  RPC(t)=(p1*t^p2)/(t^p2 + p3)",
   " ",
   "Usage: @P [Options] datafile [parfile]",
   " ",
   "Options:",
   " -HCT=<Haematocrit>",
   "     Constrain haematocrit to specified value; fitted by default.",
+  " -model=<SRC|FM2|RF|HILL>",
+  "     Use function 1 (SCR, default), function 2 (FM2), function 3 (RF), or",
+  "     function 4 (HILL).",
   " -min=<OLS|LAD>",
   "     Sum-of-squares (OLS) is minimized by default, but optionally",
   "     sum of absolute deviations (LAD) can be selected.",
@@ -118,6 +134,7 @@ int main(int argc, char **argv)
   double  fixed_hct=nan("");
   double  fixed_k=nan("");
   optimality_criterion optcrit=OPTCRIT_OLS;
+  unsigned int model=modelCodeIndex("p2bsrc");
 
 
 #ifdef MINGW
@@ -147,6 +164,16 @@ int main(int argc, char **argv)
       strlcpy(svgfile, cptr+4, FILENAME_MAX); continue;
     } else if(strncasecmp(cptr, "K=", 2)==0 && strlen(cptr)>2) {
       if(!atofCheck(cptr+2, &fixed_k) && fixed_k>=0.0) continue;
+    } else if(strncasecmp(cptr, "MODEL=", 6)==0 && strlen(cptr)>6) {
+      cptr+=6;
+      if(strcasecmp(cptr, "SRC")==0) {model=modelCodeIndex("p2bsrc"); continue;}
+      if(strcasecmp(cptr, "FM2")==0) {model=modelCodeIndex("p2bfm2"); continue;}
+      if(strcasecmp(cptr, "RF")==0) {model=modelCodeIndex("p2brf"); continue;}
+      if(strcasecmp(cptr, "HILL")==0) {model=modelCodeIndex("p2bhill"); continue;}
+      if(strcasecmp(cptr, "1")==0) {model=modelCodeIndex("p2bsrc"); continue;}
+      if(strcasecmp(cptr, "2")==0) {model=modelCodeIndex("p2bfm2"); continue;}
+      if(strcasecmp(cptr, "3")==0) {model=modelCodeIndex("p2brf"); continue;}
+      if(strcasecmp(cptr, "4")==0) {model=modelCodeIndex("p2bhill"); continue;}
     } else if(strncasecmp(cptr, "HCT=", 4)==0 && strlen(cptr)>4) {
       if(!atofCheck(cptr+4, &fixed_hct) && fixed_hct>0.0 && fixed_hct<1.0) continue;
     }
@@ -166,10 +193,7 @@ int main(int argc, char **argv)
   /* Process other arguments, starting from the first non-option */
   if(ai<argc) strlcpy(pbrfile, argv[ai++], FILENAME_MAX);
   if(ai<argc) strlcpy(parfile, argv[ai++], FILENAME_MAX);
-  if(ai<argc) {
-    fprintf(stderr, "Error: invalid argument '%s'.\n", argv[ai]);
-    return(1);
-  }
+  if(ai<argc) {fprintf(stderr, "Error: invalid argument '%s'.\n", argv[ai]); return(1);}
 
   /* In verbose mode print arguments and options */
   if(verbose>1) {
@@ -181,17 +205,38 @@ int main(int argc, char **argv)
     if(!isnan(fixed_k)) printf("fixed_k := %g\n", fixed_k);
     if(!isnan(fixed_hct)) printf("fixed_hct := %g\n", fixed_hct);
     printf("optcrit := %s\n", optcritCode(optcrit));
+    printf("model := %s\n", modelDesc(model));
     fflush(stdout);
   }
 
   /* Set parameter names and initial constraints */
-  PAR plim; parInit(&plim); if(parAllocate(&plim, maxParNr, 1)!=TPCERROR_OK) {
+  PAR plim; parInit(&plim); if(parAllocate(&plim, modelParNr(model), 1)!=TPCERROR_OK) {
     fprintf(stderr, "Error: cannot initiate parameter list.\n"); return(1);}
-  plim.parNr=maxParNr;
+  plim.parNr=modelParNr(model);
   strcpy(plim.n[0].name, "HCT"); plim.n[0].lim1=0.36;     plim.n[0].lim2=0.50;
-  strcpy(plim.n[1].name, "A");   plim.n[1].lim1=1.0E-06;  plim.n[1].lim2=1.0E+02;
-  strcpy(plim.n[2].name, "L");   plim.n[2].lim1=1.0E-06;  plim.n[2].lim2=5.0;
-  strcpy(plim.n[3].name, "k");   plim.n[3].lim1=0.0;      plim.n[3].lim2=2.0;
+  if(model==modelCodeIndex("p2bsrc")) {
+    strcpy(plim.n[1].name, "A");   plim.n[1].lim1=1.0E-06;  plim.n[1].lim2=1.0E+02;
+    strcpy(plim.n[2].name, "L");   plim.n[2].lim1=1.0E-06;  plim.n[2].lim2=5.0;
+    strcpy(plim.n[3].name, "k");   plim.n[3].lim1=0.0;      plim.n[3].lim2=2.0;
+  } else if(model==modelCodeIndex("p2brf")) {
+    strcpy(plim.n[1].name, "p1");   plim.n[1].lim1=0.0;  plim.n[1].lim2=2.0;
+    strcpy(plim.n[2].name, "p2");   plim.n[2].lim1=0.0;  plim.n[2].lim2=0.5;
+    strcpy(plim.n[3].name, "p3");   plim.n[3].lim1=0.0;  plim.n[3].lim2=0.5;
+    strcpy(plim.n[4].name, "p4");   plim.n[4].lim1=0.0;  plim.n[4].lim2=1.0;
+    strcpy(plim.n[5].name, "p5");   plim.n[5].lim1=0.0;  plim.n[5].lim2=0.1;
+    strcpy(plim.n[6].name, "p6");   plim.n[6].lim1=0.0;  plim.n[6].lim2=0.0;
+  } else if(model==modelCodeIndex("p2bfm2")) {
+    strcpy(plim.n[1].name, "A1");   plim.n[1].lim1=0.0;   plim.n[1].lim2=10.0;
+    strcpy(plim.n[2].name, "L1");   plim.n[2].lim1=0.0;   plim.n[2].lim2=5.0;
+    strcpy(plim.n[3].name, "A2");   plim.n[3].lim1=0.0;   plim.n[3].lim2=10.0;
+    strcpy(plim.n[4].name, "L2");   plim.n[4].lim1=0.0;   plim.n[4].lim2=0.5;
+    strcpy(plim.n[5].name, "A3");   plim.n[5].lim1=0.0;   plim.n[5].lim2=5.0;
+    strcpy(plim.n[6].name, "L3");   plim.n[6].lim1=-0.1;  plim.n[6].lim2=0.01;
+  } else { // if(model==modelCodeIndex("p2bhill"))
+    strcpy(plim.n[1].name, "p1");   plim.n[1].lim1=0.0;   plim.n[1].lim2=20.0;
+    strcpy(plim.n[2].name, "p2");   plim.n[2].lim1=0.0;   plim.n[2].lim2=5.0;
+    strcpy(plim.n[3].name, "p3");   plim.n[3].lim1=0.001; plim.n[3].lim2=5000.0;
+  }
   /* If only file name for parameter constraints was given, then write one and exit */
   if(limfile[0] && !pbrfile[0]) {
     /* Check that initial value file does not exist */
@@ -200,7 +245,7 @@ int main(int argc, char **argv)
       parFree(&plim); return(1);
     }
     /* Create parameter file */
-    plim.parNr=maxParNr;
+    plim.parNr=modelParNr(model);
     if(verbose>1 && strcasecmp(limfile, "stdout")!=0) 
       printf("writing parameter constraints file\n");
     if(parWriteLimits(&plim, limfile, verbose-2)!=TPCERROR_OK) {
@@ -236,7 +281,7 @@ int main(int argc, char **argv)
   }
   /* Set optional user-defined constraints */
   if(!isnan(fixed_hct)) plim.n[0].lim1=plim.n[0].lim2=fixed_hct;
-  if(!isnan(fixed_k)) plim.n[3].lim1=plim.n[3].lim2=fixed_k;
+  if(!isnan(fixed_k) && model==modelCodeIndex("p2bsrc")) plim.n[3].lim1=plim.n[3].lim2=fixed_k;
   if(verbose>1) parListLimits(&plim, stdout);
 
 
@@ -305,11 +350,11 @@ int main(int argc, char **argv)
 
 
   /*
-   *  Copy function parameters into PAR struct for printing and saving
+   *  Copy function parameters into PAR structure for printing and saving
    */
   if(verbose>1) printf("preparing space for parameters\n");
   PAR par; parInit(&par);
-  if(parAllocateWithTAC(&par, &tac, maxParNr, &status)!=TPCERROR_OK) {
+  if(parAllocateWithTAC(&par, &tac, modelParNr(model), &status)!=TPCERROR_OK) {
     fprintf(stderr, "Error: %s\n", errorMsg(status.error));
     tacFree(&tac); parFree(&plim); return(3);
   }
@@ -317,15 +362,15 @@ int main(int argc, char **argv)
   /* set time and program name */
   {
     char buf[256];
-    time_t t=time(NULL);
-    iftPut(&par.h, "analysis_time", ctime_r_int(&t, buf), 0, NULL);
     tpcProgramName(argv[0], 1, 1, buf, 256);
     iftPut(&par.h, "program", buf, 0, NULL);
+    time_t t=time(NULL);
+    iftPut(&par.h, "analysis_time", ctime_r_int(&t, buf), 0, NULL);
   }
-  par.tacNr=tac.tacNr; par.parNr=4;
+  par.tacNr=tac.tacNr; par.parNr=modelParNr(model);
   par.format=PAR_FORMAT_TSV_UK;
   for(int i=0; i<par.tacNr; i++) {
-    par.r[i].model=modelCodeIndex("p2bsrc");
+    par.r[i].model=model;
     par.r[i].dataNr=tacWSampleNr(&tac);
     par.r[i].start=xmin; 
     par.r[i].end=xmax;
@@ -334,6 +379,12 @@ int main(int argc, char **argv)
   for(int i=0; i<par.parNr; i++) strcpy(par.n[i].name, plim.n[i].name);
   /* set file names */
   iftPut(&par.h, "datafile", pbrfile, 0, NULL);
+  /* copy study number */
+  {
+    int i=iftFindKey(&tac.h, "studynr", 0);
+    if(i<0) i=iftFindKey(&tac.h, "study_number", 0);
+    if(i>=0) iftPut(&par.h, tac.h.item[i].key, tac.h.item[i].value, 0, NULL);
+  }
   /* set optimality criterion */
   iftPut(&par.h, "optimality_criterion", optcritCode(optcrit), 0, NULL);
 
@@ -359,10 +410,13 @@ int main(int argc, char **argv)
     /* Set NLLS options */
     NLOPT nlo; nloptInit(&nlo);
     if(nloptAllocate(&nlo, par.parNr)!=TPCERROR_OK) {
-      fprintf(stderr, "Error: cannot initiate NLLS.\n");
+      fprintf(stderr, "Error: cannot allocate memory.\n");
       tacFree(&tac); parFree(&plim); parFree(&par); return(5);
     }
-    nlo._fun=func_pbr;
+    if(model==modelCodeIndex("p2bsrc")) nlo._fun=func_pbr_src; 
+    else if(model==modelCodeIndex("p2brf")) nlo._fun=func_pbr_rf;
+    else if(model==modelCodeIndex("p2bhill")) nlo._fun=func_pbr_hill;
+    else if(model==modelCodeIndex("p2bfm2")) nlo._fun=func_pbr_fm2;
     nlo.fundata=&fitdata;
     nlo.totalNr=par.parNr;
     for(int i=0; i<par.parNr; i++) {
@@ -376,10 +430,17 @@ int main(int argc, char **argv)
     nlo.maxFunCalls=500000;
     /* Fit */
     if(verbose>4) nloptWrite(&nlo, stdout);
+#if(0)
     if(nloptITGO1(&nlo, 1, 0, 10000, 20, &status)!=TPCERROR_OK) {
       fprintf(stderr, "Error: %s\n", errorMsg(status.error));
       tacFree(&tac); parFree(&plim); parFree(&par); nloptFree(&nlo); return(6);
     }
+#else
+    if(nloptIATGO(&nlo, 1, 0, 0.15, &status)!=TPCERROR_OK) {
+      fprintf(stderr, "Error: %s\n", errorMsg(status.error)); fflush(stderr);
+      tacFree(&tac); parFree(&plim); parFree(&par); nloptFree(&nlo); return(6);
+    }
+#endif
     nlo._fun(nlo.totalNr, nlo.xfull, nlo.fundata);
     if(verbose>2) nloptWrite(&nlo, stdout);
     if(verbose>6) {
@@ -405,13 +466,13 @@ int main(int argc, char **argv)
     if(verbose>1) printf("  saving %s\n", parfile);
     FILE *fp=fopen(parfile, "w");
     if(fp==NULL) {
-      fprintf(stderr, "Error: cannot open file for writing.\n");
+      fprintf(stderr, "Error: cannot open file for writing.\n"); fflush(stderr);
       tacFree(&tac); parFree(&plim); parFree(&par); return(11);
     }
     int ret=parWrite(&par, fp, PAR_FORMAT_UNKNOWN, 1, &status);
     fclose(fp);
     if(ret!=TPCERROR_OK) {
-      fprintf(stderr, "Error: %s\n", errorMsg(status.error));
+      fprintf(stderr, "Error: %s\n", errorMsg(status.error)); fflush(stderr);
       tacFree(&tac); parFree(&plim); parFree(&par); return(12);
     }
     if(verbose>0) printf("parameters saved in %s\n", parfile);
@@ -431,7 +492,7 @@ int main(int argc, char **argv)
     TAC ftac; tacInit(&ftac);
     int ret=tacAllocate(&ftac, snr, tac.tacNr);
     if(ret!=TPCERROR_OK) {
-      fprintf(stderr, "Error: %s\n", errorMsg(status.error));
+      fprintf(stderr, "Error: %s\n", errorMsg(status.error)); fflush(stderr);
       tacFree(&tac); parFree(&plim); parFree(&par); return(21);
     }
     ftac.tacNr=tac.tacNr; ftac.sampleNr=snr;
@@ -439,7 +500,7 @@ int main(int argc, char **argv)
     for(int ci=0; ci<tac.tacNr && ret==0; ci++)
       ret=tacCopyTacchdr(tac.c+ci, ftac.c+ci);
     if(ret!=TPCERROR_OK) {
-      fprintf(stderr, "Error: %s\n", errorMsg(status.error));
+      fprintf(stderr, "Error: %s\n", errorMsg(status.error)); fflush(stderr);
       tacFree(&tac); parFree(&plim); parFree(&par); tacFree(&ftac);
       return(22);
     }
@@ -452,7 +513,7 @@ int main(int argc, char **argv)
                   ftac.sampleNr, ftac.x, ftac.c[ci].y, verbose-5);
     }
     if(ret!=TPCERROR_OK) {
-      fprintf(stderr, "Error: cannot calculate function values.\n");
+      fprintf(stderr, "Error: cannot calculate function values.\n"); fflush(stderr);
       tacFree(&tac); parFree(&plim); parFree(&par); tacFree(&ftac);
       return(23);
     }
@@ -460,7 +521,7 @@ int main(int argc, char **argv)
     /* Plot */
     ret=tacPlotFitSVG(&tac, &ftac, "", nan(""), nan(""), nan(""), nan(""), svgfile, &status);
     if(ret!=TPCERROR_OK) {
-      fprintf(stderr, "Error: %s\n", errorMsg(status.error));
+      fprintf(stderr, "Error: %s\n", errorMsg(status.error)); fflush(stderr);
       tacFree(&tac); parFree(&plim); parFree(&par); tacFree(&ftac);
       return(24);
     }
@@ -480,7 +541,7 @@ int main(int argc, char **argv)
  *  Functions to be minimized
  *
  *****************************************************************************/
-double func_pbr(int parNr, double *p, void *fdata)
+double func_pbr_src(int parNr, double *p, void *fdata)
 {
   FITDATA *d=(FITDATA*)fdata;
 
@@ -507,6 +568,87 @@ double func_pbr(int parNr, double *p, void *fdata)
   return(wss);
 }
 /*****************************************************************************/
+double func_pbr_fm2(int parNr, double *p, void *fdata)
+{
+  FITDATA *d=(FITDATA*)fdata;
+
+  if(d->verbose>0) {printf("%s()\n", __func__); fflush(stdout);}
+  if(parNr!=7) return(nan(""));
+  if(d->verbose>20) printf("p[]: %g %g %g %g %g %g %g\n", p[0], p[1], p[2], p[3], p[4], p[5], p[6]);
+
+  /* Check that D(0)>0 */
+  double d0=p[1] - p[3]*p[4] - p[5]*p[6] + p[2]*(p[3]+p[5]);
+  if(d0<=0.0) return(nan(""));
+
+  /* Calculate the curve values and weighted SS */
+  double wss=0.0;
+  for(unsigned int i=0; i<d->n; i++) {
+    d->ysim[i]=nan("");
+    if(!isfinite(d->ymeas[i]) || !isfinite(d->x[i]) || d->x[i]<0.0) continue;
+    double rc=(p[1]*d->x[i]-p[3]-p[5])*exp(-p[2]*d->x[i])
+              + p[3]*exp(-p[4]*d->x[i]) + p[5]*exp(-p[6]*d->x[i]);
+    d->ysim[i]=1.0/((1.0-p[0])+p[0]*rc);
+    double v=d->ysim[i]-d->ymeas[i];
+    if(d->optcrit==OPTCRIT_LAD)
+      wss+=d->w[i]*fabs(v);
+    else
+      wss+=d->w[i]*v*v;
+  }
+
+  return(wss);
+}
+/*****************************************************************************/
+double func_pbr_rf(int parNr, double *p, void *fdata)
+{
+  FITDATA *d=(FITDATA*)fdata;
+
+  if(d->verbose>0) {printf("%s()\n", __func__); fflush(stdout);}
+  if(parNr!=7) return(nan(""));
+  if(d->verbose>20) printf("p[]: %g %g %g %g %g %g %g\n", p[0], p[1], p[2], p[3], p[4], p[5], p[6]);
+
+  /* Calculate the curve values and weighted SS */
+  double wss=0.0;
+  for(unsigned int i=0; i<d->n; i++) {
+    d->ysim[i]=nan("");
+    if(isnan(d->ymeas[i]) || isnan(d->x[i]) || d->x[i]<0.0) continue;
+    double a =       p[1]*d->x[i] + p[3]*d->x[i]*d->x[i] + p[5]*d->x[i]*d->x[i]*d->x[i];
+    double b = 1.0 + p[2]*d->x[i] + p[4]*d->x[i]*d->x[i] + p[6]*d->x[i]*d->x[i]*d->x[i];
+    d->ysim[i]=1.0/((1.0-p[0])+p[0]*(a/b));
+    double v=d->ysim[i]-d->ymeas[i]; if(!isfinite(v)) return(nan(""));
+    if(d->optcrit==OPTCRIT_LAD)
+      wss+=d->w[i]*fabs(v);
+    else
+      wss+=d->w[i]*v*v;
+  }
+
+  return(wss);
+}
+/*****************************************************************************/
+double func_pbr_hill(int parNr, double *p, void *fdata)
+{
+  FITDATA *d=(FITDATA*)fdata;
+
+  if(d->verbose>0) {printf("%s()\n", __func__); fflush(stdout);}
+  if(parNr!=4) return(nan(""));
+  if(d->verbose>20) printf("p[]: %g %g %g %g\n", p[0], p[1], p[2], p[3]);
+
+  /* Calculate the curve values and weighted SS */
+  double wss=0.0;
+  for(unsigned int i=0; i<d->n; i++) {
+    d->ysim[i]=nan("");
+    if(isnan(d->ymeas[i]) || isnan(d->x[i]) || d->x[i]<0.0) continue;
+    double rc=p[1]*pow(d->x[i], p[2])/(p[3]+pow(d->x[i], p[2]));
+    d->ysim[i]=1.0/((1.0-p[0])+p[0]*rc);
+    double v=d->ysim[i]-d->ymeas[i]; if(!isfinite(v)) return(nan(""));
+    if(d->optcrit==OPTCRIT_LAD)
+      wss+=d->w[i]*fabs(v);
+    else
+      wss+=d->w[i]*v*v;
+  }
+
+  return(wss);
+}
+/*****************************************************************************/
 
 /*****************************************************************************/
 /// @endcond
