@@ -248,7 +248,7 @@ int main(int argc, char **argv)
     fp=fopen(ratfile, "r");
     if(fp==NULL) {
       fprintf(stderr, "Error: cannot open '%s'.\n", ratfile);
-      dftEmpty(&plasma); fclose(fp); return(3);
+      dftEmpty(&plasma); return(3);
     }
     fclose(fp);
   }
