@@ -11,7 +11,7 @@
 typedef enum {NORBC,INWATER,FDG,FLUORIDE,FBPA,FDOPA,MEAIB,PIB,FLUMAZENIL,
               AH690,AH691,FMPEPD2,
               PALMITATE,PK11195,PE2I,CARFENTANIL,METOMIDATE,ORMB,
-              PBR28HAB,PBR28MAB,PBR28LAB,SMW139,
+              PBR28HAB,PBR28MAB,PBR28LAB,SMW139,UCBJ,
               MOUSEFDG1,MOUSEFDG2,RATFDG
              } tracerCode;
 /*****************************************************************************/
