@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_absscal
-#: Date       : 2018-04-27
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,7 +11,6 @@ else
 EXT=;
 fi
 PROGRAM=../../absscal$EXT;
-
 if [ ! -f $PROGRAM ]; then
   printf "Failed: executable does not exist.\n"
   exit 1
@@ -372,7 +371,7 @@ if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "\n ok \n"
 
 rm -f test1.dat stdout.txt
-$PROGRAM -c=pump_cal2.dat -i=C-11 t2.bld test1.dat &> stdout.txt
+$PROGRAM -c=pump_cal2.dat -i=C-11 t2.bld test1.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then echo Failed! ; exit 1 ; fi
 iftisval stdout.txt Error "different isotope in file and given by user."
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
@@ -388,7 +387,7 @@ if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "\n ok \n"
 
 rm -f test1.dat stdout.txt
-$PROGRAM -c=pump_cal2.dat -i=C-11 tf04042018_2.bld test1.dat &> stdout.txt
+$PROGRAM -c=pump_cal2.dat -i=C-11 tf04042018_2.bld test1.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then echo Failed! ; exit 1 ; fi
 iftisval stdout.txt Error "different isotope in file and given by user."
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
@@ -753,8 +752,8 @@ printf "\n   should return error \n"
 
 printf "\n ... with pump 2\n\n"
 
-rm -f test1.dat stdout.txt
-$PROGRAM -c=pump_cal2.dat ch_0.bld test1.dat &> stdout.txt
+rm -f test1.dat
+$PROGRAM -c=pump_cal2.dat ch_0.bld test1.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "All values from channel 1 are zeros. Contact the physicist!"
@@ -768,8 +767,8 @@ printf "\n\n4.1.0: Missing Allogg background must lead to an error \n"
 
 printf "\n ... with pump 3\n\n"
 
-rm -f test1.dat stdout.txt
-$PROGRAM -c=pump_cal2.dat -i=C t00061nobkg.alg test1.dat &> stdout.txt
+rm -f test1.dat
+$PROGRAM -c=pump_cal2.dat -i=C t00061nobkg.alg test1.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "t00061nobkg.alg does not contain background."
@@ -778,8 +777,8 @@ printf "\n ok \n"
 
 printf "\n ... with pump 4\n\n"
 
-rm -f test1.dat stdout.txt
-$PROGRAM -c=pump_cal2.dat -i=C ME_ABSS09282_is731dy1_nobkg.txt test1.dat &> stdout.txt
+rm -f test1.dat
+$PROGRAM -c=pump_cal2.dat -i=C ME_ABSS09282_is731dy1_nobkg.txt test1.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "ME_ABSS09282_is731dy1_nobkg.txt does not contain background."
