@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_eabaort
-#: Date       : 2022-02-08
+#: Date       : 2023-06-30
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -394,10 +394,10 @@ iftisval -abs=0.5 output210.tac vessel_diameter 10.0
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-tacmatch -abs=1 tissue.tac bkg210.tac
+tacmatch -abs=1 -rel=1 tissue.tac bkg210.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-tacmatch -abs=3 blood.tac output210.tac
+tacmatch -abs=2 -rel=2 blood.tac output210.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
