@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fit_feng
-#: Date       : 2019-09-20
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -547,8 +547,7 @@ printf "\n 2.0.1 \n"
 printf " Test case: existing constraint file and option -lim=fname.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=output.par &> stdout.txt
+$PROGRAM -lim=output.par 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "parameter constraint file output.par exists."
@@ -560,8 +559,7 @@ printf "\n 2.0.2 \n"
 printf " Test case: trying to use nonexisting constraint file.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=nonexisting.par s2exp.bld output.fit &> stdout.txt
+$PROGRAM -lim=nonexisting.par s2exp.bld output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.par'" "cannot open file"
@@ -573,8 +571,7 @@ printf "\n 2.0.3 \n"
 printf " Test case: trying to use constraint file with bad contents.\n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -lim=badfile.dat s2exp.bld output.fit &> stdout.txt
+$PROGRAM -lim=badfile.dat s2exp.bld output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'badfile.dat'" "file contains no data"
@@ -588,7 +585,7 @@ printf " Expected result 1: Limits are set correctly. \n"
 printf " Expected result 2: With reasonable limits the fit is good. \n\n"
 
 rm -f limit.par
-rm -f stdout.txt output.fit output.bld
+rm -f output.fit output.bld
 
 printf "A1_lower := 250\n" >> limit.par
 printf "A1_upper := 350\n" >> limit.par
@@ -613,7 +610,7 @@ printf "L4_upper := 0\n" >> limit.par
 printf "DT_lower := 0.9\n" >> limit.par
 printf "DT_upper := 1.1\n" >> limit.par
 
-$PROGRAM -d2 -n=4 -lim=limit.par -fast -svg=output.svg -fit=output.bld s4exp.bld output.fit &> stdout.txt
+$PROGRAM -d2 -n=4 -lim=limit.par -fast -svg=output.svg -fit=output.bld s4exp.bld output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[250,350] [150,250] [50,150] [0,50] [-5,-3] [-0.5,-0.3] [-0.05,-0.03] [0,0] [0.9,1.1]"
@@ -633,9 +630,9 @@ printf " Test case 1: Option -delay overwrites limits given with lim file.\n"
 printf " Expected result 1: Limits are set correctly. \n"
 printf " Expected result 2: With reasonable limits the fit is good. \n\n"
 
-rm -f stdout.txt output.fit output.bld
+rm -f output.fit output.bld
 
-$PROGRAM -d2 -n=4 -lim=limit.par -delay=1 -fast -svg=output.svg -fit=output.bld s4exp.bld output.fit &> stdout.txt
+$PROGRAM -d2 -n=4 -lim=limit.par -delay=1 -fast -svg=output.svg -fit=output.bld s4exp.bld output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt constraints "[250,350] [150,250] [50,150] [0,50] [-5,-3] [-0.5,-0.3] [-0.05,-0.03] [0,0] [1,1]"
