@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fit_ppf
-#: Date       : 2023-04-21
+#: Date       : 2023-06-30
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -272,8 +272,7 @@ printf "\n 0.1.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption data1.dat &> stdout.txt
+$PROGRAM -stupidoption data1.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -286,8 +285,7 @@ printf "\n 0.2.0 \n"
 printf " Test case: Defaults. \n"
 printf " Expected result: Default values of variables are correct. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 data1.dat &> stdout.txt
+$PROGRAM -d2 data1.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -331,8 +329,7 @@ printf "\n 0.2.1 \n"
 printf " Test case: Options are correctly interpreted. \n"
 printf " Expected result: Values of variables are correct. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -model=HILL -wf -mrl -nd -delaymin=0,5 -svg=test.svg -mdelay=separated -wp=2 -wm1=1.5 -wm2=1 -wm3=0.5 data1.dat &> stdout.txt
+$PROGRAM -d2 -model=HILL -wf -mrl -nd -delaymin=0,5 -svg=test.svg -mdelay=separated -wp=2 -wm1=1.5 -wm2=1 -wm3=0.5 data1.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -377,8 +374,7 @@ printf "\n 0.3.0 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n"
 
-rm -f stdout.txt
-$PROGRAM -d -model=HILL -wf -mrl -nd &> stdout.txt
+$PROGRAM -d -model=HILL -wf -mrl -nd 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing command-line argument; use option --help"
@@ -390,8 +386,7 @@ printf "\n 0.3.1 \n"
 printf " Test case: Appropriate arguments entered. \n"
 printf " Expected result: Arguments are correctly identified. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 data1.dat test.fit &> stdout.txt
+$PROGRAM -d2 data1.dat test.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt dfile "data1.dat"
@@ -406,8 +401,7 @@ printf "\n 0.3.2 \n"
 printf " Test case: Extra argument entered. \n"
 printf " Expected result: Error. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 data1.dat test.fit extra &> stdout.txt
+$PROGRAM -d2 data1.dat test.fit extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too many arguments: 'extra'."
@@ -420,8 +414,7 @@ printf "\n 1.0.0 \n"
 printf " Test case: Input file does not exist. \n"
 printf " Expected result: Error. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 nonexistingfile.dat test.fit &> stdout.txt
+$PROGRAM -d2 nonexistingfile.dat test.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexistingfile.dat'" "cannot open file"
@@ -433,10 +426,9 @@ printf "\n 1.1.0 \n"
 printf " Test case: Input file in wrong format. \n"
 printf " Expected result: Error. \n"
 
-rm -f test.dat stdout.txt
 echo meh ngh      >  test.dat
 echo zzzzhhhh bop >> test.dat
-$PROGRAM -d2 test.dat test.fit &> stdout.txt
+$PROGRAM -d2 test.dat test.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'test.dat'" "wrong format"
@@ -448,13 +440,13 @@ printf "\n 1.2.0 \n"
 printf " Test case: Input file contains more than one fraction curve. \n"
 printf " Expected result: First is used, and warning is printed. \n"
 
-rm -f output.fit output2.fit stdout.txt
+rm -f output.fit output2.fit
 rm -f output.dat output2.dat
 
 $PROGRAM -model=HILL data1.dat output.fit
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM -model=HILL data1_multi.dat output2.fit &> stdout.txt
+$PROGRAM -model=HILL data1_multi.dat output2.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "extra columns in data1_multi.dat are ignored."
@@ -485,8 +477,7 @@ printf "\n passed. \n\n"
 printf "\n 1.3.1 \n"
 printf "\n Equal number of parameters and samples \n\n"
 
-rm -f stdout.txt
-$PROGRAM -model=HILL data1_snr5.dat output2.fit &> stdout.txt
+$PROGRAM -model=HILL data1_snr5.dat output2.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too few samples for fitting in data1_snr5.dat"
@@ -496,16 +487,14 @@ printf "\n passed. \n\n"
 printf "\n 1.3.2 \n"
 printf "\n ... fixing one parameter helps ... \n\n"
 
-rm -f stdout.txt
-$PROGRAM -model=HILL -d=1 data1_snr5.dat output2.fit &> stdout.txt
+$PROGRAM -model=HILL -d=1 data1_snr5.dat output2.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 printf "\n 1.3.3 \n"
 printf "\n with one sample less the same error \n\n"
 
-rm -f stdout.txt
-$PROGRAM -model=HILL -d=1 data1_snr4.dat output2.fit &> stdout.txt
+$PROGRAM -model=HILL -d=1 data1_snr4.dat output2.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too few samples for fitting in data1_snr4.dat"
@@ -515,24 +504,21 @@ printf "\n passed. \n\n"
 printf "\n 1.3.4 \n"
 printf "\n ... fixing one more parameter helps ... \n\n"
 
-rm -f stdout.txt
-$PROGRAM -model=HILL -d=1 -e=0.5 data1_snr4.dat output2.fit &> stdout.txt
+$PROGRAM -model=HILL -d=1 -e=0.5 data1_snr4.dat output2.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 printf "\n 1.3.5 \n"
 printf "\n One free parameter can be fitted to two samples \n\n"
 
-rm -f stdout.txt
-$PROGRAM -model=HILL -a=0.6002 -b=2.9029 -d=1 -e=0.5 data1_snr2.dat output2.fit &> stdout.txt
+$PROGRAM -model=HILL -a=0.6002 -b=2.9029 -d=1 -e=0.5 data1_snr2.dat output2.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 printf "\n 1.3.6 \n"
 printf "\n ... but not to one sample \n\n"
 
-rm -f stdout.txt
-$PROGRAM -model=HILL -a=0.6002 -b=2.9029 -d=1 -e=0.5 data1_snr1.dat output2.fit &> stdout.txt
+$PROGRAM -model=HILL -a=0.6002 -b=2.9029 -d=1 -e=0.5 data1_snr1.dat output2.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too few samples for fitting in data1_snr1.dat"
@@ -543,8 +529,7 @@ printf "\n passed. \n\n"
 printf "\n 1.3.7 \n"
 printf "\n All parameters can not be fixed \n\n"
 
-rm -f stdout.txt
-$PROGRAM -model=HILL -a=0.6002 -b=2.9029 -c=1012.7 -d=1 -e=0.5 data1_snr1.dat output2.fit &> stdout.txt
+$PROGRAM -model=HILL -a=0.6002 -b=2.9029 -c=1012.7 -d=1 -e=0.5 data1_snr1.dat output2.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too many parameters were fixed."
@@ -558,16 +543,14 @@ printf " Test case: NA in file. \n"
 printf " Expected result: sample gets zero weight. \n\n"
 printf " Expected result: NA is not counted in sample nr. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d3 -model=HILL data1_na.dat output.fit &> stdout.txt
+$PROGRAM -d3 -model=HILL data1_na.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights "1, 1, 1, 1, 1, 1, 1, 0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d3 -wf -model=HILL data1_na.dat output.fit &> stdout.txt
+$PROGRAM -d3 -wf -model=HILL data1_na.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights "0.264463, 0.297521, 0.495868, 0.661157, 0.826446, 0.991736, 1.81818, 0"
@@ -638,13 +621,13 @@ printf "\n 1.6.0 \n"
 printf " Test case: File contains percentages instead of fractions. \n"
 printf " Expected result: Automatically converted to fractions with warning. \n\n"
 
-rm -f output.res output2.res stdout.txt
+rm -f output.res output2.res
 
 $PROGRAM -model=HILL data1.dat output.fit
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM -model=HILL data1_perc.dat output2.fit &> stdout.txt
+$PROGRAM -model=HILL data1_perc.dat output2.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning" "converting percentages to fractions."
@@ -664,16 +647,14 @@ printf " Test case: File contains a fraction that exceeds 1. \n"
 printf " Expected result: Assumed to be percentages, leads to stupid results, \n"
 printf "                  unless option -nd is used. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -model=HILL data1_onehigh.dat output.fit &> stdout.txt
+$PROGRAM -model=HILL data1_onehigh.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning" "converting percentages to fractions."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -nd -model=HILL data1_onehigh.dat output.fit &> stdout.txt
+$PROGRAM -nd -model=HILL data1_onehigh.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning" "converting percentages to fractions."
@@ -1146,9 +1127,7 @@ printf "\n 4.0.0 \n"
 printf " Test case: Extended Hill function without option -MRL \n"
 printf " Expected result: Warning of bad fit. \n\n"
 
-rm -f output.fit stdout.txt
-
-$PROGRAM -model=Hill -svg=data2_bad.svg data2_bad.dat output.fit &> stdout.txt
+$PROGRAM -model=Hill -svg=data2_bad.svg data2_bad.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ ! -f output.fit ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -1161,9 +1140,9 @@ printf "\n 4.0.1 \n"
 printf " Test case: Extended Hill function with option -MRL \n"
 printf " Expected result: Error of bad fit. \n\n"
 
-rm -f output.fit stdout.txt
+rm -f output.fit
 
-$PROGRAM -MRL -model=Hill -svg=data2_bad.svg data2_bad.dat output.fit &> stdout.txt
+$PROGRAM -MRL -model=Hill -svg=data2_bad.svg data2_bad.dat output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ -f output.fit ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -1176,9 +1155,9 @@ printf "\n 4.1.0 \n"
 printf " Test case: Extended Power function without option -MRL \n"
 printf " Expected result: Warning of bad fit. \n\n"
 
-rm -f output.fit stdout.txt
+rm -f output.fit
 
-$PROGRAM -model=PF -svg=data4_bad.svg data4_bad.dat output.fit &> stdout.txt
+$PROGRAM -model=PF -svg=data4_bad.svg data4_bad.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ ! -f output.fit ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -1191,9 +1170,9 @@ printf "\n 4.1.1 \n"
 printf " Test case: Extended Power function with option -MRL \n"
 printf " Expected result: Error of bad fit. \n\n"
 
-rm -f output.fit stdout.txt
+rm -f output.fit
 
-$PROGRAM -mrl -model=PF -svg=data4_bad.svg data4_bad.dat output.fit &> stdout.txt
+$PROGRAM -mrl -model=PF -svg=data4_bad.svg data4_bad.dat output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ -f output.fit ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -1213,9 +1192,7 @@ printf " Test case: Parameter A is fixed. \n"
 printf " Expected result 1: Test print shows correct parameter limits. \n"
 printf " Expected result 2: Fitted parameter is as required. \n\n"
 
-rm -f output.fit stdout.txt
-
-$PROGRAM -d2 -a=0.6 -model=PF data4.dat output.fit &> stdout.txt
+$PROGRAM -d2 -a=0.6 -model=PF data4.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "limit[1]" "0.6 - 0.6"
@@ -1230,9 +1207,7 @@ printf " Test case: Parameter B is fixed. \n"
 printf " Expected result 1: Test print shows correct parameter limits. \n"
 printf " Expected result 2: Fitted parameter is as required. \n\n"
 
-rm -f output.fit stdout.txt
-
-$PROGRAM -d2 -b=1,2 -model=PF data4.dat output.fit &> stdout.txt
+$PROGRAM -d2 -b=1,2 -model=PF data4.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "limit[2]" "1.2 - 1.2"
@@ -1247,9 +1222,7 @@ printf " Test case: Parameter C is fixed. \n"
 printf " Expected result 1: Test print shows correct parameter limits. \n"
 printf " Expected result 2: Fitted parameter is as required. \n\n"
 
-rm -f output.fit stdout.txt
-
-$PROGRAM -d2 -c=0.35 -model=PF data4.dat output.fit &> stdout.txt
+$PROGRAM -d2 -c=0.35 -model=PF data4.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "limit[3]" "0.35 - 0.35"
@@ -1264,9 +1237,7 @@ printf " Test case: Parameter D is fixed. \n"
 printf " Expected result 1: Test print shows correct parameter limits. \n"
 printf " Expected result 2: Fitted parameter is as required. \n\n"
 
-rm -f output.fit stdout.txt
-
-$PROGRAM -d2 -d=0.3 -model=PF data4.dat output.fit &> stdout.txt
+$PROGRAM -d2 -d=0.3 -model=PF data4.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "limit[4]" "0.3 - 0.3"
@@ -1281,9 +1252,7 @@ printf " Test case: Parameter E is fixed. \n"
 printf " Expected result 1: Test print shows correct parameter limits. \n"
 printf " Expected result 2: Fitted parameter is as required. \n\n"
 
-rm -f output.fit stdout.txt
-
-$PROGRAM -d2 -e=2 -model=PF data4.dat output.fit &> stdout.txt
+$PROGRAM -d2 -e=2 -model=PF data4.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "limit[5]" "2 - 2"
@@ -1301,9 +1270,7 @@ printf " Test case 2: Data does not contain zero sample. \n"
 printf " Expected result 1: Option -fix0 is ignored. \n"
 printf " Expected result 2: No warning related to these options. \n\n"
 
-rm -f output.fit stdout.txt
-
-$PROGRAM -d2 -d=0.3 -fix0 -model=PF data4.dat output.fit &> stdout.txt
+$PROGRAM -d2 -d=0.3 -fix0 -model=PF data4.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "limit[4]" "0.3 - 0.3"
@@ -1322,9 +1289,7 @@ printf " Test case 2: Data contains zero sample. \n"
 printf " Expected result 1: Option -d is ignored because of option -fix0. \n"
 printf " Expected result 2: Warning that -d is not effective. \n\n"
 
-rm -f output.fit stdout.txt
-
-$PROGRAM -d2 -d=0.3 -fix0 -model=PF data4z.dat output.fit &> stdout.txt
+$PROGRAM -d2 -d=0.3 -fix0 -model=PF data4z.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "limit[4]" "0.25 - 0.25"
@@ -1345,9 +1310,7 @@ printf " Test case 1: Parameter D is fixed with only -fix0. \n"
 printf " Test case 2: Data contains zero sample. \n"
 printf " Expected result 1: Option -fix0 is effective. \n\n"
 
-rm -f output.fit stdout.txt
-
-$PROGRAM -d2 -fix0 -model=PF data4z.dat output.fit &> stdout.txt
+$PROGRAM -d2 -fix0 -model=PF data4z.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "limit[4]" "0.25 - 0.25"
@@ -1365,11 +1328,11 @@ printf " Test case 1: Parameter D is fixed with -fix0. \n"
 printf " Test case 2: Data contains duplicate samples including zeroes. \n"
 printf " Expected result 1: D is correctly fixed. \n\n"
 
-rm -f temp.dat output.fit stdout.txt
+rm -f temp.dat output.fit
 tacblend --force temp.dat data4z.dat data4z.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 -fix0 -model=PF temp.dat output.fit &> stdout.txt
+$PROGRAM -d2 -fix0 -model=PF temp.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "limit[4]" "0.25 - 0.25"
@@ -1387,9 +1350,9 @@ printf " Test case 1: Parameter D is fixed with -fix0. \n"
 printf " Test case 2: Hill metabolite model, parent level initially 1. \n"
 printf " Expected result: Fitted curve and parameters are close to correct. \n\n"
 
-rm -f output.fit output.res output.dat stdout.txt
+rm -f output.fit output.res output.dat
 
-$PROGRAM -d2 -model=mhill -fix0 -e=1 -svg=hillm3z.svg data_hillm3.dat output.fit &> stdout.txt
+$PROGRAM -d2 -model=mhill -fix0 -e=1 -svg=hillm3z.svg data_hillm3.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -1420,9 +1383,9 @@ printf " Test case: Minimum delay can be set with option -delaymin \n"
 printf " Expected result 1: Test print shows correct parameter limits. \n"
 printf " Expected result 2: Fitted parameter is as required. \n\n"
 
-rm -f output.fit stdout.txt
+rm -f output.fit
 
-$PROGRAM -d2 -delaymin=5 -model=PF data4.dat output.fit &> stdout.txt
+$PROGRAM -d2 -delaymin=5 -model=PF data4.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "limit[5]" "5 - 7.5"
@@ -1438,9 +1401,9 @@ printf " Test case: Minimum delay can be set to zero with option -delaymin \n"
 printf " Expected result 1: Test print shows correct parameter limits. \n"
 printf " Expected result 2: Fitted parameter is as required. \n\n"
 
-rm -f output.fit stdout.txt
+rm -f output.fit
 
-$PROGRAM -d2 -delaymin=0 -model=PF data3.dat output.fit &> stdout.txt
+$PROGRAM -d2 -delaymin=0 -model=PF data3.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "limit[5]" "0 - 5"
@@ -1460,9 +1423,9 @@ printf "\n 6.0.0 \n"
 printf " Test case: No weights in data and not set with options. \n"
 printf " Expected result: Test print shows correct weights. \n\n"
 
-rm -f output.fit stdout.txt
+rm -f output.fit
 
-$PROGRAM -d2 -model=PF data5_noweights.dat output.fit &> stdout.txt
+$PROGRAM -d2 -model=PF data5_noweights.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights "1, 1, 1, 1, 1, 1, 1, 1"
@@ -1474,9 +1437,9 @@ printf "\n 6.0.1 \n"
 printf " Test case: Weights in data but not set with options. \n"
 printf " Expected result: Test print shows correct weights. \n\n"
 
-rm -f output.fit stdout.txt
+rm -f output.fit
 
-$PROGRAM -d2 -model=PF data5_weights.dat output.fit &> stdout.txt
+$PROGRAM -d2 -model=PF data5_weights.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights "0.8, 0.8, 0.8, 0.8, 0.8, 0.8, 1.6, 1.6"
@@ -1489,11 +1452,11 @@ printf "\n 6.1.0 \n"
 printf " Test case: Option -wc, when file only contains times and parent fractions. \n"
 printf " Expected result: Error. \n"
 
-rm -f output.fit stdout.txt
+rm -f output.fit
 tacformat -f=simple -hdr=no -mid data5_weights.dat temp.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 -wc -model=PF temp.dat output.fit &> stdout.txt
+$PROGRAM -d2 -wc -model=PF temp.dat output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "no column for weights in temp.dat"
@@ -1505,7 +1468,7 @@ printf "\n 6.1.1 \n"
 printf " Test case: Option -wc, when file contains times and 2 data cols. \n"
 printf " Expected result: Weights are correctly set. \n"
 
-rm -f output.fit stdout.txt
+rm -f output.fit
 tacformat -f=simple -hdr=no -mid data5_weights.dat temp.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 taccalc -f temp.dat : temp.dat temp2.dat
@@ -1515,7 +1478,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacadd -force temp.dat temp2.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 -wc -model=PF temp.dat output.fit &> stdout.txt
+$PROGRAM -d2 -wc -model=PF temp.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "extra columns in temp.dat are ignored."
@@ -1530,11 +1493,11 @@ printf "\n 6.1.2 \n"
 printf " Test case: Option -wc, when file contains times and 3 data cols. \n"
 printf " Expected result: Weights are correctly set. \n"
 
-rm -f output.fit stdout.txt
+rm -f output.fit
 tacadd -force temp.dat temp2.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -d2 -wc -model=PF temp.dat output.fit &> stdout.txt
+$PROGRAM -d2 -wc -model=PF temp.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "extra columns in temp.dat are ignored."
@@ -1552,9 +1515,9 @@ printf "\n 6.2.0 \n"
 printf " Test case: Option -w1 overrides weights in file. \n"
 printf " Expected result: Weights are correctly set. \n"
 
-rm -f output.fit stdout.txt
+rm -f output.fit
 
-$PROGRAM -d2 -w1 -model=PF data5_weights.dat output.fit &> stdout.txt
+$PROGRAM -d2 -w1 -model=PF data5_weights.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights "1, 1, 1, 1, 1, 1, 1, 1"
@@ -1566,9 +1529,9 @@ printf "\n 6.2.1 \n"
 printf " Test case: Option -wf overrides weights in file. \n"
 printf " Expected result: Weights are correctly set. \n"
 
-rm -f output.fit stdout.txt
+rm -f output.fit
 
-$PROGRAM -d2 -wf -model=PF data5_weights.dat output.fit &> stdout.txt
+$PROGRAM -d2 -wf -model=PF data5_weights.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights "0.8, 0.8, 0.8, 0.8, 0.8, 1, 1.4, 1.6"
@@ -1580,16 +1543,16 @@ printf "\n 6.2.2 \n"
 printf " Test case: Option -wf when samples are not ordered by time. \n"
 printf " Expected result: Weights are correctly set. \n"
 
-rm -f output.fit output2.fit stdout.txt
+rm -f output.fit output2.fit
 
-$PROGRAM -d2 -model=HILL -wf data1_catenated1.dat output.fit &> stdout.txt
+$PROGRAM -d2 -model=HILL -wf data1_catenated1.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights "0.0669145, 0.301115, 0.60223, 0.669145, 0.669145, 1.00372, 1.67286, 2.00743, 2.00743"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-$PROGRAM -d2 -model=HILL -wf data1_catenated2.dat output2.fit &> stdout.txt
+$PROGRAM -d2 -model=HILL -wf data1_catenated2.dat output2.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights "0.0669145, 0.301115, 0.60223, 0.669145, 0.669145, 1.00372, 1.67286, 2.00743, 2.00743"
@@ -1601,9 +1564,9 @@ printf "\n 6.2.3 \n"
 printf " Test case: Option -wf when duplicate samples. \n"
 printf " Expected result: Weights are correctly set. \n"
 
-rm -f output.fit output2.fit stdout.txt
+rm -f output.fit output2.fit
 
-$PROGRAM -d2 -model=HILL -wf data1_duplicated.dat output.fit &> stdout.txt
+$PROGRAM -d2 -model=HILL -wf data1_duplicated.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights "0.408759, 0.408759, 0.459854, 0.459854, 0.766423, 0.766423, 1.0219, 1.0219, 1.27737, 1.27737, 1.53285, 1.53285, 1.53285, 1.53285"
@@ -1622,7 +1585,7 @@ printf " Test case: PMOD BLD format. \n"
 printf " Expected result 1: Data is correctly fitted. \n\n"
 printf " Expected result 2: Fit file contains time unit. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
 $PROGRAM -model=HILL -wf data1.bld output.fit
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -1641,7 +1604,7 @@ printf " Test case: CSV format. \n"
 printf " Expected result 1: Data is correctly fitted. \n\n"
 printf " Expected result 2: Fit file contains time unit. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
 $PROGRAM -model=HILL -wf data1.csv output.fit
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -1660,7 +1623,7 @@ printf " Test case: TSV format. \n"
 printf " Expected result 1: Data is correctly fitted. \n\n"
 printf " Expected result 2: Fit file contains time unit. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
 $PROGRAM -model=HILL -wf data1.tsv output.fit
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
