@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fit_sinf
-#: Date       : 2018-04-22
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -592,10 +592,10 @@ printf "\n 2.0.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Appropriate error message and error code returned. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 fname=c11-carfentanil_metabcorr
 
-$PROGRAM -stupidoption '../ptac/'$fname'.kbq' output.fit &> stdout.txt
+$PROGRAM -stupidoption '../ptac/'$fname'.kbq' output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -607,10 +607,10 @@ printf "\n 2.0.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Appropriate error message and error code returned. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 fname=c11-carfentanil_metabcorr
 
-$PROGRAM '../ptac/'$fname'.kbq' output.fit extra &> stdout.txt
+$PROGRAM '../ptac/'$fname'.kbq' output.fit extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -622,9 +622,9 @@ printf "\n 2.1.0 \n"
 printf " Test case: Nonexisting data file. \n"
 printf " Expected result: Appropriate error message and error code returned. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM nonexistingfile.dat output.fit &> stdout.txt
+$PROGRAM nonexistingfile.dat output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexistingfile.dat'" "cannot open file"
