@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fitdelay
-#: Date       : 2020-01-24
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,7 +11,6 @@ else
 EXT=;
 fi
 PROGRAM=../../fitdelay$EXT;
-
 if [ ! -f $PROGRAM ]; then
   printf "Failed: executable does not exist.\n"
   exit 1
@@ -382,8 +381,7 @@ printf "\n 3.0.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption flumazenil_delayed_apc.bld flumazenil.head 300 &> stdout.txt
+$PROGRAM -stupidoption flumazenil_delayed_apc.bld flumazenil.head 300 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -395,8 +393,7 @@ printf "\n 3.1.0 \n"
 printf " Test case: Non-existing input file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.dat flumazenil.head 300 &> stdout.txt
+$PROGRAM nonexistingfile.dat flumazenil.head 300 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -405,8 +402,7 @@ printf "\n 3.1.1 \n"
 printf " Test case: Non-existing tissue file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM flumazenil_delayed_apc.bld nonexistingfile.dat 600 &> stdout.txt
+$PROGRAM flumazenil_delayed_apc.bld nonexistingfile.dat 600 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -415,8 +411,7 @@ printf "\n 3.1.2 \n"
 printf " Test case: Fittime missing. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM flumazenil_delayed_apc.bld flumazenil.head &> stdout.txt
+$PROGRAM flumazenil_delayed_apc.bld flumazenil.head 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -425,8 +420,7 @@ printf "\n 3.1.3 \n"
 printf " Test case: Too many input files. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM flumazenil_delayed_apc.bld flumazenil.head 900 flumazenil_delayed_ab.bld flumazenil_delayed_ab.bld flumazenil_delayed_ab.bld flumazenil_delayed_ab.bld flumazenil_delayed_ab.bld &> stdout.txt
+$PROGRAM flumazenil_delayed_apc.bld flumazenil.head 900 flumazenil_delayed_ab.bld flumazenil_delayed_ab.bld flumazenil_delayed_ab.bld flumazenil_delayed_ab.bld flumazenil_delayed_ab.bld 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -435,8 +429,7 @@ printf "\n 3.1.4 \n"
 printf " Test case: Nonexisting extra file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM flumazenil_delayed_apc.bld flumazenil.head 900 nonexistingfile.dat &> stdout.txt
+$PROGRAM flumazenil_delayed_apc.bld flumazenil.head 900 nonexistingfile.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -446,11 +439,11 @@ printf "\n 3.2.0 \n"
 printf " Test case: Input peak is missed. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt nopeak.bld
+rm -f nopeak.bld
 tactime -nogap flumazenil_apc.bld -3 nopeak.bld 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM nopeak.bld flumazenil.head 900 &> stdout.txt
+$PROGRAM nopeak.bld flumazenil.head 900 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missed the ascending phase of plasma/blood data."
@@ -461,8 +454,7 @@ printf "\n 3.2.1 \n"
 printf " Test case: Tissue peak is missed. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM radiowater_delayed.bld nopeak.bld 360 &> stdout.txt
+$PROGRAM radiowater_delayed.bld nopeak.bld 360 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missed the ascending phase of tissue data."
