@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_metabcor
-#: Date       : 2015-11-20
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,11 @@ else
 EXT=;
 fi
 PROGRAM=../../metabcor$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -19,11 +24,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 
 
 if [ ! -f correct_data1_1_3_pure.dat ] || [ ! -f correct_data1_1_4_pure.dat ] ; then
@@ -112,9 +112,7 @@ printf " Test case: Plasma file contains more than one TAC. \n"
 printf " Expected result 1: First is used, and warning is printed. \n"
 printf " Expected result 2: Calculated parent TAC is correct. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_1_3.dat data1_x_x.rat &> stdout.txt
+$PROGRAM data1_1_3.dat data1_x_x.rat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "plasma file contains several TACs; only the first is used."
@@ -131,9 +129,7 @@ printf " Test case: Plasma file contains missing value. \n"
 printf " Expected result 1: Missing value not included in results. \n"
 printf " Expected result 2: Calculated parent TAC is correct. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_1_4.dat data1_x_x.rat &> stdout.txt
+$PROGRAM data1_1_4.dat data1_x_x.rat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -x=y -y=y correct_data1_1_4_pure.dat data1_1_4_pure.dat
@@ -150,7 +146,7 @@ rm -f stdout.txt
 cp -f data1_3_2.dat temp.dat
 printf "1000 1\n" >> temp.dat
 
-$PROGRAM temp.dat data1_x_x.rat &> stdout.txt
+$PROGRAM temp.dat data1_x_x.rat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "excessive extrapolation needed for fractions."
@@ -162,9 +158,7 @@ printf "\n 1.1.1 \n"
 printf " Test case: Discrete fractions must not be extrapolated too much. \n"
 printf " Expected result: Warning when only reasonable extrapolation. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_3_2.dat data1_x_x.rat &> stdout.txt
+$PROGRAM data1_3_2.dat data1_x_x.rat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "excessive extrapolation needed for fractions."
@@ -176,9 +170,7 @@ printf "\n 1.2.0 \n"
 printf " Test case: Sum of discrete fractions is clearly over 100. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_x_x.dat data1_3_3.rat &> stdout.txt
+$PROGRAM data1_x_x.dat data1_3_3.rat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid fraction values."
@@ -190,9 +182,7 @@ printf "\n 1.2.1 \n"
 printf " Test case: Sum of discrete fractions is clearly over 1 but less than 100. \n"
 printf " Expected result: Fractions divided by 100. Warning. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_3_4.dat data1_3_4.rat &> stdout.txt
+$PROGRAM data1_3_4.dat data1_3_4.rat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "converting percentages to fractions."
@@ -207,9 +197,7 @@ printf "\n 1.2.2 \n"
 printf " Test case: Discrete parent fractions contain a missing value. \n"
 printf " Expected result: Missing value is replaced by interpolated value. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_3_4.dat data1_3_5.rat &> stdout.txt
+$PROGRAM data1_3_4.dat data1_3_5.rat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch correct_data1_3_4_pure.dat data1_3_4_pure.dat
@@ -221,9 +209,7 @@ printf "\n 1.2.3 \n"
 printf " Test case: Discrete metabolite fractions contain a missing value. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_3_4.dat data1_3_6.rat &> stdout.txt
+$PROGRAM data1_3_4.dat data1_3_6.rat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "missing metabolite fraction(s)."
@@ -235,9 +221,7 @@ printf "\n 1.2.4 \n"
 printf " Test case: Discrete fractions file contain over 4 fractions. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_3_4.dat data1_3_7.rat &> stdout.txt
+$PROGRAM data1_3_4.dat data1_3_7.rat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in 'data1_3_7.rat'" "too many metabolites."
@@ -252,9 +236,7 @@ printf "\n 1.3.0 \n"
 printf " Test case: Fitted fractions must be excessively extrapolated. \n"
 printf " Expected result: Warning. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_x_x.dat data1_4_1.fit &> stdout.txt
+$PROGRAM data1_x_x.dat data1_4_1.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning" "excessive extrapolation needed for fractions."
@@ -267,9 +249,7 @@ printf "\n 1.3.1 \n"
 printf " Test case: Sum of fitted fractions exceeds 100. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_x_x.dat data1_4_2.fit &> stdout.txt
+$PROGRAM data1_x_x.dat data1_4_2.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "invalid fraction values."
@@ -282,9 +262,7 @@ printf "\n 1.3.2 \n"
 printf " Test case: Sum of fitted fractions exceeds 1 but not 100. \n"
 printf " Expected result: Warning. Automatically converted to fractions.\n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_x_x.dat data1_4_3.fit &> stdout.txt
+$PROGRAM data1_x_x.dat data1_4_3.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning" "converting percentages to fractions."
@@ -310,9 +288,7 @@ printf "\n 1.3.3 \n"
 printf " Test case: More than 4 fitted fractions. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_x_x.dat data1_4_4.fit &> stdout.txt
+$PROGRAM data1_x_x.dat data1_4_4.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in 'data1_4_4.fit'" "too many metabolites."
@@ -327,9 +303,7 @@ printf "\n 1.4.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM -nonexistingoption data1_x_x.dat data1_x_x.rat &> stdout.txt
+$PROGRAM -nonexistingoption data1_x_x.dat data1_x_x.rat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-nonexistingoption'."
@@ -341,9 +315,7 @@ printf "\n 1.4.1 \n"
 printf " Test case: Too many arguments. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_x_x.dat data1_x_x.rat extra &> stdout.txt
+$PROGRAM data1_x_x.dat data1_x_x.rat extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -357,7 +329,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: discrete fractions for parent tracer only. \n"
 printf " Expected result: Correct parent and one metabolite TAC calculated. \n\n"
 
-rm -f stdout.txt data2_1_1_pure.dat data2_1_1_met.dat
+rm -f data2_1_1_pure.dat data2_1_1_met.dat
 
 $PROGRAM data2_1_1.dat data2_1_1.rat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -373,7 +345,7 @@ printf "\n 2.0.1 \n"
 printf " Test case: discrete fractions for parent tracer and metabolite, sum 1. \n"
 printf " Expected result: Correct parent and one metabolite TAC calculated. \n\n"
 
-rm -f stdout.txt data2_1_1_pure.dat data2_1_1_met.dat
+rm -f data2_1_1_pure.dat data2_1_1_met.dat
 
 $PROGRAM data2_1_1.dat data2_1_2.rat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -389,7 +361,7 @@ printf "\n 2.0.2 \n"
 printf " Test case: discrete fractions for parent tracer and metabolite, sum less than 1. \n"
 printf " Expected result: Correct parent and two metabolite TACs calculated. \n\n"
 
-rm -f stdout.txt data2_1_3_pure.dat data2_1_3_met.dat data2_1_3_met2.dat
+rm -f data2_1_3_pure.dat data2_1_3_met.dat data2_1_3_met2.dat
 
 $PROGRAM data2_1_3.dat data2_1_3.rat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -409,7 +381,7 @@ printf "\n 2.0.2 \n"
 printf " Test case: discrete fractions for parent tracer and 2 metabolite, sum 1. \n"
 printf " Expected result: Correct parent and two metabolite TACs calculated. \n\n"
 
-rm -f stdout.txt data2_1_3_pure.dat data2_1_3_met.dat data2_1_3_met2.dat
+rm -f data2_1_3_pure.dat data2_1_3_met.dat data2_1_3_met2.dat
 
 $PROGRAM data2_1_3.dat data2_1_4.rat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -430,7 +402,7 @@ printf "\n 2.0.3 \n"
 printf " Test case: discrete fractions for parent tracer and 2 metabolite, sum less than 1. \n"
 printf " Expected result: Correct parent and 3 metabolite TACs calculated. \n\n"
 
-rm -f stdout.txt data2_1_5_pure.dat data2_1_5_met.dat data2_1_5_met2.dat data2_1_5_met3.dat
+rm -f data2_1_5_pure.dat data2_1_5_met.dat data2_1_5_met2.dat data2_1_5_met3.dat
 
 $PROGRAM data2_1_5.dat data2_1_5.rat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -515,9 +487,7 @@ printf "\n 3.2.0 \n"
 printf " Test case: Exponential function fitted to 4 percentages (fit_exp). \n"
 printf " Expected result: Correct parent TAC calculated. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM data1_x_x.dat data2_4_1.fit &> stdout.txt
+$PROGRAM data1_x_x.dat data2_4_1.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning" "converting percentages to fractions."
