@@ -67,16 +67,16 @@ printf "=====================================================================\n"
 
 printf "\n 0.1.0 Unknown option \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 -stupidoption PE2I input.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 -stupidoption PE2I input.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 -stupidoption PE2I input.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 -stupidoption PE2I input.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -87,16 +87,16 @@ printf "\n===================================================================\n"
 
 printf "\n0.2.0 Extra argument \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 PE2I input.kbq 0.40 output.kbq extra &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 PE2I input.kbq 0.40 output.kbq extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 PE2I input.kbq 0.40 output.kbq extra &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 PE2I input.kbq 0.40 output.kbq extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -107,8 +107,8 @@ printf "\n===================================================================\n"
 
 printf "\n0.3.0 Option -Log \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 -d -log PE2I input.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 -d -log PE2I input.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt save_log "1"
@@ -118,8 +118,8 @@ iftisval output.kbq HCT "0.40"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 -d -log PE2I input.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 -d -log PE2I input.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt save_log "1"
@@ -134,16 +134,16 @@ printf "\n===================================================================\n"
 
 printf "\n0.4.0 Unknown tracer code \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 NONEXISTING input.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 NONEXISTING input.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid tracer code 'NONEXISTING'."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 NONEXISTING input.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 NONEXISTING input.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid tracer code 'NONEXISTING'."
@@ -154,13 +154,13 @@ printf "\n===================================================================\n"
 
 printf "\n0.5.0 Missing tracer code \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 input.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 input.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 input.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 input.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -170,13 +170,13 @@ printf "\n===================================================================\n"
 
 printf "\n0.5.1 Missing input file \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 PE2I 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 PE2I 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 PE2I 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 PE2I 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -186,13 +186,13 @@ printf "\n===================================================================\n"
 
 printf "\n0.5.2 Missing hematocrit \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 PE2I input.kbq output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 PE2I input.kbq output.kbq 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 PE2I input.kbq output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 PE2I input.kbq output.kbq 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -203,12 +203,12 @@ printf "\n===================================================================\n"
 printf "\n0.5.3 Missing output file \n\n"
 
 rm -f stdout.txt output.kbq
-$PROGRAM1 PE2I input.kbq 0.40 &> stdout.txt
+$PROGRAM1 PE2I input.kbq 0.40 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 PE2I input.kbq 0.40 &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 PE2I input.kbq 0.40 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -218,16 +218,16 @@ printf "\n===================================================================\n"
 
 printf "\n1.0.0 NORBC \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 norbc NORBC_b.kbq 0.37 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 norbc NORBC_b.kbq 0.37 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y input.kbq output.kbq
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 norbc input.kbq 0.37 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 norbc input.kbq 0.37 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y NORBC_b.kbq output.kbq
@@ -238,16 +238,16 @@ printf "\n===================================================================\n"
 
 printf "\n1.1.0 FTHA \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 ftha NORBC_b.kbq 0.37 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 ftha NORBC_b.kbq 0.37 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y input.kbq output.kbq
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 ftha input.kbq 0.37 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 ftha input.kbq 0.37 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y NORBC_b.kbq output.kbq
@@ -258,16 +258,16 @@ printf "\n===================================================================\n"
 
 printf "\n1.2.0 PK11195 \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 PK11195 PK11195_b.kbq 0.41 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 PK11195 PK11195_b.kbq 0.41 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y input.kbq output.kbq
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 pk11195 input.kbq 0.41 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 pk11195 input.kbq 0.41 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y PK11195_b.kbq output.kbq
@@ -278,16 +278,16 @@ printf "\n===================================================================\n"
 
 printf "\n1.3.0 PE2I \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 PE2I PE2I_b.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 PE2I PE2I_b.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y input.kbq output.kbq
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 pe2i input.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 pe2i input.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y PE2I_b.kbq output.kbq
@@ -298,16 +298,16 @@ printf "\n===================================================================\n"
 
 printf "\n1.4.0 Metomidate \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 Metomidate MTO_b.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 Metomidate MTO_b.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y input.kbq output.kbq
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 MTO input.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 MTO input.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y MTO_b.kbq output.kbq
@@ -318,16 +318,16 @@ printf "\n===================================================================\n"
 
 printf "\n1.5.0 InWater \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 inwater MTO_b.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 inwater MTO_b.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y input.kbq output.kbq
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 inwater input.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 inwater input.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y MTO_b.kbq output.kbq
@@ -338,16 +338,16 @@ printf "\n===================================================================\n"
 
 printf "\n1.6.0 RATFDG \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 ratfdg test_ratfdg_ab.kbq 0,4 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 ratfdg test_ratfdg_ab.kbq 0,4 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y test_ratfdg_ap.kbq output.kbq
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 RATFDG test_ratfdg_ap.kbq 0,4 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 RATFDG test_ratfdg_ap.kbq 0,4 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y test_ratfdg_ab.kbq output.kbq
@@ -358,11 +358,11 @@ printf "\n===================================================================\n"
 
 printf "\n2.0.0 Time units: sec \n\n"
 
-rm -f stdout.txt output.kbq secinput.kbq
+rm -f output.kbq secinput.kbq
 cp -f PE2I_b.kbq secinput.kbq
 tacunit -xconv=sec secinput.kbq
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-$PROGRAM1 pe2i secinput.kbq 0.40 output.kbq &> stdout.txt
+$PROGRAM1 pe2i secinput.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacunit -xconv=min output.kbq
@@ -371,11 +371,11 @@ tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y input.kbq outpu
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq secinput.kbq
+rm -f output.kbq secinput.kbq
 cp -f input.kbq secinput.kbq
 tacunit -xconv=sec secinput.kbq
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-$PROGRAM2 pe2i secinput.kbq 0.40 output.kbq &> stdout.txt
+$PROGRAM2 pe2i secinput.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacunit -xconv=min output.kbq
@@ -388,16 +388,16 @@ printf "\n===================================================================\n"
 
 printf "\n2.0.1 Time units: min \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM1 pe2i PE2I_b.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM1 pe2i PE2I_b.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y input.kbq output.kbq
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM2 pe2i input.kbq 0.40 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM2 pe2i input.kbq 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=y -xunit=y -yunit=y PE2I_b.kbq output.kbq
@@ -408,20 +408,20 @@ printf "\n===================================================================\n"
 
 printf "\n2.0.2 Time units: min , but not given in datafile \n\n"
 
-rm -f stdout.txt output.kbq input.dat
+rm -f output.kbq input.dat
 tacformat -f=SIMPLE -hdr=n PE2I_b.kbq input.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-$PROGRAM1 pe2i input.dat 0.40 output.kbq &> stdout.txt
+$PROGRAM1 pe2i input.dat 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=n -xunit=n -yunit=n input.kbq output.kbq
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.kbq input.dat
+rm -f output.kbq input.dat
 tacformat -f=SIMPLE -hdr=n input.kbq input.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-$PROGRAM2 pe2i input.dat 0.40 output.kbq &> stdout.txt
+$PROGRAM2 pe2i input.dat 0.40 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 -x=y -y=y -tacnames=n -xunit=n -yunit=n PE2I_b.kbq output.kbq
