@@ -216,8 +216,8 @@ int dftRead(
       cptr=strtok(lptr, " \t\n\r"); if(cptr==NULL) continue; else i++;
       if(i==1) { /* VOI names */
         for(j=0; j<voiNr; j++) {
-          if((cptr=strtok(NULL, " \t\n\r"))==NULL) {
-            strcpy(dfterrmsg, "wrong format"); free(line); fclose(fp); return 103;}
+          cptr=strtok(NULL, " \t\n\r");
+          if(cptr==NULL) {strcpy(dfterrmsg, "wrong format"); free(line); fclose(fp); return 103;}
           if(strlen(cptr)>1 || *cptr!='.') {
             strncpy(data->voi[j].name, cptr, MAX_REGIONNAME_LEN);
             data->voi[j].name[MAX_REGIONNAME_LEN]=(char)0;
