@@ -88,16 +88,14 @@ typedef struct {
   char          radiopharmaceutical[32];
   /** Isotope (for example C-11, Cu-62, unknown) */
   char          isotope[8];
-  /** Decay correction: DFT_DECAY_UNKNOWN, DFT_DECAY_CORRECTED,
-   *                    DFT_DECAY_NOTCORRECTED */
+  /** Decay correction: DFT_DECAY_UNKNOWN, DFT_DECAY_CORRECTED, DFT_DECAY_NOTCORRECTED */
   char          decayCorrected;
   /** Scan start date and time: YYYY-MM-DD hh:mm:ss */
   char          scanStartTime[20];
   /** Tracer injection date and time: YYYY-MM-DD hh:mm:ss */
   char          injectionTime[20];
   /* Specified frame time */
-  /** Available frame times: DFT_TIME_MIDDLE, DFT_TIME_START, DFT_TIME_END,
-   *                         DFT_TIME_STARTEND */
+  /** Available frame times: DFT_TIME_MIDDLE, DFT_TIME_START, DFT_TIME_END, DFT_TIME_STARTEND */
   int           timetype;
   /* Pointers to time values */
   /** Middle frame time */
@@ -123,8 +121,7 @@ typedef struct {
   /** Internal variable: Number of allocated curves (VOIs)*/
   int           _voidataNr;
 /// @endcond
-  /** Internal variable: 0=plain datafile, 1=standard DFT, ...;
-                         use defines DFT_FORMAT_X */
+  /** Internal variable: 0=plain datafile, 1=standard DFT, ...; use defines DFT_FORMAT_X */
   int           _type;
   } DFT;
 
@@ -251,21 +248,25 @@ enum mathfuncs {
   MF_LUNDQVIST=321, MF_LUNDQVIST2, MF_LUNDQVIST3,
   MF_EXPBOLUSINF=331, MF_EXPBOLUSINF_RW=332, MF_MF_EXPBOLUSINF_AZ=334,
   MF_PK11195=351,
+  MF_PPFIGAM=403,
+  MF_PF_MU=831,
   MF_HILL=841, MF_1MHILL=842, MF_1MHILL_ADE=843, MF_HILL_B=844, MF_AMHILL=845,
   MF_EHILL_PAR=846, MF_EHILL_MET=847,
   MF_EHILL2_PAR=848, MF_EHILL2_MET=849,
   MF_MAMEDE=851, MF_1MMAMEDE,
-  MF_MAYER_PAR=861, MF_MAYER_MET, MF_EMAYER_PAR, MF_EMAYER_MET,
+  MF_MAYER_PAR=861, MF_MAYER_MET, MF_EMAYER_PAR=863, MF_EMAYER_MET,
   MF_HILL3M_PAR=871, MF_HILL3M_M1, MF_HILL3M_M2, MF_HILL3M_M3, 
   MF_PF3M_PAR=881, MF_PF3M_M1, MF_PF3M_M2, MF_PF3M_M3, 
+  MF_STEP=1010,
   MF_RATF33D=1232,
-  MF_FENGM2=1313, MF_FENGM2E=1314,
+  MF_FENGM2S=1312, MF_FENGM2=1313, MF_FENGM2E=1314,
   MF_GAMMAV=1401, MF_GAMMAVB=1402, MF_GAMMAVR=1403,
   MF_WEIBULLCDF_D=1421, MF_WEIBULLCDF_DD=1423,
   MF_SURGE=1431, MF_SURGE_TRAD=1432, MF_SURGE_RECIRC=1433, MF_P2B_SRC=1434, MF_SURGE_FDG=1435,
   MF_ERLANGPDF=1441,
   MF_HILL_D=1801, MF_HILL_DD=1811, MF_HILL_SDD=1821,
   MF_IMGPROFILE=2111,
+  MF_P2B_RF=2233, MF_P2B_FM2=2313, MF_P2B_HILL=2841,
   MF_GRAHAM_INP=9501, MF_GRAHAM_EINP, MF_GRAHAM_INPM,
   MF_HUANG_MET=9601, MF_CARSON_EMET, MF_NEW_MET,
   MF_MLMCM=9701,
@@ -619,6 +620,8 @@ extern int fitDerivEval(FitVOI *r, double x, double *yd);
 extern int fitDerivEvaltac(FitVOI *r, double *x, double *yd, int dataNr);
 extern unsigned int factorial(unsigned int n);
 extern unsigned long long int lfactorial(unsigned long long int n);
+extern double igam(double a, double x);
+extern double igamc(double a, double x);
 
 /// @cond
 /* Deprecated functions. Please don't use these anymore */
