@@ -14,10 +14,14 @@
 
 /*****************************************************************************/
 static char *tpclicense[] = {
-  "This program comes with ABSOLUTELY NO WARRANTY.",
-  "This is free software, and you are welcome to redistribute it under",
-  "GNU General Public License. Source codes are available in",
-  "https://gitlab.utu.fi/vesoik/tpcclib.git",
+  "This program comes with ABSOLUTELY NO WARRANTY. This is free software, and",
+  "you are welcome to redistribute it under GNU General Public License v3.",
+  "Source codes are available in https://gitlab.utu.fi/vesoik/tpcclib.git",
+  0};
+static char *tpclicense4html[] = {
+  "This program comes with ABSOLUTELY NO WARRANTY. This is free software, and you are welcome",
+  "to redistribute it under <a href=\"https://www.gnu.org/licenses/gpl-3.0.html\">GNU General Public License</a>.",
+  "Source codes are available in <a href=\"https://gitlab.utu.fi/vesoik/tpcclib.git\">https://gitlab.utu.fi/vesoik/tpcclib.git</a>.",
   0};
 static char *tpcstdoptions[] = {
   " -h, --help",
@@ -165,7 +169,7 @@ void tpcPrintUsage(
 int tpcHtmlUsage(
   /** Program name, may contain extension and path. */
   const char *program,
-  /** Program usage text */
+  /** Program usage text. */
   char *text[],
   /** Path name where to create file programname.html; path may contain trailing '/' or '\\'.   */
   const char *path
@@ -196,17 +200,27 @@ int tpcHtmlUsage(
   /* Write HTML header */
   len=fprintf(fp, "<!DOCTYPE html>\n");
   if(len<10) {free(bprogram); free(fname); return 2;}
-  fprintf(fp, "<html>\n");
+  fprintf(fp, "<html lang=\"en-GB\">\n");
   fprintf(fp, "<head>\n");
-  fprintf(fp, "  <meta charset=\"UTF-8\">\n");
+  fprintf(fp, "  <meta charset=\"utf-8\">\n");
+  fprintf(fp, "  <meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0\">\n");
   fprintf(fp, "  <title>%s</title>\n", bprogram);
   fprintf(fp, "  <style type=\"text/css\">\n");
-  fprintf(fp, "    * {font-family: monospace;}\n");
+  fprintf(fp, "    body {\n");
+  fprintf(fp, "      margin-left: 2em;\n");
+  fprintf(fp, "      font-family: monospace;\n");
+  fprintf(fp, "      font-size: 1em;\n");
+  fprintf(fp, "    }\n");
+  fprintf(fp, "    h1 {\n");
+  fprintf(fp, "      font-size: 1.3em;\n");
+  fprintf(fp, "      margin-top: 1em;\n");
+  fprintf(fp, "      margin-bottom: 1em;\n");
+  fprintf(fp, "    }\n");
   fprintf(fp, "    footer {\n");
   fprintf(fp, "      border:1px solid gray;\n");
-  fprintf(fp, "      font-size: smaller;\n");
+  fprintf(fp, "      font-size: 0.8em;\n");
   fprintf(fp, "    }\n");
-  fprintf(fp, "    img {border-width: 0px;}\n");
+  fprintf(fp, "    footer p {margin-left: 1em;}\n");
   fprintf(fp, "  </style>\n");
   fprintf(fp, "</head>\n\n");
   
@@ -215,14 +229,14 @@ int tpcHtmlUsage(
   
   /* Write program name, version and copyright as title; */
   /* replace (c) with html code when necessary */
-  fprintf(fp, "<h2>%s - tpcclib %d.%d.%d ", bprogram, tpcclib_VERSION_MAJOR,
+  fprintf(fp, "<h1>%s - tpcclib %d.%d.%d ", bprogram, tpcclib_VERSION_MAJOR,
           tpcclib_VERSION_MINOR, tpcclib_VERSION_PATCH);
   line=tpcclib_COPYRIGHT; len=strlen(line);
   for(j=0; j<len; j++) {
     if(strncasecmp(line+j, "(C)", 3)==0) {fputs("&copy;", fp); j+=2; continue;}
     fputc(line[j], fp);
   }
-  fputs("</h2>\n\n", fp);
+  fputs("</h1>\n\n", fp);
 
   /* Print usage */
   fprintf(fp, "<pre>\n");
@@ -301,21 +315,11 @@ int tpcHtmlUsage(
 
   /* Write footer */
   fprintf(fp, "\n<footer>\n");
-
-  /* Licence info */
-  fprintf(fp, "<div>\n");
-  /* Icon with link to GNU-GPL */
-  fprintf(fp, "<a href=\"http://www.gnu.org/licenses/gpl-3.0-standalone.html\">\n");
-  fprintf(fp, "<img alt=\"GNU GPL\" ");
-  fprintf(fp, "style=\"width:88px; height:31px; float:left; margin: 5px 20px 5px 5px;\"");
-  fprintf(fp, "\n src=\"http://www.turkupetcentre.net/petanalysis/pic/gplv3-88x31.png\"></a>\n");
-  /* Text */
   fprintf(fp, "<p>");
-  i=0; while(tpclicense[i]!=0) fprintf(fp, "%s<br>\n", tpclicense[i++]);
+  i=0; while(tpclicense4html[i]!=0) fprintf(fp, "%s<br>\n", tpclicense4html[i++]);
   fprintf(fp, "</p>\n");
-  fprintf(fp, "</div>\n");
   fprintf(fp, "</footer>\n");
-           
+
   /* Close HTML */
   fprintf(fp, "</body>\n");
   fprintf(fp, "</html>\n");
