@@ -639,7 +639,8 @@ size_t strlcpy(
    */ 
   size_t dstsize
 ) {
-  if(src==NULL) return(0);
+  if(dstsize>0) dst[0]='\0';
+  if(strlen(src)==0) return(0);
 
   char *d=dst;
   const char *s=src;
@@ -743,7 +744,7 @@ char *strEncodeForXML(
   }
   if(n==0) return(NULL);
   /* Allocate memory for new string (one char to max 6 chars) */
-  n*=5; n+=strlen(s);
+  n*=5; n+=strlen(s)+1;
   char *ns=(char*)malloc(n*sizeof(char));
   if(ns==NULL) return(NULL);
   /* Process the string */
