@@ -1226,12 +1226,6 @@ int test_strlcat(
   if(verbose>1) printf("-> n=%zu str1='%s'\n", n, str1);
   if(n!=1 || strcmp(str1, "b")!=0) return(12);
 
-  strcpy(str1, "a"); strcpy(str2, "NULL"); m=2;
-  if(verbose>1) printf("strlcat('%s', '%s', %zu)\n", str1, str2, m);
-  n=strlcat(str1, NULL, m);
-  if(verbose>1) printf("-> n=%zu str1='%s'\n", n, str1);
-  if(n!=1 || strcmp(str1, "a")!=0) return(13);
-
 
   strcpy(str1, "abcdefgh"); strcpy(str2, "ijklmnop"); m=10;
   if(verbose>1) printf("strlcat('%s', '%s', %zu)\n", str1, str2, m);
@@ -1293,12 +1287,6 @@ int test_strlcpy(
   if(verbose>1) printf("-> n=%zu str1='%s'\n", n, str1);
   if(n!=0 || strcmp(str1, "")!=0) return(1);
 
-  strcpy(str1, ""); strcpy(str2, "NULL"); m=0;
-  if(verbose>1) printf("strlcpy('%s', '%s', %zu)\n", str1, str2, m);
-  n=strlcpy(str1, NULL, m);
-  if(verbose>1) printf("-> n=%zu str1='%s'\n", n, str1);
-  if(n!=0 || strcmp(str1, "")!=0) return(2);
-
   strcpy(str1, "xyz"); strcpy(str2, "abcdefgh"); m=0;
   if(verbose>1) printf("strlcpy('%s', '%s', %zu)\n", str1, str2, m);
   n=strlcpy(str1, str2, m);
