@@ -187,14 +187,17 @@ typedef enum {
 /// (table can not be accessed directly outside the c file).
 /// @sa tpcerrormsg, statusmsg.c, TPCSTATUS
 typedef enum {
+// tpcerrormsg[] in statusmsg.c must be edited accordingly
   TPCERROR_OK,                 ///< No error
   TPCERROR_FAIL,               ///< General error
   TPCERROR_OUT_OF_MEMORY,      ///< Cannot allocate memory
   TPCERROR_NO_FILE,            ///< File does not exist
+  TPCERROR_FILE_EXISTS,        ///< File exists
   TPCERROR_INVALID_FILENAME,   ///< Invalid file name
   TPCERROR_CANNOT_OPEN,        ///< Cannot open file
   TPCERROR_CANNOT_READ,        ///< Cannot read file
   TPCERROR_CANNOT_WRITE,       ///< Cannot write file
+  TPCERROR_CANNOT_DELETE,      ///< Cannot delete
   TPCERROR_INVALID_FORMAT,     ///< Invalid file format
   TPCERROR_UNSUPPORTED,        ///< Unsupported file type
   TPCERROR_NO_DATA,            ///< File contains no data
