@@ -45,6 +45,21 @@ int mfEvalY(
   }
   if(parNr<1 || p==NULL || sampleNr<1 || x==NULL || y==NULL) return(1);
 
+  if(strcasecmp(fid, "step")==0) {
+    /* Parameter number must be an even number and >=2 */
+    if(parNr<2 || parNr&1) return(2);
+    for(int i=0; i<sampleNr; i++) {
+      y[i]=0.0;
+      for(int j=0; j<parNr; j+=2) if(x[i]>=p[j]) y[i]=p[j+1];
+    }
+    return(0);
+  }
+
+  if(strcasecmp(fid, "level")==0) {
+    for(int i=0; i<sampleNr; i++) y[i]=p[0];
+    return(0);
+  }
+
   if(strcasecmp(fid, "fengm2")==0) {
     if(parNr<6) return(2);
     double delayt=0.0; if(parNr>6) delayt=p[6];
@@ -145,6 +160,21 @@ int mfEvalY(
     return(0);
   }
 
+  /* Inverted gamma cdf for plasma parent fraction */
+  if(strcasecmp(fid, "ppfigamc")==0) {
+    if(parNr<4) return(2);
+    double delayt=0.0; if(parNr>4) delayt=p[4];
+    double a=p[0];
+    double b=p[1];
+    double c=p[2]; if(c<0.0) return(2);
+    double d=p[3]; if(d<=0.0) return(2);
+    for(int i=0; i<sampleNr; i++) {
+      double t=x[i]-delayt; if(t<0.0) t=0.0;
+      y[i]=a*(1.0-b*igam(d, c*t));
+    }
+    return(0);
+  }
+
   /* Weibull cdf with time delay */
   if(strcasecmp(fid, "weibullcdfd")==0) {
     if(parNr<4) return(2);
@@ -211,6 +241,22 @@ int mfEvalY(
     return(0);
   }
 
+  /* Surge function with recirculation and delay, in form
+     f(x)=a*((x-d)*exp(-b*(x-d)) + (c/(b*b))*(1-(b*(x-d)+1)*exp(-b*(x-d)))). */
+  if(strcasecmp(fid, "surgerecircd")==0) {
+    if(parNr<2) return(2);
+    double c=0.0; if(parNr>=3) c=p[2];
+    double delayt=0.0; if(parNr>=4) delayt=p[3];
+    for(int i=0; i<sampleNr; i++) {
+      double xt=x[i]-delayt; y[i]=0.0; 
+      if(!(xt>0.0)) continue;
+      double e=exp(-p[1]*xt);
+      y[i] = xt*e + (c/(p[1]*p[1]))*(1.0 - (p[1]*xt+1.0)*e);
+      y[i] *= p[0];
+    }
+    return(0);
+  }
+
   /* Surge function with recirculation, for plasma-to-blood ratio.
      RBC-to-plasma r(x)=a*(x*exp(-b*x) + (c/(b*b))*(1-(b*x+1)*exp(-b*x)))
      Plasma-to-blood f(x)=1/(1-HCT*(1-r(x))). */
@@ -229,6 +275,25 @@ int mfEvalY(
     return(0);
   }
 
+  /* Feng M2 function for plasma-to-blood ratio.
+     RBC-to-plasma ratio r(x) using Feng M2, and then Plasma-to-blood f(x)=1/(1-HCT*(1-r(x))). */
+  if(strcasecmp(fid, "p2bfm2")==0) {
+    if(parNr<3) return(2);
+    double HCT=p[0];
+    double A1=p[1];
+    double L1=p[2];
+    double A2=0.0; if(parNr>3) A2=p[3];
+    double L2=0.0; if(parNr>4) L2=p[4];
+    double A3=0.0; if(parNr>5) A3=p[5];
+    double L3=0.0; if(parNr>6) L3=p[6];
+    for(int i=0; i<sampleNr; i++) {
+      double xt=x[i]; if(!(xt>0.0)) {y[i]=1.0/(1.0-HCT); continue;}
+      double r=(A1*xt - A2 - A3)*exp(-L1*xt) + A2*exp(-L2*xt) + A3*exp(-L3*xt);
+      y[i] = 1.0/(1.0-HCT*(1.0-r));
+    }
+    return(0);
+  }
+
   /* Surge function for late FDG AIF with time delay */
   if(strcasecmp(fid, "surgefdgaif")==0) {
     if(parNr<5) return(2);
@@ -254,6 +319,90 @@ int mfEvalY(
     return(0);
   }
 
+  /* Rational functions */
+  if(strcasecmp(fid, "ratf11")==0) {
+    if(parNr<4) return(2);
+    for(int i=0; i<sampleNr; i++) {
+      double a=p[0]+p[2]*x[i];
+      double b=p[1]+p[3]*x[i];
+      y[i]=a/b;
+    }
+    return(0);
+  }
+  if(strcasecmp(fid, "ratf21")==0) {
+    if(parNr<5) return(2);
+    for(int i=0; i<sampleNr; i++) {
+      double a=p[0]+p[2]*x[i]+p[4]*x[i]*x[i];
+      double b=p[1]+p[3]*x[i];
+      y[i]=a/b;
+    }
+    return(0);
+  }
+  if(strcasecmp(fid, "ratf22")==0) {
+    if(parNr<6) return(2);
+    for(int i=0; i<sampleNr; i++) {
+      double sqrx=x[i]*x[i];
+      double a=p[0]+p[2]*x[i]+p[4]*sqrx;
+      double b=p[1]+p[3]*x[i]+p[5]*sqrx;
+      y[i]=a/b;
+    }
+    return(0);
+  }
+  if(strcasecmp(fid, "ratf32")==0) {
+    if(parNr<7) return(2);
+    for(int i=0; i<sampleNr; i++) {
+      double sqrx=x[i]*x[i];
+      double a=p[0]+p[2]*x[i]+p[4]*sqrx+p[6]*sqrx*x[i];
+      double b=p[1]+p[3]*x[i]+p[5]*sqrx;
+      y[i]=a/b;
+    }
+    return(0);
+  }
+  if(strcasecmp(fid, "ratf33")==0) {
+    if(parNr<8) return(2);
+    for(int i=0; i<sampleNr; i++) {
+      double sqrx=x[i]*x[i];
+      double cubx=sqrx*x[i];
+      double a=p[0]+p[2]*x[i]+p[4]*sqrx+p[6]*cubx;
+      double b=p[1]+p[3]*x[i]+p[5]*sqrx+p[7]*cubx;
+      y[i]=a/b;
+    }
+    return(0);
+  }
+  if(strcasecmp(fid, "p2brf")==0) {
+    if(parNr<7) return(2);
+    for(int i=0; i<sampleNr; i++) {
+      if(x[i]<=0.0) {
+        y[i]=1.0/(1.0-p[0]);
+      } else {
+        double sqrx=x[i]*x[i];
+        double cubx=sqrx*x[i];
+        double a=0.0+p[1]*x[i]+p[3]*sqrx+p[5]*cubx;
+        double b=1.0+p[2]*x[i]+p[4]*sqrx+p[6]*cubx;
+        y[i]=1.0/(1.0-p[0]*(1.0-(a/b)));
+      }
+    }
+    return(0);
+  }
+
+  /* Hill functions */
+  if(strcasecmp(fid, "mpfhill")==0) {
+    if(parNr<3) return(2);
+    for(int i=0; i<sampleNr; i++) {
+      y[i]=p[0]*pow(x[i], p[1]) / (pow(x[i], p[1]) + p[2]);
+    }
+    return(0);
+  }
+  if(strcasecmp(fid, "p2bhill")==0) {
+    if(parNr<4) return(2);
+    for(int i=0; i<sampleNr; i++) {
+      double cpr=p[1]*pow(x[i], p[2]) / (pow(x[i], p[2]) + p[3]);
+      y[i]=1.0/(1.0-p[0]*(1.0-cpr));
+    }
+    return(0);
+  }
+
+
   if(verbose>1) printf("function '%s' not supported by %s()\n", fid, __func__);
   return(10);
 }
