@@ -130,6 +130,9 @@ int imgReadNifti(
   int bitpix=0;
   if(dsr.n==1) bitpix=dsr.h1.bitpix; else bitpix=dsr.h2.bitpix;
   if(verbose>2) printf("  bits per pixel := %d\n", bitpix);
+  if(bitpix==0) { // Carimas Nifti Writer does not set bitpix
+    if(datatype==NIFTI_DT_UNSIGNED_SHORT) bitpix=16;
+  }
   if(bitpix<8 || (bitpix%8)!=0) { // We don't support bit data
     statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_UNSUPPORTED);
     return(TPCERROR_UNSUPPORTED);
