@@ -91,10 +91,7 @@ int anaExistsNew(
   }
   /* Is this Analyze header file? */
   if((ret=anaReadHeader(temp, &h))!=0) {
-    if(ANALYZE_TEST) {
-      printf("\n  %s was not identified as Analyze header file (%d).\n",
-        temp, ret);
-    }
+    if(ANALYZE_TEST) printf("\n  %s was not identified as Analyze header file (%d).\n", temp, ret);
     return(0);
   }
   /* Preserve header filename */
@@ -115,7 +112,7 @@ int anaExistsNew(
     strcpy(temp, basefile); strcat(temp, ".img.sif");
     if(access(temp, 0) == -1) {
       if(ANALYZE_TEST) printf("\n  SIF not found or accessible.\n");
-     if(siffile!=NULL) strcpy(siffile, "");
+      if(siffile!=NULL) strcpy(siffile, "");
       return(1); // but otherwise ok
     }
   }
@@ -126,16 +123,16 @@ int anaExistsNew(
 /*****************************************************************************/
 
 /*****************************************************************************/
-/*!
- * Read analyze header contents.
- *
- * @param filename name of file to read (including path and extension)
- * @param h Pointer to previously allocated header structure
- * @return 0, if ok, 1 if invalid input, 2 if file cannot be opened, 3 if
- * header cound not be read, 4 if header image dimension could not be read
+/*! Read analyze header contents.
+   @return 0, if ok, 1 if invalid input, 2 if file cannot be opened, 3 if header could not be read,
+    4 if header image dimension could not be read.
+   @sa anaWriteHeader, anaPrintHeader, anaEditHeader, imgReadAnalyzeHeader, imgGetAnalyzeHeader
  */
 int anaReadHeader(
-  char *filename, ANALYZE_DSR *h
+  /** Name of file to read (including path and extension). */
+  char *filename,
+  /** Pointer to previously allocated header structure. */
+  ANALYZE_DSR *h
 ) {
   unsigned char buf1[ANALYZE_HEADER_KEY_SIZE];
   unsigned char buf2[ANALYZE_HEADER_IMGDIM_SIZE];
@@ -274,12 +271,13 @@ int anaReadHeader(
 /*****************************************************************************/
 
 /*****************************************************************************/
-/** Write analyze header contents. Header field 'little' is used to determine
+/** Write Analyze header contents. Header field 'little' is used to determine
     the required byte order.
  
-  @return Returns 0, if ok, 1 if invalid input, 2 if file could not be opened
-   for writing, 3 if data header write failed, 4 if image dimension write
-   failed, and 5 if header history write failed.
+  @return Returns 0, if ok, 1 if invalid input, 2 if file could not be opened for writing, 
+   3 if data header write failed, 4 if image dimension write failed, and 
+   5 if header history write failed.
+  @sa anaReadHeader
  */
 int anaWriteHeader(
   /** Name of file to read (including path and extension) */
@@ -375,14 +373,15 @@ int anaWriteHeader(
 
 /*****************************************************************************/
 /*!
- * Print the contents of Analyze header to specified file pointer.
- *
- * @param h analyze header structure
- * @param fp file pointer
- * @return Returns 0 if ok, 1 if invalid input
+   Print the contents of Analyze header to specified file pointer.
+   @return Returns 0 if ok, 1 if invalid input
+   @sa anaReadHeader
  */
 int anaPrintHeader(
-  ANALYZE_DSR *h, FILE *fp
+  /** Pointer to Analyze header structure. */
+  ANALYZE_DSR *h,
+  /** Output file pointer. */
+  FILE *fp
 ) {
   if(fp==NULL || h==NULL) return(1);
   fprintf(fp, "original_byte_order := %d (1=little, 0=big)\n", h->little);
@@ -450,6 +449,7 @@ int anaPrintHeader(
 /** Read Analyze 7.5 image data, convert byte order if necessary,
     and scale values to floats. Reads only one frame at a time!
    @return Returns 0 if ok, <>0 in case of an error.
+   @sa anaReadHeader
  */
 int anaReadImagedata(
   /** File, opened previously in binary mode. */
@@ -517,8 +517,7 @@ int anaReadImagedata(
   {
     size_t n=fread(mptr, rawSize, 1, fp);
     if(n<1) {
-      if(ANALYZE_TEST>5)
-        printf("could read only %zu bytes when request was %lld\n", n, rawSize);
+      if(ANALYZE_TEST>5) printf("could read only %zu bytes when request was %lld\n", n, rawSize);
       free(mdata); return(8);
     }
   }
@@ -533,8 +532,7 @@ int anaReadImagedata(
       case 32: swawbip(mptr, rawSize); break;
       case 64: swawbip(mptr, rawSize); break;
       default: 
-        if(ANALYZE_TEST>5)
-          printf("unsupported anahdr.dime.bitpix := %d\n", h->dime.bitpix);
+        if(ANALYZE_TEST>5) printf("unsupported anahdr.dime.bitpix := %d\n", h->dime.bitpix);
         free(mdata); return(5);
     }
   }
@@ -548,9 +546,8 @@ int anaReadImagedata(
   switch(h->dime.datatype) {
     case ANALYZE_DT_UNSIGNED_CHAR:
       if(h->dime.bitpix!=8) {
-        if(ANALYZE_TEST>5)
-          printf("invalid combination of datatype and bitpix (%d, %d)\n",
-            h->dime.datatype, h->dime.bitpix);
+        if(ANALYZE_TEST>5) printf("invalid combination of datatype and bitpix (%d, %d)\n",
+                                  h->dime.datatype, h->dime.bitpix);
         free(mdata); return(5);
       }
       for(long long i=0; i<pxlNr; i++, mptr++, fptr++)
@@ -558,9 +555,8 @@ int anaReadImagedata(
       break;
     case ANALYZE_DT_SIGNED_SHORT:
       if(h->dime.bitpix!=16) {
-        if(ANALYZE_TEST>5)
-          printf("invalid combination of datatype and bitpix (%d, %d)\n",
-            h->dime.datatype, h->dime.bitpix);
+        if(ANALYZE_TEST>5) printf("invalid combination of datatype and bitpix (%d, %d)\n",
+                                  h->dime.datatype, h->dime.bitpix);
         free(mdata); return(5);
       }
       for(long long i=0; i<pxlNr; i++, mptr+=2, fptr++) {
@@ -569,9 +565,8 @@ int anaReadImagedata(
       break;
     case ANALYZE_DT_SIGNED_INT:
       if(h->dime.bitpix!=16 && h->dime.bitpix!=32) {
-        if(ANALYZE_TEST>5)
-          printf("invalid combination of datatype and bitpix (%d, %d)\n",
-            h->dime.datatype, h->dime.bitpix);
+        if(ANALYZE_TEST>5) printf("invalid combination of datatype and bitpix (%d, %d)\n",
+                                  h->dime.datatype, h->dime.bitpix);
         free(mdata); return(5);
       }
       if(h->dime.bitpix==16) {
@@ -586,9 +581,8 @@ int anaReadImagedata(
       break;
     case ANALYZE_DT_FLOAT:
       if(h->dime.bitpix!=16 && h->dime.bitpix!=32) {
-        if(ANALYZE_TEST>5)
-          printf("invalid combination of datatype and bitpix (%d, %d)\n",
-            h->dime.datatype, h->dime.bitpix);
+        if(ANALYZE_TEST>5) printf("invalid combination of datatype and bitpix (%d, %d)\n",
+                                  h->dime.datatype, h->dime.bitpix);
         free(mdata); return(5);
       }
       if(h->dime.bitpix==16) {
@@ -601,9 +595,8 @@ int anaReadImagedata(
       break;
     case ANALYZE_DT_COMPLEX:
       if(h->dime.bitpix!=32) {
-        if(ANALYZE_TEST>5)
-          printf("invalid combination of datatype and bitpix (%d, %d)\n",
-            h->dime.datatype, h->dime.bitpix);
+        if(ANALYZE_TEST>5) printf("invalid combination of datatype and bitpix (%d, %d)\n",
+                                  h->dime.datatype, h->dime.bitpix);
         free(mdata); return(5);
       }
       if(h->dime.bitpix==32) {
@@ -614,9 +607,8 @@ int anaReadImagedata(
     case ANALYZE_DT_DOUBLE:
       /* Add support for 64-bit double, if needed */
       if(h->dime.bitpix!=32) {
-        if(ANALYZE_TEST>5)
-          printf("invalid combination of datatype and bitpix (%d, %d)\n",
-            h->dime.datatype, h->dime.bitpix);
+        if(ANALYZE_TEST>5) printf("invalid combination of datatype and bitpix (%d, %d)\n",
+                                  h->dime.datatype, h->dime.bitpix);
         free(mdata); return(5);
       }
       for(long long i=0; i<pxlNr; i++, mptr+=8, fptr++) {
@@ -624,8 +616,7 @@ int anaReadImagedata(
       }
       break;
     default:
-      if(ANALYZE_TEST>5)
-        printf("unsupported anahdr.dime.datatype := %d\n", h->dime.datatype);
+      if(ANALYZE_TEST>5) printf("unsupported anahdr.dime.datatype := %d\n", h->dime.datatype);
       free(mdata); return(5);
   }
 
@@ -638,8 +629,8 @@ int anaReadImagedata(
 /*****************************************************************************/
 /** Check whether Analyze image is flipped in z-direction when it
     is read from/written to file (x,y-flipping is done always).
-  
    @return 1 if Analyze data is flipped.
+   @sa anaReadHeader, anaEditHeader, anaReadImagedata
  */
 int anaFlipping() {
   int ret;
@@ -670,6 +661,7 @@ int anaFlipping() {
    @return Returns 0 when call was successful, 1 if header file deletion failed, 
     2 if data file deletion failed. Call is considered successful, if database
     does not exist initially.
+   @sa anaExists
  */
 int anaRemove(
   /** Analyze database name. */
@@ -688,8 +680,9 @@ int anaRemove(
 
 /*****************************************************************************/
 /** Check if Analyze 7.5 filename was given accidentally with extension.
-
     Remove the extension if necessary.
+   @sa anaExists, anaRemove
+
  */
 void anaRemoveFNameExtension(
   /** Full name of file. */
@@ -705,8 +698,8 @@ void anaRemoveFNameExtension(
 
 /*****************************************************************************/
 /** Check if Analyze database files exist (*.hdr, *.img, and optionally *.sif).
-   @return Returns 0, if files do not exist, 1 if .img and .hdr do exist,
-    and 2, if also .sif exists.
+   @return Returns 0, if files do not exist, 1 if .img and .hdr do exist, and 2, if also .sif exists.
+   @sa anaExists, anaRemove, anaRemoveFNameExtension
  */
 int anaDatabaseExists(
   /** analyze database name that is tested. String may contain standard
@@ -764,8 +757,8 @@ int anaDatabaseExists(
 
 /*****************************************************************************/
 /** Make SIF filename from Analyze 7.5 database name.
-   @return Returns 0 if SIF file is accessible, 1 if invalid input,
-    2 if sif name not found.
+   @return Returns 0 if SIF file is accessible, 1 if invalid input, 2 if sif name not found.
+   @sa anaDatabaseExists, anaExists
  */
 int anaMakeSIFName(
   /** Analyze 7.5 database name (including possible path but not extension. */
@@ -785,6 +778,7 @@ int anaMakeSIFName(
 /*****************************************************************************/
 /** Edits Analyze 7.5 header. 
    @return Returns 0, if ok, and 1 or 2, if field name or or value is invalid. 
+   @sa anaReadHeader, imgSetAnalyzeHeader, imgReadAnalyzeHeader
  */
 int anaEditHeader(
   /** Pointer to Analyze header struct. */
@@ -800,154 +794,107 @@ int anaEditHeader(
 
   si=atoi(value); ii=atoi(value); f=atof(value);
   /* Header keys */
-  if(strcmp(field, "header_key.sizeof_hdr")==0 ||
-     strcmp(field, "sizeof_hdr")==0) {
+  if(strcmp(field, "header_key.sizeof_hdr")==0 || strcmp(field, "sizeof_hdr")==0) {
     h->hk.sizeof_hdr=ii;
-  } else if(strcmp(field, "header_key.data_type")==0 ||
-            strcmp(field, "data_type")==0) {
+  } else if(strcmp(field, "header_key.data_type")==0 || strcmp(field, "data_type")==0) {
     strlcpy(h->hk.data_type, value, 10);
-  } else if(strcmp(field, "header_key.db_name")==0 ||
-            strcmp(field, "db_name")==0) {
+  } else if(strcmp(field, "header_key.db_name")==0 || strcmp(field, "db_name")==0) {
     strlcpy(h->hk.db_name, value, 18);
-  } else if(strcmp(field, "header_key.extents")==0 ||
-            strcmp(field, "extents")==0) {
+  } else if(strcmp(field, "header_key.extents")==0 || strcmp(field, "extents")==0) {
     h->hk.extents=ii;
-  } else if(strcmp(field, "header_key.session_error")==0 ||
-            strcmp(field, "session_error")==0) {
+  } else if(strcmp(field, "header_key.session_error")==0 || strcmp(field, "session_error")==0) {
     h->hk.session_error=si;
-  } else if(strcmp(field, "header_key.regular")==0 ||
-            strcmp(field, "regular")==0) {
+  } else if(strcmp(field, "header_key.regular")==0 || strcmp(field, "regular")==0) {
     h->hk.regular=value[0];
-  } else if(strcmp(field, "header_key.hkey_un0")==0 ||
-            strcmp(field, "hkey_un0")==0) {
+  } else if(strcmp(field, "header_key.hkey_un0")==0 || strcmp(field, "hkey_un0")==0) {
     h->hk.hkey_un0=value[0];
   /* Header imgdim */
-  } else if(strcmp(field, "header_image_dimension.dim")==0 ||
-            strcmp(field, "dim")==0) {
+  } else if(strcmp(field, "header_image_dimension.dim")==0 || strcmp(field, "dim")==0) {
     sscanf(value, "%hd %hd %hd %hd %hd %hd %hd %hd",
       h->dime.dim+0, h->dime.dim+1, h->dime.dim+2, h->dime.dim+3,
       h->dime.dim+4, h->dime.dim+5, h->dime.dim+6, h->dime.dim+7
     );
-  } else if(strcmp(field, "header_image_dimension.unused8")==0 ||
-            strcmp(field, "unused8")==0) {
+  } else if(strcmp(field, "header_image_dimension.unused8")==0 || strcmp(field, "unused8")==0) {
     h->dime.unused8=si;
-  } else if(strcmp(field, "header_image_dimension.unused9")==0 ||
-            strcmp(field, "unused9")==0) {
+  } else if(strcmp(field, "header_image_dimension.unused9")==0 || strcmp(field, "unused9")==0) {
     h->dime.unused9=si;
-  } else if(strcmp(field, "header_image_dimension.unused10")==0 ||
-            strcmp(field, "unused10")==0) {
+  } else if(strcmp(field, "header_image_dimension.unused10")==0 || strcmp(field, "unused10")==0) {
     h->dime.unused10=si;
-  } else if(strcmp(field, "header_image_dimension.unused11")==0 ||
-            strcmp(field, "unused11")==0) {
+  } else if(strcmp(field, "header_image_dimension.unused11")==0 || strcmp(field, "unused11")==0) {
     h->dime.unused11=si;
-  } else if(strcmp(field, "header_image_dimension.unused12")==0 ||
-            strcmp(field, "unused12")==0) {
+  } else if(strcmp(field, "header_image_dimension.unused12")==0 || strcmp(field, "unused12")==0) {
     h->dime.unused12=si;
-  } else if(strcmp(field, "header_image_dimension.unused13")==0 ||
-            strcmp(field, "unused13")==0) {
+  } else if(strcmp(field, "header_image_dimension.unused13")==0 || strcmp(field, "unused13")==0) {
     h->dime.unused13=si;
-  } else if(strcmp(field, "header_image_dimension.unused14")==0 ||
-            strcmp(field, "unused14")==0) {
+  } else if(strcmp(field, "header_image_dimension.unused14")==0 || strcmp(field, "unused14")==0) {
     h->dime.unused14=si;
-  } else if(strcmp(field, "header_image_dimension.datatype")==0 ||
-            strcmp(field, "datatype")==0) {
+  } else if(strcmp(field, "header_image_dimension.datatype")==0 || strcmp(field, "datatype")==0) {
     h->dime.datatype=si;
-  } else if(strcmp(field, "header_image_dimension.bitpix")==0 ||
-            strcmp(field, "bitpix")==0) {
+  } else if(strcmp(field, "header_image_dimension.bitpix")==0 || strcmp(field, "bitpix")==0) {
     h->dime.bitpix=si;
-  } else if(strcmp(field, "header_image_dimension.dim_un0")==0 ||
-            strcmp(field, "dim_un0")==0) {
+  } else if(strcmp(field, "header_image_dimension.dim_un0")==0 || strcmp(field, "dim_un0")==0) {
     h->dime.dim_un0=si;
-  } else if(strcmp(field, "header_image_dimension.pixdim")==0 ||
-            strcmp(field, "pixdim")==0) {
+  } else if(strcmp(field, "header_image_dimension.pixdim")==0 || strcmp(field, "pixdim")==0) {
     sscanf(value, "%f %f %f %f %f %f %f %f",
       h->dime.pixdim+0, h->dime.pixdim+1, h->dime.pixdim+2, h->dime.pixdim+3,
       h->dime.pixdim+4, h->dime.pixdim+5, h->dime.pixdim+6, h->dime.pixdim+7
     );
-  } else if(strcmp(field, "header_image_dimension.vox_offset")==0 ||
-            strcmp(field, "vox_offset")==0) {
+  } else if(strcmp(field, "header_image_dimension.vox_offset")==0 || strcmp(field, "vox_offset")==0) {
     h->dime.vox_offset=f;
-  } else if(strcmp(field, "header_image_dimension.funused1")==0 ||
-            strcmp(field, "funused1")==0) {
+  } else if(strcmp(field, "header_image_dimension.funused1")==0 || strcmp(field, "funused1")==0) {
     h->dime.funused1=f;
-  } else if(strcmp(field, "header_image_dimension.funused2")==0 ||
-            strcmp(field, "funused2")==0) {
+  } else if(strcmp(field, "header_image_dimension.funused2")==0 || strcmp(field, "funused2")==0) {
     h->dime.funused2=f;
-  } else if(strcmp(field, "header_image_dimension.funused3")==0 ||
-            strcmp(field, "funused3")==0) {
+  } else if(strcmp(field, "header_image_dimension.funused3")==0 || strcmp(field, "funused3")==0) {
     h->dime.funused3=f;
-  } else if(strcmp(field, "header_image_dimension.cal_max")==0 ||
-            strcmp(field, "cal_max")==0) {
+  } else if(strcmp(field, "header_image_dimension.cal_max")==0 || strcmp(field, "cal_max")==0) {
     h->dime.cal_max=f;
-  } else if(strcmp(field, "header_image_dimension.cal_min")==0 ||
-            strcmp(field, "cal_min")==0) {
+  } else if(strcmp(field, "header_image_dimension.cal_min")==0 || strcmp(field, "cal_min")==0) {
     h->dime.cal_min=f;
-  } else if(strcmp(field, "header_image_dimension.compressed")==0 ||
-            strcmp(field, "compressed")==0) {
+  } else if(strcmp(field, "header_image_dimension.compressed")==0 || strcmp(field, "compressed")==0) {
     h->dime.compressed=f;
-  } else if(strcmp(field, "header_image_dimension.verified")==0 ||
-            strcmp(field, "verified")==0) {
+  } else if(strcmp(field, "header_image_dimension.verified")==0 || strcmp(field, "verified")==0) {
     h->dime.verified=f;
-  } else if(strcmp(field, "header_image_dimension.glmax")==0 ||
-            strcmp(field, "glmax")==0) {
+  } else if(strcmp(field, "header_image_dimension.glmax")==0 || strcmp(field, "glmax")==0) {
     h->dime.glmax=ii;
-  } else if(strcmp(field, "header_image_dimension.glmin")==0 ||
-            strcmp(field, "glmin")==0) {
+  } else if(strcmp(field, "header_image_dimension.glmin")==0 || strcmp(field, "glmin")==0) {
     h->dime.glmin=ii;
   /* Header history */
-  } else if(strcmp(field, "header_data_history.descrip")==0 ||
-            strcmp(field, "descrip")==0) {
+  } else if(strcmp(field, "header_data_history.descrip")==0 || strcmp(field, "descrip")==0) {
     strlcpy(h->hist.descrip, value, 80);
-  } else if(strcmp(field, "header_data_history.aux_file")==0 ||
-            strcmp(field, "aux_file")==0) {
+  } else if(strcmp(field, "header_data_history.aux_file")==0 || strcmp(field, "aux_file")==0) {
     strlcpy(h->hist.aux_file, value, 24);
-  } else if(strcmp(field, "header_data_history.orient")==0 ||
-            strcmp(field, "orient")==0) {
+  } else if(strcmp(field, "header_data_history.orient")==0 || strcmp(field, "orient")==0) {
     h->hist.orient=value[0];
-  } else if(strcmp(field, "header_data_history.originator")==0 ||
-            strcmp(field, "originator")==0) {
+  } else if(strcmp(field, "header_data_history.originator")==0 || strcmp(field, "originator")==0) {
     strlcpy(h->hist.originator, value, 10);
-  } else if(strcmp(field, "header_data_history.generated")==0 ||
-            strcmp(field, "generated")==0) {
+  } else if(strcmp(field, "header_data_history.generated")==0 || strcmp(field, "generated")==0) {
     strlcpy(h->hist.generated, value, 10);
-  } else if(strcmp(field, "header_data_history.scannum")==0 ||
-            strcmp(field, "scannum")==0) {
+  } else if(strcmp(field, "header_data_history.scannum")==0 || strcmp(field, "scannum")==0) {
     strlcpy(h->hist.scannum, value, 10);
-  } else if(strcmp(field, "header_data_history.patient_id")==0 ||
-            strcmp(field, "patient_id")==0) {
+  } else if(strcmp(field, "header_data_history.patient_id")==0 || strcmp(field, "patient_id")==0) {
     strlcpy(h->hist.patient_id, value, 10);
-  } else if(strcmp(field, "header_data_history.exp_date")==0 ||
-            strcmp(field, "exp_date")==0) {
+  } else if(strcmp(field, "header_data_history.exp_date")==0 || strcmp(field, "exp_date")==0) {
     strlcpy(h->hist.exp_date, value, 10);
-  } else if(strcmp(field, "header_data_history.exp_time")==0 ||
-            strcmp(field, "exp_time")==0) {
+  } else if(strcmp(field, "header_data_history.exp_time")==0 || strcmp(field, "exp_time")==0) {
     strlcpy(h->hist.exp_time, value, 10);
-  } else if(strcmp(field, "header_data_history.hist_un0")==0 ||
-            strcmp(field, "hist_un0")==0) {
+  } else if(strcmp(field, "header_data_history.hist_un0")==0 || strcmp(field, "hist_un0")==0) {
     memcpy(h->hist.hist_un0, value, 3);
-  } else if(strcmp(field, "header_data_history.views")==0 ||
-            strcmp(field, "views")==0) {
+  } else if(strcmp(field, "header_data_history.views")==0 || strcmp(field, "views")==0) {
     h->hist.views=ii;
-  } else if(strcmp(field, "header_data_history.vols_added")==0 ||
-            strcmp(field, "vols_added")==0) {
+  } else if(strcmp(field, "header_data_history.vols_added")==0 || strcmp(field, "vols_added")==0) {
     h->hist.vols_added=ii;
-  } else if(strcmp(field, "header_data_history.start_field")==0 ||
-            strcmp(field, "start_field")==0) {
+  } else if(strcmp(field, "header_data_history.start_field")==0 || strcmp(field, "start_field")==0) {
     h->hist.start_field=ii;
-  } else if(strcmp(field, "header_data_history.field_skip")==0 ||
-            strcmp(field, "field_skip")==0) {
+  } else if(strcmp(field, "header_data_history.field_skip")==0 || strcmp(field, "field_skip")==0) {
     h->hist.field_skip=ii;
-  } else if(strcmp(field, "header_data_history.omax")==0 ||
-            strcmp(field, "omax")==0) {
+  } else if(strcmp(field, "header_data_history.omax")==0 || strcmp(field, "omax")==0) {
     h->hist.omax=ii;
-  } else if(strcmp(field, "header_data_history.omin")==0 ||
-            strcmp(field, "omin")==0) {
+  } else if(strcmp(field, "header_data_history.omin")==0 || strcmp(field, "omin")==0) {
     h->hist.omin=ii;
-  } else if(strcmp(field, "header_data_history.smax")==0 ||
-            strcmp(field, "smax")==0) {
+  } else if(strcmp(field, "header_data_history.smax")==0 || strcmp(field, "smax")==0) {
     h->hist.smax=ii;
-  } else if(strcmp(field, "header_data_history.smin")==0 ||
-            strcmp(field, "smin")==0) {
+  } else if(strcmp(field, "header_data_history.smin")==0 || strcmp(field, "smin")==0) {
     h->hist.smin=ii;
   } else
     return(1);
