@@ -651,3 +651,32 @@ int imgExistentCounts(
 /*****************************************************************************/
 
 /*****************************************************************************/
+/** Searches the image data for missing pixel values, optionally setting those to zero.
+   @sa imgExistentTimes
+   @return the number of missing pixel values.
+ */
+unsigned long long imgNaNs(
+  /** Pointer to IMG structure. */
+  IMG *img,
+  /** Set (1) or do not set (0) missing pixels to zero. */
+  int fix
+) {
+  if(img==NULL) return(0);
+  unsigned long long n=0;
+  for(int zi=0; zi<img->dimz; zi++) {
+    for(int yi=0; yi<img->dimy; yi++) {
+      for(int xi=0; xi<img->dimx; xi++) {
+        for(int ti=0; ti<img->dimt; ti++) {
+          if(!isfinite(img->m[zi][yi][xi][ti])) {
+            n++;
+            if(fix!=0) img->m[zi][yi][xi][ti]=0.0;
+          }
+        }
+      }
+    }
+  }
+  return(n);
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
