@@ -129,6 +129,7 @@ int imgReadNiftiFirstFrame(
     information concerning separate frames or planes is not filled.
   
     @return 0 if ok, and otherwise IMG status code (<>0); sets IMG->statmsg in case of an error.
+    @sa imgGetNiftiHeader
  */
 int imgReadNiftiHeader(
   /** Nifti database name with path, with or without extension */
@@ -145,8 +146,7 @@ int imgReadNiftiHeader(
   SIF sif;
   double f;
 
-  if(verbose>0) {
-    printf("imgReadNiftiHeader(%s, ...)\n", filename); fflush(stdout);}
+  if(verbose>0) {printf("imgReadNiftiHeader(%s, ...)\n", filename); fflush(stdout);}
 
   /* Check the arguments */
   if(img==NULL || img->status!=IMG_STATUS_INITIALIZED) {
@@ -213,6 +213,7 @@ int imgReadNiftiHeader(
 /** Copy Nifti header information into IMG.
   @return Returns IMG status, which is STATUS_OK (0) when call was successful,
    and >0 in case of an error.
+  @sa imgSetNiftiHeader, imgReadNiftiHeader
  */
 int imgGetNiftiHeader(
   /** Pointer to IMG struct */
@@ -296,8 +297,7 @@ int imgGetNiftiHeader(
 /*****************************************************************************/
 
 /*****************************************************************************/
-/** Read a specified frame from a Nifti database files into preallocated IMG
-    data structure.
+/** Read a specified frame from a Nifti database files into preallocated IMG data structure.
 
     IMG header is assumed to be filled correctly before calling this function,
     except for information concerning separate planes and this frame,
@@ -306,6 +306,7 @@ int imgGetNiftiHeader(
     @return 0 if ok, and otherwise IMG status code (<>0); sets IMG->statmsg
      in case of an error.
      If frame does not exist, then and only then STATUS_NOMATRIX is returned.
+    @sa imgReadNifti, imgNaNs
  */ 
 int imgReadNiftiFrame(
   /** Pointer to string that contains the name of NIfTI database with path,
@@ -400,10 +401,10 @@ int imgReadNiftiFrame(
     return STATUS_UNSUPPORTED;
   }
 
-  /* Check for invalid pixel values and set to zero.
-     SPM can write lots of NaNs on image borders.
-     Remove this later, if/when all image processing functions support NaN and Inf. */
-  if(1) {
+  if(0) { // Call imgNaNs(IMG, 1) instead
+    /* Check for invalid pixel values and set to zero.
+       SPM can write lots of NaNs on image borders.
+       Remove this later, if/when all image processing functions support NaN and Inf. */
     long long int goodNr=0;
     fptr=fdata;
     for(int zi=0; zi<img->dimz; zi++)
@@ -459,15 +460,16 @@ int imgReadNiftiFrame(
 /*****************************************************************************/
 
 /*****************************************************************************/
-/** Copy header information in IMG struct into NIfTI header struct.
+/** Copy header information in IMG structure into NIfTI header structure.
 
     Min, max, and scale factor are set here and they apply to all frames.
 
    @return errstatus, which is STATUS_OK (0) when call was successful,
     and >0 in case of an error.
+   @sa imgGetNiftiHeader, imgReadNiftiHeader
  */
 int imgSetNiftiHeader(
-  /** pointer to IMG struct from which header information is read */
+  /** pointer to IMG structure from which header information is read */
   IMG *img,
   /** NIfTI database name */
   const char *dbname,
@@ -587,6 +589,7 @@ int imgSetNiftiHeader(
 
     @return Returns errstatus, which is STATUS_OK (0) when call was successful,
      and >0 in case of an error.
+    @sa imgReadNiftiFrame
  */
 int imgWriteNiftiFrame(
   /** Name of NIfTI file where IMG contents will be written.
@@ -890,7 +893,7 @@ int imgWriteNifti(
     return ret;
   }
 
-  /* If SIF is not needed, then thats it */
+  /* If SIF is not needed, then that's it */
   if(save_sif==0) {
     imgSetStatus(img, STATUS_OK);
     return 0;
