@@ -359,7 +359,7 @@ int imgReadFrame(
       break;
     case IMG_NIFTI_1S:
     case IMG_NIFTI_1D:
-      ret=imgReadNiftiFrame(fname, frame_to_read, img, frame_index, 0);
+      ret=imgReadNiftiFrame(fname, frame_to_read, img, frame_index, IMG_TEST-2);
       if(IMG_TEST>1) printf("imgReadNiftiFrame() return value := %d\n", ret);
       break;
     case IMG_MICROPET:
