@@ -671,7 +671,7 @@ int niftiReadImagedata(
 
   // data_type is unused in Nifti
   /* Check that datatype is supported */
-  if(verbose>1) printf("  verifying datatype\n");
+  if(verbose>1) printf("  verifying datatype %d\n", dsr->h.datatype);
   {
     int n=0;
     if(dsr->h.datatype & NIFTI_DT_RGB) n+=NIFTI_DT_RGB;
@@ -688,6 +688,9 @@ int niftiReadImagedata(
   /* Allocate memory for the binary data */
   if(verbose>1) printf("  allocating memory for binary data\n");
   if(status!=NULL) sprintf(status, "invalid pixel data format");
+  if(dsr->h.bitpix==0) { // Carimas Nifti Writer does not set bitpix
+    if(dsr->h.datatype==NIFTI_DT_UNSIGNED_SHORT) dsr->h.bitpix=16;
+  }
   if(dsr->h.bitpix<8) return(5); // We don't support bit data
   long long rawSize=pxlNr*(dsr->h.bitpix/8); if(rawSize<1) return(6);
   if(verbose>1) printf("  pxlNr=%lld  rawSize=%lld\n", pxlNr, rawSize);
