@@ -19,15 +19,12 @@
 /** @brief Linear integration of TAC with trapezoidal method.
   
     @details
-    Use this function for input data, or PET data when frame start and end
-    times are not known. 
+    Use this function for input data, or PET data when frame start and end times are not known. 
     Data must be frequently sampled to get accurate results.
-    AUC calculation is started from time 0 or first input sample time,
-    whichever is smaller.
+    AUC calculation is started from time 0 or first input sample time, whichever is smaller.
     Very simple data extrapolation can be optionally enabled.
     Results will be wrong if data contains NaNs.
-    To get the same result as with integrate() in the libtpcmodel,
-    set se=3.
+    To get the same result as with integrate() in the libtpcmodel, set se=3.
    
     @sa liInterpolate(), liIntegratePET()
     @author Vesa Oikonen
@@ -35,29 +32,27 @@
  */
 int liIntegrate(
   /** Array of input data x (time) values; obligatory.
-      Data must be sorted by ascending x, but consecutive points may have the
-      same x. Negative x is accepted, AUCs are then started from the first x,
-      otherwise from 0. */
+      Data must be sorted by ascending x, but consecutive points may have the same x.
+      Negative x is accepted, AUCs are then started from the first x, otherwise from 0. */
   double *x,
-  /** Array of input data y (concentration) values; obligatory */
+  /** Array of input data y (concentration) values; obligatory. */
   double *y,
-  /** Number of samples in input data; obligatory */
+  /** Number of samples in input data; obligatory. */
   const int nr,
-  /** Array for integrals (AUCs) at each x; obligatory */
+  /** Array for integrals (AUCs) at each x; obligatory. */
   double *yi,
   /** Extrapolation setting for the start of data:
       - 0= assuming y=0 when x<x[0]
       - 1= assuming y=y[0] when 0<=x<x[0] and y=0 when x<x[0]<0
-      - 2= assuming y=0 when x<=0 and x[0]>0, and
-                    y=x*y[0]/x[0] when 0<x<x[0] and y[0]>0
-      - 3= same as '2' if 2*x[0]-x[1]<=0, otherwise same as '0'     
+      - 2= assuming y=0 when x<=0 and x[0]>0, and y=x*y[0]/x[0] when 0<x<x[0] and y[0]>0
+      - 3= same as '2' if 2*x[0]-x[1]<=0, otherwise same as '0'
       - 4= same as '2' if 2*x[0]-x[1]<=0, otherwise assuming 
            y=0 when x<=2*x[0]-x[1], and 
            y=(x-(2*x[0]-x[1]))*y[0]/x[0] when (2*x[0]-x[1])<x<x[0]
            and y[0]>0.
    */
   const int se,
-  /** Verbose level; if zero, then nothing is printed to stderr or stdout */
+  /** Verbose level; if zero, then nothing is printed to stderr or stdout. */
   const int verbose
 ) {
   if(verbose>0) printf("liIntegrate(x, y, %d, yi, %d)\n", nr, se);
@@ -105,18 +100,17 @@ int liIntegrate(
 /*****************************************************************************/
 
 /*****************************************************************************/
-/** @brief Linear integration of PET TAC to middle frame times.
+/** @brief Calculate PET TAC AUC from start to each time frame, as averages during each frame
  
     @details 
-    Use this function for PET data when frame start and end
-    times are known. 
-    AUC calculation is started from first frame start time, ignoring possible
-    time gap before it.
-    Any gaps between time frames are filled with an imaginary frame calculated
-    as weighted average of previous and next frame.
+    Use this function for PET data when frame start and end times are known. 
+    AUC at the end of frame i is calculated as AUCe[i]=AUCe[i-1]+y[i]*(x2[i]-x1[i]),
+    and the integral for frame i is calculated as an average AUC[i]=(AUCe[i]+AUCe[i-1])/2.
+    AUC calculation is started from first frame start time, ignoring possible time gap before it.
+    Any gaps between time frames are filled with an imaginary frame calculated as weighted average 
+    of previous and next frame.
     Frames must be in ascending time order and frame overlaps removed; 
-    wrong order or large overlaps will lead to substantial errors in integrals
-    without warning.
+    wrong order or large overlaps will lead to substantial errors in integrals without warning.
     Results will be wrong if data contains NaNs.
    
     @sa liInterpolate(), liIntegrate(), liInterpolateForPET()
@@ -125,23 +119,20 @@ int liIntegrate(
  */
 int liIntegratePET(
   /** Array of input data x1 (frame start time) values; obligatory.
-   *  Negative frame times are accepted. */
+      Negative frame times are accepted. */
   double *x1,
   /** Array of input data x2 (frame end time) values; obligatory.
-   *  Negative frame times are accepted, but it is required that for each frame
-   *  x2>=x1. */
+      Negative frame times are accepted, but it is required that for each frame x2>=x1. */
   double *x2,
-  /** Array of frame mean y (concentration) values; obligatory */
+  /** Array of frame mean y (concentration) values; obligatory. */
   double *y,
-  /** Number of samples (frames); obligatory */
+  /** Number of samples (frames); obligatory. */
   int nr,
-  /** Array for integrals (AUCs) at each x (frame middle time);
-      enter NULL if not needed. */
+  /** Array for integrals (AUCs) at each x (frame middle time); enter NULL if not needed. */
   double *ie,
-  /** Array for 2nd integrals (AUCs) at each x (frame middle time);
-      enter NULL if not needed. */
+  /** Array for 2nd integrals (AUCs) at each x (frame middle time); enter NULL if not needed. */
   double *iie,
-  /** Verbose level; if zero, then nothing is printed to stderr or stdout */
+  /** Verbose level; if zero, then nothing is printed to stderr or stdout. */
   const int verbose
 ) {
   if(verbose>0) printf("liIntegratePET(x1, x2, y, %d, i, ii)\n", nr);
@@ -209,6 +200,95 @@ int liIntegratePET(
   if(verbose>3) printf("liIntegratePET() ready\n");
   return(0);
 }
+/*****************************************************************************/
+
+/*****************************************************************************/
+/** @brief Linear integration of PET TAC to frame end times.
+ 
+    @details 
+    Use this function for PET data when frame start and end times are known. 
+    AUC calculation is started from first frame start time, ignoring possible time gap before it.
+    Any gaps between time frames are filled with an imaginary frame calculated as weighted average 
+    of previous and next frame.
+    Frames must be in ascending time order and frame overlaps removed.
+   
+    @sa liIntegratePET, liInterpolate(), liIntegrate(), liInterpolateForPET()
+    @author Vesa Oikonen
+    @return enum tpcerror (TPCERROR_OK when successful).
+ */
+int liIntegrateFE(
+  /** Array of input data x1 (frame start time) values; obligatory.
+      Negative frame times are accepted. */
+  double *x1,
+  /** Array of input data x2 (frame end time) values; obligatory.
+      Negative frame times are accepted, but it is required that for each frame x2>=x1. */
+  double *x2,
+  /** Array of frame mean y (concentration) values; obligatory. */
+  double *y,
+  /** Number of samples (frames); obligatory. */
+  int nr,
+  /** Array for integrals (AUCs) at each x (frame middle time); enter NULL if not needed. */
+  double *ie,
+  /** Array for 2nd integrals (AUCs) at each x (frame middle time); enter NULL if not needed. */
+  double *iie,
+  /** Verbose level; if zero, then nothing is printed to stderr or stdout. */
+  const int verbose
+) {
+  if(verbose>0) printf("liIntegrateFE(x1, x2, y, %d, i, ii, %d)\n", nr, verbose);
+
+  /* Check for data */
+  if(nr<1) return(TPCERROR_FAIL);
+  if(x1==NULL || x2==NULL || y==NULL) return(TPCERROR_FAIL);
+  /* No use to do anything if both output arrays are NULL */
+  if(ie==NULL && iie==NULL) return(TPCERROR_OK);
+
+  double prev_fdur=0.0;
+  double prev_iy=0.0, prev_iiy=0.0;
+  double iy=0.0, iiy=0.0;
+  for(int i=0; i<nr; i++) {
+    /* Duration of this time frame */
+    double fdur=x2[i]-x1[i]; 
+    if(!isfinite(fdur)) return(TPCERROR_INVALID_X);
+    if(fabs(fdur)<1.0E-10) { // frame length is about zero
+      if(ie!=NULL) ie[i]=prev_iy;
+      if(iie!=NULL) iie[i]=prev_iiy;
+      continue;
+    }
+    if(fdur<0.0) return(TPCERROR_INVALID_X);
+    /* Check for gap */
+    if(i>0) {
+      double gap=x1[i]-x2[i-1];
+      if(gap<0.0) return(TPCERROR_INVALID_X); // overlap not accepted
+      if(gap>1.0E-10) {
+        /* Estimate the integral of during the gap;
+           estimate y during gap as weighted mean of previous and this frame */
+        double gap_y=fdur*y[i]+prev_fdur*(y[i-1]);
+        double xs=fdur+prev_fdur; if(xs>0.0) gap_y/=xs;
+        double gap_integral=gap*gap_y;
+        double gap_integral2=gap*0.5*(iy+iy+gap_integral);
+        /* Add gap integrals */
+        iy+=gap_integral;
+        iiy+=gap_integral2;
+      }
+    }
+    /* Calculate integrals at frame end */
+    double box_integral=fdur*y[i];
+    double box_integral2=fdur*0.5*(iy+iy+box_integral);
+    /* Add gap integrals */
+    iy+=box_integral;
+    iiy+=box_integral2;
+    if(ie!=NULL) ie[i]=iy; 
+    if(iie!=NULL) iie[i]=iiy;
+    /* Prepare for the next frame */
+    prev_fdur=fdur; prev_iy=iy; prev_iiy=iiy;
+  } // next time frame
+
+  if(verbose>3) printf("liIntegrateFE() ready\n");
+  return(TPCERROR_OK);
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
 
 #if(0)
 /** @brief Linear integration of TAC with trapezoidal method.
