@@ -552,6 +552,44 @@ int test_liIntegratePET(
 }
 /*****************************************************************************/
 
+/*****************************************************************************/
+int test_liIntegrateFE(
+  TPCSTATUS *status
+) {
+  int verbose=0; if(status!=NULL) verbose=status->verbose;
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  if(verbose>0) {
+    printf("\n=====================================\n");
+    printf("\n%s\n", __func__);
+    printf("\n=====================================\n");
+  }
+
+  liIntegrateFE(NULL, NULL, NULL, 0, NULL, NULL, 1);
+  if(verbose>1) printf("did not segfault, that is good.\n");
+
+  {
+    int n=2;
+    double x1[]={1.0,2.0};
+    double x2[]={2.0,4.0};
+    double y[]={1.0,5.0};
+    double iy[n], iiy[n];
+    double ciy[]={1.0,11.0};
+    double ciiy[]={0.5,12.5};
+    if(liIntegrateFE(x1, x2, y, n, iy, iiy, 1)) return(11);
+    for(int i=0; i<n; i++) {
+      if(!doubleMatch(ciy[i],  iy[i],  1.0E-10) || !doubleMatch(ciiy[i],  iiy[i],  1.0E-10)) {
+        printf("x1=%g x2=%g y=%g iy=%g iiy=%g\n", x1[i], x2[i], y[i], iy[i], iiy[i]);
+        return(12);
+      }
+    }
+    if(verbose>2) printf("\n ok \n");
+  }
+
+  fflush(stderr);
+  return(0);
+}
+/*****************************************************************************/
+
 /*****************************************************************************/
 int test_liIntegrateHalfFrame(
   TPCSTATUS *status
@@ -568,7 +606,7 @@ int test_liIntegrateHalfFrame(
 
   {
   if(verbose>1) printf("testing with empty data\n");
-  ret=liFrameMidValue(NULL, NULL, NULL, 0, NULL, verbose-1);
+  ret=liIntegrateHalfFrame(NULL, NULL, NULL, 0, NULL, verbose-1);
   if(verbose>1) printf("did not segfault, that is good.\n");
   if(ret==0) return 1;
   ret=liIntegrateHalfFrame(NULL, NULL, NULL, 100, NULL, verbose-1);
