@@ -1035,6 +1035,7 @@ int test_liInterpolateForPET(
 /*****************************************************************************/
 
 /*****************************************************************************/
+#if(0)
 int test_liFrameMidValue(
   TPCSTATUS *status
 ) {
@@ -1222,6 +1223,7 @@ int test_liFrameMidValue(
   statusSet(status, __func__, __FILE__, __LINE__, 0);
   return(0);
 }
+#endif
 /*****************************************************************************/
 
 /*****************************************************************************/
