@@ -68,7 +68,7 @@ int strTokenNCpy(
     // if this is the required token nr, then stop here
     if(n==i) {
       if(j>count-1) j=count-1;
-      strncpy(str3, cptr, j); str3[j]=(char)0;
+      strlcpy(str3, cptr, j+1); //strncpy(str3, cptr, j); str3[j]=(char)0;
       break;
     }
     cptr+=j;
@@ -251,7 +251,8 @@ size_t strlcpy(
       for example, destination string has been allocated as char dst[dstsize]; */
   size_t dstsize
 ) {
-  if(src==NULL) return(0);
+  if(dstsize>0) dst[0]='\0';
+  if(strlen(src)==0) return(0);
 
   char *d=dst;
   const char *s=src;
@@ -376,7 +377,7 @@ char *strEncodeForXML(
   }
   if(n==0) return(NULL);
   /* Allocate memory for new string (one char to max 6 chars) */
-  n*=5; n+=strlen(s);
+  n*=5; n+=strlen(s)+1;
   char *ns=(char*)malloc(n*sizeof(char));
   if(ns==NULL) return(NULL);
   /* Process the string */
