@@ -769,6 +769,10 @@ extern int powell(double *p, double *delta, int parNr, double ftol, int *iterNr,
 
 /*****************************************************************************/
 /* qr */
+extern int qrLSQ(
+  double **mat, double *rhs, double *sol, 
+  const unsigned int rows, const unsigned int cols, double *r2
+);
 extern int qr(
   double **A, int m, int n, double *B, double *X, double *rnorm,
   double *tau, double *res, double **wws, double *ws
