@@ -29,7 +29,7 @@ int niftiExists(
   char *imgfile,
   /** If file name refers to a NIfTI file, and if SIF exists, then SIF file name
       will be written in this char pointer (space needs to allocated by caller);
-      exter NULL if not needed. */
+      enter NULL if not needed. */
   char *siffile,
   /** Pointer to NIfTI header, which is filled in this function; enter NULL, if not needed. */
   NIFTI_DSR *header,
@@ -148,7 +148,7 @@ int niftiReadHeader(
   const char *filename,
   /** Pointer to previously allocated header structure. */
   NIFTI_DSR *dsr,
-  /** Verbose level; if zero, then nothing is printed to stderr or stdout */
+  /** Verbose level; if zero, then nothing is printed to stderr or stdout. */
   int verbose
 ) {
   if(verbose>0) {printf("%s(%s, ...)\n", __func__, filename); fflush(stdout);}
@@ -195,12 +195,19 @@ int niftiReadHeader(
     // opposite order in file and in current machine
     if(little==1) dsr->byte_order=0; else dsr->byte_order=1;
   }
-  if(verbose>1) {printf("  Nifti byte order := %d\n", dsr->byte_order); fflush(stdout);}
+  if(verbose>1) {
+    printf("  Nifti byte order := ");
+    if(dsr->byte_order==0) printf("big\n"); else printf("little\n");
+    if(same_order==1) printf("  No need for byte swapping\n");
+    else printf("  Byte swapping needed.\n");
+    fflush(stdout);
+  }
 
 
   /* Read file into NIfTI header structure */
   if(verbose>1) {printf("  reading header as binary data\n"); fflush(stdout);}
   unsigned char buf[hdrSize];
+  rewind(fp);
   if(fread(buf, hdrSize, 1, fp)<1) {fclose(fp); return(TPCERROR_CANNOT_READ);}
 
   /* Read NIfTI-1 extender */
@@ -305,7 +312,7 @@ int niftiReadHeader(
     if(!same_order) swawbip(buf+76, 32);
     memcpy(dsr->h1.pixdim, buf+76, 32);
     if(!same_order) swawbip(buf+108, 4);
-    memcpy(&dsr->h1.vox_offset, buf+108, 4);
+    memcpy(&dsr->h1.vox_offset, buf+108, 4); //printf("dsr->h1.vox_offset := %g\n", dsr->h1.vox_offset);
     if(!same_order) swawbip(buf+112, 4);
     memcpy(&dsr->h1.scl_slope, buf+112, 4);
     if(!same_order) swawbip(buf+116, 4);
@@ -373,14 +380,7 @@ int niftiReadHeader(
     memcpy(&dsr->h2.intent_p2, buf+88, 8);
     memcpy(&dsr->h2.intent_p3, buf+96, 8);
     if(!same_order) swap64ip(buf+104, 8); /* pixdim array */
-    memcpy(&dsr->h2.pixdim[0], buf+104, 8);
-    memcpy(&dsr->h2.pixdim[1], buf+112, 8);
-    memcpy(&dsr->h2.pixdim[2], buf+120, 8);
-    memcpy(&dsr->h2.pixdim[3], buf+128, 8);
-    memcpy(&dsr->h2.pixdim[4], buf+136, 8);
-    memcpy(&dsr->h2.pixdim[5], buf+144, 8);
-    memcpy(&dsr->h2.pixdim[6], buf+152, 8);
-    memcpy(&dsr->h2.pixdim[7], buf+160, 8);
+    memcpy(dsr->h2.pixdim, buf+104, 64);
     if(!same_order) swap64ip(buf+168, 1);
     memcpy(&dsr->h2.vox_offset, buf+168, 8);
     if(!same_order) swap64ip(buf+176, 6);
@@ -429,6 +429,7 @@ int niftiReadHeader(
   }
 
   if(verbose>1) {printf("  complete Nifti header was read.\n"); fflush(stdout);}
+  
 
   return(TPCERROR_OK);
 }
@@ -446,10 +447,10 @@ int niftiWriteHeader(
   const char *filename,
   /** Pointer to header structure to write. */
   NIFTI_DSR *dsr,
-  /** Verbose level; if zero, then nothing is printed to stderr or stdout */
+  /** Verbose level; if zero, then nothing is printed to stderr or stdout. */
   int verbose
 ) {
-  if(verbose>0) {printf("%s(%s, ...)\n", __func__, filename); fflush(stdout);}
+  if(verbose>0) {printf("%s(%s, dsr, %d)\n", __func__, filename, verbose); fflush(stdout);}
 
   /* Check arguments */
   if(strnlen(filename, 2)<1) return(TPCERROR_INVALID_FILENAME);
@@ -460,7 +461,7 @@ int niftiWriteHeader(
     if(strncmp(dsr->h1.magic, "ni1", 3)!=0 && strncmp(dsr->h1.magic, "n+1", 3)!=0)
       return(TPCERROR_INVALID_FORMAT);
   } else if(dsr->n==2) {
-    if(strncmp(dsr->h2.magic, "ni2", 3)!=0 && strncmp(dsr->h1.magic, "n+2", 3)!=0)
+    if(strncmp(dsr->h2.magic, "ni2", 3)!=0 && strncmp(dsr->h2.magic, "n+2", 3)!=0)
       return(TPCERROR_INVALID_FORMAT);
   } else
     return(TPCERROR_FAIL);
@@ -534,18 +535,11 @@ int niftiWriteHeader(
     bptr=buf+4; memcpy(bptr, &dsr->h2.magic, 8);
     bptr=buf+12; memcpy(bptr, &dsr->h2.datatype, 2); if(!same_order) swap16ip(bptr, 1);
     bptr=buf+14; memcpy(bptr, &dsr->h2.bitpix, 2); if(!same_order) swap16ip(bptr, 1);
-    bptr=buf+16; memcpy(bptr, &dsr->h2.dim, 8); if(!same_order) swap64ip(bptr, 8);
+    bptr=buf+16; memcpy(bptr, &dsr->h2.dim, 64); if(!same_order) swap64ip(bptr, 8);
     bptr=buf+80; memcpy(bptr, &dsr->h2.intent_p1, 8); if(!same_order) swap64ip(bptr, 1);
     bptr=buf+88; memcpy(bptr, &dsr->h2.intent_p2, 8); if(!same_order) swap64ip(bptr, 1);
     bptr=buf+96; memcpy(bptr, &dsr->h2.intent_p3, 8); if(!same_order) swap64ip(bptr, 1);
-    bptr=buf+104; memcpy(bptr, dsr->h2.pixdim, 8); if(!same_order) swap64ip(bptr, 1);
-    bptr+=8; memcpy(bptr, dsr->h2.pixdim+1, 8); if(!same_order) swap64ip(bptr, 1);
-    bptr+=8; memcpy(bptr, dsr->h2.pixdim+2, 8); if(!same_order) swap64ip(bptr, 1);
-    bptr+=8; memcpy(bptr, dsr->h2.pixdim+3, 8); if(!same_order) swap64ip(bptr, 1);
-    bptr+=8; memcpy(bptr, dsr->h2.pixdim+4, 8); if(!same_order) swap64ip(bptr, 1);
-    bptr+=8; memcpy(bptr, dsr->h2.pixdim+5, 8); if(!same_order) swap64ip(bptr, 1);
-    bptr+=8; memcpy(bptr, dsr->h2.pixdim+6, 8); if(!same_order) swap64ip(bptr, 1);
-    bptr+=8; memcpy(bptr, dsr->h2.pixdim+7, 8); if(!same_order) swap64ip(bptr, 1);
+    bptr=buf+104; memcpy(bptr, &dsr->h2.pixdim, 64); if(!same_order) swap64ip(bptr, 8);
     bptr=buf+168; memcpy(bptr, &dsr->h2.vox_offset, 8); if(!same_order) swap64ip(bptr, 1);
     bptr=buf+176; memcpy(bptr, &dsr->h2.scl_slope, 8); if(!same_order) swap64ip(bptr, 1);
     bptr=buf+184; memcpy(bptr, &dsr->h2.scl_inter, 8); if(!same_order) swap64ip(bptr, 1);
