@@ -249,11 +249,9 @@ typedef struct {
   float pixdim[8];
   /** Offset into .nii file (byte offset 108) */
   float vox_offset;
-  /** Data scaling: slope (byte offset 112); pixel values should be scaled
-      as scl_slope*x + scl_inter */
+  /** Data scaling: slope (byte offset 112); pixel values should be scaled as scl_slope*x + scl_inter */
   float scl_slope;
-  /** Data scaling: offset (byte offset 116); pixel values should be scaled
-   *  as scl_slope*x + scl_inter */
+  /** Data scaling: offset (byte offset 116); pixel values should be scaled as scl_slope*x + scl_inter */
   float scl_inter;
   /** Last slice index (byte offset 120) */
   short int slice_end;
@@ -304,8 +302,7 @@ typedef struct {
   /** Name or Meaning of data (Offset 0) (byte offset 328) */
   char intent_name[16];
   /** Magic string, "ni1\0" (dual file) or "n+1\0" (single file) (byte offset 344). 
-      If zero, file should be treated as Analyze.
-  */
+      If zero, file should be treated as Analyze. */
   char magic[4];
 } NIFTI_1_HEADER;
 
@@ -334,11 +331,9 @@ typedef struct {
   double pixdim[8];
   /** Offset into .nii file (byte offset 168) */
   int64_t vox_offset;
-  /** Data scaling: slope (byte offset 176); pixel values should be scaled
-      as scl_slope*x + scl_inter */
+  /** Data scaling: slope (byte offset 176); pixel values should be scaled as scl_slope*x + scl_inter */
   double scl_slope;
-  /** Data scaling: offset (byte offset 184); pixel values should be scaled
-      as scl_slope*x + scl_inter */
+  /** Data scaling: offset (byte offset 184); pixel values should be scaled as scl_slope*x + scl_inter */
   double scl_inter;
   /** Max display intensity (byte offset 192) */
   double cal_max;
@@ -488,9 +483,8 @@ typedef struct {
   char descrip[80];
   /** aux_file */
   char aux_file[24];
-  /** Slice orientation for the dataset; 0=transverse unflipped, 1=coronal 
-      unflipped, 2=sagittal unflipped, 3=transverse flipped, 4=coronal flipped,
-      5=sagittal flipped. */
+  /** Slice orientation for the dataset; 0=transverse unflipped, 1=coronal unflipped, 
+      2=sagittal unflipped, 3=transverse flipped, 4=coronal flipped, 5=sagittal flipped. */
   char orient;
   /** originator */
   char originator[10];
