@@ -726,7 +726,7 @@ int nloptIATGO(
   unsigned int fixedParNr=nloptLimitFixedNr(nlo);
   if(verbose>2 && fixedParNr>0) fprintf(fp, "fixedParNr := %d\n", fixedParNr);
   unsigned int fittedParNr=nlo->totalNr-fixedParNr;
-  if(verbose>2) fprintf(fp, "fittedParNr := %d\n", fittedParNr);
+  if(verbose>2) {fprintf(fp, "fittedParNr := %d\n", fittedParNr); fflush(fp);}
   if(fittedParNr<1) {
     statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_NO_DATA);
     return TPCERROR_NO_DATA;
@@ -836,10 +836,7 @@ int nloptIATGO(
   while(iterNr<maxIterNr && nlo->funCalls<nlo->maxFunCalls) {
     iterNr++;
     unsigned int sampleNr=nlo->funCalls; // LOCAL sampleNr, increasing in each iteration
-    if(verbose>3) {
-      fprintf(fp, "\nIteration %d with %d samples\n", iterNr, sampleNr);
-      fflush(fp);
-    }
+    if(verbose>3) {fprintf(fp, "\nIteration %d with %d samples\n", iterNr, sampleNr); fflush(fp);}
 
     /* Sort samples based on the evaluated function value */
     if(nloptSortP(nlo)!=TPCERROR_OK) {
@@ -855,13 +852,15 @@ int nloptIATGO(
     }
 
     /* If SD of the best points is minimal, and fit is not improving, then stop */
-    if(!isnan(prevBest) && prevBest==nlo->plist[dim]) {
+    if(verbose>4 && !isnan(prevBest))
+      fprintf(fp, "dif_to_prev_point :=  %e\n", prevBest-nlo->plist[dim]);
+    if(!isnan(prevBest) && (prevBest-nlo->plist[dim])<1.0E-20) {
       if(verbose>4) fprintf(fp, "Best point did not improve.\n");
       if(nloptMeanP(nlo, neighNr, nlo->xfull, nlo->xdelta)==TPCERROR_OK) {
         unsigned int i=0;
         for(i=0; i<dim; i++) if(fabs(nlo->xdelta[i])>nlo->xtol[i]) break;
         if(i==dim) {
-          if(verbose>4) fprintf(fp, "Small SD of best points.\n");
+          if(verbose>2) fprintf(fp, "Small SD of best points.\n");
           stopCounter++;
         } else stopCounter=0;
       }
@@ -869,6 +868,7 @@ int nloptIATGO(
     prevBest=nlo->plist[dim];
 
     /* Stop, if stopping rules bumped into several times */
+    if(verbose>4) fprintf(fp, "stopCounter := %d\n", stopCounter);
     if(stopCounter>2) {
       if(verbose>2) fprintf(fp, "\n Required tolerance reached.\n");
       break;
@@ -957,7 +957,7 @@ int nloptIATGO(
         fflush(fp);
       }
     }
-    if(verbose>4) {fprintf(fp, "topographic minima: %d\n", topoNr); fflush(fp);}
+    if(verbose>3) {fprintf(fp, "topographic minima: %d\n", topoNr); fflush(fp);}
     if(topoNr==0) {
       if(verbose>0) {fprintf(stderr, "Error: no topographical minima found\n"); fflush(stderr);}
       statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_BAD_FIT);
@@ -1028,7 +1028,7 @@ int nloptIATGO(
 
   } // end of iterations
 
-  /* Check the reason for loop exist */
+  /* Check the reason for loop exit */
   if(verbose>1) {
     if(iterNr>=maxIterNr)
       fprintf(fp, "\n Exceeded the maximum number for loops.\n");
