@@ -432,7 +432,7 @@ void parListLimits(
 int parWriteLimits(
   /** Pointer to PAR structure, from which the limits are to be written. */
   PAR *par,
-  /** Output file name. */
+  /** Output file name. Enter 'stdout' to print to stdout. */
   const char *fname,
   /** Verbose level; if zero, then nothing is printed to stderr or stdout */
   const int verbose
@@ -461,17 +461,20 @@ int parWriteLimits(
   if(verbose>1) printf("  keyNr=%d\n", ift.keyNr);
   if(ift.keyNr<1) {iftFree(&ift); return TPCERROR_NO_DATA;}
 
-  /* Open file */
-  if(verbose>1) printf("  opening %s\n", fname);
-  FILE *fp=fopen(fname, "w");
-  if(fp==NULL) {iftFree(&ift); return TPCERROR_CANNOT_WRITE;}
-
   /* Write IFT */
-  if(verbose>1) printf("  writing in %s\n", fname);
-  if(iftWrite(&ift, fp, NULL)!=TPCERROR_OK) {
-    iftFree(&ift); fclose(fp); return TPCERROR_CANNOT_WRITE;
+  if(strcasecmp(fname, "stdout")==0) { // into stdout
+    iftWrite(&ift, stdout, NULL);
+  } else { // into specified file
+    if(verbose>1) printf("  opening %s\n", fname);
+    FILE *fp=fopen(fname, "w");
+    if(fp==NULL) {iftFree(&ift); return TPCERROR_CANNOT_WRITE;}
+    if(verbose>1) printf("  writing in %s\n", fname);
+    if(iftWrite(&ift, fp, NULL)!=TPCERROR_OK) {
+      iftFree(&ift); fclose(fp); return TPCERROR_CANNOT_WRITE;
+    }
+    fclose(fp);
   }
-  iftFree(&ift); fclose(fp);
+  iftFree(&ift); 
 
   return TPCERROR_OK;
 }
