@@ -76,7 +76,7 @@ int parWriteRES(
   /* Write the studynr (optional) */
   i=iftFindKey(&par->h, "studynr", 0);
   if(i<0) i=iftFindKey(&par->h, "study_number", 0);
-  if(i>0) fprintf(fp, "Study:\t%s\n", par->h.item[i].value);
+  if(i>=0) fprintf(fp, "Study:\t%s\n", par->h.item[i].value);
 
   /* Write the names of the original datafiles (optional) */
   i=iftFindKey(&par->h, "datafile", 0);
