@@ -400,7 +400,7 @@ int tacReadScanditronics(
   if(verbose>2) printf("  reading data lines...\n");
   ii++;
   int i=0, stopped=0;
-  double time_of_day, first_tod, time_since_start, meas_interval;
+  double time_of_day, first_tod=0.0, time_since_start, meas_interval;
   while(ii<hdr->keyNr && i<tac->_sampleNr) {
     if(stopped) {iftDelete(hdr, ii); continue;}
     if(strnlen(hdr->item[ii].key, 3)>0 || hdr->item[ii].value==NULL) {
@@ -595,7 +595,7 @@ int tacReadGEMS(
   if(verbose>2) printf("  reading data lines...\n");
   ii++;
   int i=0, stopped=0;
-  double time_of_day, first_tod, time_since_start, meas_interval;
+  double time_of_day, first_tod=0.0, time_since_start, meas_interval;
   while(ii<hdr->keyNr && i<tac->_sampleNr) {
     if(stopped) {iftDelete(hdr, ii); continue;}
     if(strnlen(hdr->item[ii].key, 3)>0 || hdr->item[ii].value==NULL) {
