@@ -138,13 +138,13 @@ int tacXRange(
   mi=ma=nan("");
   if(d->isframe) {xi=d->x1; xa=d->x2;} else xi=xa=d->x;
   for(int i=0; i<d->sampleNr; i++) {
-    if(isnan(xi[i]) || isnan(xa[i])) continue;
+    if(!isfinite(xi[i]) || !isfinite(xa[i])) continue;
     if(isnan(mi) || isnan(ma)) {mi=xi[i]; ma=xa[i]; continue;}
     if(xi[i]<mi) mi=xi[i]; else if(xa[i]>ma) ma=xa[i];
   }
   if(xmin!=NULL) *xmin=mi;
   if(xmax!=NULL) *xmax=ma;
-  if(isnan(mi) || isnan(ma)) return(2);
+  if(!isfinite(mi) || !isfinite(ma)) return(2);
   return(0);
 }
 /*****************************************************************************/
@@ -178,20 +178,16 @@ int tacSampleXRange(
   int weighted=tacIsWeighted(d);
   int i, j;
   for(i=0; i<d->sampleNr; i++) {
-    if(isnan(xi[i]) || isnan(xa[i])) continue;
+    if(!isfinite(xi[i]) || !isfinite(xa[i])) continue;
     if(weighted && !(d->w[i]>0.0)) continue;
     for(j=0; j<d->tacNr; j++) if(isfinite(d->c[j].y[i])) break;
     if(j==d->tacNr) continue;
-/* before 2019-03-29
-    for(j=0; j<d->tacNr; j++) if(isnan(d->c[j].y[i])) break;
-    if(j!=d->tacNr) continue;
-*/
     if(isnan(mi) || isnan(ma)) {mi=xi[i]; ma=xa[i]; continue;}
     if(xi[i]<mi) mi=xi[i]; else if(xa[i]>ma) ma=xa[i];
   }
   if(xmin!=NULL) *xmin=mi;
   if(xmax!=NULL) *xmax=ma;
-  if(isnan(mi) || isnan(ma)) return(2);
+  if(!isfinite(mi) || !isfinite(ma)) return(2);
   return(0);
 }
 /*****************************************************************************/
@@ -223,7 +219,7 @@ int tacMinX(
     Data can contain NaNs, as long as some x values are available. 
     Note that x values are considered not to exist even when there is only one sample with x=0.
     @sa tacXRange, tacSetX, tacXCopy, tacCheckX1X2X, tacXNaNs, tacFixNaNs, tacMultipleSamples,
-        tacVerifyTimeOrder, tacIsWeighted
+        tacVerifyTimeOrder, tacIsWeighted, tacIsXContiguous
     @author Vesa Oikonen
     @return Returns 1 if x values are present, 0 if not (all zeroes or missing).
  */
@@ -241,8 +237,7 @@ int tacIsX(
 /*****************************************************************************/
 
 /*****************************************************************************/
-/** @brief Check whether sample (frame) times are the same (or very close to) 
-           in two TAC structures. 
+/** @brief Check whether sample (frame) times are the same (or very close to) in two TAC structures. 
     @details Data is not modified. 
     Sort by sample time before calling this.
     The order of TAC structures is not important.
@@ -311,6 +306,7 @@ int tacXMatch(
   if(d1->isframe==0 && d2->isframe==0) {
     if(verbose>2) {printf("frame mid times\n"); fflush(stdout);}
     for(fi=0; fi<smaller_sampleNr; fi++) {
+      if(d1->x[fi]*ts1==d2->x[fi]*ts2) continue;
       if(isnan(d1->x[fi]) && isnan(d2->x[fi])) continue; // match if both NaN
       if(isnan(d1->x[fi]) || isnan(d2->x[fi])) {n++; continue;} // no match
       f=fabs(d1->x[fi]*ts1-d2->x[fi]*ts2);
@@ -321,6 +317,7 @@ int tacXMatch(
   } else if(d1->isframe!=0 && d2->isframe!=0) {
     if(verbose>2) {printf("frame start and end times\n"); fflush(stdout);}
     for(fi=0; fi<smaller_sampleNr; fi++) {
+      if(d1->x1[fi]*ts1==d2->x1[fi]*ts2) continue;
       if(isnan(d1->x1[fi]) && isnan(d2->x1[fi])) continue; // match if both NaN
       if(isnan(d1->x1[fi]) || isnan(d2->x1[fi])) {n++; continue;} // no match
       f=fabs(d1->x1[fi]*ts1-d2->x1[fi]*ts2);
@@ -329,6 +326,7 @@ int tacXMatch(
       if(f>accepted_timedif) n++;
     }
     for(fi=0; fi<smaller_sampleNr; fi++) {
+      if(d1->x2[fi]*ts1==d2->x2[fi]*ts2) continue;
       if(isnan(d1->x2[fi]) && isnan(d2->x2[fi])) continue; // match if both NaN
       if(isnan(d1->x2[fi]) || isnan(d2->x2[fi])) {n++; continue;} // no match
       f=fabs(d1->x2[fi]*ts1-d2->x2[fi]*ts2);
@@ -342,6 +340,7 @@ int tacXMatch(
     for(fi=0; fi<smaller_sampleNr; fi++) {
       if(d1->isframe) x1=0.5*(d1->x1[fi]+d1->x2[fi]); else x1=d1->x[fi];
       if(d2->isframe) x2=0.5*(d2->x1[fi]+d2->x2[fi]); else x2=d2->x[fi];
+      if(x1*ts1==x2*ts2) continue;
       if(isnan(x1) && isnan(x2)) continue; // match if both NaN
       if(isnan(x1) || isnan(x2)) {n++; continue;} // no match
       f=fabs(x1*ts1-x2*ts2);
@@ -445,7 +444,7 @@ int tacDeleteSample(
 /*****************************************************************************/
 /** @brief Delete those samples (time frames) from TAC structure, which contain
            only missing y values, and/or x is NaN.
-    @sa tacDeleteSample, tacExtractRange, tacIsX, tacXNaNs, tacFixNaNs
+    @sa tacDeleteSample, tacExtractRange, tacIsX, tacXNaNs, tacFixNaNs, tacIsXContiguous
     @return Returns TPCERROR status (0 if ok).
  */
 int tacDeleteMissingSamples(
@@ -459,12 +458,12 @@ int tacDeleteMissingSamples(
     delthat=0;
     /* check the x value(s) for this sample */
     if(d->isframe) {
-      if(isnan(d->x1[fi]) || isnan(d->x2[fi])) delthat=1;
+      if(!isfinite(d->x1[fi]) || !isfinite(d->x2[fi])) delthat=1;
     } else {
-      if(isnan(d->x[fi])) delthat=1;
+      if(!isfinite(d->x[fi])) delthat=1;
     }
     /* check the y value(s) for this sample */
-    for(ri=n=0; ri<d->tacNr; ri++) if(!isnan(d->c[ri].y[fi])) n++;
+    for(ri=n=0; ri<d->tacNr; ri++) if(isfinite(d->c[ri].y[fi])) n++;
     if(n==0) delthat=1;
     if(delthat!=0) {
       /* delete sample */
@@ -614,7 +613,8 @@ int tacExtractSamples(
 /*****************************************************************************/
 /** @brief Check that sample (time frame) x, x1, and x2 values are reasonably
     set when compared to each other in TAC structure.
-    @sa tacSortByTime, tacIsX, tacAddZeroSample, tacXCopy, tacSetX, tacXNaNs, tacGetSampleInterval
+    @sa tacSortByTime, tacIsX, tacAddZeroSample, tacXCopy, tacSetX, tacXNaNs, tacGetSampleInterval, 
+        tacIsXContiguous
     @author Vesa Oikonen
     @return Returns 1 if reasonable, 0 if not.
  */
@@ -645,10 +645,10 @@ int tacCheckX1X2X(
 /*****************************************************************************/
 /** @brief Set TAC x values based on x1 and x2 values, or guess x1 and x2 values based on x values.
     @details This is not an idiot proof method, but works reasonably well in common cases.
-    @sa tacSortByTime, tacIsX, tacAddZeroSample, tacXCopy, tacCheckX1X2X, tacXNaNs, tacFixNaNs
+    @sa tacSortByTime, tacIsX, tacAddZeroSample, tacXCopy, tacCheckX1X2X, tacXNaNs, tacFixNaNs,
+        tacIsXContiguous
     @author Vesa Oikonen
     @return Returns TPCERROR status (0 if ok).
-    @todo Not ready!
  */
 int tacSetX(
   /** Pointer to the TAC structure. TAC samples must be sorted for increasing x,
@@ -661,6 +661,7 @@ int tacSetX(
 ) {
   int verbose=0; if(status!=NULL) verbose=status->verbose;
   if(verbose>0) printf("%s()\n", __func__);
+
   if(d==NULL) {
     statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_FAIL);
     return TPCERROR_FAIL;
@@ -681,7 +682,7 @@ int tacSetX(
     int i, n, ret;
     for(i=n=0; i<d->sampleNr; i++) {
       d->x[i]=0.5*(d->x1[i]+d->x2[i]);
-      if(!isnan(d->x[i])) n++;
+      if(isfinite(d->x[i])) n++;
     }
     if(n>0) ret=TPCERROR_OK; else ret=TPCERROR_NO_X; 
     statusSet(status, __func__, __FILE__, __LINE__, ret);
@@ -745,11 +746,12 @@ int tacSetX(
   double gap, v;
   gap=nan("");
   for(i=0; i<n-1; i++) {
-    v=x[i+1]-x[i]; if(v<0.001) continue;
+    v=x[i+1]-x[i]; if(!isfinite(v) || v<0.001) continue;
     if(isnan(gap)) {gap=v; continue;}
     if(v<gap) gap=v;
   }
-  if(isnan(gap)) {
+
+  if(!isfinite(gap)) {
     tacFree(&t);
     statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_NO_X);
     return(TPCERROR_NO_X);
@@ -847,14 +849,14 @@ int tacGetSampleInterval(
   if(d->isframe) {
     for(int i=0; i<d->sampleNr; i++) {
       double f=d->x2[i]-d->x1[i];
-      if(!isnan(ilimit) && f<ilimit) continue;
+      if(!isnan(ilimit) && !(f>=ilimit)) continue;
       if(isnan(mi) || f<mi) mi=f;
       if(isnan(ma) || f>ma) ma=f;
     }
   } else {
     for(int i=1; i<d->sampleNr; i++) {
       double f=d->x[i]-d->x[i-1];
-      if(!isnan(ilimit) && f<ilimit) continue;
+      if(!isnan(ilimit) && !(f>=ilimit)) continue;
       if(isnan(mi) || f<mi) mi=f;
       if(isnan(ma) || f>ma) ma=f;
     }
@@ -880,7 +882,7 @@ int tacGetSampleInterval(
 /** @brief Transform TAC data with frame start and end times into suitable form 
            for plotting with frames as bars.
     @attention Output data must not be used for quantitative purposes.
-    @sa tacFramesToSteps, tacXRange, tacIsX, tacCheckX1X2X, tacExtractRange
+    @sa tacFramesToSteps, tacXRange, tacIsX, tacCheckX1X2X, tacExtractRange, tacSetXContiguous
     @return Returns <>0 in case of failure.
  */
 int tacToBars(
@@ -930,3 +932,319 @@ int tacToBars(
 /*****************************************************************************/
 
 /*****************************************************************************/
+#if(1)
+/** @brief Transform TAC with frames into TAC with frames represented with
+           stepwise changing dot-to-dot data. 
+
+    @sa tacInterpolate, tacToBars, tacAUC, tacDelay, tacInterpolateToEqualLengthFrames, liInterpolate
+    @return enum tpcerror (TPCERROR_OK when successful).
+ */ 
+int tacFramesToSteps(
+  /** Pointer to source TAC structure. 
+      @pre Data must be sorted by increasing x. There must be no gaps or overlap between frames.
+      @sa tacSortByTime, tacSetXContiguous
+   */
+  TAC *inp,
+  /** Pointer to the initiated target TAC structure; any previous contents are deleted. */
+  TAC *out,
+  /** Pointer to status data; enter NULL if not needed. */
+  TPCSTATUS *status
+) {
+  int verbose=0; if(status!=NULL) verbose=status->verbose;
+  if(verbose>0) printf("%s()\n", __func__);
+  if(inp==NULL || out==NULL) {
+    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_FAIL);
+    return TPCERROR_FAIL;
+  }
+  /* Check the function input */
+  if(inp->sampleNr<1 || inp->tacNr<1) {
+    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_NO_DATA);
+    return TPCERROR_NO_DATA;
+  }
+
+  /* Check that input does not have any missing values */
+  if(tacNaNs(inp)>0) {
+    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_MISSING_DATA);
+    return TPCERROR_MISSING_DATA;
+  }
+
+  /* Check that there are no gaps or overlap between frames */
+  {
+    //printf("  checking that there are no gaps or overlap\n"); fflush(stdout);
+    int ret=tacIsXContiguous(inp);
+    statusSet(status, __func__, __FILE__, __LINE__, ret);
+    if(ret!=TPCERROR_OK) return(ret);
+  }
+
+  /* First, duplicate the TAC data */
+  //printf("  copying data\n"); fflush(stdout);
+  if(tacDuplicate(inp, out)!=TPCERROR_OK) {
+    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_FAIL);
+    return TPCERROR_FAIL;
+  }
+
+  /* If frame start and end times are NOT present, then consider that work is done */
+  if(inp->isframe==0) return(TPCERROR_OK);
+
+  /* Add room for more frames */
+  //printf("  allocating memory for output\n"); fflush(stdout);
+  if(tacAllocateMoreSamples(out, 2+2*out->sampleNr)!=0) {
+    tacFree(out);
+    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_OUT_OF_MEMORY);
+    return TPCERROR_OUT_OF_MEMORY;
+  }
+
+  /* Make separate 'samples' for each frame start and end time */
+  out->isframe=0;
+  out->sampleNr=0;
+  /* Add zero sample at zero time if data starts later */
+  if(inp->x1[0]>0.01*(inp->x2[0]-inp->x1[0])) {
+    if(verbose>10) printf("  add zero sample\n");
+    out->x[0]=0.0;
+    for(int ri=0; ri<out->tacNr; ri++) out->c[ri].y[0]=0.0;
+    out->sampleNr++;
+  }
+  /* Add zero sample at the start of the first frame */
+  if(verbose>10) printf("  add first frame zero sample\n");
+  out->x[out->sampleNr]=inp->x1[0];
+  for(int ri=0; ri<out->tacNr; ri++) out->c[ri].y[out->sampleNr]=0.0;
+  out->sampleNr++;
+
+  /* Add frame start and end times */
+  for(int fi=0; fi<inp->sampleNr; fi++) {
+    if(verbose>10) printf("  frame %d: %g - %g\n", 1+fi, inp->x1[fi], inp->x2[fi]);
+    /* add start sample, if any of y values differs from previous one */
+    out->x[out->sampleNr]=out->x[out->sampleNr-1];
+//    if(fi==0) out->x[out->sampleNr]=inp->x1[fi];
+//    else out->x[out->sampleNr]=out->x[out->sampleNr-1];
+    int dn=0;
+    for(int ri=0; ri<out->tacNr; ri++) {
+      out->c[ri].y[out->sampleNr]=inp->c[ri].y[fi];
+      if(out->c[ri].y[out->sampleNr]!=out->c[ri].y[out->sampleNr-1]) dn++;
+    }
+    if(dn>0) out->sampleNr++;
+    /* add end sample */
+    out->x[out->sampleNr]=inp->x2[fi];
+    for(int ri=0; ri<out->tacNr; ri++)
+      out->c[ri].y[out->sampleNr]=inp->c[ri].y[fi];
+    out->sampleNr++;
+  }
+
+  statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_OK);
+  return(TPCERROR_OK);
+}
+#else
+/** @brief Transform TAC with frames into TAC with frames represented with
+           stepwise changing dot-to-dot data. 
+
+    @details Gaps are replaced with lines connecting the corners of frame rectangles.
+     Small frame overlaps are replaced by step at the midpoint of the overlap.
+    @sa tacInterpolate, tacToBars, tacInterpolateToEqualLengthFrames, liInterpolate
+    @return enum tpcerror (TPCERROR_OK when successful).
+ */ 
+int tacFramesToSteps(
+  /** Pointer to source TAC struct.
+      @pre Data must be sorted by increasing x. */
+  TAC *inp,
+  /** Pointer to the initiated target TAC struct; any previous contents are deleted. */
+  TAC *out,
+  /** Pointer to status data; enter NULL if not needed. */
+  TPCSTATUS *status
+) {
+  int verbose=0; if(status!=NULL) verbose=status->verbose;
+  if(verbose>0) printf("%s()\n", __func__);
+  if(inp==NULL || out==NULL) {
+    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_FAIL);
+    return TPCERROR_FAIL;
+  }
+  /* Check the function input */
+  if(inp->sampleNr<1 || inp->tacNr<1) {
+    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_NO_DATA);
+    return TPCERROR_NO_DATA;
+  }
+
+  /* Check that input does not have any missing values */
+  if(tacNaNs(inp)>0) {
+    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_MISSING_DATA);
+    return TPCERROR_MISSING_DATA;
+  } 
+
+  /* First, duplicate the TAC data */
+  if(tacDuplicate(inp, out)!=TPCERROR_OK) {
+    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_FAIL);
+    return TPCERROR_FAIL;
+  }
+
+  /* Make sure that frame start and end times are present */
+  if(inp->isframe==0) return(TPCERROR_OK); // if not, consider that work is done
+
+  /* Add room for more frames */
+  if(tacAllocateMoreSamples(out, 1+2*out->sampleNr)!=0) {
+    tacFree(out);
+    statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_OUT_OF_MEMORY);
+    return TPCERROR_OUT_OF_MEMORY;
+  }
+
+  /* Make separate 'samples' for each frame start and end time */
+  out->isframe=0;
+  int fi=0, fj=0;
+  if(fabs(inp->x1[fi])>1.0E-20) { // add zero sample, if data does not already have it
+    out->x[fj]=inp->x1[fi];
+    for(int ri=0; ri<out->tacNr; ri++) out->c[ri].y[fj]=0.0;
+    fj++;
+  }
+  for(fi=0; fi<inp->sampleNr; fi++) {
+    if(fi>0 && inp->x1[fi]<inp->x2[fi-1]) { // overlap
+      double x=0.5*(inp->x1[fi]+inp->x2[fi-1]);
+      if(x<out->x[fj-2]) { // too large overlap
+        tacFree(out);
+        statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_OVERLAPPING_DATA);
+        return TPCERROR_OVERLAPPING_DATA;
+      }
+      out->x[fj-1]=out->x[fj]=x;
+    } else { // no overlap
+      out->x[fj]=inp->x1[fi];
+    }
+    for(int ri=0; ri<out->tacNr; ri++) out->c[ri].y[fj]=inp->c[ri].y[fi];
+    fj++;
+    out->x[fj]=inp->x2[fi];
+    for(int ri=0; ri<out->tacNr; ri++) out->c[ri].y[fj]=inp->c[ri].y[fi];
+    fj++;
+  }
+  out->sampleNr=fj;
+
+  statusSet(status, __func__, __FILE__, __LINE__, TPCERROR_OK);
+  return(TPCERROR_OK);
+}
+#endif
+/*****************************************************************************/
+
+/*****************************************************************************/
+/** @short Check that PET TAC frame times are contiguous, without even tiny overlap or gaps in between.
+    
+   @sa tacSetXContiguous, tacIsX, tacXRange, tacVerifyTimeOrder, tacSortByTime, tacXCopy, tacMultipleSamples
+  
+   @return If no overlap or gaps, TPCERROR_OK (0) is returned.
+   @author Vesa Oikonen
+ */
+int tacIsXContiguous(
+  /** Pointer to TAC data which is sorted by increasing sample time. */
+  TAC *d
+) {
+  if(d==NULL) return TPCERROR_FAIL;
+  if(tacXNaNs(d)>0) return(TPCERROR_INVALID_X);
+
+  /* If no frame start and end times, then just check the order */
+  if(d->isframe==0) {
+    if(tacVerifyTimeOrder(d, NULL)) return(TPCERROR_INVALID_XRANGE);
+    return TPCERROR_OK;
+  }
+
+  /* Check each frame */
+  for(int fi=0; fi<d->sampleNr-1; fi++) {
+    double e=d->x2[fi]-d->x1[fi+1];
+    if(e<0.0) return(TPCERROR_LARGE_GAP);
+    if(e>0.0) return(TPCERROR_OVERLAPPING_DATA);
+  }
+
+  return(TPCERROR_OK);
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
+/** @short Set PET TAC frame times contiguous, without even tiny overlap or gaps in between.
+
+   Tiny overlaps and gaps are fixed by modifying frame times.
+   Large gaps are filled with new frames based on linear interpolation between adjacent frames.
+   Error is returned in case of larger frame overlaps.
+
+   @sa tacIsXContiguous, tacIsX, tacXRange, tacVerifyTimeOrder, tacSortByTime, tacMultipleSamples
+  
+   @return If successful, TPCERROR_OK (0) is returned.
+   @author Vesa Oikonen
+ */
+int tacSetXContiguous(
+  /** Pointer to TAC data which is sorted by increasing sample time. */
+  TAC *d
+) {
+  if(d==NULL) return TPCERROR_FAIL;
+  if(tacXNaNs(d)>0) return(TPCERROR_INVALID_X);
+
+  /* If no frame start and end times, then just make the times increasing */
+  if(d->isframe==0) return(tacSortByTime(d, NULL));
+
+  /* If there are no gaps or overlap, then we're done */
+  if(tacIsXContiguous(d)==TPCERROR_OK) return(TPCERROR_OK);
+
+  /* Make a duplicate for editing */
+  TAC tac; tacInit(&tac);
+  int ret=tacDuplicate(d, &tac); if(ret!=TPCERROR_OK) return(ret);
+
+  /* Check for small frame overlaps or gaps; fix small, and return error if large overlap */
+  int fixed=0, large=0;
+  for(int fi=0; fi<d->sampleNr-1; fi++) {
+    double dif=d->x1[fi+1]-d->x2[fi]; if(dif==0.0) continue; // not gap or overlap
+    double fdur1=d->x2[fi]-d->x1[fi];
+    double fdur2=d->x2[fi+1]-d->x1[fi+1];
+    if(dif>0) { // gap
+      if(dif<0.2*fdur1 && dif<0.2*fdur2) { // small gap; increase the shorter frame duration
+        if(fdur1<fdur2) tac.x2[fi]=d->x1[fi+1]; else tac.x1[fi+1]=d->x2[fi];
+        fixed++;
+      } else {
+        large++; // large gap not fixed yet
+      }
+      continue;
+    }
+    /* Overlap */
+    dif=-dif;
+    if(dif>0.2*fdur1 || dif>0.2*fdur2) { // too large overlap
+      tacFree(&tac); return(TPCERROR_OVERLAPPING_DATA);
+    }
+    /* Reduce the longer frame length */
+    if(fdur1>fdur2) tac.x2[fi]=d->x1[fi+1]; else tac.x1[fi+1]=d->x2[fi];
+    fixed++;
+  }
+
+  /* If we fixed something, then copy the fixed frame times */
+  if(fixed>0) {
+    for(int i=0; i<d->sampleNr; i++) {
+      d->x1[i]=tac.x1[i]; d->x2[i]=tac.x2[i]; d->x[i]=0.5*(d->x1[i]+d->x2[i]);
+    }
+  }
+
+  /* If there were no large gaps, we're done */
+  if(large==0) {tacFree(&tac); return(TPCERROR_OK);}
+
+  /* Fill large gaps with new frames */
+  d->weighting=WEIGHTING_OFF;
+  if(tacAllocateMoreSamples(d, large)!=0) {
+    tacFree(&tac); return(TPCERROR_OUT_OF_MEMORY);
+  }
+  d->sampleNr=1;
+  for(int fi=1; fi<tac.sampleNr; fi++) {
+    double dif=tac.x1[fi]-tac.x2[fi-1];
+    if(dif>0.0) {
+      /* Add new frame times */
+      d->x1[d->sampleNr]=tac.x2[fi-1]; d->x2[d->sampleNr]=tac.x1[fi];
+      d->x[fi]=0.5*(d->x1[d->sampleNr]+d->x2[d->sampleNr]);
+      /* Calculate y values for the new frame */
+      double x1=0.5*(tac.x1[fi-1]+tac.x2[fi-1]);
+      double x2=0.5*(tac.x1[fi]+tac.x2[fi]);
+      for(int ri=0; ri<tac.tacNr; ri++) {
+        double s=(tac.c[ri].y[fi]-tac.c[ri].y[fi-1])/(x2-x1);
+        d->c[ri].y[d->sampleNr]=tac.c[ri].y[fi-1] + s*(d->x[fi]-x1);
+      }
+      d->sampleNr++;
+    }
+    /* copy the existing frame */
+    d->x1[d->sampleNr]=tac.x1[fi]; d->x2[d->sampleNr]=tac.x2[fi];
+    for(int ri=0; ri<tac.tacNr; ri++) d->c[ri].y[d->sampleNr]=tac.c[ri].y[fi];
+    d->sampleNr++;
+  }
+
+  tacFree(&tac);
+  return(TPCERROR_OK);
+}
+/*****************************************************************************/
+
+/*****************************************************************************/
