@@ -47,6 +47,7 @@ typedef enum {
   TAC_FORMAT_CARIMAS_TXT, ///< Carimas txt format (reading supported) 
   TAC_FORMAT_QVIEW,       ///< QView CSV TAC format (reading supported)
   TAC_FORMAT_MAT,         ///< Matlab matrix TAC format (reading supported)
+  TAC_FORMAT_4DM,         ///< 4DM TAC format (reading supported)
   TAC_FORMAT_HRRT_HC,     ///< HRRT head curve format (reading supported)
   TAC_FORMAT_HRPLUS_HC,   ///< HR+ head curve format (reading supported)
   TAC_FORMAT_ABSS_SCANDITRONICS, ///< Scanditronics ABSS data; reading supported
@@ -244,6 +245,11 @@ extern int tacReadPMOD(TAC *tac, CSV *csv, IFT *hdr, TPCSTATUS *status);
 extern int tacReadQView(TAC *tac, CSV *csv, const int grouponly, TPCSTATUS *status);
 /*****************************************************************************/
 
+/*****************************************************************************/
+/* 4dmio */
+extern int tacRead4DM(TAC *tac, CSV *csv, TPCSTATUS *status);
+/*****************************************************************************/
+
 /*****************************************************************************/
 /* matio */
 extern int tacReadMat(TAC *tac, CSV *csv, TPCSTATUS *status);
@@ -345,6 +351,9 @@ extern int tacCheckX1X2X(TAC *d);
 extern int tacSetX(TAC *d, TPCSTATUS *status);
 extern int tacGetSampleInterval(TAC *d, double ilimit, double *minfdur, double *maxfdur);
 extern int tacToBars(TAC *tac1, TAC *tac2);
+extern int tacFramesToSteps(TAC *inp, TAC *out, TPCSTATUS *status);
+extern int tacIsXContiguous(TAC *d);
+extern int tacSetXContiguous(TAC *d);
 /*****************************************************************************/
 
 /*****************************************************************************/
