@@ -5,6 +5,64 @@
 #include "test_tpctacmod.h"
 /*****************************************************************************/
 
+/*****************************************************************************/
+int test_tacIntegrate(
+  TPCSTATUS *status
+) {
+  int verbose=0; if(status!=NULL) verbose=status->verbose;
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  if(verbose>0) {
+    printf("\n=====================================\n");
+    printf("\n%s\n", __func__);
+    printf("\n=====================================\n");
+  }
+  int ret;
+
+  if(verbose>1) printf("\n testing with NULL data \n");
+  ret=tacIntegrate(NULL, NULL, NULL);
+  if(ret==TPCERROR_OK) return(1);
+
+  if(verbose>1) printf("\n making test data \n");
+  TAC tac1; tacInit(&tac1);
+  TAC tac2; tacInit(&tac2);
+  if(create_inp1(&tac1)) {return(10);}
+
+  /* Integrate when frame durations are available */
+  tac1.isframe=1;
+  ret=tacIntegrate(&tac1, &tac2, NULL);
+  if(ret!=TPCERROR_OK) return(11);
+  if(tac1.tacNr!=tac2.tacNr || tac1.sampleNr!=tac2.sampleNr) {
+    tacFree(&tac1); tacFree(&tac2); return(12);}
+  {
+    for(int ri=0; ri<tac1.tacNr; ri++) {
+      double auc[tac1.sampleNr];
+      liIntegratePET(tac1.x1, tac1.x2, tac1.c[ri].y, tac1.sampleNr, auc, NULL, 0);
+      if(!doubleArrayMatch(tac2.c[ri].y, auc, tac1.sampleNr, 1.0E-10)) {
+        tacFree(&tac1); tacFree(&tac2); return(13);}
+    }
+  }
+
+  /* Integrate when frame durations are not available */
+  tac1.isframe=0;
+  ret=tacIntegrate(&tac1, &tac2, NULL);
+  if(ret!=TPCERROR_OK) return(21);
+  if(tac1.tacNr!=tac2.tacNr || tac1.sampleNr!=tac2.sampleNr) {
+    tacFree(&tac1); tacFree(&tac2); return(12);}
+  {
+    for(int ri=0; ri<tac1.tacNr; ri++) {
+      double auc[tac1.sampleNr];
+      liIntegrate(tac1.x, tac1.c[ri].y, tac1.sampleNr, auc, 3, 0);
+      if(!doubleArrayMatch(tac2.c[ri].y, auc, tac1.sampleNr, 1.0E-10)) {
+        tacFree(&tac1); tacFree(&tac2); return(13);}
+    }
+  }
+
+  tacFree(&tac1); tacFree(&tac2);
+  statusSet(status, __func__, __FILE__, __LINE__, 0);
+  return(0);
+}
+/*****************************************************************************/
+
 /*****************************************************************************/
 int test_tacInterpolate(
   TPCSTATUS *status
@@ -693,208 +751,6 @@ int test_tacInterpolateToEqualLengthFrames(
 }
 /*****************************************************************************/
 
-/*****************************************************************************/
-int test_tacFramesToSteps(
-  TPCSTATUS *status
-) {
-  int verbose=0; if(status!=NULL) verbose=status->verbose;
-  statusSet(status, __func__, __FILE__, __LINE__, 0);
-  if(verbose>0) {
-    printf("\n=====================================\n");
-    printf("\n%s\n", __func__);
-    printf("\n=====================================\n");
-  }
-
-  int ret;
-
-  if(verbose>1) printf("\n testing with NULL data \n");
-  ret=tacFramesToSteps(NULL, NULL, NULL);
-  if(ret==TPCERROR_OK) return(1);
-
-  TAC tac1, tac2; tacInit(&tac1); tacInit(&tac2);
-
-  if(verbose>1) printf("\n testing with empty data \n");
-  ret=tacFramesToSteps(&tac1, &tac2, NULL);
-  if(ret==TPCERROR_OK) return(2);
-
-  if(verbose>1) printf("\n making test data \n");
-  if(create_inp1(&tac1)) {tacFree(&tac1); tacFree(&tac2); return(10);}
-
-  if(verbose>1) printf("\n original data has no frames\n");
-  tac1.isframe=0;
-  ret=tacFramesToSteps(&tac1, &tac2, NULL);
-  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(11);}
-  ret=tacCompareTimes(&tac1, &tac2, 1.0E-20, 1.0E-20, NULL);
-  if(ret==0) tacCompareConc(&tac1, &tac2, -1, 1.0E-20, 1.0E-20, NULL);
-  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(12);}
-
-  if(verbose>1) printf("\n original data has frames\n");
-  tac1.isframe=1;
-  if(verbose>2) {
-    printf("\ninput:\n");
-    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
-  }
-  ret=tacFramesToSteps(&tac1, &tac2, NULL);
-  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(21);}
-  if(verbose>2) {
-    printf("\noutput:\n");
-    tacWrite(&tac2, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
-  }
-  if(tac2.sampleNr!=8) {tacFree(&tac1); tacFree(&tac2); return(22);}
-  ret= !doubleMatch(tac2.x[0], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[1], 2.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[2], 2.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[3], 4.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[4], 4.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[5], 6.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[6], 6.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[7], 194.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[0], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[1], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[2], 50.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[3], 50.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[4], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[5], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[6], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[7], 0.0, 1.0E-12);
-  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(23);}
-
-  if(verbose>1) printf("\n original data has small frame overlap\n");
-  tac1.isframe=1;
-  tac1.x2[0]=2.5; tac1.x1[1]=1.5;
-  if(verbose>2) {
-    printf("\ninput:\n");
-    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
-  }
-  ret=tacFramesToSteps(&tac1, &tac2, NULL);
-  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(31);}
-  if(verbose>2) {
-    printf("\noutput:\n");
-    tacWrite(&tac2, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
-  }
-  if(tac2.sampleNr!=8) {tacFree(&tac1); tacFree(&tac2); return(32);}
-  ret= !doubleMatch(tac2.x[0], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[1], 2.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[2], 2.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[3], 4.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[4], 4.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[5], 6.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[6], 6.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[7], 194.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[0], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[1], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[2], 50.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[3], 50.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[4], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[5], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[6], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[7], 0.0, 1.0E-12);
-  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(33);}
-
-  if(verbose>1) printf("\n original data has large frame overlap\n");
-  tac1.isframe=1;
-  tac1.x1[0]=0.0; tac1.x2[0]=2.0; 
-  tac1.x1[1]=2.0; tac1.x2[1]=2.1; 
-  tac1.x1[2]=1.0;
-  if(verbose>2) {
-    printf("\ninput:\n");
-    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
-  }
-  ret=tacFramesToSteps(&tac1, &tac2, NULL);
-  if(ret==TPCERROR_OK && verbose>2) {
-    printf("\noutput:\n");
-    tacWrite(&tac2, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
-  }
-  if(ret==TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(41);}
-
-
-  if(verbose>1) printf("\n original data has gaps\n");
-  tac1.isframe=1;
-  tac1.x1[0]=1.0;   tac1.x2[0]=2.0;
-  tac1.x1[1]=2.0;   tac1.x2[1]=4.0;
-  tac1.x1[2]=4.0;   tac1.x2[2]=6.0;
-  tac1.x1[3]=190.0; tac1.x2[3]=194.0;
-  if(verbose>2) {
-    printf("\ninput:\n");
-    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
-  }
-  ret=tacFramesToSteps(&tac1, &tac2, NULL);
-  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(51);}
-  if(verbose>2) {
-    printf("\noutput:\n");
-    tacWrite(&tac2, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
-  }
-  if(tac2.sampleNr!=9) {tacFree(&tac1); tacFree(&tac2); return(52);}
-  ret= !doubleMatch(tac2.x[0], 1.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[1], 1.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[2], 2.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[3], 2.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[4], 4.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[5], 4.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[6], 6.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[7], 190.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[8], 194.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[0], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[1], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[2], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[3], 50.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[4], 50.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[5], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[6], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[7], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[8], 0.0, 1.0E-12);
-  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(53);}
-
-
-  if(verbose>1) printf("\n more than one TAC\n");
-  tacFree(&tac1); if(create_inp1(&tac1)) {tacFree(&tac1); tacFree(&tac2); return(100);}
-  if(tacAllocateMore(&tac1, 1)!=0) {tacFree(&tac1); tacFree(&tac2); return(100);}
-  for(int i=0; i<tac1.sampleNr; i++) tac1.c[1].y[i]=2.0*tac1.c[0].y[i];
-  tac1.tacNr=2;
-  if(verbose>2) {
-    printf("\ninput:\n");
-    tacWrite(&tac1, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
-  }
-  ret=tacFramesToSteps(&tac1, &tac2, NULL);
-  if(ret!=TPCERROR_OK) {tacFree(&tac1); tacFree(&tac2); return(101);}
-  if(verbose>2) {
-    printf("\noutput:\n");
-    tacWrite(&tac2, stdout, TAC_FORMAT_CSV_UK, 0, NULL);
-  }
-  if(tac2.sampleNr!=8) {tacFree(&tac1); tacFree(&tac2); return(102);}
-  ret= !doubleMatch(tac2.x[0], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[1], 2.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[2], 2.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[3], 4.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[4], 4.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[5], 6.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[6], 6.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.x[7], 194.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[0], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[1], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[2], 50.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[3], 50.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[4], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[5], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[6], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[0].y[7], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[1].y[0], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[1].y[1], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[1].y[2], 100.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[1].y[3], 100.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[1].y[4], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[1].y[5], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[1].y[6], 0.0, 1.0E-12);
-  ret+=!doubleMatch(tac2.c[1].y[7], 0.0, 1.0E-12);
-  if(ret!=0) {tacFree(&tac1); tacFree(&tac2); return(103);}
-
-
-  tacFree(&tac1); tacFree(&tac2);
-  statusSet(status, __func__, __FILE__, __LINE__, 0);
-  return(0);
-}
-/*****************************************************************************/
-
 /*****************************************************************************/
 int test_tacDelay(
   TPCSTATUS *status
