@@ -1009,7 +1009,7 @@ int main(int argc, char **argv)
     sprintf(buf, "%s %s", method_str[method], model_str[model]);
     i=iftFindKey(&ttac0.h, "studynr", 0);
     if(i<0) i=iftFindKey(&ttac0.h, "study_number", 0);
-    if(i>0) {strcat(buf, ": "); strcat(buf, ttac0.h.item[i].value);}
+    if(i>=0) {strcat(buf, ": "); strcat(buf, ttac0.h.item[i].value);}
     ret=tacPlotFitSVG(&ttac0, &ttac1, buf, 0.0, nan(""), 0.0, nan(""), svgfile, &status);
     if(ret!=TPCERROR_OK) {
       fprintf(stderr, "Error: %s\n", errorMsg(status.error));
