@@ -555,7 +555,7 @@ int main(int argc, char **argv)
     sprintf(buf, "3exp");
     i=iftFindKey(&tac0.h, "studynr", 0);
     if(i<0) i=iftFindKey(&tac0.h, "study_number", 0);
-    if(i>0) {strcat(buf, ": "); strcat(buf, tac0.h.item[i].value);}
+    if(i>=0) {strcat(buf, ": "); strcat(buf, tac0.h.item[i].value);}
     ret=tacPlotFitSVG(&tac0, &tac2, buf, 0.0, nan(""), 0.0, nan(""), svgfile, &status);
     if(ret!=TPCERROR_OK) {
       fprintf(stderr, "Error: %s\n", errorMsg(status.error));
