@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_llsqrk2
-#: Date       : 2019-03-31
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -493,8 +493,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: Reference region does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM framed1.tac tac9999 output.par &> stdout.txt
+$PROGRAM framed1.tac tac9999 output.par 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "reference not found"
@@ -506,8 +505,7 @@ printf "\n 2.0.1 \n"
 printf " Test case: Reference that is part of all region names. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -svg=tmp.svg -d2 framed1.tac tac output.par &> stdout.txt
+$PROGRAM -svg=tmp.svg -d2 framed1.tac tac output.par 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "reference not found"
