@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgdv
-#: Date       : 2018-06-26
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,7 +11,6 @@ else
 EXT=;
 fi
 PROGRAM=../../imgdv$EXT;
-
 if [ ! -f $PROGRAM ]; then
   printf "Failed: executable does not exist.\n"
   exit 1
@@ -352,8 +351,7 @@ printf "\n 1.0.0 \n"
 printf " Test case: No command line options or arguments. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM &> stdout.txt
+$PROGRAM 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Usage"
@@ -367,8 +365,7 @@ printf "\n 1.0.1 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption plasma.dat dynamic.v 30 output.v &> stdout.txt
+$PROGRAM -stupidoption plasma.dat dynamic.v 30 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -379,8 +376,7 @@ printf "\n 1.0.2 \n"
 printf " Test case: Too many arguments. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.dat dynamic.v 30 output.v extra &> stdout.txt
+$PROGRAM plasma.dat dynamic.v 30 output.v extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -391,18 +387,15 @@ printf "\n 1.0.3 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v 30 output.v &> stdout.txt
+$PROGRAM dynamic.v 30 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.dat dynamic.v output.v &> stdout.txt
+$PROGRAM plasma.dat dynamic.v output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.dat dynamic.v 30  &> stdout.txt
+$PROGRAM plasma.dat dynamic.v 30  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -537,9 +530,9 @@ printf "\n 3.0.1 \n"
 printf " Test case: Dynamic NIfTI image without SIF. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt nifti/*.sif
+rm -f nifti/*.sif
 
-$PROGRAM plasma.dat nifti/dynamic2 45 nifti/dv2 &> stdout.txt
+$PROGRAM plasma.dat nifti/dynamic2 45 nifti/dv2 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading data" "image frame times not available."
@@ -569,9 +562,9 @@ printf "\n 3.1.1 \n"
 printf " Test case: Dynamic Analyze image without SIF. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt ana/*.sif
+rm -f ana/*.sif
 
-$PROGRAM plasma.dat ana/dynamic2 45 ana/dv2 &> stdout.txt
+$PROGRAM plasma.dat ana/dynamic2 45 ana/dv2 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading data" "image frame times not available."
