@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgfur
-#: Date       : 2014-10-10
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,11 @@ else
 EXT=;
 fi
 PROGRAM=../../imgfur$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -19,11 +24,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f plasma.dat ] || [ ! -f frames.dat ]; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -198,8 +198,7 @@ printf "\n 1.0.0 \n"
 printf " Test case: No command line options or arguments. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM &> stdout.txt
+$PROGRAM 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Usage"
@@ -213,8 +212,7 @@ printf "\n 1.0.1 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption plasma.dat dynamic.v 0 0 output.v &> stdout.txt
+$PROGRAM -stupidoption plasma.dat dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -226,7 +224,7 @@ printf " Test case: Too many arguments. \n"
 printf " Expected result: Error. \n\n"
 
 rm -f stdout.txt
-$PROGRAM plasma.dat dynamic.v 0 0 output.v extra &> stdout.txt
+$PROGRAM plasma.dat dynamic.v 0 0 output.v extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -237,18 +235,15 @@ printf "\n 1.0.3 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v 0 0 output.v &> stdout.txt
+$PROGRAM dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.dat dynamic.v 0 output.v &> stdout.txt
+$PROGRAM plasma.dat dynamic.v 0 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.dat dynamic.v 0 0  &> stdout.txt
+$PROGRAM plasma.dat dynamic.v 0 0  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -261,8 +256,7 @@ printf " Test case: Substrate concentration given with option -ca. \n"
 printf " Expected result 1: Concentration is read correctly. \n"
 printf " Expected result 2: Warning that default density and LC are used. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -ca=5.2 plasma.dat dynamic.v 0 0 output.v &> stdout.txt
+$PROGRAM -d2 -ca=5.2 plasma.dat dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Ca" "5.2"
@@ -280,13 +274,11 @@ printf "\n 1.1.1 \n"
 printf " Test case: Invalid use of option -ca. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -ca= plasma.dat dynamic.v 0 0 output.v &> stdout.txt
+$PROGRAM -d2 -ca= plasma.dat dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -ca plasma.dat dynamic.v 0 0 output.v &> stdout.txt
+$PROGRAM -d2 -ca plasma.dat dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -297,8 +289,7 @@ printf "\n 1.2.0 \n"
 printf " Test case: Lumped constant given with option -lc. \n"
 printf " Expected result: LC is read correctly. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -ca=5,2 -lc=0,82 plasma.dat dynamic.v 0 0 output.v &> stdout.txt
+$PROGRAM -d2 -ca=5,2 -lc=0,82 plasma.dat dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "LC" "0.82"
@@ -315,8 +306,8 @@ printf "\n passed. \n\n"
 printf "\n 1.2.1 \n"
 printf " Test case: Lumped constant given with option -lc, without -ca. \n"
 printf " Expected result: Warning that LC will not ge used. \n\n"
-rm -f stdout.txt
-$PROGRAM -d2 -LC=0.82 plasma.dat dynamic.v 0 0 output.v &> stdout.txt
+
+$PROGRAM -d2 -LC=0.82 plasma.dat dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "LC was set but is not used."
@@ -329,13 +320,11 @@ printf "\n 1.2.2 \n"
 printf " Test case: Invalid use of option -lc. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -lc= plasma.dat dynamic.v 0 0 output.v &> stdout.txt
+$PROGRAM -d2 -lc= plasma.dat dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -lc plasma.dat dynamic.v 0 0 output.v &> stdout.txt
+$PROGRAM -d2 -lc plasma.dat dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -346,8 +335,7 @@ printf "\n 1.3.0 \n"
 printf " Test case: Density given with option -density. \n"
 printf " Expected result: Density is read correctly. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -ca=5.2 -density=1,02 plasma.dat dynamic.v 0 0 output.v &> stdout.txt
+$PROGRAM -d2 -ca=5.2 -density=1,02 plasma.dat dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "density" "1.02"
@@ -364,8 +352,8 @@ printf "\n passed. \n\n"
 printf "\n 1.3.1 \n"
 printf " Test case: Density given with option, without -ca. \n"
 printf " Expected result: Warning that density will not ge used. \n\n"
-rm -f stdout.txt
-$PROGRAM -d2 -density=1.02 plasma.dat dynamic.v 0 0 output.v &> stdout.txt
+
+$PROGRAM -d2 -density=1.02 plasma.dat dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "tissue density was set but is not used."
@@ -378,13 +366,11 @@ printf "\n 1.3.2 \n"
 printf " Test case: Invalid use of option -density. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -density= plasma.dat dynamic.v 0 0 output.v &> stdout.txt
+$PROGRAM -d2 -density= plasma.dat dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -density plasma.dat dynamic.v 0 0 output.v &> stdout.txt
+$PROGRAM -d2 -density plasma.dat dynamic.v 0 0 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -534,11 +520,10 @@ printf "\n 3.1.0 \n"
 printf " Test case: Image data stops much earlier than time range. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
 esplit dynamic.v 1-14 1 short.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM plasma.dat short.v 40 60 output.v &> stdout.txt
+$PROGRAM plasma.dat short.v 40 60 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "integration time range oversteps data range."
@@ -550,11 +535,10 @@ printf "\n 3.1.1 \n"
 printf " Test case: Plasma data stops much earlier than time range. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
 taccut plasma.dat 0 15 short.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM short.dat dynamic.v 40 60 output.v &> stdout.txt
+$PROGRAM short.dat dynamic.v 40 60 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "integration time range oversteps data range."
@@ -566,9 +550,7 @@ printf "\n 3.1.2 \n"
 printf " Test case: Plasma and image data stops much earlier than time range. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM short.dat short.v 40 60 output.v &> stdout.txt
+$PROGRAM short.dat short.v 40 60 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "integration time range oversteps data range."
@@ -620,9 +602,9 @@ printf "\n 4.0.2 \n"
 printf " Test case: FUR from static NIfTI image without SIF. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt nifti/*.sif
+rm -f nifti/*.sif
 
-$PROGRAM plasma.dat nifti/mean_40_60 0 0 nifti/fur &> stdout.txt
+$PROGRAM plasma.dat nifti/mean_40_60 0 0 nifti/fur 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "nifti/mean_40_60 does not contain frame times."
@@ -670,9 +652,9 @@ printf "\n 4.1.2 \n"
 printf " Test case: FUR from static Analyze image without SIF. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt ana/*.sif
+rm -f ana/*.sif
 
-$PROGRAM plasma.dat ana/mean_40_60 0 0 ana/fur &> stdout.txt
+$PROGRAM plasma.dat ana/mean_40_60 0 0 ana/fur 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "ana/mean_40_60 does not contain frame times."
