@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgki
-#: Date       : 2019-09-18
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,7 +11,6 @@ else
 EXT=;
 fi
 PROGRAM=../../imgki$EXT;
-
 if [ ! -f $PROGRAM ]; then
   printf "Failed: executable does not exist.\n"
   exit 1
@@ -234,8 +233,7 @@ printf "\n 1.0.0 \n"
 printf " Test case: No command line options or arguments. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM &> stdout.txt
+$PROGRAM 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Usage"
@@ -249,8 +247,7 @@ printf "\n 1.0.1 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption plasma.dat dynamic.v 30 output.v &> stdout.txt
+$PROGRAM -stupidoption plasma.dat dynamic.v 30 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -261,8 +258,7 @@ printf "\n 1.0.2 \n"
 printf " Test case: Too many arguments. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.dat dynamic.v 30 output.v extra &> stdout.txt
+$PROGRAM plasma.dat dynamic.v 30 output.v extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -273,18 +269,15 @@ printf "\n 1.0.3 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM dynamic.v 30 output.v &> stdout.txt
+$PROGRAM dynamic.v 30 output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.dat dynamic.v output.v &> stdout.txt
+$PROGRAM plasma.dat dynamic.v output.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.dat dynamic.v 30  &> stdout.txt
+$PROGRAM plasma.dat dynamic.v 30  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -301,9 +294,9 @@ printf "\n 2.0.0 \n"
 printf " Test case 1: Dynamic ECAT7 image, starting fit from 30 min. \n"
 printf " Expected result: Correct result. \n\n"
 
-rm -f output.v output.dft output.res stdout.txt
+rm -f output.v output.dft output.res
 
-$PROGRAM plasma.dat dynamic.v 30 output.v &> stdout.txt
+$PROGRAM plasma.dat dynamic.v 30 output.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 img2tif -s -rb output.v output_200.tif
@@ -336,9 +329,9 @@ printf "\n 2.0.1 \n"
 printf " Test case: Dynamic ECAT6 image. \n"
 printf " Expected result: Correct result. \n\n"
 
-rm -f output.img output.dft output.res stdout.txt
+rm -f output.img output.dft output.res
 
-$PROGRAM plasma.dat dynamic.img 30 output.img &> stdout.txt
+$PROGRAM plasma.dat dynamic.img 30 output.img 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 img2dft -P output.img plane1.roi output.dft 
@@ -360,9 +353,9 @@ printf "\n 2.1.0 \n"
 printf " Test case: Calculation of MR image. \n"
 printf " Expected result: Correct result. \n\n"
 
-rm -f output2.v output2.dft output2.res stdout.txt
+rm -f output2.v output2.dft output2.res
 
-$PROGRAM -d2 -ca=4,2 -density=1,01 -LC=0,8 plasma.dat dynamic.v 30 output2.v &> stdout.txt
+$PROGRAM -d2 -ca=4,2 -density=1,01 -LC=0,8 plasma.dat dynamic.v 30 output2.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "LC" "0.8"
@@ -404,9 +397,9 @@ printf " Test case: Dynamic ECAT7 image, automatic fit start time. \n"
 printf " Expected result 1: Results are close to correct. \n\n"
 printf " Expected result 2: Nr of points in fit can be saved in image. \n\n"
 
-rm -f output.v output.dft output.res nr.v nr.dft nr.res stdout.txt
+rm -f output.v output.dft output.res nr.v nr.dft nr.res
 
-$PROGRAM -n=nr.v plasma.dat dynamic.v 0 output.v &> stdout.txt
+$PROGRAM -n=nr.v plasma.dat dynamic.v 0 output.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 img2tif -s -rb output.v output_210.tif
@@ -435,7 +428,7 @@ printf " Test case 1: Dynamic ECAT7 image, starting fit from 30 min. \n"
 printf " Test case 2: Option -noneg sets negative values to zero. \n"
 printf " Expected result: Correct result. \n\n"
 
-rm -f output.v output.dft output.res stdout.txt
+rm -f output.v output.dft output.res
 
 $PROGRAM -noneg plasma.dat dynamic.v 30 output.v
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -484,9 +477,9 @@ printf "\n 4.0.1 \n"
 printf " Test case: Ki from NIfTI image without SIF. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt nifti/*.sif
+rm -f nifti/*.sif
 
-$PROGRAM plasma.dat nifti/dynamic 30 nifti/ki &> stdout.txt
+$PROGRAM plasma.dat nifti/dynamic 30 nifti/ki 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading data" "image frame times not available."
@@ -517,9 +510,9 @@ printf "\n 4.1.1 \n"
 printf " Test case: Ki from Analyze image without SIF. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt ana/*.sif
+rm -f ana/*.sif
 
-$PROGRAM plasma.dat ana/dynamic 30 ana/ki &> stdout.txt
+$PROGRAM plasma.dat ana/dynamic 30 ana/ki 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading data" "image frame times not available."
