@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_patlak
-#: Date       : 2020-05-26
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -202,10 +202,9 @@ echo passed. ; echo ""
 echo ===============================================================================
 echo ""
 echo ===============================================================================
-rm -f stdout.txt
 echo "1.5.1: option -ca"
 echo "$PROGRAM --debug=3 -ca=5.2 dynamic.dft plasma.dat 30 999 output.res"
-$PROGRAM --debug=3 -ca=5.2 dynamic.dft plasma.dat 30 999 output.res &> stdout.txt
+$PROGRAM --debug=3 -ca=5.2 dynamic.dft plasma.dat 30 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
 echo passed. ; echo ""
 iftisval stdout.txt Ca "5.2"
@@ -218,16 +217,14 @@ iftisval stdout.txt Warning "tissue density not set, using default 1"
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
 echo passed. ; echo ""
 
-rm -f stdout.txt
-$PROGRAM --debug=3 -ca=5,2 dynamic.dft plasma.dat 30 999 output.res &> stdout.txt
+$PROGRAM --debug=3 -ca=5,2 dynamic.dft plasma.dat 30 999 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
 echo passed.
 iftisval stdout.txt Ca "5.2"
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
 echo passed. ; echo ""
 
-rm -f stdout.txt
-$PROGRAM --debug=3 dynamic.dft plasma.dat 30 999 output.res &> stdout.txt
+$PROGRAM --debug=3 dynamic.dft plasma.dat 30 999 output.res 1>stdout.txt 2>&1
 iftisval stdout.txt Ca
 if [ $? -ne 10 ] ; then echo Failed! ; exit 1 ; fi
 echo passed. ; echo ""
