@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_regfur
-#: Date       : 2014-10-05
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,11 @@ else
 EXT=;
 fi
 PROGRAM=../../regfur$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -19,11 +24,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f plasma.dat ] || [ ! -f frames.dat ] ; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -198,8 +198,7 @@ printf "\n 1.0.0 \n"
 printf " Test case: No command line options or arguments. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM &> stdout.txt
+$PROGRAM 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Usage"
@@ -213,8 +212,7 @@ printf "\n 1.0.1 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption plasma.dat dynamic.dft 0 0 output.res &> stdout.txt
+$PROGRAM -stupidoption plasma.dat dynamic.dft 0 0 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -225,8 +223,7 @@ printf "\n 1.0.2 \n"
 printf " Test case: Too many arguments. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.dat dynamic.dft 0 0 output.dft extra &> stdout.txt
+$PROGRAM plasma.dat dynamic.dft 0 0 output.dft extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -237,8 +234,7 @@ printf "\n 1.0.3 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM plasma.dat dynamic.dft 0 0 &> stdout.txt
+$PROGRAM plasma.dat dynamic.dft 0 0 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -250,8 +246,7 @@ printf " Test case: Substrate concentration given with option -ca. \n"
 printf " Expected result 1: Concentration is read correctly. \n"
 printf " Expected result 2: Warning that default density and LC are used. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -ca=5.2 plasma.dat dynamic.dft 0 0 output.res &> stdout.txt
+$PROGRAM -d2 -ca=5.2 plasma.dat dynamic.dft 0 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Ca" "5.2"
@@ -269,13 +264,11 @@ printf "\n 1.1.1 \n"
 printf " Test case: Invalid use of option -ca. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -ca= plasma.dat dynamic.dft 0 0 output.res &> stdout.txt
+$PROGRAM -d2 -ca= plasma.dat dynamic.dft 0 0 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -ca plasma.dat dynamic.dft 0 0 output.res &> stdout.txt
+$PROGRAM -d2 -ca plasma.dat dynamic.dft 0 0 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -286,8 +279,7 @@ printf "\n 1.2.0 \n"
 printf " Test case: Lumped constant given with option -lc. \n"
 printf " Expected result: LC is read correctly. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -Ca=5,2 -LC=0.82 plasma.dat dynamic.dft 0 0 output.res &> stdout.txt
+$PROGRAM -d2 -Ca=5,2 -LC=0.82 plasma.dat dynamic.dft 0 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "LC" "0.82"
@@ -304,8 +296,8 @@ printf "\n passed. \n\n"
 printf "\n 1.2.1 \n"
 printf " Test case: Lumped constant given with option -lc, without -ca. \n"
 printf " Expected result: Warning that LC will not ge used. \n\n"
-rm -f stdout.txt
-$PROGRAM -d2 -LC=0.82 plasma.dat dynamic.dft 0 0 output.res &> stdout.txt
+
+$PROGRAM -d2 -LC=0.82 plasma.dat dynamic.dft 0 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "LC was set but is not used."
@@ -318,13 +310,11 @@ printf "\n 1.2.2 \n"
 printf " Test case: Invalid use of option -lc. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -lc= plasma.dat dynamic.dft 0 0 output.res &> stdout.txt
+$PROGRAM -d2 -lc= plasma.dat dynamic.dft 0 0 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -lc plasma.dat dynamic.dft 0 0 output.res &> stdout.txt
+$PROGRAM -d2 -lc plasma.dat dynamic.dft 0 0 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -335,8 +325,7 @@ printf "\n 1.3.0 \n"
 printf " Test case: Density given with option -density. \n"
 printf " Expected result: Density is read correctly. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -Ca=5.2 -density=1,06 plasma.dat dynamic.dft 0 0 output.res &> stdout.txt
+$PROGRAM -d2 -Ca=5.2 -density=1,06 plasma.dat dynamic.dft 0 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "density" "1.06"
@@ -353,8 +342,8 @@ printf "\n passed. \n\n"
 printf "\n 1.3.1 \n"
 printf " Test case: Density given with option, without -ca. \n"
 printf " Expected result: Warning that density will not ge used. \n\n"
-rm -f stdout.txt
-$PROGRAM -d2 -density=1.02 plasma.dat dynamic.dft 0 0 output.res &> stdout.txt
+
+$PROGRAM -d2 -density=1.02 plasma.dat dynamic.dft 0 0 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "tissue density was set but is not used."
@@ -367,13 +356,11 @@ printf "\n 1.3.2 \n"
 printf " Test case: Invalid use of option -density. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -density= plasma.dat dynamic.dft 0 0 output.res &> stdout.txt
+$PROGRAM -d2 -density= plasma.dat dynamic.dft 0 0 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -density plasma.dat dynamic.dft 0 0 output.res &> stdout.txt
+$PROGRAM -d2 -density plasma.dat dynamic.dft 0 0 output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -390,7 +377,7 @@ printf " Test case 1: Simple plasma data with some header information. \n"
 printf " Test case 2: Tissue data with frame start and end times. \n"
 printf " Expected result: Correct result. \n\n"
 
-rm -f stdout.txt output.dft test_fur.dft
+rm -f output.dft test_fur.dft
 
 dftinteg --silent -avg dynamic.dft 40 20 mean_40_60.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -402,7 +389,7 @@ taccalc --silent mean_40_60.dft : $auc test_fur.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM plasma.dat dynamic.dft 40 60 output.dft &> stdout.txt
+$PROGRAM plasma.dat dynamic.dft 40 60 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.000001 -rel=0.1 -x=y -xunit=y -yunit=n test_fur.dft output.dft
@@ -418,9 +405,9 @@ printf " Expected result: Correct result. \n\n"
 sed '/^#/ d' < plasma.dat > temp.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-rm -f stdout.txt output.dft
+rm -f output.dft
 
-$PROGRAM temp.dat dynamic.dft 40 60 output.dft &> stdout.txt
+$PROGRAM temp.dat dynamic.dft 40 60 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.000001 -rel=0.1 -x=y -xunit=y -yunit=y correct_fur_50.dft output.dft
@@ -444,9 +431,9 @@ sed '/^#/ d' < correct_fur_50.dat > temp2.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
 
-rm -f stdout.txt output.dat
+rm -f output.dat
 
-$PROGRAM plasma.dat temp.dat 40 60 output.dat &> stdout.txt
+$PROGRAM plasma.dat temp.dat 40 60 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.00001 -rel=0.5 -x=y -y=y -xunit=y -yunit=y temp2.dat output.dat
@@ -462,9 +449,9 @@ printf " Test case 3: Output in CSV format. \n"
 printf " Expected result: Correct result. \n\n"
 
 
-rm -f stdout.txt output.csv
+rm -f output.csv
 
-$PROGRAM plasma.dat dynamic.dft 40 60 output.csv &> stdout.txt
+$PROGRAM plasma.dat dynamic.dft 40 60 output.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.00001 -rel=0.5 -x=y -y=y -xunit=n -yunit=n correct_fur_50.dat output.csv
@@ -479,9 +466,9 @@ printf " Test case 3: Output in RES format. \n"
 printf " Expected result: Correct result. \n\n"
 
 
-rm -f stdout.txt output.res
+rm -f output.res
 
-$PROGRAM plasma.dat dynamic.dft 40 60 output.res &> stdout.txt
+$PROGRAM plasma.dat dynamic.dft 40 60 output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 resmatch -abs=0.0001 -param=y -regions=n -errors=n correct_fur_50.res output.res
@@ -597,9 +584,9 @@ printf "\n 4.0.0 \n"
 printf " Test case: Option -it=time. \n"
 printf " Expected result: Correct result. \n\n"
 
-rm -f stdout.txt output.dft
+rm -f output.dft
 
-$PROGRAM -it=40 plasma.dat dynamic.dft 40 60 output.dft &> stdout.txt
+$PROGRAM -it=40 plasma.dat dynamic.dft 40 60 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.000001 -rel=0.1 -x=y -xunit=y -yunit=y correct_fur_50b.dft output.dft
@@ -612,11 +599,11 @@ printf "\n 4.1.0 \n"
 printf " Test case: User enters the same start and end time. \n"
 printf " Expected result: Correct result. \n\n"
 
-rm -f stdout.txt output.dft
+rm -f output.dft
 # dftinteg --silent -avg dynamic.dft 59.5 1 mean_60.dft
 # taccalc --silent mean_60.dft : 548.5 correct_fur_60.dft
 
-$PROGRAM -curve=fur3.dft plasma.dat dynamic.dft 60 60 output.dft &> stdout.txt
+$PROGRAM -curve=fur3.dft plasma.dat dynamic.dft 60 60 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.000001 -rel=0.1 -x=y -xunit=y -yunit=y correct_fur_60.dft output.dft
@@ -629,12 +616,12 @@ printf "\n 4.2.0 \n"
 printf " Test case: TTAC does not extend to the calculation range. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f short.dft stdout.txt output.dft
+rm -f short.dft output.dft
 taccut dynamic.dft 0 30 short.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM plasma.dat short.dft 40 60 output.dft &> stdout.txt
+$PROGRAM plasma.dat short.dft 40 60 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ -f output.dft ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -648,12 +635,12 @@ printf "\n 4.2.1 \n"
 printf " Test case: PTAC does not extend to the calculation range. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f short.dat stdout.txt output.dft
+rm -f short.dat output.dft
 taccut plasma.dat 0 15 short.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM -curve=fur4.dft short.dat dynamic.dft 40 60 output.dft &> stdout.txt
+$PROGRAM -curve=fur4.dft short.dat dynamic.dft 40 60 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ -f output.dft ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -667,9 +654,9 @@ printf "\n 4.2.2 \n"
 printf " Test case: PTAC and TTAC do not extend to the calculation range. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dft
+rm -f output.dft
 
-$PROGRAM -curve=fur5.dft short.dat short.dft 40 60 output.dft &> stdout.txt
+$PROGRAM -curve=fur5.dft short.dat short.dft 40 60 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ -f output.dft ] ; then printf "Failed!\n" ; exit 1 ; fi
