@@ -65,8 +65,7 @@ echo ===========================================================================
 echo ""
 echo ===============================================================================
 echo "1.1.1: No command line options or arguments. Error with user info."
-if [ -f stdout.txt ] ; then rm stdout.txt ; fi
-$PROGRAM &> stdout.txt
+$PROGRAM 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then echo Failed! ; exit 1 ; fi
 echo passed.
 iftisval stdout.txt "See also"
