@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_pardiff
-#: Date       : 2015-12-03
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -12,6 +12,10 @@ EXT=;
 fi
 
 PROGRAM=../../pardiff$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -20,10 +24,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
 
 if [ ! -f plasma.bld ]; then
   printf "Failed: required data file does not exist.\n"
@@ -397,8 +397,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: Invalid option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption presdcl.csv postsdcl.csv output.csv &> stdout.txt
+$PROGRAM -stupidoption presdcl.csv postsdcl.csv output.csv 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -410,16 +409,14 @@ printf "\n 2.1.0 \n"
 printf " Test case: Nonexisting input filename. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexisting.csv postsdcl.csv output.csv &> stdout.txt
+$PROGRAM nonexisting.csv postsdcl.csv output.csv 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot open file (nonexisting.csv)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM presdcl.csv nonexisting.csv output.csv &> stdout.txt
+$PROGRAM presdcl.csv nonexisting.csv output.csv 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot open file (nonexisting.csv)"
@@ -437,16 +434,14 @@ printf "0,2,3\n" >> stupid.csv
 printf "1,2\n" >> stupid.csv
 printf "2,3,4\n" >> stupid.csv
 
-rm -f stdout.txt
-$PROGRAM stupid.csv postsdcl.csv output.csv &> stdout.txt
+$PROGRAM stupid.csv postsdcl.csv output.csv 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid file format (stupid.csv)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM presdcl.csv stupid.csv output.csv &> stdout.txt
+$PROGRAM presdcl.csv stupid.csv output.csv 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid file format (stupid.csv)"
@@ -466,7 +461,7 @@ resdel less.res reg1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
 rm -f output.res
-$PROGRAM less.res prek3.res output.res &> stdout.txt
+$PROGRAM less.res prek3.res output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "different TAC number in parameter files."
@@ -474,7 +469,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 rm -f output.res
-$PROGRAM prek3.res less.res output.res &> stdout.txt
+$PROGRAM prek3.res less.res output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "different TAC number in parameter files."
@@ -487,7 +482,7 @@ printf " Test case: different TAC names in file1 and file2. \n"
 printf " Expected result: Error. \n\n"
 
 rm -f output.csv
-$PROGRAM tacname1.csv tacname2.csv output.csv &> stdout.txt
+$PROGRAM tacname1.csv tacname2.csv output.csv 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "different TAC names in parameter files."
@@ -501,7 +496,7 @@ printf " Test case: different parameter nr in file1 and file2. \n"
 printf " Expected result: Error. \n\n"
 
 rm -f output.res
-$PROGRAM prek2.res postk3.res output.res &> stdout.txt
+$PROGRAM prek2.res postk3.res output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "different parameters in parameter files."
@@ -509,7 +504,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 rm -f output.res
-$PROGRAM prek3.res postk2.res output.res &> stdout.txt
+$PROGRAM prek3.res postk2.res output.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "different parameters in parameter files."
@@ -522,12 +517,12 @@ printf " Test case 2: option --force. \n"
 printf " Expected result: No error. \n\n"
 
 rm -f output.res
-$PROGRAM --force prek2.res postk3.res output.res &> stdout.txt
+$PROGRAM --force prek2.res postk3.res output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 rm -f output.res
-$PROGRAM -f prek3.res postk2.res output.res &> stdout.txt
+$PROGRAM -f prek3.res postk2.res output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -540,7 +535,7 @@ printf "\n 2.5.0 \n"
 printf " Test case: output filename not given. \n"
 printf " Expected result: output is written in stdout. \n\n"
 
-rm -f output.csv stdout.txt
+rm -f output.csv
 $PROGRAM --silent prek2.csv postk2.csv > stdout.txt
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
