@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_parformat
-#: Date       : 2020-06-19
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -62,8 +62,7 @@ printf "\n 0.1.0 \n"
 printf " Test case: Invalid option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption mrglu.res &> stdout.txt
+$PROGRAM -stupidoption mrglu.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -75,8 +74,7 @@ printf "\n 0.2.0 \n"
 printf " Test case: Extra argument when format is given. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -f=CSV-UK mrglu.res output.csv extra &> stdout.txt
+$PROGRAM -f=CSV-UK mrglu.res output.csv extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -88,8 +86,7 @@ printf "\n 0.2.1 \n"
 printf " Test case: Extra argument when format is not given. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res extra &> stdout.txt
+$PROGRAM mrglu.res extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -103,8 +100,7 @@ printf " Test case: Optional settings are correct by default. \n"
 printf " Expected result 1: Test print shows correct option setting. \n"
 printf " Expected result 2: Output lists the correct file format. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  --debug mrglu.res &> stdout.txt
+$PROGRAM  --debug mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -129,8 +125,8 @@ printf " Test case 2: Option to not save headers. \n"
 printf " Expected result 1: Test print shows correct option setting. \n"
 printf " Expected result 2: Output file is in intended file format. \n\n"
 
-rm -f stdout.txt output.csv
-$PROGRAM  --debug -f=CSV-INT -hdr=n mrglu.res output.csv &> stdout.txt
+rm -f output.csv
+$PROGRAM  --debug -f=CSV-INT -hdr=n mrglu.res output.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -154,8 +150,7 @@ iftisval output.csv weighting
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM output.csv &> stdout.txt
+$PROGRAM output.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftisval stdout.txt format "CSV-INT"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -168,8 +163,8 @@ printf " Test case: Option to save headers. \n"
 printf " Expected result 1: Test print shows correct option setting. \n"
 printf " Expected result 2: Output file has headers. \n\n"
 
-rm -f stdout.txt output.csv
-$PROGRAM  --debug -f=CSV-INT -hdr=y mrglu.res output.csv &> stdout.txt
+rm -f output.csv
+$PROGRAM  --debug -f=CSV-INT -hdr=y mrglu.res output.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt save_header "1"
@@ -188,8 +183,7 @@ printf "\n 0.9.0 \n"
 printf " Test case: Input file not given. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -f=CSV-UK &> stdout.txt
+$PROGRAM -f=CSV-UK 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -197,16 +191,14 @@ printf "\n 0.9.1 \n"
 printf " Test case: Input file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.res &> stdout.txt
+$PROGRAM nonexistingfile.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "cannot open file (nonexistingfile.res)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -f=CSV-UK nonexistingfile.res &> stdout.txt
+$PROGRAM -f=CSV-UK nonexistingfile.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "cannot open file (nonexistingfile.res)"
@@ -224,8 +216,7 @@ printf " Test case: CSV-INT to CSV-UK with headers\n"
 printf " Expected result 1: parmatch reports matching data. \n"
 printf " Expected result 2: formats are correctly identified. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu_csvint.csv &> stdout.txt
+$PROGRAM mrglu_csvint.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "CSV-INT"
@@ -237,8 +228,7 @@ $PROGRAM -f=CSV-UK -hdr=y mrglu_csvint.csv output.csv
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM output.csv &> stdout.txt
+$PROGRAM output.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "CSV-UK"
@@ -263,8 +253,7 @@ $PROGRAM -f=CSV-UK -hdr=n mrglu_csvint.csv output.csv
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM output.csv &> stdout.txt
+$PROGRAM output.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "CSV-UK"
@@ -285,8 +274,7 @@ printf " Test case: CSV-INT to TSV-UK with headers\n"
 printf " Expected result 1: parmatch reports matching data. \n"
 printf " Expected result 2: formats are correctly identified. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu_csvint.csv &> stdout.txt
+$PROGRAM mrglu_csvint.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "CSV-INT"
@@ -298,8 +286,7 @@ $PROGRAM -f=TSV-UK -hdr=y mrglu_csvint.csv output.csv
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM output.csv &> stdout.txt
+$PROGRAM output.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "TSV-UK"
@@ -324,8 +311,7 @@ $PROGRAM -f=TSV-UK -hdr=n mrglu_csvint.csv output.csv
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM output.csv &> stdout.txt
+$PROGRAM output.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "TSV-UK"
@@ -347,8 +333,7 @@ printf " Test case: CSV-UK to TSV-INT with headers\n"
 printf " Expected result 1: parmatch reports matching data. \n"
 printf " Expected result 2: formats are correctly identified. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu_csvuk.csv &> stdout.txt
+$PROGRAM mrglu_csvuk.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "CSV-UK"
@@ -360,8 +345,7 @@ $PROGRAM -f=TSV-INT -hdr=y mrglu_csvuk.csv output.csv
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM output.csv &> stdout.txt
+$PROGRAM output.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "TSV-INT"
@@ -386,8 +370,7 @@ $PROGRAM -f=TSV-INT -hdr=n mrglu_csvuk.csv output.csv
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM output.csv &> stdout.txt
+$PROGRAM output.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "TSV-INT"
@@ -457,8 +440,7 @@ printf " Test case 2: Back to RES format\n"
 printf " Expected result 1: parmatch reports matching data. \n"
 printf " Expected result 2: formats are correctly identified. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res &> stdout.txt
+$PROGRAM mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "RES"
@@ -470,8 +452,7 @@ $PROGRAM -f=CSV-UK -hdr=y mrglu.res output.csv
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM output.csv &> stdout.txt
+$PROGRAM output.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "CSV-UK"
@@ -493,8 +474,7 @@ $PROGRAM -f=RES output.csv output.res
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM output.res &> stdout.txt
+$PROGRAM output.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "RES"
@@ -517,8 +497,7 @@ printf " Test case 2: Back to FIT format\n"
 printf " Expected result 1: parmatch reports matching data. \n"
 printf " Expected result 2: formats are correctly identified. \n\n"
 
-rm -f stdout.txt
-$PROGRAM old.fit &> stdout.txt
+$PROGRAM old.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "FIT"
@@ -530,8 +509,7 @@ $PROGRAM -f=CSV-UK -hdr=y old.fit output.csv
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM output.csv &> stdout.txt
+$PROGRAM output.csv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "CSV-UK"
@@ -547,8 +525,7 @@ $PROGRAM -f=FIT output.csv output.fit
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f stdout.txt
-$PROGRAM output.fit &> stdout.txt
+$PROGRAM output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format "FIT"
