@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_resmatch
-#: Date       : 2014-10-17
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -12,6 +12,11 @@ EXT=;
 fi
 
 PROGRAM=../../resmatch$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -20,11 +25,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f mrglu.res ] || [ ! -f mrglu_ht.res ] || [ ! -f mrgluesd.res ]; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -58,8 +58,7 @@ printf "\n 0.1.0 \n"
 printf " Test case: Invalid option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -stupidoption mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -71,8 +70,7 @@ printf "\n 0.2.0 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res mrglu.res extra &> stdout.txt
+$PROGRAM mrglu.res mrglu.res extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -84,24 +82,21 @@ printf "\n 0.3.0 \n"
 printf " Test case: Option -header. \n"
 printf " Expected result: Test print shows correct option setting. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM  --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt header "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -header=y --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -header=y --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt header "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -header=n --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -header=n --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt header "0"
@@ -113,24 +108,21 @@ printf "\n 0.4.0 \n"
 printf " Test case: Option -param. \n"
 printf " Expected result: Test print shows correct option setting. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM  --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parameters "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -param=y --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -param=y --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parameters "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -param=n --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -param=n --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parameters "0"
@@ -143,24 +135,21 @@ printf "\n 0.5.0 \n"
 printf " Test case: Option -regions. \n"
 printf " Expected result: Test print shows correct option setting. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM  --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt regions "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -regions=y --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -regions=y --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt regions "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -regions=n --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -regions=n --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt regions "0"
@@ -173,56 +162,49 @@ printf "\n 0.6.0 \n"
 printf " Test case: Option -res. \n"
 printf " Expected result: Test print shows correct option setting. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM  --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt results ""
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -res=0 --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -res=0 --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt results "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -res=2 --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -res=2 --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt results "2"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -res=10 --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -res=10 --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "results do not contain required column 10"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -res=1-2 --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -res=1-2 --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt results "1 2"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -res=1,2 --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -res=1,2 --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt results "1 2"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -res --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -res --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -232,24 +214,21 @@ printf "\n 0.7.0 \n"
 printf " Test case: Options -roughly and -around. \n"
 printf " Expected result: Test print shows correct option setting. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM  --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt rough_test "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -roughly --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -roughly --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt rough_test "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -around --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -around --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt rough_test "2"
@@ -257,13 +236,11 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
-rm -f stdout.txt
-$PROGRAM -roughly -abs=1 --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -roughly -abs=1 --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -abs=1 -roughly --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -abs=1 -roughly --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -273,37 +250,32 @@ printf "\n 0.7.1 \n"
 printf " Test case: Options -abs. \n"
 printf " Expected result: Test print shows correct option setting. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM  --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt test_abs "-1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -abs=1 --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -abs=1 --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt test_abs "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -abs=0 --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -abs=0 --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt test_abs "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -abs=-0.05 --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -abs=-0.05 --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -abs --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -abs --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -312,29 +284,25 @@ printf "\n 0.8.0 \n"
 printf " Test case: Options -errors. \n"
 printf " Expected result: Test print shows correct option setting. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -errors --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -errors --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM  --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt test_errors "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -errors=y --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -errors=y --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt test_errors "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -errors=n --debug mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -errors=n --debug mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt test_errors "0"
@@ -346,8 +314,7 @@ printf "\n 0.9.0 \n"
 printf " Test case: Input files not given. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  mrglu.res &> stdout.txt
+$PROGRAM  mrglu.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -355,16 +322,14 @@ printf "\n 0.9.1 \n"
 printf " Test case: Input file does not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.res mrglu.res &> stdout.txt
+$PROGRAM nonexistingfile.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexistingfile.res'" "cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res nonexistingfile.res &> stdout.txt
+$PROGRAM mrglu.res nonexistingfile.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexistingfile.res'" "cannot open file"
@@ -376,56 +341,49 @@ printf "\n 1.0.0 \n"
 printf " Test case: Testing file against itself. \n"
 printf " Expected result: Match must be found, with any option. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res mrglu.res &> stdout.txt
+$PROGRAM mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -header=y -parameters=y -regions=y mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -header=y -parameters=y -regions=y mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -results=1,4 mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -results=1,4 mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -results=1-4 mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -results=1-4 mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -roughly mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -roughly mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -around mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -around mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -abs=0 mrglu.res mrglu.res &> stdout.txt
+$PROGRAM -abs=0 mrglu.res mrglu.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
@@ -437,8 +395,7 @@ printf "\n 1.1.0 \n"
 printf " Test case: Different nr of parameters. \n"
 printf " Expected result: Match is found with option -res=1. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -results=1 mrglu.res mrglue3.res &> stdout.txt
+$PROGRAM -results=1 mrglu.res mrglue3.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
@@ -449,8 +406,7 @@ printf "\n 1.1.1 \n"
 printf " Test case: Different nr of parameters. \n"
 printf " Expected result: No match is found without option -res=1. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res mrglue3.res &> stdout.txt
+$PROGRAM mrglu.res mrglue3.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match"
@@ -463,16 +419,14 @@ printf "\n 1.2.0 \n"
 printf " Test case: No match in header. \n"
 printf " Expected result: Match or No match, depending on whether header is tested. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -header=n mrglu.res mrglueh.res &> stdout.txt
+$PROGRAM -header=n mrglu.res mrglueh.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -header=y mrglu.res mrglueh.res &> stdout.txt
+$PROGRAM -header=y mrglu.res mrglueh.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in header field (17)"
@@ -486,16 +440,14 @@ printf "\n 1.3.0 \n"
 printf " Test case: No match in parameter names. \n"
 printf " Expected result: Match or No match, depending on whether tested or not. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -parameters=n mrglu.res mrgluep.res &> stdout.txt
+$PROGRAM -parameters=n mrglu.res mrgluep.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -parameters=y mrglu.res mrgluep.res &> stdout.txt
+$PROGRAM -parameters=y mrglu.res mrgluep.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter names"
@@ -508,16 +460,14 @@ printf "\n 1.4.0 \n"
 printf " Test case: No match in region names. \n"
 printf " Expected result: Match or No match, depending on whether tested or not. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -regions=n mrglu.res mrgluer.res &> stdout.txt
+$PROGRAM -regions=n mrglu.res mrgluer.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -regions=y mrglu.res mrgluer.res &> stdout.txt
+$PROGRAM -regions=y mrglu.res mrgluer.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in regions"
@@ -530,32 +480,28 @@ printf "\n 1.5.0 \n"
 printf " Test case: No match in column 1. \n"
 printf " Expected result: No match, unless that col is not tested. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res mrglue1.res &> stdout.txt
+$PROGRAM mrglu.res mrglue1.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 1)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -results=1 mrglu.res mrglue1.res &> stdout.txt
+$PROGRAM -results=1 mrglu.res mrglue1.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 1)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -results=2 mrglu.res mrglue1.res &> stdout.txt
+$PROGRAM -results=2 mrglu.res mrglue1.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -results=1-2 mrglu.res mrglue1.res &> stdout.txt
+$PROGRAM -results=1-2 mrglu.res mrglue1.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 1)"
@@ -568,32 +514,28 @@ printf "\n 1.5.1 \n"
 printf " Test case: No match in column 2. \n"
 printf " Expected result: No match, unless that col is not tested. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res mrglue2.res &> stdout.txt
+$PROGRAM mrglu.res mrglue2.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 2)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -results=2 mrglu.res mrglue2.res &> stdout.txt
+$PROGRAM -results=2 mrglu.res mrglue2.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 2)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -results=1 mrglu.res mrglue2.res &> stdout.txt
+$PROGRAM -results=1 mrglu.res mrglue2.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -results=1,2 mrglu.res mrglue2.res &> stdout.txt
+$PROGRAM -results=1,2 mrglu.res mrglue2.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 2)"
@@ -607,24 +549,21 @@ printf "\n 1.5.2 \n"
 printf " Test case: No match in SD in column 2. \n"
 printf " Expected result: No match, unless that col or SD is not tested. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res mrgluesd.res &> stdout.txt
+$PROGRAM mrglu.res mrgluesd.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 2)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -errors=n mrglu.res mrgluesd.res &> stdout.txt
+$PROGRAM -errors=n mrglu.res mrgluesd.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -res=1 mrglu.res mrgluesd.res &> stdout.txt
+$PROGRAM -res=1 mrglu.res mrgluesd.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
@@ -636,24 +575,21 @@ printf "\n 1.5.3 \n"
 printf " Test case: No match in CL1 in column 2. \n"
 printf " Expected result: No match, unless that col or CL1 is not tested. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res mrgluecl1.res &> stdout.txt
+$PROGRAM mrglu.res mrgluecl1.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 2)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -errors=n mrglu.res mrgluecl1.res &> stdout.txt
+$PROGRAM -errors=n mrglu.res mrgluecl1.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -res=1,3 mrglu.res mrgluecl1.res &> stdout.txt
+$PROGRAM -res=1,3 mrglu.res mrgluecl1.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
@@ -665,24 +601,21 @@ printf "\n 1.5.4 \n"
 printf " Test case: No match in CL2 in column 3. \n"
 printf " Expected result: No match, unless that col or CL2 is not tested. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res mrgluecl2.res &> stdout.txt
+$PROGRAM mrglu.res mrgluecl2.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 3)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -errors=n mrglu.res mrgluecl2.res &> stdout.txt
+$PROGRAM -errors=n mrglu.res mrgluecl2.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -res=1-2 mrglu.res mrgluecl2.res &> stdout.txt
+$PROGRAM -res=1-2 mrglu.res mrgluecl2.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
@@ -700,8 +633,7 @@ printf "\n 2.0.0 \n"
 printf " Test case: difference larger than 0.011. \n"
 printf " Expected result: No match, when limit not given. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res mrglu_ht.res &> stdout.txt
+$PROGRAM mrglu.res mrglu_ht.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 1)"
@@ -712,8 +644,7 @@ printf "\n 2.0.1 \n"
 printf " Test case: difference larger than 0.011. \n"
 printf " Expected result: Still no match with option -roughly. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -roughly mrglu.res mrglu_ht.res &> stdout.txt
+$PROGRAM -roughly mrglu.res mrglu_ht.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 1)"
@@ -724,8 +655,7 @@ printf "\n 2.0.2 \n"
 printf " Test case: difference larger than 0.011. \n"
 printf " Expected result: Match with option -around. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -around mrglu.res mrglu_ht.res &> stdout.txt
+$PROGRAM -around mrglu.res mrglu_ht.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
@@ -739,8 +669,7 @@ printf "\n 2.1.0 \n"
 printf " Test case: difference smaller than 0.01. \n"
 printf " Expected result: No match, when limit not given. \n\n"
 
-rm -f stdout.txt
-$PROGRAM mrglu.res mrglu_lt.res &> stdout.txt
+$PROGRAM mrglu.res mrglu_lt.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 1)"
@@ -752,8 +681,7 @@ printf "\n 2.1.1 \n"
 printf " Test case: difference smaller than 0.01. \n"
 printf " Expected result: Match with option -roughly. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -roughly mrglu.res mrglu_lt.res &> stdout.txt
+$PROGRAM -roughly mrglu.res mrglu_lt.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
@@ -768,8 +696,7 @@ printf "\n 2.2.0 \n"
 printf " Test case: difference larger than 0.05. \n"
 printf " Expected result: No match with option around. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -around mrglu.res mrglu_hta.res &> stdout.txt
+$PROGRAM -around mrglu.res mrglu_hta.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 1)"
@@ -781,8 +708,7 @@ printf "\n 2.2.1 \n"
 printf " Test case: difference smaller than 0.05. \n"
 printf " Expected result: Match with option -around. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -around mrglu.res mrglu_lta.res &> stdout.txt
+$PROGRAM -around mrglu.res mrglu_lta.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
@@ -798,8 +724,7 @@ printf "\n 3.0.0 \n"
 printf " Test case: absolute difference higher than limit given with -abs. \n"
 printf " Expected result: No match. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -abs=1.5 mrglu.res mrglu_lt.res &> stdout.txt
+$PROGRAM -abs=1.5 mrglu.res mrglu_lt.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 1)"
@@ -811,8 +736,7 @@ printf "\n 3.0.1 \n"
 printf " Test case: absolute difference lower than limit given with -abs. \n"
 printf " Expected result: Match. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -abs=2,0 mrglu.res mrglu_lt.res &> stdout.txt
+$PROGRAM -abs=2,0 mrglu.res mrglu_lt.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
@@ -825,8 +749,7 @@ printf " Test case 1: absolute difference in SD higher than limit given with -ab
 printf " Test case 2: errors are also tested. \n"
 printf " Expected result: No match. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -errors=y -abs=0 mrglu.res mrgluesd.res &> stdout.txt
+$PROGRAM -errors=y -abs=0 mrglu.res mrgluesd.res 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "no match in parameter values (column 2)"
@@ -838,8 +761,7 @@ printf " Test case 1: absolute difference in SD higher than limit given with -ab
 printf " Test case 2: errors are not tested. \n"
 printf " Expected result: Match. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -errors=n -abs=0 mrglu.res mrgluesd.res &> stdout.txt
+$PROGRAM -errors=n -abs=0 mrglu.res mrgluesd.res 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt result "match was found"
