@@ -194,7 +194,7 @@ int main(int argc, char **argv)
     if(tac.isframe) printf("frames := yes\n"); else printf("frames := no\n");
     fflush(stdout);
   }
-  if(verbose>0) {
+  if(verbose>2) {
     printf("contains_weights := ");
     if(tacIsWeighted(&tac)) printf("yes\n"); else printf("no\n");
     fflush(stdout);
@@ -207,7 +207,8 @@ int main(int argc, char **argv)
   if(print_weights!=0) {
     if(verbose>2) printf("printing existing weights\n");
     if(!tacIsWeighted(&tac)) {
-      printf("%s does not contain weights.\n", tacfile);
+      printf("contains_weights := no\n");
+      //printf("%s does not contain weights.\n", tacfile);
       tacFree(&tac); return(100);
     } else if(tac.isframe) {
       printf("start[]\tend[]\tweight\n");
