@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_tacweigh
-#: Date       : 2022-03-29
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -230,7 +230,7 @@ cp -f weigh1.dft temp2.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 rm -f output.sif
 
-$PROGRAM -moderate=0 temp2.dft &> stdout.txt
+$PROGRAM -moderate=0 temp2.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "valid isotope not specified."
@@ -266,7 +266,7 @@ printf "# isotope := C-11\n" >> temp2.dft
 rm -f output.sif
 
 # now isotope is in data file thus no problem that its not given as option
-$PROGRAM -moderate=0 -sif=output.sif temp2.dft &> stdout.txt
+$PROGRAM -moderate=0 -sif=output.sif temp2.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 taclist -ift -weights -na -nv temp2.dft head > output.ift
@@ -293,7 +293,7 @@ cp -f weigh1.dft temp2.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
 # now isotope is NOT in data file
-$PROGRAM -moderate=0 -sif=output.sif temp2.dft &> stdout.txt
+$PROGRAM -moderate=0 -sif=output.sif temp2.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "valid isotope not specified."
@@ -447,7 +447,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 rm -f output.ift
 
-$PROGRAM -wfd -moderate=0 temp.tac &> stdout.txt
+$PROGRAM -wfd -moderate=0 temp.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "valid isotope not specified."
@@ -504,7 +504,7 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacunit -xset=unknown --silent temp.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -wf temp.tac &> stdout.txt
+$PROGRAM -wf temp.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "unknown time unit."
@@ -525,15 +525,15 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 tacunit -yset=unknown --silent temp.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM -wf temp.tac &> stdout.txt
+$PROGRAM -wf temp.tac 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-$PROGRAM -wfd -i=C-11 temp.tac &> stdout.txt
+$PROGRAM -wfd -i=C-11 temp.tac 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-$PROGRAM -wfd -i=C-11 -sif=output.sif temp.tac &> stdout.txt
+$PROGRAM -wfd -i=C-11 -sif=output.sif temp.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "unknown calibration unit."
