@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_sim_3tcm
-#: Date       : 2021-02-09
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -15,6 +15,10 @@ else
 EXT=;
 fi
 PROGRAM=../../sim_3tcm$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -23,10 +27,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
 
 if [ ! -f stead100.dat ]; then
   printf "Failed: required data does not exist.\n"
@@ -117,7 +117,7 @@ rm -f stdout.txt output.par
 $PROGRAM output.par
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-parformat output.par &> stdout.txt
+parformat output.par 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format TSV-UK
@@ -135,7 +135,7 @@ rm -f stdout.txt output.par
 $PROGRAM --verbose -parallel output.par
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-parformat output.par &> stdout.txt
+parformat output.par 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt format TSV-UK
@@ -929,8 +929,7 @@ printf "\n 4.0.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption test.par bolus.dat bolus.dat tissue.dat &> stdout.txt
+$PROGRAM -stupidoption test.par bolus.dat bolus.dat tissue.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -942,8 +941,7 @@ printf "\n 4.0.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM test.par bolus.dat bolus.dat tissue.dat extra &> stdout.txt
+$PROGRAM test.par bolus.dat bolus.dat tissue.dat extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -955,8 +953,7 @@ printf "\n 4.0.2 \n"
 printf " Test case: Missing argument(s). \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM bolus.dat tissue.dat &> stdout.txt
+$PROGRAM bolus.dat tissue.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftisval stdout.txt Error "missing filename."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -973,24 +970,24 @@ printf "\n 4.1.0 \n"
 printf " Test case: Non-existing input file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM nonexisting.par bolus.dat bolus.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM nonexisting.par bolus.dat bolus.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "cannot open file (nonexisting.par)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM test.par nonexisting.dat bolus.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM test.par nonexisting.dat bolus.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "cannot open file (input files)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM test.par bolus.dat nonexisting.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM test.par bolus.dat nonexisting.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "cannot open file (input files)"
@@ -1005,24 +1002,24 @@ printf " Expected result: Error. \n\n"
 
 printf "abc defg\nbubudum\nmeh\n" > bad.dat
 
-rm -f stdout.txt output.dat
-$PROGRAM bad.dat bolus.dat bolus.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bad.dat bolus.dat bolus.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "unsupported file type (bad.dat)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM test.par bad.dat bolus.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM test.par bad.dat bolus.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "invalid file format (input files)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM test.par bolus.dat bad.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM test.par bolus.dat bad.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "invalid file format (input files)"
@@ -1034,16 +1031,16 @@ printf "\n 4.1.2 \n"
 printf " Test case: Input TAC file contains more than one TAC. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM --verbose test.par multi.dat bolus.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM --verbose test.par multi.dat bolus.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning" "using only first TAC in multi.dat"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM --verbose test.par bolus.dat multi.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM --verbose test.par bolus.dat multi.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Warning" "using only first TAC in multi.dat"
@@ -1055,24 +1052,24 @@ printf "\n 4.1.3 \n"
 printf " Test case: Input TAC file contains less than 3 samples. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM test.par bolus_toofew.dat bolus.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM test.par bolus_toofew.dat bolus.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "file contains too few samples (input files)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM test.par bolus.dat bolus_toofew.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM test.par bolus.dat bolus_toofew.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "file contains too few samples (input files)"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM test.par bolus_toofew.dat bolus_toofew.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM test.par bolus_toofew.dat bolus_toofew.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "file contains too few samples (input files)"
@@ -1085,18 +1082,18 @@ printf "\n 4.1.4 \n"
 printf " Test case: Input TAC file samples are not in ascending order. \n"
 printf " Expected result: No error (data is sorted). \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM test.par bolus_wrongorder.dat bolus_short.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM test.par bolus_wrongorder.dat bolus_short.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt output.dat
-$PROGRAM test.par bolus_short.dat bolus_wrongorder.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM test.par bolus_short.dat bolus_wrongorder.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt output.dat
-$PROGRAM test.par bolus_wrongorder.dat bolus_wrongorder.dat output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM test.par bolus_wrongorder.dat bolus_wrongorder.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -1121,8 +1118,8 @@ printf "tac1	1.2	1.8	0.1\n" >> test1.par
 cp -f bolus_short.dat test_min.dat
 tacunit -xconv=min test_min.dat
 
-rm -f stdout.txt output1.dat output.ift
-$PROGRAM --verbose -sub test1.par test_min.dat test_min.dat output1.dat &> stdout.txt
+rm -f output1.dat output.ift
+$PROGRAM --verbose -sub test1.par test_min.dat test_min.dat output1.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tac2svg -legend=y t500.svg test_min.dat output1.dat
@@ -1149,8 +1146,8 @@ printf "tac1	0.02	0.03	10\n" >> test2.par
 cp -f bolus_short.dat test_sec.dat
 tacunit -xconv=sec test_sec.dat
 
-rm -f stdout.txt output2.dat output.ift
-$PROGRAM --verbose -sub test2.par test_sec.dat test_sec.dat output2.dat &> stdout.txt
+rm -f output2.dat output.ift
+$PROGRAM --verbose -sub test2.par test_sec.dat test_sec.dat output2.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tac2svg -legend=y t501.svg test_sec.dat output2.dat
@@ -1172,8 +1169,8 @@ printf " Test case 2: Vb as percentage. \n"
 printf " Expected result 1: Correct output units. \n"
 printf " Expected result 2: Same output TACs as in simulation with default units. \n\n"
 
-rm -f stdout.txt output3.dat output.ift
-$PROGRAM --verbose -sub test2.par test_min.dat test_min.dat output3.dat &> stdout.txt
+rm -f output3.dat output.ift
+$PROGRAM --verbose -sub test2.par test_min.dat test_min.dat output3.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tac2svg -legend=y t502.svg test_min.dat output3.dat
@@ -1194,8 +1191,8 @@ printf " Test case 1: Input TAC file time unit is sec, parameters per min. \n"
 printf " Expected result 1: Correct output units. \n"
 printf " Expected result 2: Same output TACs as in simulation with default units. \n\n"
 
-rm -f stdout.txt output4.dat output.ift
-$PROGRAM --verbose -sub test1.par test_sec.dat test_sec.dat output4.dat &> stdout.txt
+rm -f output4.dat output.ift
+$PROGRAM --verbose -sub test1.par test_sec.dat test_sec.dat output4.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tac2svg -legend=y t503.svg test_sec.dat output4.dat
