@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_simframe
-#: Date       : 2023-03-19
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -70,8 +70,7 @@ printf "=====================================================================\n"
 
 printf "\n1.1.0 Unknown option\n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption t01.dat frames.dat output.dat &> stdout.txt
+$PROGRAM -stupidoption t01.dat frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -82,8 +81,7 @@ printf "\n===================================================================\n"
 
 printf "\n1.2.0 Extra argument\n\n"
 
-rm -f stdout.txt
-$PROGRAM t01.dat frames.dat output.dat C-11 extra &> stdout.txt
+$PROGRAM t01.dat frames.dat output.dat C-11 extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -94,16 +92,14 @@ printf "\n===================================================================\n"
 
 printf "\n1.3.0 Option -mid\n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 t01.dat frames.dat output.dat &> stdout.txt
+$PROGRAM -d2 t01.dat frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt midFrame 0
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -mid t01.dat frames.dat output.dat &> stdout.txt
+$PROGRAM -d2 -mid t01.dat frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt midFrame 1
@@ -114,24 +110,21 @@ printf "\n===================================================================\n"
 
 printf "\n1.3.1 Option -min and -sec\n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 t01.dat frames.dat output.dat &> stdout.txt
+$PROGRAM -d2 t01.dat frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt knownTimeunit
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -min t01.dat frames.dat output.dat &> stdout.txt
+$PROGRAM -d2 -min t01.dat frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt knownTimeunit min
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -sec t01.dat frames.dat output.dat &> stdout.txt
+$PROGRAM -d2 -sec t01.dat frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt knownTimeunit sec
@@ -142,40 +135,35 @@ printf "\n===================================================================\n"
 
 printf "\n1.3.2 Option -i and -ii\n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 t01.dat frames.dat output.dat &> stdout.txt
+$PROGRAM -d2 t01.dat frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt mode 0
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -i t01.dat frames.dat output.dat &> stdout.txt
+$PROGRAM -d2 -i t01.dat frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt mode 1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -ii t01.dat frames.dat output.dat &> stdout.txt
+$PROGRAM -d2 -ii t01.dat frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt mode 2
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -i t01.dat frames.dat output.dat C-11 &> stdout.txt
+$PROGRAM -d2 -i t01.dat frames.dat output.dat C-11 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error  "decay option cannot be used with integrals."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -ii t01.dat frames.dat output.dat C-11 &> stdout.txt
+$PROGRAM -d2 -ii t01.dat frames.dat output.dat C-11 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error  "decay option cannot be used with integrals."
@@ -187,8 +175,7 @@ printf "\n===================================================================\n"
 
 printf "\n2.1.1 Input filename not given\n\n"
 
-rm -f stdout.txt
-$PROGRAM -d  frames.dat output.dat &> stdout.txt
+$PROGRAM -d  frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing file name; use option --help"
@@ -197,8 +184,7 @@ printf "\n passed. \n"
 
 printf "\n2.1.2 Nonexisting input file\n\n"
 
-rm -f stdout.txt
-$PROGRAM nonexistingfile.dat frames.dat output.dat &> stdout.txt
+$PROGRAM nonexistingfile.dat frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "cannot open file (nonexistingfile.dat)"
@@ -207,8 +193,7 @@ printf "\n passed. \n"
 
 printf "\n2.1.3 Wrong file format\n\n"
 
-rm -f stdout.txt
-$PROGRAM $PROGRAM frames.dat output.dat &> stdout.txt
+$PROGRAM $PROGRAM frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
@@ -219,8 +204,7 @@ printf "\n===================================================================\n"
 
 printf "\n3.1.1 Frame filename not given\n\n"
 
-rm -f stdout.txt
-$PROGRAM -d t01.dat  output.dat &> stdout.txt
+$PROGRAM -d t01.dat  output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing file name; use option --help"
@@ -229,8 +213,7 @@ printf "\n passed. \n"
 
 printf "\n3.1.2 Nonexisting frame file\n\n"
 
-rm -f stdout.txt
-$PROGRAM t01.dat nonexistingfile.dat output.dat &> stdout.txt
+$PROGRAM t01.dat nonexistingfile.dat output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "cannot open nonexistingfile.dat"
@@ -239,8 +222,7 @@ printf "\n passed. \n"
 
 printf "\n3.1.3 Wrong file format\n\n"
 
-rm -f stdout.txt
-$PROGRAM t01.dat $PROGRAM output.dat &> stdout.txt
+$PROGRAM t01.dat $PROGRAM output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error"
@@ -251,8 +233,7 @@ printf "\n===================================================================\n"
 
 printf "\n4.1.1 Output filename not given\n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 t01.dat frames.dat &> stdout.txt
+$PROGRAM -d2 t01.dat frames.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "missing file name; use option --help"
@@ -263,8 +244,7 @@ printf "\n===================================================================\n"
 
 printf "\n5.1.1 Isotope code: not given\n\n"
 
-rm -f stdout.txt
-$PROGRAM -d t01.dat frames.dat output.dat &> stdout.txt
+$PROGRAM -d t01.dat frames.dat output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope"
@@ -273,8 +253,7 @@ printf "\n passed. \n"
 
 printf "\n5.1.2 Isotope code: invalid\n\n"
 
-rm -f stdout.txt
-$PROGRAM t01.dat frames.dat output.dat C-12 &> stdout.txt
+$PROGRAM t01.dat frames.dat output.dat C-12 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "invalid isotope argument 'C-12'."
@@ -283,24 +262,21 @@ printf "\n passed. \n"
 
 printf "\n5.2.1 Isotope code: C-11 or c-11 or 11C \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 t01.dat frames.dat output.dat C-11 &> stdout.txt
+$PROGRAM -d2 t01.dat frames.dat output.dat C-11 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 t01.dat frames.dat output.dat c-11 &> stdout.txt
+$PROGRAM -d2 t01.dat frames.dat output.dat c-11 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 t01.dat frames.dat output.dat 11C &> stdout.txt
+$PROGRAM -d2 t01.dat frames.dat output.dat 11C 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "C-11"
@@ -309,24 +285,21 @@ printf "\n passed. \n"
 
 printf "\n5.3.1 Isotope code: F-18 or f-18 or 18F \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 t01.dat frames.dat output.dat F-18 &> stdout.txt
+$PROGRAM -d2 t01.dat frames.dat output.dat F-18 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "F-18"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 t01.dat frames.dat output.dat f-18 &> stdout.txt
+$PROGRAM -d2 t01.dat frames.dat output.dat f-18 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "F-18"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-rm -f stdout.txt
-$PROGRAM -d2 t01.dat frames.dat output.dat 18F &> stdout.txt
+$PROGRAM -d2 t01.dat frames.dat output.dat 18F 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "F-18"
@@ -335,8 +308,7 @@ printf "\n passed. \n"
 
 printf "\n5.4.1 Isotope code: O-15 \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d t01.dat frames.dat output.dat O-15 &> stdout.txt
+$PROGRAM -d t01.dat frames.dat output.dat O-15 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "isotope" "O-15"
@@ -436,11 +408,11 @@ printf "\n passed. \n"
 
 printf "\n but proper TAC file without frame start and end times must not work \n\n"
 
-rm -f output2.tac stdout.txt
+rm -f output2.tac
 tacformat -mid -f=PMOD output.tac temp.bld
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM t01.dat temp.bld output2.tac &> stdout.txt
+$PROGRAM t01.dat temp.bld output2.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "no frame start and end times in temp.bld"
@@ -564,7 +536,7 @@ printf "\n===================================================================\n"
 
 printf "\n7.2.1 Short extrapolation is ok without isotope, but not with isotope \n\n"
 
-rm -f test.dat output.dat output2.dat stdout.txt
+rm -f test.dat output.dat output2.dat
 interpol -c=0,92,0.05 t21.dat test.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
@@ -573,7 +545,7 @@ $PROGRAM test.dat frames7b.dat output.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-$PROGRAM test.dat frames7b.dat output.dat C-11 &> stdout.txt
+$PROGRAM test.dat frames7b.dat output.dat C-11 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "required extrapolation is too risky."
@@ -585,16 +557,16 @@ printf "\n===================================================================\n"
 
 printf "\n7.2.2 Too much extrapolation is never ok \n\n"
 
-rm -f output2.dat stdout.txt
+rm -f output2.dat
 
-$PROGRAM test.dat frames7c.dat output2.dat &> stdout.txt
+$PROGRAM test.dat frames7c.dat output2.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "required extrapolation is too risky."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n"
 
-$PROGRAM test.dat frames7c.dat output2.dat C-11 &> stdout.txt
+$PROGRAM test.dat frames7c.dat output2.dat C-11 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "required extrapolation is too risky."
