@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_var4tac
-#: Date       : 2022-03-29
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,7 +11,6 @@ else
 EXT=;
 fi
 PROGRAM=../../var4tac$EXT;
-
 if [ ! -f $PROGRAM ]; then
   printf "Failed: executable does not exist.\n"
   exit 1
@@ -250,8 +249,7 @@ printf "\n 3.0.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption renal.tac 10 output.tac &> stdout.txt
+$PROGRAM -stupidoption renal.tac 10 output.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -263,8 +261,7 @@ printf "\n 3.0.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM renal.tac 10 output.tac extra &> stdout.txt
+$PROGRAM renal.tac 10 output.tac extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -276,8 +273,7 @@ printf "\n 3.0.2 \n"
 printf " Test case: Missing argument(s). \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM renal.tac 10  &> stdout.txt
+$PROGRAM renal.tac 10  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 iftisval stdout.txt Error
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -288,16 +284,14 @@ printf "\n 3.1.0 \n"
 printf " Test case: Invalid CV. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM renal.tac -1 output.tac &> stdout.txt
+$PROGRAM renal.tac -1 output.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid CV% '-1'."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM renal.tac CV output.tac &> stdout.txt
+$PROGRAM renal.tac CV output.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid CV% 'CV'."
@@ -308,8 +302,7 @@ printf "\n 3.1.1 \n"
 printf " Test case: Small CV. \n"
 printf " Expected result: Warning. \n\n"
 
-rm -f stdout.txt
-$PROGRAM renal.tac 0.1 output.tac &> stdout.txt
+$PROGRAM renal.tac 0.1 output.tac 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning 
@@ -322,9 +315,9 @@ printf " Test case: CV set to zero. \n"
 printf " Expected result 1: Warning. \n"
 printf " Expected result 2: Results saved without noise. \n\n"
 
-rm -f output.tac stdout.txt
+rm -f output.tac
 
-$PROGRAM renal.tac 0 output.tac &> stdout.txt
+$PROGRAM renal.tac 0 output.tac 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -342,8 +335,7 @@ printf "\n 3.2.0 \n"
 printf " Test case: Invalid minsd. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -minsd=999999 renal.tac 10 output.tac &> stdout.txt
+$PROGRAM -minsd=999999 renal.tac 10 output.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid minimum SD percentage '-minsd=999999'."
@@ -356,8 +348,8 @@ printf "\n 3.3.0 \n"
 printf " Test case: Non-existing input file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.tac
-$PROGRAM nonexisting.tac 10 output.tac &> stdout.txt
+rm -f output.tac
+$PROGRAM nonexisting.tac 10 output.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "cannot open file (nonexisting.tac)"
