@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_b2t_h2o
-#: Date       : 2014-08-05
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,16 +11,17 @@ else
 EXT=;
 fi
 PROGRAM=../../b2t_h2o$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "\nError: application file missing.\n\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
 printf "=====================================================================\n"
 
 # Check that required files exist
-if [ ! -f $PROGRAM ]; then
-  printf "\nError: application file missing.\n\n"
-  exit 1
-fi
 if [ ! -f b2t_h2o_blood.dat ]; then
   printf "\nError: required file missing.\n\n"
   exit 1
@@ -153,7 +154,6 @@ printf "passed.\n\n"
 printf "===============================================================\n\n"
 
 printf "\n0.2.0\n"
-rm -f stdout.txt
 printf "Default and given variables are correct\n"
 $PROGRAM -d2 b2t_h2o_blood.dat 60.0 0.97 1.0 5.0 30.0 output.dat > stdout.txt
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
@@ -193,7 +193,6 @@ if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "passed.\n"
 
 printf "\n0.2.1\n"
-rm -f stdout.txt
 printf "Default and given variables are correct with decimal commas\n"
 $PROGRAM -d2 b2t_h2o_blood.dat 66,6 0,97 0,9 5,1 33,3 output.dat > stdout.txt
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
@@ -218,7 +217,6 @@ printf "passed.\n"
 printf "===============================================================\n\n"
 
 printf "\n0.3.0\n"
-rm -f stdout.txt
 printf "Options -sub and -nosub\n"
 
 $PROGRAM -d2 -sub b2t_h2o_blood.dat 3 0.97 1.0 5 30 output.dat > stdout.txt
@@ -237,7 +235,6 @@ printf "passed.\n"
 
 
 printf "\n0.3.1\n"
-rm -f stdout.txt
 printf "Option -add\n"
 
 $PROGRAM -d2 -add b2t_h2o_blood.dat 3 0.97 1.0 5 30 output.dat > stdout.txt
@@ -249,7 +246,6 @@ printf "passed.\n"
 
 
 printf "\n0.3.2\n"
-rm -f stdout.txt
 printf "Option -voiname\n"
 
 $PROGRAM -d2 -voiname=nasse b2t_h2o_blood.dat 3 0.97 1.0 5 30 output.dat > stdout.txt
@@ -267,7 +263,6 @@ $PROGRAM -d2 -voiname=thisistoolongnameforavoi b2t_h2o_blood.dat 3 0.97 1.0 5 30
 if [ $? -eq 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "passed.\n"
 
-rm -f stdout.txt
 $PROGRAM -d2 -sub -voiname='this_is_long' b2t_h2o_blood.dat 3 0.97 1.0 5 30 output.dat
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "passed.\n"
@@ -276,7 +271,6 @@ iftisval stdout.txt tacname[1] "this_is_long"
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "passed.\n"
 
-rm -f stdout.txt
 $PROGRAM -d2 -sub -voiname=. b2t_h2o_blood.dat 3 0.97 1.0 5 30 output.dat
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "passed.\n"
@@ -288,7 +282,6 @@ printf "passed.\n"
 
 
 printf "\n0.3.3\n"
-rm -f stdout.txt
 printf "Option -fpt\n"
 
 $PROGRAM -d2 -fpt b2t_h2o_blood.dat 3 0.97 1.0 5 30 output.dat > stdout.txt
@@ -300,7 +293,6 @@ printf "passed.\n"
 
 
 printf "\n0.3.4\n"
-rm -f stdout.txt
 printf "Option -vena\n"
 
 $PROGRAM -d2 -vena=vena.dat b2t_h2o_blood.dat 3 0.97 1.0 5 30 output.dat > stdout.txt
@@ -493,20 +485,20 @@ printf "Input data\n\n"
 
 printf "\n3.0.0 \n"
 printf "Too few samples \n"
-rm -f short.dat output.dat stdout.txt
+rm -f output.dat
 echo 0 0 > short.dat
 cat short.dat
-$PROGRAM -sub short.dat 20 0.8 1.0 10 33 output.dat &> stdout.txt
+$PROGRAM -sub short.dat 20 0.8 1.0 10 33 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "passed.\n\n"
 iftisval stdout.txt Error "too few samples in 'short.dat'."
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "passed.\n\n"
 
-rm -f output.dat stdout.txt
+rm -f output.dat
 echo 30 56 >> short.dat
 cat short.dat
-$PROGRAM -sub short.dat 20 0.8 1.0 10 33 output.dat &> stdout.txt
+$PROGRAM -sub short.dat 20 0.8 1.0 10 33 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then echo Failed! ; exit 1 ; fi
 printf "passed.\n\n"
 iftisval stdout.txt Warning "few samples in 'short.dat'."
