@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_heartcor
-#: Date       : 2019-08-26
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -91,8 +91,7 @@ printf "\n 0.1.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption errorfree.dft cav myo 52 10 10 output.dft &> stdout.txt
+$PROGRAM -stupidoption errorfree.dft cav myo 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -103,8 +102,7 @@ printf "\n 0.1.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM errorfree.dft cav myo 52 10 10 output.dft extra &> stdout.txt
+$PROGRAM errorfree.dft cav myo 52 10 10 output.dft extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -116,36 +114,35 @@ printf "\n 0.1.2 \n"
 printf " Test case: Missing argument(s). \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  cav myo 52 10 10 output.dft &> stdout.txt
+$PROGRAM  cav myo 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM errorfree.dft  myo 52 10 10 output.dft &> stdout.txt
+$PROGRAM errorfree.dft  myo 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM errorfree.dft cav  52 10 10 output.dft &> stdout.txt
+$PROGRAM errorfree.dft cav  52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM errorfree.dft cav myo  10 10 output.dft &> stdout.txt
+$PROGRAM errorfree.dft cav myo  10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM errorfree.dft cav myo 52 10  output.dft &> stdout.txt
+$PROGRAM errorfree.dft cav myo 52 10  output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM errorfree.dft cav myo 52 10 10  &> stdout.txt
+$PROGRAM errorfree.dft cav myo 52 10 10  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM 52 10 10 &> stdout.txt
+$PROGRAM 52 10 10 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM  &> stdout.txt
+$PROGRAM  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -159,8 +156,8 @@ printf " Test case: Correct input, no options. \n"
 printf " Expected result 1: Values of variables are correct. \n"
 printf " Expected result 2: Output file is created. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 errorfree.dft cav myo 52 10 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 errorfree.dft cav myo 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -201,16 +198,14 @@ printf "\n 0.2.1 \n"
 printf " Test case: Option -simulate. \n"
 printf " Expected result: Options are correctly identified. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -simulation errorfree.dft cav myo 52 10 10 output.dft &> stdout.txt
+$PROGRAM -d2 -simulation errorfree.dft cav myo 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt simulation "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -d2 -sim errorfree.dft cav myo 52 10 10 output.dft &> stdout.txt
+$PROGRAM -d2 -sim errorfree.dft cav myo 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt simulation "1"
@@ -222,32 +217,32 @@ printf "\n 0.2.2 \n"
 printf " Test case: Option -Vb with valid and nonvalid fraction. \n"
 printf " Expected result: Options are correctly identified. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 -Vb=0.11 errorfree.dft cav myo 52 10 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 -Vb=0.11 errorfree.dft cav myo 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Vb "0.11"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 -Vb=0,11 errorfree.dft cav myo 52 10 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 -Vb=0,11 errorfree.dft cav myo 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Vb "0.11"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 -Vb=0.0 errorfree.dft cav myo 52 10 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 -Vb=0.0 errorfree.dft cav myo 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Vb "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 -Vb=1.0 errorfree.dft cav myo 52 10 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 -Vb=1.0 errorfree.dft cav myo 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-Vb=1.0'."
@@ -260,8 +255,8 @@ printf "\n 0.3.0 \n"
 printf " Test case: Non-existing input file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM nonexisting.dat 2 1 52 10 7 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM nonexisting.dat 2 1 52 10 7 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.dat'" "cannot open file"
@@ -274,8 +269,8 @@ printf " Test case: Wrong input file format. \n"
 printf " Expected result: Error. \n\n"
 
 printf "abc defg\nbubudum\nmeh\n" > bad.dat
-rm -f stdout.txt output.dat
-$PROGRAM bad.dat 2 1 52 10 7 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bad.dat 2 1 52 10 7 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'bad.dat'" "wrong format"
@@ -288,8 +283,8 @@ printf "\n 0.4.0 \n"
 printf " Test case: ROIs given with numbers that exist. \n"
 printf " Expected result: Correct TACs selected. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 errorfree.dft 2 1 52 10 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 errorfree.dft 2 1 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt cav_roi "2"
@@ -309,16 +304,16 @@ printf "\n 0.4.1 \n"
 printf " Test case: ROIs given with numbers that do not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 errorfree.dft 0 1 52 10 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 errorfree.dft 0 1 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "ROI '0' not found in errorfree.dft"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 errorfree.dft 2 8 52 10 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 errorfree.dft 2 8 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "ROI '8' not found in errorfree.dft"
@@ -329,16 +324,16 @@ printf "\n 0.4.2 \n"
 printf " Test case: ROIs given as names that do not exist. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 errorfree.dft vac myo 52 10 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 errorfree.dft vac myo 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "ROI 'vac' not found in errorfree.dft"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 errorfree.dft cav moy 52 10 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 errorfree.dft cav moy 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "ROI 'moy' not found in errorfree.dft"
@@ -350,8 +345,8 @@ printf "\n 0.4.3 \n"
 printf " Test case: Same ROI given as cavity and myocardium. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 errorfree.dft myo myo 52 10 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 errorfree.dft myo myo 52 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "same ROI selected for cavity and myocardium."
@@ -365,8 +360,8 @@ printf "\n 0.5.0 \n"
 printf " Test case: Invalid diameter given. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 errorfree.dft 2 1 0 10 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 errorfree.dft 2 1 0 10 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid diameter '0'"
@@ -377,8 +372,8 @@ printf "\n 0.5.1 \n"
 printf " Test case: Invalid thickness given. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 errorfree.dft 2 1 52 0 10 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 errorfree.dft 2 1 52 0 10 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid thickness '0'"
@@ -389,8 +384,8 @@ printf "\n 0.5.2 \n"
 printf " Test case: Invalid resolution given. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 errorfree.dft 2 1 52 10 0 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 errorfree.dft 2 1 52 10 0 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid resolution '0'"
@@ -407,7 +402,7 @@ printf " Test case 1: Spillover errors are simulated. \n"
 printf " Test case 2: Spillover errors are corrected again. \n"
 printf " Expected result: Correct output is written. \n\n"
 
-rm -f stdout.txt output.dft output2.dft
+rm -f output.dft output2.dft
 $PROGRAM --silent -simulate errorfree.dft cav myo 52 10 10 output.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
@@ -430,8 +425,8 @@ printf "\n 1.1.0 \n"
 printf " Test case: Correction with different relative concentration levels. \n"
 printf " Expected result: Correct output is written. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM observ.dft 2 1 52 10 7 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM observ.dft 2 1 52 10 7 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.01 -rel=0.1 correct_corrected.dft output.dft
@@ -442,8 +437,8 @@ printf "\n 1.1.1 \n"
 printf " Test case: Different relative concentration levels, Vb=0. \n"
 printf " Expected result: Correct output is written. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -Vb=0 observ0.dft 2 1 52 10 7 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -Vb=0 observ0.dft 2 1 52 10 7 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.01 -rel=0.1 correct_corrected0.dft output.dft
@@ -468,8 +463,8 @@ printf "\n 2.0.0 \n"
 printf " Test case: Option -Vb not given, using default Vb. \n"
 printf " Expected result: Correct output is written. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d2 observ.dft 2 1 52 10 7 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d2 observ.dft 2 1 52 10 7 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Vb "0.1"
@@ -486,8 +481,7 @@ printf "\n 2.1.0 \n"
 printf " Test case: Just compute the correction parameters. \n"
 printf " Expected result: Correct output is written in stdout. \n\n"
 
-rm -f stdout.txt
-$PROGRAM none 2 1 52 10 7 none &> stdout.txt
+$PROGRAM none 2 1 52 10 7 none 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval -abs=0.0001 stdout.txt FMB 0.000000
