@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_p2t_3c
-#: Date       : 2014-11-04
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,11 @@ else
 EXT=;
 fi
 PROGRAM=../../p2t_3c$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -19,11 +24,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f bolus.dat ] || [ ! -f stead100.dat ]; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -110,8 +110,7 @@ printf "\n 0.1.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption bolus.dat 0.1 0.2 0 0 0 0 tissue.dat &> stdout.txt
+$PROGRAM -stupidoption bolus.dat 0.1 0.2 0 0 0 0 tissue.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -122,8 +121,7 @@ printf "\n 0.1.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM bolus.dat 0.1 0.2 0 0 0 0 tissue.dat extra &> stdout.txt
+$PROGRAM bolus.dat 0.1 0.2 0 0 0 0 tissue.dat extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -134,20 +132,19 @@ printf "\n 0.1.2 \n"
 printf " Test case: Missing argument(s). \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  0.1 0.2 0 0 0 0 tissue.dat &> stdout.txt
+$PROGRAM  0.1 0.2 0 0 0 0 tissue.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM bolus.dat 0.1 0.2 0 0 0 0  &> stdout.txt
+$PROGRAM bolus.dat 0.1 0.2 0 0 0 0  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM bolus.dat 0.1 0.2 0 0  tissue.dat &> stdout.txt
+$PROGRAM bolus.dat 0.1 0.2 0 0  tissue.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM bolus.dat  &> stdout.txt
+$PROGRAM bolus.dat  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -161,8 +158,8 @@ printf " Test case: Correct input, no options. \n"
 printf " Expected result 1: Values of variables are correct. \n"
 printf " Expected result 2: Output file is created. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 bolus.dat 0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 bolus.dat 0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -190,16 +187,16 @@ printf "\n 0.2.1 \n"
 printf " Test case: Options -sub and -nosub. \n"
 printf " Expected result: Options are correctly identified. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -sub bolus.dat 0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -sub bolus.dat 0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt save_only_total "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -nosub bolus.dat 0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -nosub bolus.dat 0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt save_only_total "1"
@@ -211,32 +208,32 @@ printf "\n 0.2.2 \n"
 printf " Test case: Options -parallel and -series. \n"
 printf " Expected result: Options are correctly identified. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -parallel bolus.dat 0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -parallel bolus.dat 0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parallel "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -series bolus.dat 0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -series bolus.dat 0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parallel "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -paral bolus.dat 0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -paral bolus.dat 0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parallel "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -ser bolus.dat 0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -ser bolus.dat 0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parallel "0"
@@ -253,8 +250,8 @@ printf "\n 1.0.0 \n"
 printf " Test case: Non-existing input file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM nonexisting.dat 0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM nonexisting.dat 0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.dat'" "cannot open file"
@@ -267,8 +264,8 @@ printf " Test case: Wrong input file format. \n"
 printf " Expected result: Error. \n\n"
 
 printf "abc defg\nbubudum\nmeh\n" > bad.dat
-rm -f stdout.txt output.dat
-$PROGRAM bad.dat 0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bad.dat 0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'bad.dat'" "wrong format"
@@ -280,8 +277,8 @@ printf "\n 1.0.2 \n"
 printf " Test case: Input file contains more than one TAC. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM multi.dat 0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM multi.dat 0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "plasma data contains more than one curve."
@@ -293,8 +290,8 @@ printf "\n 1.0.3 \n"
 printf " Test case: Input file contains less than 3 samples. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus_toofew.dat 0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus_toofew.dat 0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "too few samples in plasma data."
@@ -306,8 +303,8 @@ printf "\n 1.0.4 \n"
 printf " Test case: Input file samples are not in ascending order. \n"
 printf " Expected result: Error (from simulation routine). \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus_wrongorder.dat 0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus_wrongorder.dat 0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -325,24 +322,24 @@ printf " Expected result 1: Error if first is zero or less. \n"
 printf " Expected result 2: Error if any rate constant is negative. \n"
 printf " Expected result 3: Error if any rate constant is too large. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus.dat 0 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus.dat 0 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "k1 must be > 0."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -parallel -d2 bolus.dat 0.1 0 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -parallel -d2 bolus.dat 0.1 0 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "parameters" "0.1 0 0 0 0 0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -series -d2 bolus.dat 0.1 0 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -series -d2 bolus.dat 0.1 0 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "parameters" "0.1 0 0 0 0 0"
@@ -351,44 +348,44 @@ printf "\n passed. \n\n"
 
 
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus.dat -0.1 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus.dat -0.1 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat 0.1 -0.2 0 0 0 0 output.dat &> stdout.txt
+$PROGRAM bolus.dat 0.1 -0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat 0.1 0.2 -0.05 0 0 0 output.dat &> stdout.txt
+$PROGRAM bolus.dat 0.1 0.2 -0.05 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat 0.1 0.2 0.05 -0.1 0 0 output.dat &> stdout.txt
+$PROGRAM bolus.dat 0.1 0.2 0.05 -0.1 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat 0.1 0.2 0.1 0.05 -0.01 0 output.dat &> stdout.txt
+$PROGRAM bolus.dat 0.1 0.2 0.1 0.05 -0.01 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat 0.1 0.2 0.05 0.1 0.2 -0.000001 output.dat &> stdout.txt
+$PROGRAM bolus.dat 0.1 0.2 0.05 0.1 0.2 -0.000001 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus.dat 2.0E+08 0.2 0 0 0 0 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus.dat 2.0E+08 0.2 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat 0.1 2.0E+08 0 0 0 0 output.dat &> stdout.txt
+$PROGRAM bolus.dat 0.1 2.0E+08 0 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat 0.1 0.2 2.0E+08 0 0 0 output.dat &> stdout.txt
+$PROGRAM bolus.dat 0.1 0.2 2.0E+08 0 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat 0.1 0.2 0.05 2.0E+08 0 0 output.dat &> stdout.txt
+$PROGRAM bolus.dat 0.1 0.2 0.05 2.0E+08 0 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat 0.1 0.2 0.1 0.05 2.0E+08 0 output.dat &> stdout.txt
+$PROGRAM bolus.dat 0.1 0.2 0.1 0.05 2.0E+08 0 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat 0.1 0.2 0.05 0.1 0.2 2.0E+08 output.dat &> stdout.txt
+$PROGRAM bolus.dat 0.1 0.2 0.05 0.1 0.2 2.0E+08 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -400,7 +397,7 @@ printf "===================================================================\n"
 printf "\n 1.2.0 \n"
 printf " Test case: Output file exists. \n"
 printf " Expected result: Backup is made from the existing one. \n\n"
-rm -f stdout.txt output.dat output.dat.bak
+rm -f output.dat output.dat.bak
 $PROGRAM -nosub bolus.dat 0.4 0.2 0.2 0.2 0.1 0.2 output.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
