@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_p2t_di
-#: Date       : 2016-02-21
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,11 @@ else
 EXT=;
 fi
 PROGRAM=../../p2t_di$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -19,11 +24,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f frames.dat ] || [ ! -f framel.dat ] || [ ! -f frames5.dat ]; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -253,8 +253,7 @@ printf "\n 0.1.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption parent.dat metabolite1.dat blood.dat 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0 sim.dat &> stdout.txt
+$PROGRAM -stupidoption parent.dat metabolite1.dat blood.dat 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0 sim.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -265,8 +264,7 @@ printf "\n 0.1.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM parent.dat metabolite1.dat blood.dat 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0 sim.dat extra &> stdout.txt
+$PROGRAM parent.dat metabolite1.dat blood.dat 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0 sim.dat extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -278,24 +276,23 @@ printf "\n 0.1.2 \n"
 printf " Test case: Missing argument(s). \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  metabolite1.dat blood.dat 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0 sim.dat &> stdout.txt
+$PROGRAM  metabolite1.dat blood.dat 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0 sim.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM parent.dat  blood.dat 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0 sim.dat &> stdout.txt
+$PROGRAM parent.dat  blood.dat 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0 sim.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM parent.dat metabolite1.dat blood.dat 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0  &> stdout.txt
+$PROGRAM parent.dat metabolite1.dat blood.dat 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM parent.dat metabolite1.dat blood.dat 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1  sim.dat &> stdout.txt
+$PROGRAM parent.dat metabolite1.dat blood.dat 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1  sim.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM   &> stdout.txt
+$PROGRAM   1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -309,8 +306,8 @@ printf " Test case: Correct input, no options. \n"
 printf " Expected result 1: Values of variables are correct. \n"
 printf " Expected result 2: Output file is created. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -353,16 +350,16 @@ printf "\n 0.2.1 \n"
 printf " Test case: Options -sub and -nosub. \n"
 printf " Expected result: Options are correctly identified. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -sub parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -sub parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt save_only_total "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -nosub parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -nosub parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt save_only_total "1"
@@ -374,32 +371,32 @@ printf "\n 0.2.2 \n"
 printf " Test case: Options -parallel and -series. \n"
 printf " Expected result: Options are correctly identified. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -parallel parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -parallel parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parallel "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -series parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -series parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parallel "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -paral parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -paral parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parallel "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -ser parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -ser parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parallel "0"
@@ -416,24 +413,24 @@ printf "\n 1.0.0 \n"
 printf " Test case: Non-existing input file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM nonexisting.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM nonexisting.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.dat'" "cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM parent_short.dat nonexisting.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM parent_short.dat nonexisting.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.dat'" "cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM parent_short.dat metabolite1_short.dat nonexisting.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM parent_short.dat metabolite1_short.dat nonexisting.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.dat'" "cannot open file"
@@ -447,24 +444,24 @@ printf " Test case: Wrong input file format. \n"
 printf " Expected result: Error. \n\n"
 
 printf "abc defg\nbubudum\nmeh\n" > bad.dat
-rm -f stdout.txt output.dat
-$PROGRAM bad.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bad.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'bad.dat'" "wrong format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM parent_short.dat bad.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM parent_short.dat bad.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'bad.dat'" "wrong format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM parent_short.dat metabolite1_short.dat bad.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM parent_short.dat metabolite1_short.dat bad.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'bad.dat'" "wrong format"
@@ -476,24 +473,24 @@ printf "\n 1.0.2 \n"
 printf " Test case: Input file contains more than one TAC. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM multi.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM multi.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "plasma data contains more than one curve."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM parent_short.dat multi.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM parent_short.dat multi.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "metabolite data contains more than one curve."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM parent_short.dat metabolite1_short.dat multi.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM parent_short.dat metabolite1_short.dat multi.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "blood data contains more than one curve."
@@ -505,24 +502,24 @@ printf "\n 1.0.3 \n"
 printf " Test case: Input file contains less than 3 samples. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM parent_tooshort.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM parent_tooshort.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "too few samples in plasma data."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM parent_short.dat metabolite1_short.dat blood_tooshort.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM parent_short.dat metabolite1_short.dat blood_tooshort.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "too few samples in blood data."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM parent_tooshort.dat metabolite1_tooshort.dat blood_tooshort.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM parent_tooshort.dat metabolite1_tooshort.dat blood_tooshort.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "too few samples in plasma data."
@@ -543,16 +540,16 @@ printf " Expected result 1: Error if first is zero or less. \n"
 printf " Expected result 2: Error if any rate constant is negative. \n"
 printf " Expected result 3: Error if any rate constant is too large. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 parent_short.dat metabolite1_short.dat blood_short.dat 0 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 parent_short.dat metabolite1_short.dat blood_short.dat 0 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "rate_constants" "0 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 parent_short.dat metabolite1_short.dat blood_short.dat 0,20 0 0 0 0 0 0 0 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 parent_short.dat metabolite1_short.dat blood_short.dat 0,20 0 0 0 0 0 0 0 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "rate_constants" "0.2 0 0 0 0 0 0 0 0.02 0.01"
@@ -560,8 +557,8 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 parent_short.dat metabolite1_short.dat blood_short.dat -0.10 0.09 -0.08 0.07 -0.06 0.05 -0.04 0.03 0.02 -0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 parent_short.dat metabolite1_short.dat blood_short.dat -0.10 0.09 -0.08 0.07 -0.06 0.05 -0.04 0.03 0.02 -0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "rate_constants" "0 0.09 0 0.07 0 0.05 0 0.03 0.02 0"
@@ -570,29 +567,29 @@ printf "\n passed. \n\n"
 
 
 
-rm -f stdout.txt output.dat
-$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 2.0E+08 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 2.0E+08 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 2.0E+08 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 2.0E+08 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 2.0E+08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 2.0E+08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 2.0E+08 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 2.0E+08 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 2.0E+08 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 2.0E+08 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 2.0E+08 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 2.0E+08 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 2.0E+08 0.03 0.02 0.01 5 output.dat &> stdout.txt
+$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 2.0E+08 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 2.0E+08 0.02 0.01 5 output.dat &> stdout.txt
+$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 2.0E+08 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -604,11 +601,11 @@ printf "===================================================================\n"
 printf "\n 1.2.0 \n"
 printf " Test case: Output file exists. \n"
 printf " Expected result: Backup is made from the existing one. \n\n"
-rm -f stdout.txt output.dat output.dat.bak
-$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat &> stdout.txt
+rm -f output.dat output.dat.bak
+$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.10 0.09 0.08 0.07 0.06 0.05 0.04 0.03 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.40 0.60 0.18 0.17 0.16 0.15 0.14 0.13 0.02 0.01 5 output.dat &> stdout.txt
+$PROGRAM parent_short.dat metabolite1_short.dat blood_short.dat 0.40 0.60 0.18 0.17 0.16 0.15 0.14 0.13 0.02 0.01 5 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -x=n -y=y -xunit=n -yunit=n output.dat output.dat.bak
