@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_p2t_v3c
-#: Date       : 2020-03-11
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -66,8 +66,7 @@ printf "\n 0.1.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption bolus.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 tissue.dat &> stdout.txt
+$PROGRAM -stupidoption bolus.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 tissue.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -78,8 +77,7 @@ printf "\n 0.1.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM bolus.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 tissue.dat extra &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 tissue.dat extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -90,24 +88,23 @@ printf "\n 0.1.2 \n"
 printf " Test case: Missing argument(s). \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM bolus.dat 0.2 0.4 0 0 0 0 0 10 1 tissue.dat &> stdout.txt
+$PROGRAM bolus.dat 0.2 0.4 0 0 0 0 0 10 1 tissue.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM bolus.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM bolus.dat bolus.dat 0.2 0.4 0  0 0 0 10 1 tissue.dat tissue.dat &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.2 0.4 0  0 0 0 10 1 tissue.dat tissue.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM bolus.dat  tissue.dat &> stdout.txt
+$PROGRAM bolus.dat  tissue.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM   &> stdout.txt
+$PROGRAM   1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -121,9 +118,9 @@ printf " Test case: Correct input, no options. \n"
 printf " Expected result 1: Values of variables are correct. \n"
 printf " Expected result 2: Output file is created. \n\n"
 
-rm -f stdout.txt output.dat
+rm -f output.dat
 taccalc bolus_short.dat x 0.5 blood_short.dat
-$PROGRAM -d2 bolus_short.dat blood_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+$PROGRAM -d2 bolus_short.dat blood_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
@@ -163,16 +160,16 @@ printf "\n 0.2.1 \n"
 printf " Test case: Options -sub and -nosub. \n"
 printf " Expected result: Options are correctly identified. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -sub bolus_short.dat bolus_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -sub bolus_short.dat bolus_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt save_only_total "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -nosub bolus_short.dat bolus_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -nosub bolus_short.dat bolus_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt save_only_total "1"
@@ -184,32 +181,32 @@ printf "\n 0.2.2 \n"
 printf " Test case: Options -parallel and -series. \n"
 printf " Expected result: Options are correctly identified. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -parallel bolus_short.dat bolus_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -parallel bolus_short.dat bolus_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parallel "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -series bolus_short.dat bolus_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -series bolus_short.dat bolus_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parallel "0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -paral bolus_short.dat bolus_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -paral bolus_short.dat bolus_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parallel "1"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -d2 -ser bolus_short.dat bolus_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -d2 -ser bolus_short.dat bolus_short.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt parallel "0"
@@ -226,16 +223,16 @@ printf "\n 1.0.0 \n"
 printf " Test case: Non-existing input file. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM nonexisting.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM nonexisting.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.dat'" "cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus.dat nonexisting.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus.dat nonexisting.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexisting.dat'" "cannot open file"
@@ -249,16 +246,16 @@ printf " Test case: Wrong input file format. \n"
 printf " Expected result: Error. \n\n"
 
 printf "abc defg\nbubudum\nmeh\n" > bad.dat
-rm -f stdout.txt output.dat
-$PROGRAM bad.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bad.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'bad.dat'" "wrong format"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus.dat bad.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus.dat bad.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'bad.dat'" "wrong format"
@@ -270,16 +267,16 @@ printf "\n 1.0.2 \n"
 printf " Test case: Input file contains more than one TAC. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM multi.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM multi.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "plasma data contains more than one curve."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus.dat multi.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus.dat multi.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "blood data contains more than one curve."
@@ -291,24 +288,24 @@ printf "\n 1.0.3 \n"
 printf " Test case: Input file contains less than 3 samples. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus_toofew.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus_toofew.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "too few samples in plasma data."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus.dat bolus_toofew.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus.dat bolus_toofew.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "too few samples in blood data."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus_toofew.dat bolus_toofew.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus_toofew.dat bolus_toofew.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "too few samples in plasma data."
@@ -321,18 +318,18 @@ printf "\n 1.0.4 \n"
 printf " Test case: Input file samples are not in ascending order. \n"
 printf " Expected result: Error (from simulation routine). \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus_wrongorder.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus_wrongorder.dat bolus.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus.dat bolus_wrongorder.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus.dat bolus_wrongorder.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus_wrongorder.dat bolus_wrongorder.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus_wrongorder.dat bolus_wrongorder.dat 0.2 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -349,24 +346,24 @@ printf " Expected result 1: Error if first is zero or less. \n"
 printf " Expected result 2: Error if any rate constant is negative. \n"
 printf " Expected result 3: Error if any rate constant is too large. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus.dat bolus.dat 0 0.4 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus.dat bolus.dat 0 0.4 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "k1 must be > 0."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -parallel -d2 bolus_short.dat bolus_short.dat 0.2 0 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -parallel -d2 bolus_short.dat bolus_short.dat 0.2 0 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "parameters" "0.2 0 0 0 0 0"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dat
-$PROGRAM -series -d2 bolus_short.dat bolus_short.dat 0.2 0 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM -series -d2 bolus_short.dat bolus_short.dat 0.2 0 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "parameters" "0.2 0 0 0 0 0"
@@ -375,47 +372,47 @@ printf "\n passed. \n\n"
 
 
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus.dat bolus.dat -0.1 0.2 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus.dat bolus.dat -0.1 0.2 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat bolus.dat 0.1 -0.2 0 0 0 0 0 10 1 output.dat &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.1 -0.2 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat bolus.dat 0.1 0.2 -0.05 0 0 0 0 10 1 output.dat &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.1 0.2 -0.05 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat bolus.dat 0.1 0.2 0.05 -0.1 0 0 0 10 1 output.dat &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.1 0.2 0.05 -0.1 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat bolus.dat 0.1 0.2 0.1 0.05 -0.01 0 0 10 1 output.dat &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.1 0.2 0.1 0.05 -0.01 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat bolus.dat 0.1 0.2 0.05 0.1 0.2 -0.000001 0 10 1 output.dat &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.1 0.2 0.05 0.1 0.2 -0.000001 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat bolus.dat 0.1 0.2 0 0 0 0 -0.1 10 1 output.dat &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.1 0.2 0 0 0 0 -0.1 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
-rm -f stdout.txt output.dat
-$PROGRAM bolus.dat bolus.dat 2.0E+08 0.2 0 0 0 0 0 10 1 output.dat &> stdout.txt
+rm -f output.dat
+$PROGRAM bolus.dat bolus.dat 2.0E+08 0.2 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat bolus.dat 0.1 2.0E+08 0 0 0 0 0 10 1 output.dat &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.1 2.0E+08 0 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat bolus.dat 0.1 0.2 2.0E+08 0 0 0 0 10 1 output.dat &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.1 0.2 2.0E+08 0 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat bolus.dat 0.1 0.2 0.05 2.0E+08 0 0 0 10 1 output.dat &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.1 0.2 0.05 2.0E+08 0 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat bolus.dat 0.1 0.2 0.1 0.05 2.0E+08 0 0 10 1 output.dat &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.1 0.2 0.1 0.05 2.0E+08 0 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM bolus.dat bolus.dat 0.1 0.2 0.05 0.1 0.2 2.0E+08 0 10 1 output.dat &> stdout.txt
+$PROGRAM bolus.dat bolus.dat 0.1 0.2 0.05 0.1 0.2 2.0E+08 0 10 1 output.dat 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -427,7 +424,7 @@ printf "===================================================================\n"
 printf "\n 1.2.0 \n"
 printf " Test case: Output file exists. \n"
 printf " Expected result: Backup is made from the existing one. \n\n"
-rm -f stdout.txt output.dat output.dat.bak
+rm -f output.dat output.dat.bak
 $PROGRAM -nosub bolus_short.dat bolus_short.dat 0.4 0.2 0.2 0.2 0.1 0.2 0 10 1 output.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
