@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgsuv
-#: Date       : 2014-10-09
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,11 @@ else
 EXT=;
 fi
 PROGRAM=../../imgsuv$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -19,11 +24,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f original.dft ] ; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -81,8 +81,7 @@ printf "\n 1.0.0 \n"
 printf " Test case: No command line options or arguments. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM &> stdout.txt
+$PROGRAM 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Usage"
@@ -98,8 +97,7 @@ printf "\n 1.0.1 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM -stupidoption calibrated.v 0 0 200 50 suv.v &> stdout.txt
+$PROGRAM -stupidoption calibrated.v 0 0 200 50 suv.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -111,8 +109,8 @@ printf "\n 1.0.2 \n"
 printf " Test case: Valid arguments. \n"
 printf " Expected result: Correctly identified by application. \n\n"
 
-rm -f stdout.txt suv.v
-$PROGRAM -d2 calibrated.v 0 0 200 50 suv.v &> stdout.txt
+rm -f suv.v
+$PROGRAM -d2 calibrated.v 0 0 200 50 suv.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt petfile "calibrated.v"
@@ -133,8 +131,7 @@ printf "\n 1.0.3 \n"
 printf " Test case: Too many arguments. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM calibrated.v 0 0 200 50 suv.v extra &> stdout.txt
+$PROGRAM calibrated.v 0 0 200 50 suv.v extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -147,18 +144,15 @@ printf "\n 1.0.4 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-$PROGRAM  0 0 200 50 suv.v &> stdout.txt
+$PROGRAM  0 0 200 50 suv.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM calibrated.v  0 200 50 suv.v &> stdout.txt
+$PROGRAM calibrated.v  0 200 50 suv.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt
-$PROGRAM calibrated.v 0 0 200 50  &> stdout.txt
+$PROGRAM calibrated.v 0 0 200 50  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -299,9 +293,9 @@ printf " Expected result 1: Static image in SUV units is made. \n"
 printf " Expected result 2: SUVs are correct. \n"
 printf " Expected result 3: Warning on unused timerange. \n\n"
 
-rm -f suv.v suv.dft stdout.txt
+rm -f suv.v suv.dft
 
-$PROGRAM static.v 30 120 200 50 suv.v &> stdout.txt
+$PROGRAM static.v 30 120 200 50 suv.v 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 img2dft suv.v original.roi suv.dft
@@ -348,9 +342,9 @@ printf "\n 3.0.0 \n"
 printf " Test case: ECAT image does not contain calibration units. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt suv.v
+rm -f suv.v
 
-$PROGRAM original.v 0 120 200 50 suv.v &> stdout.txt
+$PROGRAM original.v 0 120 200 50 suv.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ -f suv.v ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -364,9 +358,9 @@ printf "\n 3.1.0 \n"
 printf " Test case: User gives too large time range. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt suv.v
+rm -f suv.v
 
-$PROGRAM calibrated.v 0 9120 200 50 suv.v &> stdout.txt
+$PROGRAM calibrated.v 0 9120 200 50 suv.v 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 if [ -f suv.v ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -411,7 +405,7 @@ printf " Test case: static SUV from dynamic NIfTI image with SIF. \n"
 printf " Expected result: Results are correct \n\n"
 
 rm -f nifti/suv.*
-rm -f suv.dft stdout.txt 
+rm -f suv.dft
 
 $PROGRAM nifti/calibrated 0 120 200 50 nifti/suv
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -429,7 +423,7 @@ printf " Test case: dynamic SUV from dynamic NIfTI image without SIF. \n"
 printf " Expected result: Results are correct, just times are missing \n\n"
 
 rm -f nifti/*.sif nifti/suv.*
-rm -f suv.dft stdout.txt 
+rm -f suv.dft
 
 $PROGRAM nifti/calibrated 0 0 200 50 nifti/suv
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -447,9 +441,9 @@ printf " Test case: static SUV from dynamic NIfTI image without SIF. \n"
 printf " Expected result: Error. \n\n"
 
 rm -f nifti/*.sif nifti/suv.*
-rm -f suv.dft stdout.txt 
+rm -f suv.dft
 
-$PROGRAM nifti/calibrated 0 120 200 50 nifti/suv &> stdout.txt
+$PROGRAM nifti/calibrated 0 120 200 50 nifti/suv 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "nifti/calibrated does not contain frame times."
@@ -487,9 +481,9 @@ printf " Test case: static SUV from static NIfTI image without SIF. \n"
 printf " Expected result: Results are correct, just times are missing. \n\n"
 
 rm -f nifti/*.sif nifti/suv.*
-rm -f suv.dft stdout.txt 
+rm -f suv.dft 
 
-$PROGRAM nifti/static 0 120 200 50 nifti/suv &> stdout.txt
+$PROGRAM nifti/static 0 120 200 50 nifti/suv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 img2dft nifti/suv original.roi suv.dft
@@ -533,7 +527,7 @@ printf " Test case: static SUV from dynamic Analyze image with SIF. \n"
 printf " Expected result: Results are correct \n\n"
 
 rm -f ana/suv.*
-rm -f suv.dft stdout.txt 
+rm -f suv.dft
 dftsuv calibrated.dft 30 120 200 50 suv30-120.dft
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
@@ -554,7 +548,7 @@ printf " Test case: dynamic SUV from dynamic Analyze image without SIF. \n"
 printf " Expected result: Results are correct, just times are missing \n\n"
 
 rm -f ana/*.sif ana/suv.*
-rm -f suv.dft stdout.txt 
+rm -f suv.dft
 
 $PROGRAM ana/calibrated 0 0 200 50 ana/suv
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -572,9 +566,9 @@ printf " Test case: static SUV from dynamic Analyze image without SIF. \n"
 printf " Expected result: Error. \n\n"
 
 rm -f ana/*.sif ana/suv.*
-rm -f suv.dft stdout.txt 
+rm -f suv.dft
 
-$PROGRAM ana/calibrated 30 120 200 50 ana/suv &> stdout.txt
+$PROGRAM ana/calibrated 30 120 200 50 ana/suv 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error" "ana/calibrated does not contain frame times."
@@ -612,9 +606,9 @@ printf " Test case: static SUV from static Analyze image without SIF. \n"
 printf " Expected result: Results are correct, just times are missing. \n\n"
 
 rm -f ana/*.sif ana/suv.*
-rm -f suv.dft stdout.txt 
+rm -f suv.dft
 
-$PROGRAM ana/static 90 120 200 50 ana/suv &> stdout.txt
+$PROGRAM ana/static 90 120 200 50 ana/suv 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 img2dft ana/suv original.roi suv.dft
