@@ -677,7 +677,7 @@ int main(int argc, char **argv)
       sprintf(buf, "NNLS trap");
       int i=iftFindKey(&tac.h, "studynr", 0);
       if(i<0) i=iftFindKey(&tac.h, "study_number", 0);
-      if(i>0) {strcat(buf, ": "); strcat(buf, tac.h.item[i].value);}
+      if(i>=0) {strcat(buf, ": "); strcat(buf, tac.h.item[i].value);}
       if(tacPlotFitSVG(&tac, &taci, buf, 0.0, nan(""), 0.0, nan(""), svgfile, &status)!=TPCERROR_OK) {
         fprintf(stderr, "Error: %s\n", errorMsg(status.error));
         tacFree(&tac);  tacFree(&taci); parFree(&par);
