@@ -89,7 +89,7 @@ static char *info[] = {
   " ",
   "If TAC files contain more than one TAC, only the first is used.",
   " ",
-  "See also: convsurg, convexpf, sim_av",
+  "See also: convsurg, convexpf, sim_av, fit_suri",
   " ",
   "Keywords: TAC, curve fitting, convolution",
   0};
