@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fit_sigm
-#: Date       : 2014-09-25
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,11 @@ else
 EXT=;
 fi
 PROGRAM=../../fit_sigm$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "=====================================================================\n"
 printf "creating test data for %s\n" $PROGRAM
@@ -19,11 +24,6 @@ printf "=====================================================================\n"
 
 printf "\n verifying that required data exists \n"
 
-if [ ! -f $PROGRAM ]; then
-  printf "Failed: executable does not exist.\n"
-  exit 1
-fi
-
 if [ ! -f typical.fit ]; then
   printf "Failed: required data does not exist.\n"
   exit 1
@@ -88,9 +88,9 @@ printf " Test case 2: Options and arguments are correctly set. \n"
 printf " Expected result: Good fitting result with no errors. \n"
 printf " Options and variables have correct values in test mode. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM -d2 typical.dat output.fit &> stdout.txt
+$PROGRAM -d2 typical.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 fit2dat -f=typical.dat output.fit output.dat
@@ -413,9 +413,9 @@ printf "\n 4.0.0 \n"
 printf " Test case: File contains weights, no weighting options applied. \n"
 printf " Expected result: Weights are read correctly as seen in test mode. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM -d4 data_w.dat output.fit &> stdout.txt
+$PROGRAM -d4 data_w.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights[1] "1, 2, 3, 4, 5, 6, 7, 7"
@@ -427,9 +427,9 @@ printf "\n 4.0.1 \n"
 printf " Test case: File contains weights, which can be overwritten with option -w1. \n"
 printf " Expected result: Weights are set correctly as seen in test mode. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM -d4 -w1 data_w.dat output.fit &> stdout.txt
+$PROGRAM -d4 -w1 data_w.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights[1] "1, 1, 1, 1, 1, 1, 1, 1"
@@ -442,9 +442,9 @@ printf "\n 4.1.0 \n"
 printf " Test case: File does not contains weights, which are automatically set to 1. \n"
 printf " Expected result: Weights are set correctly as seen in test mode. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM -d4 -w1 data_now.dat output.fit &> stdout.txt
+$PROGRAM -d4 -w1 data_now.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights[1] "1, 1, 1, 1, 1, 1"
@@ -456,9 +456,9 @@ printf "\n 4.1.1 \n"
 printf " Test case: File does not contains weights, which are set with option -wf. \n"
 printf " Expected result: Weights are set correctly as seen in test mode. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM -d4 -wf data_now.dat output.fit &> stdout.txt
+$PROGRAM -d4 -wf data_now.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights[1] "0.461538, 0.692308, 0.923077, 1.15385, 1.38462, 1.38462"
@@ -473,9 +473,9 @@ printf "\n 4.2.0 \n"
 printf " Test case: File contains missing value but no weights. Weights are not set. \n"
 printf " Expected result: Missing value gets zero weight. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM -d4 data_na.dat output.fit &> stdout.txt
+$PROGRAM -d4 data_na.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights[1] "1, 1, 1, 0, 1, 1, 1, 1"
@@ -490,9 +490,9 @@ printf "\n 4.2.1 \n"
 printf " Test case: File contains missing value but no weights. Weights are set. \n"
 printf " Expected result: Missing value gets zero weight. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM -d4 -w1 data_na.dat output.fit &> stdout.txt
+$PROGRAM -d4 -w1 data_na.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights[1] "1, 1, 1, 0, 1, 1, 1, 1"
@@ -507,9 +507,9 @@ printf "\n 4.2.2 \n"
 printf " Test case: File contains missing value and weights. Weights are not set. \n"
 printf " Expected result: Missing value gets zero weight. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM -d4 data_naw.dat output.fit &> stdout.txt
+$PROGRAM -d4 data_naw.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights[1] "1, 2, 3, 0, 5, 6, 7, 8"
@@ -524,9 +524,9 @@ printf "\n 4.2.3 \n"
 printf " Test case: File contains missing value and weights. Weights are set. \n"
 printf " Expected result: Missing value gets zero weight. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM -d4 -w1 data_naw.dat output.fit &> stdout.txt
+$PROGRAM -d4 -w1 data_naw.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt data_weights[1] "1, 1, 1, 0, 1, 1, 1, 1"
@@ -548,9 +548,9 @@ printf "\n 5.0.0 \n"
 printf " Test case: Unknown option. \n"
 printf " Expected result: Appropriate error message and error code returned. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM -stupidoption typical.dat output.fit &> stdout.txt
+$PROGRAM -stupidoption typical.dat output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'"
@@ -562,9 +562,9 @@ printf "\n 5.1.0 \n"
 printf " Test case: Obligatory argument is missing. \n"
 printf " Expected result: error code returned. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM  &> stdout.txt
+$PROGRAM  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -573,9 +573,9 @@ printf "\n 5.1.1 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Appropriate error message and error code returned. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM typical.dat output.fit extra &> stdout.txt
+$PROGRAM typical.dat output.fit extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'"
@@ -587,9 +587,9 @@ printf "\n 5.2.0 \n"
 printf " Test case: Nonexisting data file. \n"
 printf " Expected result: Appropriate error message and error code returned. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM nonexistingfile.dat output.fit &> stdout.txt
+$PROGRAM nonexistingfile.dat output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'nonexistingfile.dat'" "cannot open file"
@@ -603,9 +603,9 @@ printf " Expected result: Appropriate error message and error code returned. \n\
 
 echo bleah meh > temp.dat
 echo more rubbish >> temp.dat
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM temp.dat output.fit &> stdout.txt
+$PROGRAM temp.dat output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading 'temp.dat'" "wrong format"
@@ -621,24 +621,24 @@ printf " Test case: Data file contains no more samples than there are \n"
 printf " free parameters to fit. \n"
 printf " Expected result: Appropriate error message and error code returned. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM typical_s3.dat output.fit &> stdout.txt
+$PROGRAM typical_s3.dat output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too few samples for fitting in typical_s3.dat"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM typical_s4.dat output.fit &> stdout.txt
+$PROGRAM typical_s4.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM -b typical_s4.dat output.fit &> stdout.txt
+$PROGRAM -b typical_s4.dat output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too few samples for fitting in typical_s4.dat"
@@ -652,11 +652,11 @@ printf " Test case 1: Catenated data file contains no more unique samples \n"
 printf "              than there are free parameters to fit. \n"
 printf " Expected result: Appropriate error message and error code returned. \n\n"
 
-rm -f output.fit output.dat stdout.txt temp.dat
+rm -f output.fit output.dat temp.dat
 dftcat -both typical_s3.dat typical_s3.dat temp.dat
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
-$PROGRAM temp.dat output.fit &> stdout.txt
+$PROGRAM temp.dat output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "too few samples for fitting in temp.dat"
@@ -674,9 +674,9 @@ printf "\n 6.0.0 \n"
 printf " Test case: Data which can be fitted well passes MRL test. \n"
 printf " Expected result: No errors or warnings reported. \n\n"
 
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 
-$PROGRAM -MRL -d2 typical.dat output.fit &> stdout.txt
+$PROGRAM -MRL -d2 typical.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt MRL_check "1"
@@ -692,10 +692,10 @@ printf " Expected result: Appropriate error message and error code returned. \n\
 cp -f typical.dat temp.dat 
 printf "12 0.1\n" >> temp.dat
 printf "14 0.1\n" >> temp.dat
-rm -f output.fit output.dat stdout.txt
+rm -f output.fit output.dat
 cat temp.dat
 
-$PROGRAM -MRL -d2  -svg=badfit.svg temp.dat output.fit &> stdout.txt
+$PROGRAM -MRL -d2  -svg=badfit.svg temp.dat output.fit 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "bad fit."
@@ -708,7 +708,7 @@ printf " Test case: Data which can not be fitted well does not pass MRL test. \n
 printf "            Option to stop with error if MRL test not passed is NOT turned on. \n"
 printf " Expected result: Appropriate warning message returned, but no errors. \n\n"
 
-$PROGRAM -svg=badfit.svg temp.dat output.fit &> stdout.txt
+$PROGRAM -svg=badfit.svg temp.dat output.fit 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "bad fit."
