@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_tactime
-#: Date       : 2014-08-21
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,11 @@ else
 EXT=;
 fi
 PROGRAM=../../tactime$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
+
 
 printf "\n\n"
 printf "=====================================================================\n"
@@ -20,8 +25,8 @@ printf "=====================================================================\n"
 
 printf "\n0.1.0 Unknown option \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -stupidoption -decay -i=C-11 c11.dft +20.4 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -stupidoption -decay -i=C-11 c11.dft +20.4 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid option '-stupidoption'."
@@ -32,8 +37,8 @@ printf "\n===================================================================\n"
 
 printf "\n0.2.0 Extra argument \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -decay -i=C-11 c11.dft +20.4 output.dft extra &> stdout.txt
+rm -f output.dft
+$PROGRAM -decay -i=C-11 c11.dft +20.4 output.dft extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -44,8 +49,8 @@ printf "\n===================================================================\n"
 
 printf "\n0.3.0 Missing input filename \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -decay -i=C-11 +20.4 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -decay -i=C-11 +20.4 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "file '+20.4' does not exist."
@@ -54,8 +59,8 @@ printf "\n passed. \n\n"
 
 printf "\n0.3.1 Nonexisting input file \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -decay -i=C-11 nonexisting.dft +20.4 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -decay -i=C-11 nonexisting.dft +20.4 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "file 'nonexisting.dft' does not exist."
@@ -64,8 +69,8 @@ printf "\n passed. \n\n"
 
 printf "\n0.3.2 Wrong format input file \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -decay -i=C-11 $PROGRAM +20.4 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -decay -i=C-11 $PROGRAM +20.4 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt "Error in reading '$PROGRAM'" "unknown file format"
@@ -75,8 +80,8 @@ printf "\n passed. \n\n"
 
 printf "\n0.3.3 Missing time \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -decay -i=C-11 c11.dft output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -decay -i=C-11 c11.dft output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument for time: 'output.dft'."
@@ -85,8 +90,8 @@ printf "\n passed. \n\n"
 
 printf "\n0.3.4 Time file does not exist \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -decay -i=C-11 c11.dft nonexistingfile.ift output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -decay -i=C-11 c11.dft nonexistingfile.ift output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument for time: 'nonexistingfile.ift'."
@@ -95,8 +100,8 @@ printf "\n passed. \n\n"
 
 printf "\n0.3.5 Time file in wrong format \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -decay -i=C-11 c11.dft $PROGRAM output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -decay -i=C-11 c11.dft $PROGRAM output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument for time: '$PROGRAM'."
@@ -105,16 +110,16 @@ printf "\n passed. \n\n"
 
 printf "\n0.3.6 Time is ok, also with decimal comma \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d1 -decay -i=C-11 c11.dft -30.5 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d1 -decay -i=C-11 c11.dft -30.5 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt time_diff "-30.5"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d1 -decay -i=C-11 c11.dft 11,5 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d1 -decay -i=C-11 c11.dft 11,5 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt time_diff "11.5"
@@ -126,8 +131,8 @@ printf "\n===================================================================\n"
 
 printf "\n0.4.0 Missing output filename \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -decay -i=C-11 c11.dft +20.4  &> stdout.txt
+rm -f output.dft
+$PROGRAM -decay -i=C-11 c11.dft +20.4  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "undefined output file name."
@@ -138,8 +143,8 @@ printf "\n===================================================================\n"
 
 printf "\n0.5.0 Invalid isotope code as option \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -decay -i=Hiili c11.dft +20.4 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -decay -i=Hiili c11.dft +20.4 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid isotope 'HIILI'."
@@ -150,8 +155,8 @@ printf "\n0.5.1 Invalid isotope code in the file \n\n"
 
 cp -f c11.dft c11_with_invalid_isotope.dft
 printf "\n# isotope := Hiili\n" >> c11_with_invalid_isotope.dft
-rm -f stdout.txt output.dft
-$PROGRAM -decay c11_with_invalid_isotope.dft +20.4 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -decay c11_with_invalid_isotope.dft +20.4 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid isotope 'Hiili' in 'c11_with_invalid_isotope.dft'."
@@ -160,8 +165,8 @@ printf "\n passed. \n\n"
 
 printf "\n0.5.2 Isotope missing in both file and as an option \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -decay c11.dft +20.4 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -decay c11.dft +20.4 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "isotope not specified."
@@ -169,8 +174,8 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 printf "\n0.5.3 Different isotope in input file and in option \n\n"
-rm -f stdout.txt output.dft
-$PROGRAM -decay -i=F-18 c11_with_isotope.dft +20.4 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -decay -i=F-18 c11_with_isotope.dft +20.4 output.dft 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid isotope in 'c11_with_isotope.dft' or in command line."
@@ -183,8 +188,8 @@ printf "\n===================================================================\n"
 
 printf "\n1.0.0 Correct result with i=C-11 \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d1 -decay -i=C-11 c11.dft +20.4 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d1 -decay -i=C-11 c11.dft +20.4 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Isotope "C-11"
@@ -196,8 +201,8 @@ printf "\n passed. \n\n"
 
 printf "\n1.0.1 Correct result with i=F-18 \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d1 -decay -i=F-18 f18.dft 109.8 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d1 -decay -i=F-18 f18.dft 109.8 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Isotope "F-18"
@@ -209,8 +214,8 @@ printf "\n passed. \n\n"
 
 printf "\n1.0.1 Correct result with i=O-15 \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d1 -decay -i=O-15 o15.dft 123 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d1 -decay -i=O-15 o15.dft 123 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Isotope "O-15"
@@ -225,8 +230,8 @@ printf "\n===================================================================\n"
 
 printf "\n1.1.0 Correct result with C-11 in input file \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d1 -decay c11_with_isotope.dft +20.4 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d1 -decay c11_with_isotope.dft +20.4 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Isotope "C-11"
@@ -238,8 +243,8 @@ printf "\n passed. \n\n"
 
 printf "\n1.1.1 Correct result with F-18 in input file \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d1 -decay f18_with_isotope.dft 109.8 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d1 -decay f18_with_isotope.dft 109.8 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Isotope "F-18"
@@ -251,8 +256,8 @@ printf "\n passed. \n\n"
 
 printf "\n1.1.1 Correct result with O-15 in input file \n\n"
 
-rm -f stdout.txt output.dft
-$PROGRAM -d1 -decay o15_with_isotope.dft 123 output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM -d1 -decay o15_with_isotope.dft 123 output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Isotope "O-15"
@@ -287,8 +292,8 @@ printf "\n passed. \n\n"
 
 printf "\n2.1.0 Change times is zero. \n\n"
 
-rm -f stdout.txt output.kbq
-$PROGRAM o15blood.kbq 0 output.kbq &> stdout.txt
+rm -f output.kbq
+$PROGRAM o15blood.kbq 0 output.kbq 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.05 -rel=1 o15blood.kbq output.kbq
@@ -330,9 +335,9 @@ printf "\n2.1.2 Time changes are given in a file \n\n"
 printf "\n      scan_start_time_difference is zero, \n"
 printf "\n      including time unit \n\n"
 
-rm -f test.dit output.dft stdout.txt
+rm -f test.dit output.dft
 printf "\nscan_start_time_difference := 0.0 [min]\n" > test.dit
-$PROGRAM -decay -i=C-11 c11.dft test.dit output.dft &> stdout.txt
+$PROGRAM -decay -i=C-11 c11.dft test.dit output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.05 -rel=1 c11.dft output.dft
@@ -438,8 +443,8 @@ printf "\n passed. \n\n"
 printf "\n4.1.0 Option -keeptimes should not be used without -decay, \n"
 printf "      because otherwise nothing would actually be done  \n\n"
 
-rm -f output.dft stdout.txt
-$PROGRAM -keeptimes -i=C-11 c11.dft 20.4 output.dft &> stdout.txt 
+rm -f output.dft
+$PROGRAM -keeptimes -i=C-11 c11.dft 20.4 output.dft 1>stdout.txt 2>&1 
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "change in neither sample times or decay correction were requested."
@@ -450,7 +455,7 @@ printf "\n passed. \n\n"
 printf "\n4.1.1 Change decay but not times 1 half-life forward \n"
 printf "      Check also that injection_time is changed accordingly  \n\n"
 
-rm -f output.dft stdout.txt
+rm -f output.dft
 iftlist c11_with_injtime.dft
 $PROGRAM -keeptimes -decay c11_with_injtime.dft +20.4 output.dft 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
@@ -468,7 +473,7 @@ printf "\n passed. \n\n"
 printf "\n4.1.2 Change decay but not times 1 half-life backward \n"
 printf "      Check also that injection_time is changed accordingly  \n\n"
 
-rm -f output2.dft stdout.txt
+rm -f output2.dft
 iftlist output.dft
 $PROGRAM -keeptimes -decay output.dft -20.4 output2.dft 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
