@@ -320,8 +320,10 @@ int main(int argc, char **argv)
   }
 
   /* Set cut time based on TAC preference, if that is given */
-  if(overlapMode==OVL_USE_FIRST) cutTime=xmax1;
-  if(overlapMode==OVL_USE_SECOND) cutTime=xmin2;
+//  if(overlapMode==OVL_USE_FIRST) cutTime=xmax1;
+//  if(overlapMode==OVL_USE_SECOND) cutTime=xmin2;
+  if(overlapMode==OVL_USE_FIRST) {cutTime=xmax1; if(xmax1==xmin2) cutTime+=1.0E-12;}
+  if(overlapMode==OVL_USE_SECOND) {cutTime=xmin2; if(xmax1==xmin2) cutTime-=1.0E-12;}
   if(verbose>4 && isOverlap && (overlapMode==OVL_USE_FIRST || overlapMode==OVL_USE_SECOND))
     printf("cutTime := %g\n", cutTime);
 
