@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_taccalc
-#: Date       : 2023-04-18
+#: Date       : 2023-06-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -11,6 +11,10 @@ else
 EXT=;
 fi
 PROGRAM=../../taccalc$EXT;
+if [ ! -f $PROGRAM ]; then
+  printf "Failed: executable does not exist.\n"
+  exit 1
+fi
 
 printf "=====================================================================\n"
 printf "testing %s\n" $PROGRAM
@@ -226,8 +230,8 @@ printf "\n2.0.1\n"
 
 printf "\n Substract. Same TAC nr, different sample nr \n\n"
 
-rm -f output.dft stdout.txt
-$PROGRAM calc1.dft - calc2.dft output.dft &> stdout.txt
+rm -f output.dft
+$PROGRAM calc1.dft - calc2.dft output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "ok\n"
 tacmatch -abs=0.01 -rel=0.5 calc2a.dft output.dft
@@ -433,16 +437,16 @@ printf "\n One of files has unknown time units \n\n"
 
 printf "\n Error will be printed \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM calc1_u.tac - calc2_s.tac output.tac &> stdout.txt
+rm -f output.tac
+$PROGRAM calc1_u.tac - calc2_s.tac output.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "ok\n"
 iftisval stdout.txt Error "incompatible units."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM calc1_s.tac - calc2_u.tac output.tac &> stdout.txt
+rm -f output.tac
+$PROGRAM calc1_s.tac - calc2_u.tac output.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "ok\n"
 iftisval stdout.txt Error "incompatible units."
@@ -451,16 +455,16 @@ printf "\n passed. \n\n"
 
 printf "\n With option --force ok \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM -f calc1_u.tac - calc2_s.tac output.tac &> stdout.txt
+rm -f output.tac
+$PROGRAM -f calc1_u.tac - calc2_s.tac output.tac 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "ok\n"
 tacmatch -yunit=y -x=y -y=y -abs=0.01 -rel=0.5 calc2a_s.tac output.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM -f calc1_s.tac - calc2_u.tac output.tac &> stdout.txt
+rm -f output.tac
+$PROGRAM -f calc1_s.tac - calc2_u.tac output.tac 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "ok\n"
 tacmatch -xunit=y -yunit=y -x=y -y=y -abs=0.01 -rel=0.5 calc2a_s.tac output.tac
@@ -513,16 +517,16 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 
 printf "\n Unknown conc units \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM calc1_s.tac - calc2_su.tac output.tac &> stdout.txt
+rm -f output.tac
+$PROGRAM calc1_s.tac - calc2_su.tac output.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "ok\n"
 iftisval stdout.txt Error "incompatible units."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM calc1_su.tac - calc2_s.tac output.tac &> stdout.txt
+rm -f output.tac
+$PROGRAM calc1_su.tac - calc2_s.tac output.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "ok\n"
 iftisval stdout.txt Error "incompatible units."
@@ -534,16 +538,16 @@ printf "\n5.1.1\n"
 
 printf "\n With option --force ok \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM --force calc1_s.tac - calc2_su.tac output.tac &> stdout.txt
+rm -f output.tac
+$PROGRAM --force calc1_s.tac - calc2_su.tac output.tac 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "ok\n"
 tacmatch -xunit=y -yunit=y -x=y -y=y -abs=0.01 -rel=0.5 calc2a_s.tac output.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM --force calc1_su.tac - calc2_s.tac output.tac &> stdout.txt
+rm -f output.tac
+$PROGRAM --force calc1_su.tac - calc2_s.tac output.tac 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "ok\n"
 tacmatch -x=y -y=y -abs=0.01 -rel=0.5 calc2a_s.tac output.tac
@@ -585,8 +589,7 @@ printf "\n passed. \n\n"
 printf "\n6.0.2\n"
 
 printf "\n ... division should have changed conc units to unitless \n\n"
-rm -f stdout.txt
-tacunit output.dft &> stdout.txt
+tacunit output.dft 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "ok\n"
 iftisval stdout.txt timeunit min
