@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_taccat
-#: Date       : 2022-03-15
+#: Date       : 2024-06-18
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -241,6 +241,81 @@ printf "# isotope := C-11\n" >> correct_output2c.dat
 fi
 
 
+if [ ! -f test3a.dat ] || [ ! -f test3b.dat ]; then
+printf "0.0 0\n" >  test3a.dat
+printf "0.1 0\n" >> test3a.dat
+printf "0.2 8\n" >> test3a.dat
+printf "0.3 9\n" >> test3a.dat
+printf "0.4 8\n" >> test3a.dat
+printf "0.5 6\n" >> test3a.dat
+printf "0.6 4\n" >> test3a.dat
+printf "0.7 3\n" >> test3a.dat
+printf "0.8 3\n" >> test3a.dat
+printf "0.9 2\n" >> test3a.dat
+printf "1.0 2\n" >> test3a.dat
+
+printf "1.0 1\n" >  test3b.dat
+printf "2.0 1\n" >> test3b.dat
+printf "3.0 0\n" >> test3b.dat
+printf "4.0 0\n" >> test3b.dat
+printf "5.0 0\n" >> test3b.dat
+fi
+
+if [ ! -f correct_output3a.dat ]; then
+printf "0.0 0\n" >  correct_output3a.dat
+printf "0.1 0\n" >> correct_output3a.dat
+printf "0.2 8\n" >> correct_output3a.dat
+printf "0.3 9\n" >> correct_output3a.dat
+printf "0.4 8\n" >> correct_output3a.dat
+printf "0.5 6\n" >> correct_output3a.dat
+printf "0.6 4\n" >> correct_output3a.dat
+printf "0.7 3\n" >> correct_output3a.dat
+printf "0.8 3\n" >> correct_output3a.dat
+printf "0.9 2\n" >> correct_output3a.dat
+printf "1.0 2\n" >> correct_output3a.dat
+printf "2.0 1\n" >> correct_output3a.dat
+printf "3.0 0\n" >> correct_output3a.dat
+printf "4.0 0\n" >> correct_output3a.dat
+printf "5.0 0\n" >> correct_output3a.dat
+fi
+
+if [ ! -f correct_output3b.dat ]; then
+printf "0.0 0\n" >  correct_output3b.dat
+printf "0.1 0\n" >> correct_output3b.dat
+printf "0.2 8\n" >> correct_output3b.dat
+printf "0.3 9\n" >> correct_output3b.dat
+printf "0.4 8\n" >> correct_output3b.dat
+printf "0.5 6\n" >> correct_output3b.dat
+printf "0.6 4\n" >> correct_output3b.dat
+printf "0.7 3\n" >> correct_output3b.dat
+printf "0.8 3\n" >> correct_output3b.dat
+printf "0.9 2\n" >> correct_output3b.dat
+printf "1.0 1\n" >> correct_output3b.dat
+printf "2.0 1\n" >> correct_output3b.dat
+printf "3.0 0\n" >> correct_output3b.dat
+printf "4.0 0\n" >> correct_output3b.dat
+printf "5.0 0\n" >> correct_output3b.dat
+fi
+
+if [ ! -f correct_output3c.dat ]; then
+printf "0.0 0\n" >  correct_output3c.dat
+printf "0.1 0\n" >> correct_output3c.dat
+printf "0.2 8\n" >> correct_output3c.dat
+printf "0.3 9\n" >> correct_output3c.dat
+printf "0.4 8\n" >> correct_output3c.dat
+printf "0.5 6\n" >> correct_output3c.dat
+printf "0.6 4\n" >> correct_output3c.dat
+printf "0.7 3\n" >> correct_output3c.dat
+printf "0.8 3\n" >> correct_output3c.dat
+printf "0.9 2\n" >> correct_output3c.dat
+printf "1.0 2\n" >> correct_output3c.dat
+printf "1.0 1\n" >> correct_output3c.dat
+printf "2.0 1\n" >> correct_output3c.dat
+printf "3.0 0\n" >> correct_output3c.dat
+printf "4.0 0\n" >> correct_output3c.dat
+printf "5.0 0\n" >> correct_output3c.dat
+fi
+
 
 printf "\n\n"
 printf "=====================================================================\n"
@@ -342,11 +417,11 @@ printf " Test case 2: Option -BOTH. \n"
 printf " Expected result: Warning of overlap. \n"
 printf " Expected result 2: Correctly catenated data is written in new file. \n\n"
 
-rm -f output.tac stdout.txt
+rm -f output.tac
 tactime test1a.tac +2 temp1a.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
-$PROGRAM -BOTH temp1a.tac test1b.tac output.tac &> stdout.txt 
+$PROGRAM -BOTH temp1a.tac test1b.tac output.tac 1>stdout.txt 2>&1 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "overlap in sample times is ignored."
@@ -361,8 +436,8 @@ printf "\n 1.2.1 \n"
 printf " Test case: Same as before but without option -BOTH. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM temp1a.tac test1b.tac output.tac &> stdout.txt 
+rm -f output.tac
+$PROGRAM temp1a.tac test1b.tac output.tac 1>stdout.txt 2>&1 
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "overlapping sample times."
@@ -375,8 +450,8 @@ printf " Test case: Same as before but with option -FIRST. \n"
 printf " Expected result: Warning of overlap. \n"
 printf " Expected result 2: Correctly catenated data is written in new file. \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM -FIRST temp1a.tac test1b.tac output.tac &> stdout.txt 
+rm -f output.tac
+$PROGRAM -FIRST temp1a.tac test1b.tac output.tac 1>stdout.txt 2>&1 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "overlap in sample times will be removed."
@@ -392,8 +467,8 @@ printf " Test case: Same as before but with option -SECOND. \n"
 printf " Expected result: Warning of overlap. \n"
 printf " Expected result 2: Correctly catenated data is written in new file. \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM -SECOND temp1a.tac test1b.tac output.tac &> stdout.txt 
+rm -f output.tac
+$PROGRAM -SECOND temp1a.tac test1b.tac output.tac 1>stdout.txt 2>&1 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "overlap in sample times will be removed."
@@ -409,8 +484,8 @@ printf " Test case: Same as before but with option -CUT at end of first data. \n
 printf " Expected result: Warning of overlap. \n"
 printf " Expected result 2: Correctly catenated data is written in new file. \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM -CUT=12 temp1a.tac test1b.tac output.tac &> stdout.txt 
+rm -f output.tac
+$PROGRAM -CUT=12 temp1a.tac test1b.tac output.tac 1>stdout.txt 2>&1 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "overlap in sample times will be removed."
@@ -426,8 +501,8 @@ printf " Test case: Same as before but with option -CUT at start of second data.
 printf " Expected result: Warning of overlap. \n"
 printf " Expected result 2: Correctly catenated data is written in new file. \n\n"
 
-rm -f output.tac stdout.txt
-$PROGRAM -CUT=10 temp1a.tac test1b.tac output.tac &> stdout.txt 
+rm -f output.tac
+$PROGRAM -CUT=10 temp1a.tac test1b.tac output.tac 1>stdout.txt 2>&1 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "overlap in sample times will be removed."
@@ -450,7 +525,7 @@ tacunit -xconv=min -yconv=kBq/cc temp1b.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM test1a.tac temp1b.tac output.tac &> stdout.txt
+$PROGRAM test1a.tac temp1b.tac output.tac 1>stdout.txt 2>&1
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 tacmatch -abs=0.1 -rel=1 correct_output1.tac output.tac
@@ -467,8 +542,8 @@ printf " Test case: Overlapping TAC data in simple text format, units missing fr
 printf " Test case 2: No options. \n"
 printf " Expected result: Error about overlap or missing units. \n\n"
 
-rm -f output.dat stdout.txt
-$PROGRAM test2a.dat test2b.dat output.dat  &> stdout.txt
+rm -f output.dat
+$PROGRAM test2a.dat test2b.dat output.dat  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error
@@ -486,8 +561,8 @@ printf " Test case: Overlapping TAC data in simple text format, units missing fr
 printf " Test case 2: Option -force. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f output.dat stdout.txt
-$PROGRAM -force test2a.dat test2b.dat output.dat  &> stdout.txt
+rm -f output.dat
+$PROGRAM -force test2a.dat test2b.dat output.dat  1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "overlapping sample times."
@@ -501,8 +576,8 @@ printf " Test case 2: Option -both. \n"
 printf " Expected result: Warning on missing units. \n"
 printf " Expected result 2: Error on non-compatible units. \n\n"
 
-rm -f output.dat stdout.txt
-$PROGRAM -both test2a.dat test2b.dat output.dat &> stdout.txt 
+rm -f output.dat
+$PROGRAM -both test2a.dat test2b.dat output.dat 1>stdout.txt 2>&1 
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "unknown time units."
@@ -525,8 +600,8 @@ printf " Expected result: Warning of overlap. \n"
 printf " Expected result 2: Correctly catenated data is written in new file. \n"
 printf " Expected result 3: Important comments from both files retained. \n\n"
 
-rm -f output.dat stdout.txt
-$PROGRAM -both -force test2a.dat test2b.dat output.dat &> stdout.txt 
+rm -f output.dat
+$PROGRAM -both -force test2a.dat test2b.dat output.dat 1>stdout.txt 2>&1 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "overlap in sample times is ignored."
@@ -555,8 +630,8 @@ printf " Test case 2: Option -first and -force. \n"
 printf " Expected result: Warning of overlap. \n"
 printf " Expected result 2: Correctly catenated data is written in new file. \n\n"
 
-rm -f output.dat stdout.txt
-$PROGRAM -first -force test2a.dat test2b.dat output.dat &> stdout.txt 
+rm -f output.dat
+$PROGRAM -first -force test2a.dat test2b.dat output.dat 1>stdout.txt 2>&1 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "overlap in sample times will be removed."
@@ -573,8 +648,8 @@ printf " Test case 2: Option -second and -force. \n"
 printf " Expected result: Warning of overlap. \n"
 printf " Expected result 2: Correctly catenated data is written in new file. \n\n"
 
-rm -f output.dat stdout.txt
-$PROGRAM -second -force test2a.dat test2b.dat output.dat &> stdout.txt 
+rm -f output.dat
+$PROGRAM -second -force test2a.dat test2b.dat output.dat 1>stdout.txt 2>&1 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "overlap in sample times will be removed."
@@ -592,8 +667,8 @@ printf " Test case 2: Option -cut setting time to end of first data. \n"
 printf " Expected result: Warning of overlap. \n"
 printf " Expected result 2: Correctly catenated data is written in new file. \n\n"
 
-rm -f output.dat stdout.txt
-$PROGRAM -cut=24 -force test2a.dat test2b.dat output.dat &> stdout.txt 
+rm -f output.dat
+$PROGRAM -cut=24 -force test2a.dat test2b.dat output.dat 1>stdout.txt 2>&1 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "overlap in sample times will be removed."
@@ -610,8 +685,8 @@ printf " Test case 2: Option -cut setting time to start of second data. \n"
 printf " Expected result: Warning of overlap. \n"
 printf " Expected result 2: Correctly catenated data is written in new file. \n\n"
 
-rm -f output.dat stdout.txt
-$PROGRAM -cut=20.8 -force test2a.dat test2b.dat output.dat &> stdout.txt 
+rm -f output.dat
+$PROGRAM -cut=20.8 -force test2a.dat test2b.dat output.dat 1>stdout.txt 2>&1 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "overlap in sample times will be removed."
@@ -630,9 +705,9 @@ printf " Expected result: Warning of overlap. \n"
 printf " Expected result 2: Correctly catenated data is written in new file. \n\n"
 
 printf "cuttime\nx := 5.5\n" > cuttime.ift
-rm -f output.tac stdout.txt
+rm -f output.tac
 
-$PROGRAM -cut=cuttime.ift -force test2a.dat test2b.dat output.dat &> stdout.txt 
+$PROGRAM -cut=cuttime.ift -force test2a.dat test2b.dat output.dat 1>stdout.txt 2>&1 
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Warning "overlap in sample times will be removed."
@@ -643,6 +718,43 @@ if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
 
+printf "\n 2.4.0 \n"
+printf " Test case: Just one sample overlapping in simple text format. \n"
+printf " Test case 2: Options -first, -second, and -both. \n"
+printf " Expected result: Correctly catenated data is written in new file. \n\n"
+
+$PROGRAM test3a.dat test3b.dat output.dat 1>stdout.txt 2>&1 
+if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+iftisval stdout.txt Error "overlapping sample times."
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+printf "Option -first\n"
+$PROGRAM -first test3a.dat test3b.dat output.dat 1>stdout.txt 2>&1 
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+tacmatch -xunit=n -yunit=n correct_output3a.dat output.dat
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+printf "Option -second\n"
+$PROGRAM -second test3a.dat test3b.dat output.dat 1>stdout.txt 2>&1 
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+tacmatch -xunit=n -yunit=n correct_output3b.dat output.dat
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+printf "Option -both\n"
+$PROGRAM -both test3a.dat test3b.dat output.dat 1>stdout.txt 2>&1 
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+tacmatch -xunit=n -yunit=n correct_output3c.dat output.dat
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+
 
 printf "=====================================================================\n"
 printf "  More error handling\n"
@@ -653,9 +765,7 @@ printf "\n 3.0.0 \n"
 printf " Test case: Extra argument. \n"
 printf " Expected result: Appropriate error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM test1a.tac test1b.tac output.tac extra &> stdout.txt
+$PROGRAM test1a.tac test1b.tac output.tac extra 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "invalid argument 'extra'."
@@ -667,9 +777,7 @@ printf "\n 3.0.1 \n"
 printf " Test case: Missing argument. \n"
 printf " Expected result: Error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM test1a.tac &> stdout.txt
+$PROGRAM test1a.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
@@ -678,16 +786,14 @@ printf "\n 3.1.0 \n"
 printf " Test case: File does not exist. \n"
 printf " Expected result: Appropriate error. \n\n"
 
-rm -f stdout.txt
-
-$PROGRAM nonexisting.tac test1b.tac output.tac &> stdout.txt
+$PROGRAM nonexisting.tac test1b.tac output.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot open file"
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-$PROGRAM test1a.tac nonexisting.tac output.tac &> stdout.txt
+$PROGRAM test1a.tac nonexisting.tac output.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot open file"
@@ -700,7 +806,7 @@ tacadd -ovr temp1a.tac test1a.tac
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-$PROGRAM temp1a.tac nonexisting.tac &> stdout.txt
+$PROGRAM temp1a.tac nonexisting.tac 1>stdout.txt 2>&1
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "cannot open file"
@@ -730,18 +836,18 @@ tacdel temp1b.tac cer
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f output.tac stdout.txt
+rm -f output.tac
 
-$PROGRAM temp1a.tac test1b.tac output.tac &> stdout.txt 
+$PROGRAM temp1a.tac test1b.tac output.tac 1>stdout.txt 2>&1 
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "different number of TACs."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.tac stdout.txt
+rm -f output.tac
 
-$PROGRAM test1a.tac temp1b.tac output.tac &> stdout.txt 
+$PROGRAM test1a.tac temp1b.tac output.tac 1>stdout.txt 2>&1 
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "different number of TACs."
@@ -767,18 +873,18 @@ tacren temp1b.tac cer Else
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 
-rm -f output.tac stdout.txt
+rm -f output.tac
 
-$PROGRAM temp1a.tac test1b.tac output.tac &> stdout.txt 
+$PROGRAM temp1a.tac test1b.tac output.tac 1>stdout.txt 2>&1 
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "TAC names do not match."
 if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n passed. \n\n"
 
-rm -f output.tac stdout.txt
+rm -f output.tac
 
-$PROGRAM test1a.tac temp1b.tac output.tac &> stdout.txt 
+$PROGRAM test1a.tac temp1b.tac output.tac 1>stdout.txt 2>&1 
 if [ $? -eq 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 printf "\n ok \n"
 iftisval stdout.txt Error "TAC names do not match."
